@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -57,7 +57,21 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 		$variable_function_map = array(
 										'year' => 'isNumeric',
 										'ein' => array( 'stripNonNumeric', 'isNumeric'),
-						  );
+										'l1' => array( 'stripNonNumeric', 'isNumeric'),
+										'l2' => array( 'stripNonFloat', 'isNumeric'),
+										'l3' => array( 'stripNonFloat', 'isNumeric'),
+										'l5a' => array( 'stripNonFloat', 'isNumeric'),
+										'l5b' => array( 'stripNonFloat', 'isNumeric'),
+										'l5c' => array( 'stripNonFloat', 'isNumeric'),
+										'l7a' => array( 'stripNonFloat', 'isNumeric'),
+										'l7b' => array( 'stripNonFloat', 'isNumeric'),
+										'l7c' => array( 'stripNonFloat', 'isNumeric'),
+										'l9' => array( 'stripNonFloat', 'isNumeric'),
+										'l11' => array( 'stripNonFloat', 'isNumeric'),
+										'l17_month_1' => array( 'stripNonFloat', 'isNumeric'),
+										'l17_month_2' => array( 'stripNonFloat', 'isNumeric'),
+										'l17_month_3' => array( 'stripNonFloat', 'isNumeric'),
+										);
 
 		if ( isset($variable_function_map[$name]) ) {
 			return $variable_function_map[$name];
@@ -211,6 +225,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								'name' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'coordinates' => array(
 																		'x' => 134,
 																		'y' => 125,
@@ -221,6 +237,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								'trade_name' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'coordinates' => array(
 																		'x' => 113,
 																		'y' => 149,
@@ -231,6 +249,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								'address' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'coordinates' => array(
 																		'x' => 78,
 																		'y' => 172,
@@ -241,6 +261,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								'city' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'coordinates' => array(
 																		'x' => 78,
 																		'y' => 198,
@@ -250,6 +272,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																		),
 											),
 								'state' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'coordinates' => array(
 																		'x' => 268,
 																		'y' => 198,
@@ -259,6 +283,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																		),
 											),
 								'zip_code' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'coordinates' => array(
 																		'x' => 310,
 																		'y' => 198,
@@ -270,6 +296,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 
 
 								'quarter' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawCheckBox',
 												'coordinates' => array(
 																		1 => array(
@@ -307,6 +335,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								'l1' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'coordinates' => array(
 																		'x' => 431,
 																		'y' => 257,
@@ -317,6 +347,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								'l2' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -336,6 +368,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l3' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -355,6 +389,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l4' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawCheckbox',
 												'coordinates' => array(
 																	array(
@@ -370,6 +406,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																		'type' => 'B' )
 											),
 								'l5a' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -389,6 +427,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l5b' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -408,6 +448,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l5c' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -427,6 +469,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l5a2' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL5A2', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -446,6 +490,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l5b2' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL5B2', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -465,6 +511,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l5c2' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL5C2', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -484,6 +532,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l5d' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL5D', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -503,6 +553,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l6' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL6', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -522,6 +574,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l7a' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL7A', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -541,6 +595,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l7b' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -560,6 +616,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l7c' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -579,6 +637,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l7d' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL7D', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -598,6 +658,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l8' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL8', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -617,6 +679,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l9' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -636,6 +700,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l10' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL10', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -655,6 +721,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l11' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -674,6 +742,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l12a' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -693,6 +763,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l12b' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'coordinates' => array(
 																	'x' => 254,
 																	'y' => 655,
@@ -703,6 +775,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								'l13' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL13', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -722,6 +796,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l14' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL14', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -741,6 +817,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l15' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('calcL15', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -760,6 +838,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l15a' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('filterL15A', 'drawCheckbox'),
 												'coordinates' => array(
 																	array(
@@ -775,6 +855,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																		'type' => 'B' )
 											),
 								'l15b' => array(
+												'page' => 1,
+												'template_page' => 1,
 												'function' => array('filterL15B', 'drawCheckbox'),
 												'coordinates' => array(
 																	array(
@@ -830,6 +912,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 								//Finish initialize Page 2
 
 								'l16' => array(
+												'page' => 2,
+												'template_page' => 2,
 												'function' => 'drawChars',
 												'coordinates' => array(
 																		array(
@@ -849,6 +933,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	  ),
 											),
 								'l17_month1' => array(
+												'page' => 2,
+												'template_page' => 2,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -868,6 +954,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l17_month2' => array(
+												'page' => 2,
+												'template_page' => 2,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -887,6 +975,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l17_month3' => array(
+												'page' => 2,
+												'template_page' => 2,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
@@ -906,6 +996,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																	),
 											),
 								'l17_month_total' => array(
+												'page' => 2,
+												'template_page' => 2,
 												'function' => array('calcL17MonthTotal', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -926,6 +1018,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 								//Put this after Month1,Month2,Month3 are set, as we can automatically determine it for the most part.
 								'l17' => array(
+												'page' => 2,
+												'template_page' => 2,
 												'function' => array( 'filterL17', 'drawCheckbox'),
 												'coordinates' => array(
 																	'a' => array(
@@ -1001,6 +1095,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								array(
+												'page' => 3,
+												'template_page' => 3,
 												'function' => array( 'calcL14', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
@@ -1023,6 +1119,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 											),
 
 								array(
+												'page' => 3,
+												'template_page' => 3,
 												'value' => $this->trade_name,
 												'coordinates' => array(
 																		'x' => 219,
@@ -1035,6 +1133,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																		'size' => 10 )
 											),
 								array(
+												'page' => 3,
+												'template_page' => 3,
 												'value' => $this->address,
 												'coordinates' => array(
 																		'x' => 219,
@@ -1047,6 +1147,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																		'size' => 10 )
 											),
 								array(
+												'page' => 3,
+												'template_page' => 3,
 												'value' => $this->city . ', ' . $this->state . ', ' . $this->zip_code,
 												'coordinates' => array(
 																		'x' => 219,
@@ -1059,6 +1161,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																		'size' => 10 )
 											),
 								array(
+												'page' => 3,
+												'template_page' => 3,
 												'function' => array('drawPage3Quarter', 'drawCheckBox'),
 												'coordinates' => array(
 																		1 => array(
@@ -1142,7 +1246,7 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 		$this->Draw( substr( $value, 2, 7 ), $this->getSchemaSpecificCoordinates( $schema, 1 ) );
 		return TRUE;
 	}
-	
+
 	function calcL5A2( $value, $schema ) {
 		$this->l5a2 = $this->l5a * $this->social_security_rate;
 		return $this->l5a2;
