@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: BranchFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 4073 $
+ * $Id: BranchFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -577,6 +577,7 @@ class BranchFactory extends Factory {
 			$udtf = new UserDateTotalFactory();
 			$uf = new UserFactory();
 			$sf = new StationFactory();
+			$sbf = new StationBranchFactory();
 			$sf_b = new ScheduleFactory();
 			$udf = new UserDefaultFactory();
 			$rstf = new RecurringScheduleTemplateFactory();
@@ -599,8 +600,22 @@ class BranchFactory extends Factory {
 			$query = 'update '. $sf->getTable() .' set branch_id = 0 where company_id = '. $this->getCompany() .' AND branch_id = '. $this->getId();
 			$this->db->Execute($query);
 
+			$query = 'delete from '. $sbf->getTable() .' where branch_id = '. $this->getId();
+			$this->db->Execute($query);
+
 			$query = 'update '. $rstf->getTable() .' set branch_id = 0 where branch_id = '. $this->getId();
 			$this->db->Execute($query);
+
+			//Job employee criteria
+			$cgmlf = new CompanyGenericMapListFactory();
+			$cgmlf->getByCompanyIDAndObjectTypeAndMapID( $this->getCompany(), 1010, $this->getID() );
+			if ( $cgmlf->getRecordCount() > 0 ) {
+				foreach( $cgmlf as $cgm_obj ) {
+					Debug::text('Deleteing from Company Generic Map: '. $cgm_obj->getID(), __FILE__, __LINE__, __METHOD__, 10);
+					$cgm_obj->Delete();
+				}
+			}
+
 		}
 
 		return TRUE;
@@ -661,7 +676,7 @@ class BranchFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Branch'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Branch'), NULL, $this->getTable(), $this );
 	}
 
 }
