@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3628 $
- * $Id: CompanyFactory.class.php 3628 2010-05-28 00:36:37Z ipso $
- * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
+ * $Revision: 3939 $
+ * $Id: CompanyFactory.class.php 3939 2010-11-19 22:41:24Z ipso $
+ * $Date: 2010-11-19 14:41:24 -0800 (Fri, 19 Nov 2010) $
  */
 
 /**
@@ -1053,6 +1053,7 @@ class CompanyFactory extends Factory {
 			case 'columns':
 				$retval = array(
 										'-1010-status' => TTi18n::gettext('Status'),
+										'-1020-product_edition' => TTi18n::gettext('Product Edition'),
 										'-1030-name' => TTi18n::gettext('Name'),
 										'-1040-short_name' => TTi18n::gettext('Short Name'),
 										'-1050-business_number' => TTi18n::gettext('Business Number'),
@@ -1101,7 +1102,9 @@ class CompanyFactory extends Factory {
 											'id' => 'ID',
 											'parent_id' => 'Parent',
 											'status_id' => 'Status',
+											'status' => FALSE,
 											'product_edition_id' => 'ProductEdition',
+											'product_edition' => FALSE,
 											'name' => 'Name',
 											'business_number' => 'BusinessNumber',
 											'originator_id' => 'OriginatorID',
@@ -1719,6 +1722,19 @@ class CompanyFactory extends Factory {
 		return TRUE;
 	}
 
+	function getEnableAddUserDefaultPreset() {
+		if ( isset($this->add_user_default_preset) ) {
+			return $this->add_user_default_preset;
+		}
+
+		return FALSE;
+	}
+	function setEnableAddUserDefaultPreset($bool) {
+		$this->add_user_default_preset = $bool;
+
+		return TRUE;
+	}
+
 	function getEnableSecondLastName(){
 		if ( isset($this->data['enable_second_last_name']) ) {
 			return $this->data['enable_second_last_name'];
@@ -2096,7 +2112,7 @@ class CompanyFactory extends Factory {
 					$cf->setDefault( TRUE );
 
 					if ( $cf->isValid() ) {
-						$cf->Save();
+						$currency_id = $cf->Save();
 					}
 				}
 			}
@@ -2118,18 +2134,26 @@ class CompanyFactory extends Factory {
 				}
 
 				$preset_options = $pf->getOptions('preset');
+				$preset_level_options = $pf->getOptions('preset_level');
+				$i=0;
 				foreach( $preset_options as $preset_id => $preset_name ) {
 					$pcf = new PermissionControlFactory();
 					$pcf->setCompany( $this->getId() );
 					$pcf->setName( $preset_name );
 					$pcf->setDescription( '' );
+					$pcf->setLevel( $preset_level_options[$preset_id] );
 					if ( $pcf->isValid() ) {
 						$pcf_id = $pcf->Save(FALSE);
 
+						if ( $i == 0 ) { //Regular employee
+							$regular_employee_pcf_id = $pcf_id;
+						}
+
 						$pf->applyPreset($pcf_id, $preset_id, $preset_flags );
 					}
+
+					$i++;
 				}
-				//$pf->FailTransaction();
 				$pf->CommitTransaction();
 			}
 
@@ -2160,7 +2184,6 @@ class CompanyFactory extends Factory {
 				PayStubEntryAccountFactory::addPresets( $this->getId() );
 			}
 
-
 			if ( $this->getEnableAddCompanyDeductionPreset() == TRUE ) {
 				Debug::text('Adding Company Deduction Presets', __FILE__, __LINE__, __METHOD__,9);
 				CompanyDeductionFactory::addPresets( $this->getId() );
@@ -2170,6 +2193,52 @@ class CompanyFactory extends Factory {
 				Debug::text('Adding Recurring Holiday Presets', __FILE__, __LINE__, __METHOD__,9);
 				RecurringHolidayFactory::addPresets( $this->getId(), $this->getCountry() );
 			}
+
+			if ( $this->getEnableAddUserDefaultPreset() == TRUE ) {
+				//User Default settings, always do this last.
+				$udf = new UserDefaultFactory();
+				$udf->setCompany( $this->getID() );
+				$udf->setCity( $this->getCity() );
+				$udf->setCountry( $this->getCountry() );
+				$udf->setProvince( $this->getProvince() );
+				$udf->setWorkPhone( $this->getWorkPhone() );
+
+				$udf->setLanguage( 'en' );
+				$udf->setDateFormat( 'd-M-y' );
+				$udf->setTimeFormat( 'g:i A' );
+				$udf->setTimeUnitFormat( 10 );
+				$udf->setItemsPerPage( 25 );
+				$udf->setStartWeekDay( 0 );
+
+				//$udf->setPolicyGroup( $user_data['policy_group_id'] );
+
+				if ( isset($regular_employee_pcf_id) ) {
+					$udf->setPermissionControl( $regular_employee_pcf_id );
+				}
+
+				if ( isset($currency_id) ) {
+					$udf->setCurrency( $currency_id );
+				}
+
+				$uf = new UserPreferenceFactory();
+				$location_time_zones = $uf->getOptions('location_timezone');
+				if ( isset($location_time_zones[$this->getCountry()][$this->getProvince()]) ) {
+					$udf->setTimeZone( $location_time_zones[$this->getCountry()][$this->getProvince()] );
+				} else {
+					$udf->setTimeZone( 'GMT' );
+				}
+				Debug::text('Time Zone: '. $udf->getTimeZone(), __FILE__, __LINE__, __METHOD__,9);
+
+				$udf->setEnableEmailNotificationException( TRUE );
+				$udf->setEnableEmailNotificationMessage( TRUE );
+				$udf->setEnableEmailNotificationHome( TRUE );
+
+				if ( $udf->isValid() ) {
+					Debug::text('Adding User Default settings...', __FILE__, __LINE__, __METHOD__,9);
+
+					$udf->Save();
+				}
+			}
 		}
 
 		if ( $this->getDeleted() == TRUE ) {
@@ -2231,6 +2300,9 @@ class CompanyFactory extends Factory {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
 							}
 							break;
+						case 'product_edition':
+							$data[$variable] = Option::getByKey( $this->getProductEdition(), $this->getOptions( $variable ) );
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
@@ -2247,7 +2319,7 @@ class CompanyFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Company Information'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Company Information'), NULL, $this->getTable(), $this );
 	}
 
 }
