@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3628 $
- * $Id: CompanyListFactory.class.php 3628 2010-05-28 00:36:37Z ipso $
- * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
+ * $Revision: 3725 $
+ * $Id: CompanyListFactory.class.php 3725 2010-07-28 21:16:05Z ipso $
+ * $Date: 2010-07-28 14:16:05 -0700 (Wed, 28 Jul 2010) $
  */
 
 /**
@@ -208,6 +208,7 @@ class CompanyListFactory extends CompanyFactory implements IteratorAggregate {
 
 		$sort_column_aliases = array(
 									 'status' => 'status_id',
+									 'product_edition' => 'product_edition_id',
 									 );
 
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
@@ -261,10 +262,18 @@ class CompanyListFactory extends CompanyFactory implements IteratorAggregate {
 		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
 			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
 		}
+		if ( isset($filter_data['product_edition_id']) AND isset($filter_data['product_edition_id'][0]) AND !in_array(-1, (array)$filter_data['product_edition_id']) ) {
+			$query  .=	' AND a.product_edition_id in ('. $this->getListSQL($filter_data['product_edition_id'], $ph) .') ';
+		}
+
 		if ( isset($filter_data['name']) AND trim($filter_data['name']) != '' ) {
 			$ph[] = strtolower(trim($filter_data['name']));
 			$query  .=	' AND lower(a.name) LIKE ?';
 		}
+		if ( isset($filter_data['short_name']) AND trim($filter_data['short_name']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['short_name']));
+			$query  .=	' AND lower(a.short_name) LIKE ?';
+		}
 		if ( isset($filter_data['country']) AND isset($filter_data['country'][0]) AND !in_array(-1, (array)$filter_data['country']) ) {
 			$query  .=	' AND a.country in ('. $this->getListSQL($filter_data['country'], $ph) .') ';
 		}
@@ -299,6 +308,10 @@ class CompanyListFactory extends CompanyFactory implements IteratorAggregate {
 			$ph[] = strtolower(trim($filter_data['city']));
 			$query  .=	' AND lower(a.city) LIKE ?';
 		}
+		if ( isset($filter_data['business_number']) AND trim($filter_data['business_number']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['business_number']));
+			$query  .=	' AND lower(a.business_number) LIKE ?';
+		}
 		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
 		}
