@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: Authentication.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3781 $
+ * $Id: Authentication.class.php 3781 2010-08-16 19:44:05Z ipso $
+ * $Date: 2010-08-16 12:44:05 -0700 (Mon, 16 Aug 2010) $
  */
 
 
@@ -474,7 +474,8 @@ class Authentication {
 
 	function Login($user_name, $password, $type = 'USER_NAME') {
 		//DO NOT lowercase username, because iButton values are case sensitive.
-		$user_name = trim($user_name);
+		$user_name = html_entity_decode( trim($user_name) );
+		$password = html_entity_decode( $password );
 
 		//Checks user_name/password
         if ( $user_name == '' OR $password == '' ) {
@@ -524,7 +525,7 @@ class Authentication {
 			//Write data to db.
 			$this->Write();
 
-			TTLog::addEntry( $this->getObject()->getID(), 'Login',  TTi18n::getText('SourceIP').': '. $this->getIPAddress() .' '. TTi18n::getText('Type').': '. $type .' '.  TTi18n::getText('SessionID') .': '.$this->getSessionID() .' '.  TTi18n::getText('UserID').': '. $this->getObject()->getId(), $this->getObject()->getID() , 'authentication');
+			TTLog::addEntry( $this->getObject()->getID(), 100,  TTi18n::getText('SourceIP').': '. $this->getIPAddress() .' '. TTi18n::getText('Type').': '. $type .' '.  TTi18n::getText('SessionID') .': '.$this->getSessionID() .' '.  TTi18n::getText('UserID').': '. $this->getObject()->getId(), $this->getObject()->getID() , 'authentication'); //Login
 
 			return TRUE;
 		}
@@ -538,7 +539,7 @@ class Authentication {
 		$this->destroyCookie();
 		$this->Delete();
 
-		TTLog::addEntry( $this->getObject()->getID(), 'Logout',  TTi18n::getText('SourceIP').': '. $this->getIPAddress() .' '.  TTi18n::getText('SessionID').': '.$this->getSessionID() .' '.  TTi18n::getText('UserID').': '. $this->getObject()->getId(), $this->getObject()->getID() , 'authentication');
+		TTLog::addEntry( $this->getObject()->getID(), 110,  TTi18n::getText('SourceIP').': '. $this->getIPAddress() .' '.  TTi18n::getText('SessionID').': '.$this->getSessionID() .' '.  TTi18n::getText('UserID').': '. $this->getObject()->getId(), $this->getObject()->getID() , 'authentication');
 
 		BreadCrumb::Delete();
 
@@ -551,9 +552,24 @@ class Authentication {
 
 		//Debug::text('Session Name: '. $this->getName(), __FILE__, __LINE__, __METHOD__, 10);
 
+		//Support session_ids passed by cookie, post, and get.
+		if ( $session_id == '' ) {
+			if ( isset($_COOKIE[$this->getName()]) AND $_COOKIE[$this->getName()] != '' ) {
+				$session_id = $_COOKIE[$this->getName()];
+			} elseif ( isset($_POST[$this->getName()]) AND $_POST[$this->getName()] != '' ) {
+				$session_id = $_POST[$this->getName()];
+			} elseif ( isset($_GET[$this->getName()]) AND $_GET[$this->getName()] != '' ) {
+				$session_id = $_GET[$this->getName()];
+			} else {
+				$session_id = FALSE;
+			}
+		}
+
+		/*
 		if ( $session_id == '' AND isset($_COOKIE[$this->getName()]) ) {
 			$session_id = $_COOKIE[$this->getName()];
 		}
+		*/
 
 		Debug::text('Session ID: '. $session_id .' URL: '. $_SERVER['REQUEST_URI'], __FILE__, __LINE__, __METHOD__, 10);
 		//Checks session cookie, returns user_id;
