@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2740 $
- * $Id: CurrencyFactory.class.php 2740 2009-08-19 20:21:50Z ipso $
- * $Date: 2009-08-19 13:21:50 -0700 (Wed, 19 Aug 2009) $
+ * $Revision: 4073 $
+ * $Id: CurrencyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -306,6 +306,7 @@ class CurrencyFactory extends Factory {
 				$retval = array(
 										'-1000-status' => TTi18n::gettext('Status'),
 										'-1010-name' => TTi18n::gettext('Name'),
+										'-1020-symbol' => TTi18n::gettext('Symbol'),
 										'-1020-iso_code' => TTi18n::gettext('ISO Code'),
 										'-1030-conversion_rate' => TTi18n::gettext('Conversion Rate'),
 										'-1040-auto_update' => TTi18n::gettext('Auto Update'),
@@ -355,6 +356,7 @@ class CurrencyFactory extends Factory {
 										'status_id' => 'Status',
 										'status' => FALSE,
 										'name' => 'Name',
+										'symbol' => FALSE,
 										'iso_code' => 'ISOCode',
 										'conversion_rate' => 'ConversionRate',
 										'auto_update' => 'AutoUpdate',
@@ -933,13 +935,15 @@ class CurrencyFactory extends Factory {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
 							}
 							break;
+						case 'symbol':
+							$data[$variable] = $this->getSymbol();
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
 							}
 							break;
 					}
-
 				}
 			}
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
@@ -949,7 +953,7 @@ class CurrencyFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Currency').': '. $this->getISOCode() .' '.  TTi18n::getText('Rate').': '. $this->getConversionRate(), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Currency').': '. $this->getISOCode() .' '.  TTi18n::getText('Rate').': '. $this->getConversionRate(), NULL, $this->getTable(), $this );
 	}
 
 }
