@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: Debug.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3740 $
+ * $Id: Debug.class.php 3740 2010-08-04 20:43:57Z ipso $
+ * $Date: 2010-08-04 13:43:57 -0700 (Wed, 04 Aug 2010) $
  */
 
 /**
@@ -56,19 +56,19 @@ class Debug {
 
 	static $tidy_obj = NULL;
 
-	function setEnable($bool) {
+	static function setEnable($bool) {
 		self::$enable = $bool;
 	}
 
-	function getEnable() {
+	static function getEnable() {
 		return self::$enable;
 	}
 
-	function setBufferOutput($bool) {
+	static function setBufferOutput($bool) {
 		self::$buffer_output = $bool;
 	}
 
-	function setVerbosity($level) {
+	static function setVerbosity($level) {
 		global $db;
 
 		self::$verbosity = $level;
@@ -77,31 +77,31 @@ class Debug {
 			$db->debug=TRUE;
 		}
 	}
-	function getVerbosity() {
+	static function getVerbosity() {
 		return self::$verbosity;
 	}
 
-	function setEnableTidy($bool) {
+	static function setEnableTidy($bool) {
 		self::$enable_tidy = $bool;
 	}
 
-	function getEnableTidy() {
+	static function getEnableTidy() {
 		return self::$enable_tidy;
 	}
 
-	function setEnableDisplay($bool) {
+	static function setEnableDisplay($bool) {
 		self::$enable_display = $bool;
 	}
 
-	function getEnableDisplay() {
+	static function getEnableDisplay() {
 		return self::$enable_display;
 	}
 
-	function setEnableLog($bool) {
+	static function setEnableLog($bool) {
 		self::$enable_log = $bool;
 	}
 
-	function getEnableLog() {
+	static function getEnableLog() {
 		return self::$enable_log;
 	}
 
