@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: Environment.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3725 $
+ * $Id: Environment.class.php 3725 2010-07-28 21:16:05Z ipso $
+ * $Date: 2010-07-28 14:16:05 -0700 (Wed, 28 Jul 2010) $
  */
 
 /**
@@ -60,6 +60,32 @@ class Environment {
 		return $config_vars['path']['base_url']. '/'; //Don't use directory separator here
 	}
 
+	//Returns the BASE_URL for the API functions.
+	static function getAPIBaseURL( $api = NULL ) {
+		global $config_vars;
+
+		//If "interface" appears in the base URL, replace it with API directory
+		$base_url = str_replace( array('/interface','/api'), '', $config_vars['path']['base_url']);
+
+		if ( $api == '' ) {
+			if ( defined('TIMETREX_AMF_API') AND TIMETREX_AMF_API == TRUE ) {
+				$api = 'amf';
+			} elseif ( defined('TIMETREX_SOAP_API') AND TIMETREX_SOAP_API == TRUE )  {
+				$api = 'soap';
+			} elseif ( defined('TIMETREX_JSON_API') AND TIMETREX_JSON_API == TRUE )  {
+				$api = 'json';
+			}
+		}
+
+		$base_url = $base_url.'/api/'.$api.'/';
+
+		return $base_url;
+	}
+
+	static function getAPIURL( $api ) {
+		return self::getAPIBaseURL( $api ).'api.php';
+	}
+
 	static function getTemplateDir() {
 		return self::getBasePath() . self::$template_dir . DIRECTORY_SEPARATOR;
 	}
