@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: Factory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3928 $
+ * $Id: Factory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -44,7 +44,12 @@
  */
 abstract class Factory {
 	public $data = array();
+	public $old_data = array(); //Used for detailed audit log.
+
+	protected $enable_system_log_detail = TRUE;
+
 	protected $next_insert_id = NULL;
+	protected $progress_bar_obj = NULL;
 
 	function __construct() {
 		global $db, $cache;
@@ -54,13 +59,31 @@ abstract class Factory {
 		$this->Validator = new Validator();
 
 		//Callback to the child constructor method.
-		if (method_exists($this,'childConstruct') ) {
+		if ( method_exists($this,'childConstruct') ) {
 			$this->childConstruct();
 		}
 
 		return TRUE;
 	}
 
+	/*
+	 * Used for updating progress bar for API calls.
+	 */
+	function setProgressBarObject( $obj ) {
+		if  ( is_object( $obj ) ) {
+			$this->progress_bar_obj = $obj;
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+	function getProgressBarObject() {
+		if  ( !is_object( $this->progress_bar_obj ) ) {
+			$this->progress_bar_obj = new ProgressBar();
+		}
+
+		return $this->progress_bar_obj;
+	}
 
 	/*
 	 * Cache functions
@@ -227,6 +250,19 @@ abstract class Factory {
 		return true;
 	}
 
+	function getEnableSystemLogDetail() {
+		if ( isset($this->enable_system_log_detail) ) {
+			return $this->enable_system_log_detail;
+		}
+
+		return FALSE;
+	}
+	function setEnableSystemLogDetail($bool) {
+		$this->enable_system_log_detail = (bool)$bool;
+
+		return true;
+	}
+
 	function getDeleted() {
 		if ( isset($this->data['deleted']) ) {
 			return $this->fromBool( $this->data['deleted'] );
@@ -283,7 +319,7 @@ abstract class Factory {
 		return FALSE;
 	}
 	function setCreatedBy($id = NULL) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		if ( empty($id) ) {
 			global $current_user;
@@ -295,8 +331,10 @@ abstract class Factory {
 			}
 		}
 
+		//Its possible that these are incorrect, especially if the user was created by a system or master administrator.
+		//Skip strict checks for now.
+		/*
 		$ulf = new UserListFactory();
-
 		if ( $this->Validator->isResultSetWithRows(	'created_by',
 													$ulf->getByID($id),
 													TTi18n::gettext('Incorrect User')
@@ -308,6 +346,11 @@ abstract class Factory {
 		}
 
 		return FALSE;
+		*/
+
+		$this->data['created_by'] = (int)$id;
+
+		return TRUE;
 	}
 
 	function getUpdatedDate() {
@@ -346,7 +389,7 @@ abstract class Factory {
 		return FALSE;
 	}
 	function setUpdatedBy($id = NULL) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		if ( empty($id) ) {
 			global $current_user;
@@ -358,8 +401,10 @@ abstract class Factory {
 			}
 		}
 
+		//Its possible that these are incorrect, especially if the user was created by a system or master administrator.
+		//Skip strict checks for now.
+		/*
 		$ulf = new UserListFactory();
-
 		if ( $this->Validator->isResultSetWithRows(	'updated_by',
 													$ulf->getByID($id),
 													TTi18n::gettext('Incorrect User')
@@ -371,6 +416,11 @@ abstract class Factory {
 		}
 
 		return FALSE;
+		*/
+
+		$this->data['updated_by'] = $id;
+
+		return $id;
 	}
 
 
@@ -483,15 +533,19 @@ abstract class Factory {
 		return TRUE;
 	}
 
-	function getPermissionColumns( &$data, $object_id, $created_by_id, $permission_children_ids ) {
+	function getPermissionColumns( &$data, $object_id, $created_by_id, $permission_children_ids, $include_columns = NULL ) {
 		$permission = new Permission();
 
-		$data['is_owner'] = $permission->isOwner( $created_by_id, $object_id );
+		if( $include_columns == NULL OR ( isset($include_columns['is_owner']) AND $include_columns['is_owner'] == TRUE) ) {
+			$data['is_owner'] = $permission->isOwner( $created_by_id, $object_id );
+		}
 
-		if ( is_array($permission_children_ids) ) {
-			$data['is_child'] = $permission->isChild( $object_id, $permission_children_ids );
-		} else {
-			$data['is_child'] = FALSE;
+		if ( $include_columns == NULL OR ( isset($include_columns['is_child']) AND $include_columns['is_child'] == TRUE) ) {
+			if ( is_array($permission_children_ids) ) {
+				$data['is_child'] = $permission->isChild( $object_id, $permission_children_ids );
+			} else {
+				$data['is_child'] = FALSE;
+			}
 		}
 
 		return TRUE;
@@ -923,15 +977,20 @@ abstract class Factory {
 		//Classes like station don't have updated_date, so we need to take that in to account.
 		try {
 			$rs = $this->getEmptyRecordSet( $this->getId() );
+			$this->old_data = $rs->fields; //Store old data in memory for detailed audit log.
 			//Debug::arr($rs->fields,'Data Arr Fields', __FILE__, __LINE__, __METHOD__,10);
 		} catch (Exception $e) {
 			throw new DBError($e);
 		}
 		if (!$rs) {
-			Debug::text('No Record Found! Insert instead?' , __FILE__, __LINE__, __METHOD__,9);
+			Debug::text('No Record Found! (ID: '. $this->getID() .' Insert instead?' , __FILE__, __LINE__, __METHOD__,9);
 			//Throw exception?
 		}
 
+		//Debug::Arr($rs->fields, 'RecordSet: ', __FILE__, __LINE__, __METHOD__, 9);
+		//Debug::Arr($this->data, 'Data Array: ', __FILE__, __LINE__, __METHOD__, 9);
+		//Debug::Arr( array_diff_assoc($rs->fields, $this->data), 'Data Array: ', __FILE__, __LINE__, __METHOD__, 9);\
+
 		//If no columns changed, this will be FALSE.
 		$query = $this->db->GetUpdateSQL($rs, $this->data);
 
@@ -1050,7 +1109,6 @@ abstract class Factory {
 			$time = TTDate::getTime();
 
 			if ( $this->getCreatedDate() == '' ) {
-				Debug::text('Current Created Date: '. $this->getCreatedDate() .' Setting new one...' , __FILE__, __LINE__, __METHOD__,10);
 				$this->setCreatedDate($time);
 			}
 			if ( $this->getCreatedBy() == '' ) {
@@ -1081,7 +1139,7 @@ abstract class Factory {
 			}
 
 			$retval = (int)$insert_id;
-			$log_action = 'Add';
+			$log_action = 10; //'Add';
 		} else {
 			Debug::text(' Updating...' , __FILE__, __LINE__, __METHOD__,10);
 
@@ -1092,9 +1150,9 @@ abstract class Factory {
 			$retval = TRUE;
 
 			if ( $this->getDeleted() === TRUE ) {
-				$log_action = 'Delete';
+				$log_action = 30; //'Delete';
 			} else {
-				$log_action = 'Edit';
+				$log_action = 20; //'Edit';
 			}
 		}
 
@@ -1113,9 +1171,9 @@ abstract class Factory {
 			}
 
 			if ( method_exists($this,'addLog') ) {
-				if ( $this->addLog( $log_action ) === FALSE ) {
-					throw new GeneralError('Save(): Adding log entry failed.');
-				}
+				//In some cases, like deleting users, this function will fail because the user is deleted before they are removed from other
+				//tables like PayPeriodSchedule, so addLog() can't get the user information.
+				$this->addLog( $log_action );
 			}
 
 			//Run postSave function.
@@ -1127,7 +1185,7 @@ abstract class Factory {
 			}
 
 			//Clear the data.
-			if ($reset_data == TRUE) {
+			if ( $reset_data == TRUE ) {
 				$this->clearData();
 			}
 			//IF YOUR NOT RESETTING THE DATA, BE SURE TO CLEAR THE OBJECT MANUALLY
@@ -1159,6 +1217,13 @@ abstract class Factory {
 
 			try {
 				$this->db->Execute($query, $ph);
+
+				if ( method_exists($this,'addLog') ) {
+					//In some cases, like deleting users, this function will fail because the user is deleted before they are removed from other
+					//tables like PayPeriodSchedule, so addLog() can't get the user information.
+					$this->addLog( 31 );
+				}
+
 			} catch (Exception $e) {
 				throw new DBError($e);
 			}
