@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3143 $
- * $Id: LogFactory.class.php 3143 2009-12-02 17:21:41Z ipso $
- * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
+ * $Revision: 4073 $
+ * $Id: LogFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -46,6 +46,7 @@ class LogFactory extends Factory {
 	protected $table = 'system_log';
 	protected $pk_sequence_name = 'system_log_id_seq'; //PK Sequence name
 
+	var $user_obj = NULL;
 
 	function _getFactoryOptions( $name ) {
 
@@ -56,6 +57,7 @@ class LogFactory extends Factory {
 											10 => TTi18n::gettext('Add'),
 											20 => TTi18n::gettext('Edit'),
 											30 => TTi18n::gettext('Delete'),
+											31 => TTi18n::gettext('Delete (F)'), //Full Delete
 											40 => TTi18n::gettext('UnDelete'),
 											100 => TTi18n::gettext('Login'),
 											110 => TTi18n::gettext('Logout'),
@@ -81,25 +83,40 @@ class LogFactory extends Factory {
 											'roe'								=> TTi18n::getText('Record of Employment'),
 											'station'							=> TTi18n::getText('Station'),
 											'punch'								=> TTi18n::getText('Punch'),
+											'punch_control'						=> TTi18n::getText('Punch Control'),
 											'schedule'							=> TTi18n::getText('Schedule'),
 											'other_field'						=> TTi18n::getText('Other Field'),
 											'system_setting'					=> TTi18n::getText('System Setting'),
 											'cron'								=> TTi18n::getText('Maintenance Jobs'),
 											'permission_control'				=> TTi18n::getText('Permission Groups'),
+											'permission_user'					=> TTi18n::getText('Permission Employees'),
+											'permission'						=> TTi18n::getText('Permissions'),
 
 											'policy_group'						=> TTi18n::getText('Policy Group'),
+											'policy_group_user'					=> TTi18n::getText('Policy Group Employees'),
 											'schedule_policy'					=> TTi18n::getText('Schedule Policy'),
 											'round_interval_policy'				=> TTi18n::getText('Rounding Policy'),
 											'meal_policy'						=> TTi18n::getText('Meal Policy'),
+											'break_policy'						=> TTi18n::getText('Break Policy'),
 											'accrual_policy'					=> TTi18n::getText('Accrual Policy'),
+											'accrual_policy_milestone'			=> TTi18n::getText('Accrual Policy Milestone'),
 											'over_time_policy'					=> TTi18n::getText('Overtime Policy'),
 											'premium_policy'					=> TTi18n::getText('Premium Policy'),
+											'premium_policy_branch'				=> TTi18n::getText('Premium Policy Branch'),
+											'premium_policy_department'			=> TTi18n::getText('Premium Policy Department'),
+											'premium_policy_job_group'			=> TTi18n::getText('Premium Policy Job Group'),
+											'premium_policy_job'				=> TTi18n::getText('Premium Policy Job'),
+											'premium_policy_job_item_group'		=> TTi18n::getText('Premium Policy Task Group'),
+											'premium_policy_job_item'			=> TTi18n::getText('Premium Policy Task'),
 											'absence_policy'					=> TTi18n::getText('Absense Policy'),
 											'exception_policy_control'			=> TTi18n::getText('Exception Policy'),
+											'exception_policy'					=> TTi18n::getText('Exception Policy'),
 											'holiday_policy'					=> TTi18n::getText('Holiday Policy'),
+											'holiday_policy_recurring_holiday'	=> TTi18n::getText('Holiday Policy'),
 
 											'pay_period'						=> TTi18n::getText('Pay Period'),
 											'pay_period_schedule'				=> TTi18n::getText('Pay Period Schedule'),
+											'pay_period_schedule_user'			=> TTi18n::getText('Pay Period Schedule Employees'),
 											'pay_period_time_sheet_verify'		=> TTi18n::getText('TimeSheet Verify'),
 
 											'pay_stub'							=> TTi18n::getText('Pay Stub'),
@@ -110,22 +127,36 @@ class LogFactory extends Factory {
 											'recurring_holiday'					=> TTi18n::getText('Recurring Holiday'),
 											'recurring_ps_amendment'			=> TTi18n::getText('Recurring PS Amendment'),
 											'recurring_schedule_control'		=> TTi18n::getText('Recurring Schedule'),
-											'recurring_schedule_template_control'	=> TTi18n::getText('Recurring Schedule Template'),
+											'recurring_schedule_user'			=> TTi18n::getText('Recurring Schedule Employees'),
+											'recurring_schedule_template_control' => TTi18n::getText('Recurring Schedule Template'),
+											'recurring_schedule_template'		=> TTi18n::getText('Recurring Schedule Week'),
 
 											'user_date_total'					=> TTi18n::getText('Employee Hours'),
 											'user_default'						=> TTi18n::getText('New Hire Defaults'),
 											'user_generic_data'					=> TTi18n::getText('Employee Generic Data'),
 											'user_preference'					=> TTi18n::getText('Employee Preference'),
 											'users'								=> TTi18n::getText('Employee'),
-											'company_deduction'					=> TTi18n::getText('Company Deduction'),
+											'company_deduction'					=> TTi18n::getText('Tax / Deduction'),
+											'company_deduction_pay_stub_entry_account' => TTi18n::getText('Tax / Deduction PS Accounts'),
 											'user_deduction'					=> TTi18n::getText('Employee Deduction'),
 											'user_title'						=> TTi18n::getText('Employee Title'),
 											'user_wage'							=> TTi18n::getText('Employee Wage'),
 
 											'hierarchy_control'					=> TTi18n::getText('Hierarchy'),
+											'hierarchy_object_type'				=> TTi18n::getText('Hierarchy Object Type'),
+											'hierarchy_user'					=> TTi18n::getText('Hierarchy Subordinate'),
+											'hierarchy_level'					=> TTi18n::getText('Hierarchy Superior'),
 											'hierarchy'							=> TTi18n::getText('Hierarchy Tree'),
 
 											'job'								=> TTi18n::getText('Job'),
+											'job_user_branch'					=> TTi18n::getText('Job Branch'),
+											'job_user_department'				=> TTi18n::getText('Job Department'),
+											'job_user_group'					=> TTi18n::getText('Job Group'),
+											'job_include_user'					=> TTi18n::getText('Job Include Employee'),
+											'job_exclude_user'					=> TTi18n::getText('Job Exclude Employee'),
+											'job_job_item_group'				=> TTi18n::getText('Job Task Group'),
+											'job_include_job_item'				=> TTi18n::getText('Job Include Task'),
+											'job_exclude_job_item'				=> TTi18n::getText('Job Exclude Task'),
 											'job_item'							=> TTi18n::getText('Job Task'),
 											'job_item_amendment'				=> TTi18n::getText('Job Task Amendment'),
 											'document'							=> TTi18n::getText('Document'),
@@ -137,25 +168,84 @@ class LogFactory extends Factory {
 											'invoice_config'					=> TTi18n::getText('Invoice Settings'),
 											'invoice_transaction'				=> TTi18n::getText('Invoice Transaction'),
 											'product'							=> TTi18n::getText('Product'),
+											'product_price'						=> TTi18n::getText('Product Price Bracket'),
 											'product_tax_policy'				=> TTi18n::getText('Product Tax Policy'),
 											'tax_area_policy'					=> TTi18n::getText('Invoice Tax Area Policy'),
 											'tax_policy'						=> TTi18n::getText('Invoice Tax Policy'),
 											'transaction'						=> TTi18n::getText('Invoice Transaction'),
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1010-first_name' => TTi18n::gettext('First Name'),
+										'-1020-last_name' => TTi18n::gettext('Last Name'),
+										'-1100-date' => TTi18n::gettext('Date'),
+										'-1110-object' => TTi18n::gettext('Object'),
+										'-1120-action' => TTi18n::gettext('Action'),
+										'-1130-description' => TTi18n::gettext('Description'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'date',
+								'object',
+								'action',
+								'description',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array();
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array();
+				break;
 
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'user_id' => 'User',
+										'first_name' => FALSE,
+										'last_name' => FALSE,
+										'object_id' => 'Object',
+										'table_name' => 'TableName',
+										'object' => FALSE, //Actually the display table name.
+
+										'action_id' => 'Action',
+										'action' => FALSE,
+										'description' => 'Description',
+										'date' => 'Date',
+
+										'details' => 'Details',
+
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
+
+	function getUserObject() {
+		if ( is_object($this->user_obj) ) {
+			return $this->user_obj;
+		} else {
+			$ulf = new UserListFactory();
+			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
+
+			return $this->user_obj;
+		}
+	}
 
 	function getLink() {
 
 		$link = FALSE;
 
-		//Only show links on add/edit actions.
-		if ( !in_array( $this->getAction(), array(10,20) ) ) {
+		//Only show links on add/edit/allow actions.
+		if ( !in_array( $this->getAction(), array(10,20,200) ) ) {
 			return $link;
 		}
 
@@ -364,7 +454,11 @@ class LogFactory extends Factory {
 	}
 
 	function getObject() {
-		return $this->data['object_id'];
+		if ( isset($this->data['object_id']) ) {
+			return $this->data['object_id'];
+		}
+
+		return FALSE;
 	}
 	function setObject($id) {
 		$id = trim($id);
@@ -413,11 +507,12 @@ class LogFactory extends Factory {
 	function setAction($action) {
 		$action = trim($action);
 
+		//Use integer ID values instead.
 		$key = Option::getByValue($action, $this->getOptions('action') );
 		if ($key !== FALSE) {
+			Debug::text('Text Action: '. $action .' Key: '. $key, __FILE__, __LINE__, __METHOD__, 10);
 			$action = $key;
 		}
-
 		if ( $this->Validator->inArrayKey(	'action',
 											$action,
 											TTi18n::gettext('Incorrect Action'),
@@ -517,6 +612,109 @@ class LogFactory extends Factory {
 		return FALSE;
 	}
 
+	function getDetails() {
+		if ( $this->isNew() == FALSE AND is_object( $this->getUserObject() ) ) {
+			//Get class for this table
+			Debug::Text( 'Table: '. $this->getTableName(), __FILE__, __LINE__, __METHOD__,10);
+			require_once( Environment::getBasePath() . DIRECTORY_SEPARATOR . 'includes'. DIRECTORY_SEPARATOR .'TableMap.inc.php');
+			if ( isset($global_table_map[$this->getTableName()]) ) {
+				$table_class = $global_table_map[$this->getTableName()];
+				$class = new $table_class;
+				Debug::Text( 'Table Class: '. $table_class, __FILE__, __LINE__, __METHOD__,10);
+
+				$ldlf = new LogDetailListFactory();
+				$ldlf->getBySystemLogIdAndCompanyId( $this->getID(), $this->getUserObject()->getCompany() );
+				if ( $ldlf->getRecordCount() > 0 ) {
+					foreach( $ldlf as $ld_obj ) {
+						$detail_row[] = array(
+											'field' => $ld_obj->getField(),
+											'display_field' => $ld_obj->getDisplayField( $class ),
+											'old_value' => $ld_obj->getDisplayOldValue( $class ),
+											'new_value' => $ld_obj->getDisplayNewValue( $class ),
+											);
+					}
+
+					$detail_row = Sort::multiSort( $detail_row, 'display_field' ) ;
+					Debug::Arr( $detail_row, 'Detail Row: ', __FILE__, __LINE__, __METHOD__,10);
+
+					return $detail_row;
+				}
+			}
+		}
+
+		Debug::Text('No Log Details... ID: '. $this->getID(), __FILE__, __LINE__, __METHOD__,10);
+		return FALSE;
+	}
+
+	//Don't allow remote API calls to set audit trail records.
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			//$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'first_name':
+						case 'last_name':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'date':
+							$data[$variable] = TTDate::getAPIDate('DATE+TIME', $this->getDate() );
+							break;
+						case 'object':
+							$data[$variable] = Option::getByKey( $this->getTableName(), $this->getOptions( 'table_name' ) );
+							break;
+						case 'action':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'details':
+							if ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) {
+								$data[$variable] = $this->getDetails();
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+				}
+			}
+			//$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	//This table doesn't have any of these columns, so overload the functions.
 	function getDeleted() {
 		return FALSE;
