@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: LogListFactory.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4000 $
+ * $Id: LogListFactory.class.php 4000 2010-11-30 17:13:27Z ipso $
+ * $Date: 2010-11-30 09:13:27 -0800 (Tue, 30 Nov 2010) $
  */
 
 /**
@@ -84,6 +84,37 @@ class LogListFactory extends LogFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByIdAndCompanyId($id, $company_id, $where = NULL, $order = NULL) {
+		if ( $id == '') {
+			return FALSE;
+		}
+
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		$uf = new UserFactory();
+
+		$ph = array(
+					'id' => $id,
+					'company_id' => $company_id
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+						LEFT JOIN  '. $uf->getTable() .' as b on a.user_id = b.id
+					where	a.id = ?
+						AND b.company_id = ?
+						AND a.deleted = 0';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getLastEntryByUserIdAndActionAndTable($user_id, $action, $table_name) {
 		if ( $user_id == '') {
 			return FALSE;
@@ -209,59 +240,163 @@ class LogListFactory extends LogFactory implements IteratorAggregate {
 		return $this;
 	}
 
-/*
-	function getByCompanyId($id, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
-		if ( $id == '') {
-			return FALSE;
-		}
-
-		$query = '
-					select 	*,
-							CASE WHEN ( updated_date is NULL) THEN TRUE ELSE FALSE END as updated_date_null
-					from	'. $this->getTable() .'
-					where	company_id = '. $id .'
-						AND deleted = 0
-					';
-		$query .= $this->getWhereSQL( $where );
-		//Because of the null updated date, we have to manually sort.
-		if ( $order == NULL ) {
-			//$order = array( 'type_id' => 'asc', 'status_id' => 'asc', 'updated_date_null' => 'asc', 'updated_date' => 'desc', 'created_date' => 'desc' );
-			$query .= 'ORDER BY type_id asc, status_id asc, updated_date_null asc, updated_date desc, created_date desc';
-		} else {
-			$query .= $this->getSortSQL( $order );
-		}
-
-		if ($limit == NULL) {
-			//Run query without limit
-			$this->rs = $this->db->SelectLimit($query);
-		} else {
-			$this->rs = $this->db->PageExecute($query, $limit, $page);
-		}
-
-		return $this;
-	}
-
-	function getByIdAndCompanyId($id, $company_id, $order = NULL) {
-		if ( $id == '') {
-			return FALSE;
-		}
-
+	function getByPhonePunchDataByCompanyIdAndStartDateAndEndDate($company_id, $start_date, $end_date, $where = NULL, $order = NULL) {
 		if ( $company_id == '') {
 			return FALSE;
 		}
 
-		$query = '
-					select 	*
-					from 	'. $this->getTable() .'
-					where	company_id = '. $company_id .'
-						AND	id = '. $id .'
-						AND deleted = 0';
-		$query .= $this->getSortSQL( $order );
+		if ( $start_date == '') {
+			return FALSE;
+		}
 
-		$this->rs = $this->db->Execute($query);
+		if ( $end_date == '') {
+			return FALSE;
+		}
+
+		$ph = array(
+					'company_id' => $company_id,
+					'start_date' => $start_date,
+					'end_date' => $end_date,
+					);
+
+		$query = '
+					select 	company_id,
+							sum(seconds) as phone_seconds,
+							count(*) as phone_count
+					from 	(
+								select 	company_id,
+										CASE WHEN seconds < 60 THEN 60 ELSE seconds END as seconds
+								from 	(
+											select  a.id,
+													company_id,
+													a.description,
+													array_to_string( regexp_matches(a.description, \'([0-9]{1,3})s$\', \'i\'), \'\')::int as seconds
+											from 	system_log as a
+											LEFT JOIN users as b ON a.user_id = b.id
+											where b.company_id = ?
+												AND a.table_name = \'punch\'
+												AND ( a.description ILIKE \'Telephone Punch End%\' AND a.description NOT ILIKE \'%Destination: unknown%\' )
+												AND ( date >= ? AND date <= ? )
+										) as tmp
+							) as tmp2
+					group by company_id;
+					';
+
+		//$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+
+		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
 	}
-*/
+
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array('action_id','object_id','last_name', 'first_name');
+
+		$sort_column_aliases = array(
+									 'action' => 'action_id',
+									 'object' => 'table_name',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'date' => 'desc', 'table_name' => 'asc', 'object_id' => 'asc');
+			$strict = FALSE;
+		} else {
+			//Always try to order by status first so INACTIVE employees go to the bottom.
+			if ( !isset($order['date']) ) {
+				$order['date'] = 'desc';
+			}
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$uf = new UserFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	a.*,
+							uf.first_name as first_name,
+							uf.middle_name as middle_name,
+							uf.last_name as last_name
+
+					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $uf->getTable() .' as uf ON ( a.user_id = uf.id AND uf.deleted = 0 )
+					where	uf.company_id = ?
+					';
+
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['action_id']) AND isset($filter_data['action_id'][0]) AND !in_array(-1, (array)$filter_data['action_id']) ) {
+			$query  .=	' AND a.action_id in ('. $this->getListSQL($filter_data['action_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['table_name']) AND isset($filter_data['table_name'][0]) AND !in_array(-1, (array)$filter_data['table_name']) ) {
+			$query  .=	' AND a.table_name in ('. $this->getListSQL($filter_data['table_name'], $ph) .') ';
+		}
+		if ( isset($filter_data['object_id']) AND isset($filter_data['object_id'][0]) AND !in_array(-1, (array)$filter_data['object_id']) ) {
+			$query  .=	' AND a.object_id in ('. $this->getListSQL($filter_data['object_id'], $ph) .') ';
+		}
+
+		//Need to support table_name -> object_id pairs for including log entires from different tables/objects.
+		if ( isset( $filter_data['table_name_object_id'] ) AND is_array($filter_data['table_name_object_id']) AND count($filter_data['table_name_object_id']) > 0 ) {
+			foreach( $filter_data['table_name_object_id'] as $table_name => $object_id ) {
+				$ph[] = strtolower(trim($table_name));
+				//$ph[] = (int)$object_id;
+
+				$sub_query[] =	'(a.table_name = ? AND a.object_id in ('. $this->getListSQL($object_id, $ph) .') )';
+			}
+
+			if ( isset($sub_query) ) {
+				$query .= ' AND ( '. implode(' OR ', $sub_query ) .' ) ';
+			}
+			unset($table_name, $object_id, $sub_query);
+		}
+
+		if ( isset($filter_data['description']) AND trim($filter_data['description']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['description']));
+			$query  .=	' AND lower(a.description) LIKE ?';
+		}
+
+		$query .= 	'';
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		Debug::Arr($ph, 'Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 }
 ?>
