@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: Misc.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3928 $
+ * $Id: Misc.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -212,6 +212,29 @@ class Misc {
 		return $retarr;
 	}
 
+	function flattenArray($array, $preserve = FALSE, $r = array() ) {
+		foreach( $array as $key => $value ){
+			if ( is_array($value) ) {
+				foreach( $value as $k => $v ) {
+					if ( is_array($v) ) {
+						$tmp = $v;
+						unset($value[$k]);
+					}
+				}
+
+				if ($preserve) {
+					$r[$key] = $value;
+				} else {
+					$r[] = $value;
+				}
+			}
+
+			$r = isset($tmp) ? self::flattenArray($tmp, $preserve, $r) : $r;
+		}
+
+		return $r;
+	}
+
 	/*
 		When passed an array of input_keys, and an array of output_key => output_values,
 		this function will return all the output_key => output_value pairs where
@@ -285,22 +308,38 @@ class Misc {
 		return NULL;
 	}
 
-	static function array_diff_assoc_recursive($array1, $array2) {
-		foreach($array1 as $key => $value) {
-			if ( is_array($value) ) {
-				  if ( !isset($array2[$key]) ) {
-					  $difference[$key] = $value;
-				  } elseif( !is_array($array2[$key]) ) {
-					  $difference[$key] = $value;
-				  } else {
-					  $new_diff = self::array_diff_assoc_recursive($value, $array2[$key]);
-					  if ( $new_diff !== FALSE ) {
-							$difference[$key] = $new_diff;
+	function arrayMergeRecursiveDistinct( array $array1, array $array2 ) {
+		$merged = $array1;
+
+		foreach ( $array2 as $key => &$value ) {
+			if ( is_array( $value ) AND isset( $merged[$key] ) AND is_array( $merged[$key] ) ) {
+				$merged[$key] = self::arrayMergeRecursiveDistinct( $merged[$key], $value );
+			} else {
+				$merged[$key] = $value;
+			}
+		}
+
+		return $merged;
+	}
+
+	static function arrayDiffAssocRecursive($array1, $array2) {
+		if ( is_array($array1) ) {
+			foreach($array1 as $key => $value) {
+				if ( is_array($value) ) {
+					  if ( !isset($array2[$key]) ) {
+						  $difference[$key] = $value;
+					  } elseif( !is_array($array2[$key]) ) {
+						  $difference[$key] = $value;
+					  } else {
+						  $new_diff = self::arrayDiffAssocRecursive($value, $array2[$key]);
+						  if ( $new_diff !== FALSE ) {
+								$difference[$key] = $new_diff;
+						  }
 					  }
+				  } elseif ( !isset($array2[$key]) OR $array2[$key] != $value ) {
+					  $difference[$key] = $value;
 				  }
-			  } elseif ( !isset($array2[$key]) OR $array2[$key] != $value ) {
-				  $difference[$key] = $value;
-			  }
+			}
 		}
 
 		if ( !isset($difference) ) {
@@ -310,6 +349,26 @@ class Misc {
 		return $difference;
 	}
 
+	//Adds sort prefixes to an array maintaining the original order. Primarily used because Flex likes to reorded arrays with string keys.
+	static function addSortPrefix( $arr ) {
+		$i=1;
+		foreach( $arr as $key => $value ) {
+			$sort_prefix = NULL;
+			if ( substr($key, 0, 1 ) != '-' ) {
+				$sort_prefix = '-'.str_pad($i, 4, 0, STR_PAD_LEFT).'-';
+			}
+			$retarr[$sort_prefix.$key] = $value;
+			$i++;
+		}
+
+		if ( isset($retarr) ) {
+			return $retarr;
+		}
+
+		return FALSE;
+	}
+
+	//Removes sort prefixes from an array.
 	static function trimSortPrefix( $value, $trim_arr_value = FALSE ) {
 		if ( is_array($value) AND count($value) > 0 ) {
 			foreach( $value as $key => $val ) {
@@ -355,6 +414,19 @@ class Misc {
 		return TRUE;
 	}
 
+	//This function helps sending binary data to the client for saving/viewing as a file.
+	static function APIFileDownload($file_name, $type, $data) {
+		if ( $file_name == '' OR $data == '' ) {
+			return FALSE;
+		}
+
+		$size = strlen($data);
+
+		self::FileDownloadHeader( $file_name, $type, $size );
+		echo $data;
+		return TRUE;
+	}
+
 	static function removeTrailingZeros( $value, $minimum_decimals = 2 ) {
 		//Remove trailing zeros after the decimal, leave a minimum of X though.
 		if ( strpos( $value, '.') !== FALSE ) {
@@ -364,7 +436,7 @@ class Misc {
 			if ( $tmp_minimum_decimals > $minimum_decimals ) {
 				$minimum_decimals = $tmp_minimum_decimals;
 			}
-			return number_format( $value, $minimum_decimals );
+			return number_format( $value, $minimum_decimals, '.', '' );
 		}
 
 		return $value;
@@ -460,6 +532,34 @@ class Misc {
 		return $retval;
 	}
 
+	static function calculateMultipleColumns($data, $include_elements = array(), $exclude_elements = array() ) {
+		if ( !is_array($data) ) {
+			return FALSE;
+		}
+
+		$retval = 0;
+
+		if ( is_array( $include_elements ) ) {
+			foreach($include_elements as $include_element ) {
+				if ( isset($data[$include_element]) ) {
+					$retval = bcadd( $retval, $data[$include_element]);
+					//Debug::Text('Found Element in Source Data: '. $sum_element .' Retval: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+				}
+			}
+		}
+
+		if ( is_array( $exclude_elements ) ) {
+			foreach($exclude_elements as $exclude_element ) {
+				if ( isset($data[$exclude_element]) ) {
+					$retval = bcsub( $retval, $data[$exclude_element]);
+					//Debug::Text('Found Element in Source Data: '. $sum_element .' Retval: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+				}
+			}
+		}
+
+		return $retval;
+	}
+
 	static function getPointerFromArray( $array, $element, $start = 1 ) {
 		//Debug::Arr($array, 'Source Array: ', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Text('Searching for Element: '. $element, __FILE__, __LINE__, __METHOD__,10);
@@ -813,7 +913,7 @@ class Misc {
 		return $server_domain;
 	}
 
-	//Accepts a search_str and key=>val array that it searches through, to return the array key of the closest match.
+	//Accepts a search_str and key=>val array that it searches through, to return the array key of the closest fuzzy match.
 	static function findClosestMatch( $search_str, $search_arr, $minimum_percent_match = 0, $return_all_matches = FALSE ) {
 		if ( $search_str == '' ) {
 			return FALSE;
@@ -947,5 +1047,54 @@ class Misc {
 		return $files;
 	}
 
+	static function convertObjectToArray( $obj ) {
+		if ( is_object($obj) ) {
+			$obj = get_object_vars($obj);
+		}
+
+		if ( is_array($obj) ) {
+			return array_map( array( 'Misc', __FUNCTION__) , $obj );
+		} else {
+			return $obj;
+		}
+	}
+
+	static function getSystemLoad() {
+		if ( OPERATING_SYSTEM == 'LINUX' ) {
+			$loadavg_file = '/proc/loadavg';
+			if ( file_exists( $loadavg_file ) AND is_readable( $loadavg_file ) ) {
+				$buffer = '0 0 0';
+				$buffer = file_get_contents( $loadavg_file );
+				$load = explode(' ',$buffer);
+
+				$retval = max((float)$load[0], (float)$load[1], (float)$load[2]);
+				Debug::text(' Load Average: '. $retval , __FILE__, __LINE__, __METHOD__,10);
+
+				return $retval;
+			}
+		}
+
+		return 0;
+	}
+
+	static function isSystemLoadValid() {
+		global $config_vars;
+
+		if ( !isset($config_vars['other']['max_cron_system_load']) ) {
+			$config_vars['other']['max_cron_system_load'] = 9999;
+		}
+
+		$system_load = Misc::getSystemLoad();
+		if ( isset($config_vars['other']['max_cron_system_load']) AND $system_load <= $config_vars['other']['max_cron_system_load'] ) {
+			Debug::text(' Load average within valid limits: Current: '. $system_load .' Max: '. $config_vars['other']['max_cron_system_load'], __FILE__, __LINE__, __METHOD__,10);
+
+			return TRUE;
+		}
+
+		Debug::text(' Load average NOT within valid limits: Current: '. $system_load .' Max: '. $config_vars['other']['max_cron_system_load'], __FILE__, __LINE__, __METHOD__,10);
+
+		return FALSE;
+	}
+
 }
 ?>
\ No newline at end of file
