@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2490 $
- * $Id: Pager.class.php 2490 2009-04-24 22:13:40Z ipso $
- * $Date: 2009-04-24 15:13:40 -0700 (Fri, 24 Apr 2009) $
+ * $Revision: 4073 $
+ * $Id: Pager.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -44,6 +44,7 @@
  */
 class Pager {
 	protected $rs = NULL;
+	protected $count_rows = TRUE; //Specify if we count the total rows or not.
 
 	function __construct($arr) {
 		if ( isset($arr->rs) ) {
@@ -51,6 +52,8 @@ class Pager {
 			//Make sure the ListFactory function is doing a pageselect
 			$this->rs = $arr->rs;
 
+			$this->count_rows = $arr->db->pageExecuteCountRows;
+
 			return TRUE;
 		}
 
@@ -104,7 +107,23 @@ class Pager {
 
 	function LastPageNumber() {
 		if ( is_object($this->rs) ) {
-			return $this->rs->lastpageno();
+			if ( $this->count_rows === FALSE ) {
+				if ( $this->getCurrentPage() < 0 ) {
+					//Only one page in result set.
+					return $this->rs->lastpageno();
+				} else {
+					//More than one page in result set.
+					if ( $this->rs->atlastpage() == TRUE ) {
+						return $this->getCurrentPage();
+					} else {
+						//Since we don't know what the actual last page is, just add 100 pages to the current one.
+						//The user may need to click this several times if there are more than 100 pages.
+						return $this->getCurrentPage()+99;
+					}
+				}
+			} else {
+				return $this->rs->lastpageno();
+			}
 		}
 
 		return FALSE;
