@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2490 $
- * $Id: PermissionControlListFactory.class.php 2490 2009-04-24 22:13:40Z ipso $
- * $Date: 2009-04-24 15:13:40 -0700 (Fri, 24 Apr 2009) $
+ * $Revision: 3928 $
+ * $Id: PermissionControlListFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -84,6 +84,34 @@ class PermissionControlListFactory extends PermissionControlFactory implements I
 		return $this;
 	}
 
+	function getByIdAndLevel($id, $level, $where = NULL, $order = NULL) {
+		if ( $id == '') {
+			return FALSE;
+		}
+
+		if ( $level == '') {
+			return FALSE;
+		}
+
+		$ph = array(
+					'id' => $id,
+					'level' => $level,
+					);
+
+		$query = '
+					select 	*
+					from	'. $this->getTable() .'
+					where	id = ?
+						AND level <= ?
+						AND deleted = 0';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByIdAndCompanyId($id, $company_id, $where = NULL, $order = NULL) {
 		if ( $id == '') {
 			return FALSE;
@@ -118,7 +146,7 @@ class PermissionControlListFactory extends PermissionControlFactory implements I
 		}
 
 		if ( $order == NULL ) {
-			$order = array( 'name' => 'asc' );
+			$order = array( 'level' => 'asc', 'name' => 'asc' );
 			$strict = FALSE;
 		} else {
 			$strict = TRUE;
@@ -151,6 +179,51 @@ class PermissionControlListFactory extends PermissionControlFactory implements I
 		return $this;
 	}
 
+	function getByCompanyIdAndLevel($id, $level, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $id == '') {
+			return FALSE;
+		}
+
+		if ( $level == '') {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'level' => 'asc', 'name' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$additional_sort_fields = array( 'name', 'level', 'description', 'id' );
+
+		$ph = array(
+					'id' => $id,
+					'level' => $level,
+					);
+
+		$query = '
+					select 	*
+					from	'. $this->getTable() .'
+					where
+						company_id = ?
+						AND level <= ?
+						AND deleted = 0
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_sort_fields );
+
+		//Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 	function getByCompanyIdAndUserId($company_id, $user_id, $where = NULL, $order = NULL) {
 		if ( $company_id == '') {
 			return FALSE;
@@ -194,7 +267,7 @@ class PermissionControlListFactory extends PermissionControlFactory implements I
 		}
 
 		foreach ($lf as $obj) {
-			$list[$obj->getID()] = $obj->getName();
+			$list[$obj->getID()] = $obj->getName().' ['. $obj->getLevel().']';
 		}
 
 		if ( isset($list) ) {
@@ -272,6 +345,12 @@ class PermissionControlListFactory extends PermissionControlFactory implements I
 		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
 			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
 		}
+
+		if ( isset($filter_data['level']) AND $filter_data['level'] != '' AND $filter_data['level'] > 0 ) {
+			$ph[] = (int)$filter_data['level'];
+			$query  .=	' AND a.level <= ?';
+		}
+
 		if ( isset($filter_data['name']) AND trim($filter_data['name']) != '' ) {
 			$ph[] = strtolower(trim($filter_data['name']));
 			$query  .=	' AND lower(a.name) LIKE ?';
