@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PermissionFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: PermissionFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -47,6 +47,7 @@ class PermissionFactory extends Factory {
 	protected $pk_sequence_name = 'permission_id_seq'; //PK Sequence name
 
 	protected $permission_control_obj = NULL;
+	protected $company_id = NULL;
 
 	function _getFactoryOptions( $name ) {
 
@@ -62,6 +63,16 @@ class PermissionFactory extends Factory {
 										40 => TTi18n::gettext('Administrator')
 									);
 				break;
+			case 'preset_level':
+				$retval = array(
+										10 => 1,
+										18 => 10,
+										20 => 15,
+										30 => 20,
+										40 => 25,
+									);
+				break;
+
 			case 'section_group':
 				$retval = array(
 											0 => TTi18n::gettext('-- Please Choose --'),
@@ -924,10 +935,18 @@ class PermissionFactory extends Factory {
 		return $retval;
 	}
 
+	function setCompany( $id ) {
+		$this->company_id = $id;
+		return TRUE;
+	}
 	function getCompany() {
-		$company_id = $this->getPermissionControlObject()->getCompany();
+		if ( $this->company_id != '' ) {
+			return $this->company_id;
+		} else {
+			$company_id = $this->getPermissionControlObject()->getCompany();
 
-		return $company_id;
+			return $company_id;
+		}
 	}
 
 	function getPermissionControlObject() {
@@ -960,7 +979,7 @@ class PermissionFactory extends Factory {
 
 		$pclf = new PermissionControlListFactory();
 
-		if ( $id == -1
+		if ( $id != 0
 				OR
 				$this->Validator->isResultSetWithRows(	'permission_control',
 													$pclf->getByID($id),
@@ -1395,6 +1414,7 @@ class PermissionFactory extends Factory {
 				//Supervisor (All Employees), can see all schedules and shifts, and can do authorizations
 				$preset_permissions_20 = array(
 											'user' => 	array(
+																'add' => TRUE, //Can only add user with permissions level equal or lower.
 																'view' => TRUE,
 																'edit' => TRUE,
 																'enroll' => TRUE,
@@ -1472,12 +1492,14 @@ class PermissionFactory extends Factory {
 				//Supervisor (Suborindates Only), can see all schedules and shifts, and can do authorizations
 				$preset_permissions_18 = array(
 											'user' => 	array(
+																'add' => TRUE, //Can only add user with permissions level equal or lower.
 																'view_child' => TRUE,
 																'edit_child' => TRUE,
 																'edit_advanced' => TRUE,
 																'enroll_child' => TRUE,
 																'delete_child' => TRUE,
 																'edit_pay_period_schedule' => TRUE,
+																'edit_permission_group' => TRUE,
 																'edit_policy_group' => TRUE,
 																'edit_hierarchy' => TRUE,
 															),
@@ -1822,7 +1844,7 @@ class PermissionFactory extends Factory {
 			return TRUE;
 		}
 
-		Debug::Text(' Product Edition: '. $product_edition .' Primary Company ID: '. PRIMARY_COMPANY_ID, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text(' Product Edition: '. $product_edition .' Primary Company ID: '. PRIMARY_COMPANY_ID, __FILE__, __LINE__, __METHOD__,10);
 		if ( $product_edition == 20 ) {
 			$ignore_permissions = array('help' => 'ALL',
 										'company' => array('add','delete','delete_own','undelete','view','edit','login_other_user'),
@@ -1874,7 +1896,7 @@ class PermissionFactory extends Factory {
 			Debug::Text(' IGNORING... Section: '. $section .' Name: '. $name, __FILE__, __LINE__, __METHOD__,10);
 			return TRUE;
 		} else {
-			Debug::Text(' NOT IGNORING... Section: '. $section .' Name: '. $name, __FILE__, __LINE__, __METHOD__,10);
+			//Debug::Text(' NOT IGNORING... Section: '. $section .' Name: '. $name, __FILE__, __LINE__, __METHOD__,10);
 			return FALSE;
 		}
 	}
@@ -1907,5 +1929,14 @@ class PermissionFactory extends Factory {
 
 		return TRUE;
 	}
+
+	function addLog( $log_action ) {
+		if ( $this->getValue() == TRUE ) {
+			$value_display =  TTi18n::getText( 'ALLOW' );
+		} else {
+			$value_display =  TTi18n::getText( 'DENY' );
+		}
+		return TTLog::addEntry( $this->getPermissionControl(), $log_action, TTi18n::getText('Section').': '. $this->getSection() .' Name: '. $this->getName() .' Value: '. $value_display , NULL, $this->getTable() );
+	}
 }
 ?>
