@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: PermissionUserFactory.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3768 $
+ * $Id: PermissionUserFactory.class.php 3768 2010-08-14 19:24:17Z ipso $
+ * $Date: 2010-08-14 12:24:17 -0700 (Sat, 14 Aug 2010) $
  */
 
 /**
@@ -46,6 +46,8 @@ class PermissionUserFactory extends Factory {
 	protected $table = 'permission_user';
 	protected $pk_sequence_name = 'permission_user_id_seq'; //PK Sequence name
 
+	var $user_obj = NULL;
+
 	function getPermissionControl() {
 		return $this->data['permission_control_id'];
 	}
@@ -68,6 +70,20 @@ class PermissionUserFactory extends Factory {
 		return FALSE;
 	}
 
+	function getUserObject() {
+		if ( is_object($this->user_obj) ) {
+			return $this->user_obj;
+		} else {
+			$ulf = new UserListFactory();
+			$ulf->getById( $this->getUser() );
+			if ( $ulf->getRecordCount() == 1 ) {
+				$this->user_obj = $ulf->getCurrent();
+				return $this->user_obj;
+			}
+
+			return FALSE;
+		}
+	}
 	function isUniqueUser($id) {
 		$pclf = new PermissionControlListFactory();
 
@@ -159,5 +175,14 @@ class PermissionUserFactory extends Factory {
 	function setDeletedBy($id = NULL) {
 		return FALSE;
 	}
+
+	function addLog( $log_action ) {
+		$u_obj = $this->getUserObject();
+		if ( is_object($u_obj) ) {
+			return TTLog::addEntry( $this->getPermissionControl(), $log_action, TTi18n::getText('Employee').': '. $u_obj->getFullName( FALSE, TRUE ) , NULL, $this->getTable() );
+		}
+
+		return FALSE;
+	}
 }
 ?>
