@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3060 $
- * $Id: StationFactory.class.php 3060 2009-11-13 16:08:37Z ipso $
- * $Date: 2009-11-13 08:08:37 -0800 (Fri, 13 Nov 2009) $
+ * $Revision: 4073 $
+ * $Id: StationFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 include_once('Net/IPv4.php');
 
@@ -72,8 +72,8 @@ class StationFactory extends Factory {
 					$retval[40]	= TTi18n::gettext('Barcode');
 					$retval[50]	= TTi18n::gettext('FingerPrint');
 					$retval[100] = TTi18n::gettext('TimeClock: TT-A8');
-					//$retval[110] = TTi18n::gettext('TimeClock: TT-F4');
 					$retval[120] = TTi18n::gettext('TimeClock: TT-S300');
+					$retval[150] = TTi18n::gettext('TimeClock: TT-US100');
 					//$retval[200] = TTi18n::gettext('TimeClock: ACTAtek');
 				}
 				break;
@@ -159,25 +159,30 @@ class StationFactory extends Factory {
 				break;
 			case 'mode_flag':
 				$retval = array(
-										1 =>  TTi18n::gettext('-- Default --'),
-										2 =>  TTi18n::gettext('Must Select In/Out Status'),
-										//4 =>  TTi18n::gettext('Enable Work Code (Mode 1)'),
-										//8 =>  TTi18n::gettext('Enable Work Code (Mode 2)'),
-										4 =>  TTi18n::gettext('Disable Out Status'),
-										8 =>  TTi18n::gettext('Enable Breaks'),
-										16 =>  TTi18n::gettext('Enable Lunches'),
-										32  => TTi18n::gettext('Enable: Branch'),
-										64  => TTi18n::gettext('Enable: Department'),
+										1 		=> TTi18n::gettext('-- Default --'),
+										2 		=> TTi18n::gettext('Must Select In/Out Status'),
+										//4 	=> TTi18n::gettext('Enable Work Code (Mode 1)'),
+										//8 	=> TTi18n::gettext('Enable Work Code (Mode 2)'),
+										4 		=> TTi18n::gettext('Disable Out Status'),
+										8 		=> TTi18n::gettext('Enable: Breaks'),
+										16 		=> TTi18n::gettext('Enable: Lunches'),
+										32  	=> TTi18n::gettext('Enable: Branch'),
+										64  	=> TTi18n::gettext('Enable: Department'),
+
+										32768  	=> TTi18n::gettext('Authentication: Fingerprint & Password'),
+										65536  	=> TTi18n::gettext('Authentication: Fingerprint & Proximity Card'),
+										131072 	=> TTi18n::gettext('Authentication: PIN & Fingerprint'),
+										262144	=> TTi18n::gettext('Authentication: Proximity Card & Password'),
 									);
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 					$retval[128]  = TTi18n::gettext('Enable: Job');
-					$retval[256] = TTi18n::gettext('Enable: Task');
-					$retval[512] = TTi18n::gettext('Enable: Quantity');
+					$retval[256]  = TTi18n::gettext('Enable: Task');
+					$retval[512]  = TTi18n::gettext('Enable: Quantity');
 					$retval[1024] = TTi18n::gettext('Enable: Bad Quantity');
 				}
 
+				ksort($retval);
 				break;
-
 			case 'columns':
 				$retval = array(
 										'-1010-status' => TTi18n::gettext('Status'),
@@ -187,6 +192,12 @@ class StationFactory extends Factory {
 										'-1140-station_id' => TTi18n::gettext('Station'),
 										'-1150-description' => TTi18n::gettext('Description'),
 
+										'-1160-time_zone' => TTi18n::gettext('Time Zone'),
+
+										'-1160-branch_selection_type' => TTi18n::gettext('Branch Selection Type'),
+										'-1160-department_selection_type' => TTi18n::gettext('Department Selection Type'),
+										'-1160-group_selection_type' => TTi18n::gettext('Group Selection Type'),
+										
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
 										'-2020-updated_by' => TTi18n::gettext('Updated By'),
@@ -476,7 +487,6 @@ class StationFactory extends Factory {
 	function setDefaultBranch($id) {
 		$id = trim($id);
 
-		Debug::Text('Branch ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$blf = new BranchListFactory();
 
 		if (
@@ -505,7 +515,6 @@ class StationFactory extends Factory {
 	function setDefaultDepartment($id) {
 		$id = trim($id);
 
-		Debug::Text('Department ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$dlf = new DepartmentListFactory();
 
 		if (
@@ -752,8 +761,8 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setBranch($ids) {
-		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
-		Debug::Arr($ids, 'IDs: ', __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::Arr($ids, 'IDs: ', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
 			$tmp_ids = array();
 
@@ -764,7 +773,7 @@ class StationFactory extends Factory {
 
 				foreach ($lf_a as $obj) {
 					$id = $obj->getBranch();
-					Debug::text('Branch ID: '. $obj->getBranch() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('Branch ID: '. $obj->getBranch() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
 
 					//Delete users that are not selected.
 					if ( !in_array($id, $ids) ) {
@@ -842,7 +851,7 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function setDepartment($ids) {
-		Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('Setting IDs...', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
 			$tmp_ids = array();
 
@@ -853,7 +862,7 @@ class StationFactory extends Factory {
 
 				foreach ($lf_a as $obj) {
 					$id = $obj->getDepartment();
-					Debug::text('Department ID: '. $obj->getDepartment() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('Department ID: '. $obj->getDepartment() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
 
 					//Delete users that are not selected.
 					if ( !in_array($id, $ids) ) {
@@ -1271,6 +1280,76 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 */
+
+	//Update JUST station allowed_date without affecting updated_date, and without creating an EDIT entry in the system_log.
+	function updateLastPollDateAndLastPunchTimeStamp( $id, $last_poll_date = 0, $last_punch_date = 0 ) {
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		$slf = new StationListFactory();
+		$slf->getById( $id );
+		if ( $slf->getRecordCount() == 1 ) {
+			$ph = array(
+						'last_poll_date' => $last_poll_date,
+						'last_punch_date' => $this->db->BindTimeStamp( $last_punch_date ),
+						'id' => $id,
+						);
+			$query = 'UPDATE '. $this->getTable() .' set last_poll_date = ?,last_punch_time_stamp = ? where id = ?';
+			$this->db->Execute($query, $ph);
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	//Update JUST station allowed_date without affecting updated_date, and without creating an EDIT entry in the system_log.
+	function updateLastPushDate( $id, $last_push_date = 0 ) {
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		$slf = new StationListFactory();
+		$slf->getById( $id );
+		if ( $slf->getRecordCount() == 1 ) {
+			$ph = array(
+						'last_push_date' => $last_push_date,
+						'id' => $id,
+						);
+
+			$query = 'UPDATE '. $this->getTable() .' set last_push_date = ? where id = ?';
+			$this->db->Execute($query, $ph);
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	//Update JUST station allowed_date without affecting updated_date, and without creating an EDIT entry in the system_log.
+	function updateLastPartialPushDate( $id, $last_partial_push_date = 0 ) {
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		$slf = new StationListFactory();
+		$slf->getById( $id );
+		if ( $slf->getRecordCount() == 1 ) {
+			$ph = array(
+						'last_partial_push_date' => $last_partial_push_date,
+						'id' => $id,
+						);
+
+			$query = 'UPDATE '. $this->getTable() .' set last_partial_push_date = ? where id = ?';
+			$this->db->Execute($query, $ph);
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getLastPunchTimeStamp( $raw = FALSE) {
 		if ( isset($this->data['last_punch_time_stamp']) ) {
 			if ( $raw === TRUE ) {
@@ -1599,68 +1678,34 @@ class StationFactory extends Factory {
 
 		return TRUE;
 	}
-/*
-	function getUser() {
-		$sulf = new StationUserListFactory();
-		$sulf->getByStationId( $this->getId() );
-		foreach ($sulf as $station_user) {
-			$user_list[] = $station_user->getUser();
+
+	//Update JUST station allowed_date without affecting updated_date, and without creating an EDIT entry in the system_log.
+	function updateAllowedDate( $id, $user_id ) {
+		if ( $id == '' ) {
+			return FALSE;
 		}
 
-		if ( isset($user_list) ) {
-			return $user_list;
+		if ( $user_id == '' ) {
+			return FALSE;
 		}
 
-		return FALSE;
-	}
-	function setUser($ids) {
-		if (is_array($ids) and count($ids) > 0) {
-			if ( in_array(0, $ids ) ) {
-				Debug::text('All Users is selected: ', __FILE__, __LINE__, __METHOD__, 10);
-				$ids = array(0);
-			}
+		$slf = new StationListFactory();
+		$slf->getById( $id );
+		if ( $slf->getRecordCount() == 1 ) {
+			$ph = array(
+						'allowed_date' => TTDate::getTime(),
+						'id' => $id,
+						);
+			$query = 'UPDATE '. $this->getTable() .' set allowed_date = ? where id = ?';
+			$this->db->Execute($query, $ph);
 
-			//If needed, delete mappings first.
-			$sulf = new StationUserListFactory();
-			$sulf->getByStationId( $this->getId() );
-
-			$user_ids = array();
-			foreach ($sulf as $station_user) {
-				$user_id = $station_user->getUser();
-				Debug::text('Station ID: '. $station_user->getStation() .' User: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
-
-				//Delete users that are not selected.
-				if ( !in_array($user_id, $ids) ) {
-					Debug::text('Deleting StationUser: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
-					$station_user->Delete();
-				} else {
-					//Save branch ID's that need to be updated.
-					Debug::text('NOT Deleting StationUser: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
-					$user_ids[] = $user_id;
-				}
-			}
-
-			//Insert new mappings.
-			$suf = new StationUserFactory();
-			foreach ($ids as $id) {
-				if ( !in_array($id, $user_ids) ) {
-					$suf->setStation( $this->getId() );
-					$suf->setUser( $id );
-
-					if ($this->Validator->isTrue(		'user',
-														$suf->Validator->isValid(),
-														TTi18n::gettext('Incorrect Employee selection'))) {
-						$suf->save();
-					}
-				}
-			}
+			TTLog::addEntry( $id, 200,  TTi18n::getText('Access from station Allowed'), $user_id, $this->getTable() ); //Allow
 
 			return TRUE;
 		}
 
 		return FALSE;
 	}
-*/
 
 	function getAllowedDate() {
 		if ( isset($this->data['allowed_date']) ) {
@@ -1820,16 +1865,7 @@ class StationFactory extends Factory {
 
 			//Set last allowed date, so we can track active/inactive stations.
 			if ( $id != NULL AND $id != '' ) {
-				$slf = new StationListFactory();
-				$slf->getById( $id );
-				foreach ($slf as $station_obj) {
-					$station_obj->setAllowedDate();
-					$station_obj->Save();
-					Debug::text('Updating last allowed time for station.', __FILE__, __LINE__, __METHOD__, 10);
-				}
-				unset($slf, $station_obj);
-
-				TTLog::addEntry( $id, 'Allow',  TTi18n::getText('Access from station Allowed'), $user_id, $this->getTable() );
+				$this->updateAllowedDate( $id, $user_id );
 			}
 
 			return TRUE;
@@ -1998,7 +2034,9 @@ class StationFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Station'), NULL, $this->getTable() );
+		if ( !( $log_action == 10 AND $this->getType() == 10 ) ) {
+			return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Station'), NULL, $this->getTable(), $this );
+		}
 	}
 }
 ?>
