@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3091 $
- * $Id: StationListFactory.class.php 3091 2009-11-18 18:00:31Z ipso $
- * $Date: 2009-11-18 10:00:31 -0800 (Wed, 18 Nov 2009) $
+ * $Revision: 4073 $
+ * $Id: StationListFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -124,7 +124,7 @@ class StationListFactory extends StationFactory implements IteratorAggregate {
 			//$order = array( 'type_id' => 'asc', 'status_id' => 'asc', 'updated_date_null' => 'asc', 'updated_date' => 'desc', 'created_date' => 'desc' );
 			$query .= 'ORDER BY a.type_id asc, a.status_id asc, updated_date_null asc, updated_date desc, a.created_date desc';
 		} else {
-			$query .= $this->getSortSQL( $order );
+			$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 		}
 
 		if ($limit == NULL) {
@@ -244,6 +244,37 @@ class StationListFactory extends StationFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByStationIdAndStatusIdAndTypeId($station_id, $status_id, $type_id, $order = NULL) {
+		if ( $station_id == '') {
+			return FALSE;
+		}
+
+		if ( $status_id == '') {
+			return FALSE;
+		}
+
+		if ( $type_id == '') {
+			return FALSE;
+		}
+
+		$ph = array(
+					'station_id' => $station_id,
+					);
+
+		$query = '
+					select 	*
+					from 	'. $this->getTable() .'
+					where	station_id = ?
+						AND status_id in ('. $this->getListSQL($status_id, $ph) .')
+						AND type_id in ('. $this->getListSQL($type_id, $ph) .')
+						AND deleted = 0';
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getPendingSynchronizationByCompanyIdAndTypeId($company_id, $type_id, $order = NULL) {
 		if ( $company_id == '') {
 			return FALSE;
