@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: TTDate.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: TTDate.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -76,14 +76,15 @@ class TTDate {
 
 	static $day_of_week_arr = NULL;
 
-	static $month_of_year_arr = NULL;
+	static $long_month_of_year_arr = NULL;
+	static $short_month_of_year_arr = NULL;
 
 	function __construct() {
 		self::setTimeZone();
 	}
 
 	private function _get_month_short_names() {
-		// i18n: This private method is not called anywhere in the class.
+		// i18n: This private method is not called anywhere in the class. (it is now)
 		//       It's purpose is simply to ensure that the short (3 letter)
 		//       month forms are included in gettext() calls so that they
 		//       will be properly extracted for translation.
@@ -103,6 +104,36 @@ class TTDate {
 				);
 	}
 
+	private function _get_month_long_names() {
+		// i18n: It's purpose is simply to ensure that the short (3 letter)
+		//       month forms are included in gettext() calls so that they
+		//       will be properly extracted for translation.
+		return array (
+				1 => TTi18n::gettext('January'),
+				2 => TTi18n::gettext('February'),
+				3 => TTi18n::gettext('March'),
+				4 => TTi18n::gettext('April'),
+				5 => TTi18n::gettext('May'),
+				6 => TTi18n::gettext('June'),
+				7 => TTi18n::gettext('July'),
+				8 => TTi18n::gettext('August'),
+				9 => TTi18n::gettext('September'),
+				10 => TTi18n::gettext('October'),
+				11 => TTi18n::gettext('November'),
+				12 => TTi18n::gettext('December')
+				);
+	}
+
+	public static function isDST( $epoch = NULL ) {
+		if ( $epoch == NULL ) {
+			$epoch = TTDate::getTime();
+		}
+
+		$dst = date('I', $epoch);
+		//Debug::text('Epoch: '. TTDate::getDate('DATE+TIME', $epoch) .' DST: '. $dst, __FILE__, __LINE__, __METHOD__, 10);
+		return (bool)$dst;
+	}
+
 	public static function getTimeZone() {
 		return self::$time_zone;
 	}
@@ -215,6 +246,7 @@ class TTDate {
 			$tz = new Date_TimeZone( $timezone );
 
 			$new_timezone_offset = ( $tz->getOffset( $d ) / 1000 );
+			Debug::text('Converting time: '. $epoch .' to TimeZone: '. $timezone .' Offset: '. $new_timezone_offset, __FILE__, __LINE__, __METHOD__, 10);
 
 			return $epoch - ( $old_timezone_offset - $new_timezone_offset );
 		} catch (Exception $e) {
@@ -318,6 +350,11 @@ class TTDate {
 		}
 
 		if ( isset($seconds) ) {
+			if ( $seconds > 2147483646 ) {
+				Debug::text('ERROR: Parsing time unit format exceeds maximum 4 byte integer!', __FILE__, __LINE__, __METHOD__, 10);
+				$seconds = 2147483646;
+			}
+
 			return $seconds;
 		}
 
@@ -582,25 +619,18 @@ class TTDate {
 		return $retarr;
 	}
 
-	public static function getMonthOfYearArray() {
-        if ( is_array(self::$month_of_year_arr) == FALSE ) {
-			self::$month_of_year_arr = array(
-												1 => TTi18n::gettext('January'),
-												2 => TTi18n::gettext('February'),
-												3 => TTi18n::gettext('March'),
-												4 => TTi18n::gettext('April'),
-												5 => TTi18n::gettext('May'),
-												6 => TTi18n::gettext('June'),
-												7 => TTi18n::gettext('July'),
-												8 => TTi18n::gettext('August'),
-												9 => TTi18n::gettext('September'),
-												10 => TTi18n::gettext('October'),
-												11 => TTi18n::gettext('November'),
-												12 => TTi18n::gettext('December')
-				);
-        }
-
-		return self::$month_of_year_arr;
+	public static function getMonthOfYearArray( $short_name = FALSE) {
+		if ( $short_name == TRUE ) {
+			if ( is_array(self::$short_month_of_year_arr) == FALSE ) {
+				self::$short_month_of_year_arr = self::_get_month_short_names();
+			}
+			return self::$short_month_of_year_arr;
+		} else {
+			if ( is_array(self::$long_month_of_year_arr) == FALSE ) {
+				self::$long_month_of_year_arr = self::_get_month_long_names();
+			}
+			return self::$long_month_of_year_arr;
+		}
 	}
 
 	public static function getDayOfWeekArray( $translation = TRUE ) {
@@ -642,6 +672,9 @@ class TTDate {
 			return $retval;
 		}
 	}
+	public static function getDayOfWeekName( $dow ) {
+		return self::getDayOfWeekByInt( $dow );
+	}
 
 	public static function getDayOfYear( $epoch ) {
 		return date('z', $epoch);
@@ -695,6 +728,16 @@ class TTDate {
 
 		return FALSE;
 	}
+	public static function getDSTOffset( $start_epoch, $end_epoch ) {
+		Debug::text('Start Epoch: '. TTDate::getDate('DATE+TIME', $start_epoch) .'('.date('I', $start_epoch).')  End Epoch: '. TTDate::getDate('DATE+TIME', $end_epoch) .'('.date('I', $end_epoch).')', __FILE__, __LINE__, __METHOD__, 10);
+		if ( date('I', $start_epoch) == 0 AND date('I', $end_epoch) == 1 ) {
+			return -3600; //DST==TRUE: Spring - Spring ahead an hour, which means we minus one hour from the offset.
+		} elseif ( date('I', $start_epoch) == 1 AND date('I', $end_epoch) == 0 ) {
+			return 3600; //DST==FALSE: Fall - Fall back an hour, which means we add one hour to the offset
+		}
+
+		return 0;
+	}
 
 	public static function getTime() {
 		return time();
@@ -728,6 +771,32 @@ class TTDate {
 		return date('z', $epoch);
 	}
 
+	public static function incrementDate( $epoch, $amount, $unit ) {
+		$date_arr = getdate($epoch);
+
+		//Unit: minute, hour, day
+		switch ( $unit ) {
+			case 'minute':
+				$retval = mktime( $date_arr['hours'], ($date_arr['minutes']+$amount), 0, $date_arr['mon'], $date_arr['mday'], $date_arr['year'] );
+				break;
+			case 'hour':
+				$retval = mktime( ($date_arr['hours']+$amount), $date_arr['minutes'], 0, $date_arr['mon'], $date_arr['mday'], $date_arr['year'] );
+				break;
+			case 'day':
+				$retval = mktime( $date_arr['hours'], $date_arr['minutes'], 0, $date_arr['mon'], ($date_arr['mday']+$amount), $date_arr['year'] );
+				break;
+			case 'month':
+				$retval = mktime( $date_arr['hours'], $date_arr['minutes'], 0, ($date_arr['mon']+$amount), $date_arr['mday'], $date_arr['year'] );
+				break;
+			case 'year':
+				$retval = mktime( $date_arr['hours'], $date_arr['minutes'], 0, $date_arr['mon'], $date_arr['mday'], ($date_arr['year']+$amount) );
+				break;
+		}
+
+		return $retval;
+
+	}
+
 	public static function snapTime($epoch, $snap_to_epoch, $snap_type) {
 		Debug::text('Epoch: '. $epoch .' ('.TTDate::getDate('DATE+TIME', $epoch).') Snap Epoch: '. $snap_to_epoch .' ('.TTDate::getDate('DATE+TIME', $snap_to_epoch).') Snap Type: '. $snap_type, __FILE__, __LINE__, __METHOD__, 10);
 
@@ -1009,6 +1078,34 @@ class TTDate {
 		return $retval;
 	}
 
+
+	//Returns the month of the quarter that the date falls in.
+	//Used for government forms that require a break down for each month in the quarter.
+	public static function getYearQuarterMonth( $epoch = NULL ) {
+		$year_quarter_months = array(
+									1 => 1,
+									2 => 2,
+									3 => 3,
+									4 => 1,
+									5 => 2,
+									6 => 3,
+									7 => 1,
+									8 => 2,
+									9 => 3,
+									10 => 1,
+									11 => 2,
+									12 => 3,
+								);
+
+		$month = TTDate::getMonth( $epoch );
+
+		if ( isset($year_quarter_months[$month]) ) {
+			return $year_quarter_months[$month];
+		}
+
+		return FALSE;
+	}
+
 	public static function getYearQuarter( $epoch = NULL ) {
 		if ($epoch == NULL OR $epoch == '' OR !is_numeric($epoch) ) {
 			$epoch = self::getTime();
@@ -1016,9 +1113,32 @@ class TTDate {
 
 		$quarter = ceil( date('n', $epoch ) / 3 );
 
-		Debug::text('Date: '. TTDate::getDate('DATE+TIME', $epoch ) .' is in quarter: '. $quarter, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::text('Date: '. TTDate::getDate('DATE+TIME', $epoch ) .' is in quarter: '. $quarter, __FILE__, __LINE__, __METHOD__,10);
 		return $quarter;
 	}
+	public static function getYearQuarters( $epoch = NULL, $quarter = NULL ) {
+		if ($epoch == NULL OR $epoch == '' OR !is_numeric($epoch) ) {
+			$epoch = self::getTime();
+		}
+
+		$year = TTDate::getYear( $epoch );
+		$quarter_dates = array(
+								1 => array( 'start' => mktime(0,0,0,1,1, $year ),'end' => mktime(0,0,-1,4,1, $year ) ),
+								2 => array( 'start' => mktime(0,0,0,4,1, $year ),'end' => mktime(0,0,-1,7,1, $year ) ),
+								3 => array( 'start' => mktime(0,0,0,7,1, $year ),'end' => mktime(0,0,-1,10,1, $year ) ),
+								4 => array( 'start' => mktime(0,0,0,10,1, $year ),'end' => mktime(0,0,-1,13,1, $year ) ),
+								);
+
+		if ( $quarter != '' ) {
+			if ( isset($quarter_dates[$quarter]) ) {
+				$quarter_dates = $quarter_dates[$quarter];
+			} else {
+				return FALSE;
+			}
+		}
+
+		return $quarter_dates;
+	}
 
 	public static function getDateOfNextDayOfWeek($anchor_epoch, $day_of_week_epoch) {
 		//Anchor Epoch is the anchor date to start searching from.
@@ -1242,6 +1362,15 @@ class TTDate {
 
 		return date('n', $epoch);
 	}
+	public static function getMonthName( $month, $short_name = FALSE ) {
+		$month = (int)$month;
+		$month_names = self::getMonthOfYearArray( $short_name );
+		if ( isset($month_names[$month])) {
+			return $month_names[$month];
+		}
+
+		return FALSE;
+	}
 
 	public static function getDayOfMonth( $epoch = NULL ) {
 		if ($epoch == NULL OR $epoch == '') {
@@ -1625,63 +1754,60 @@ class TTDate {
 
 	// Function to return "13 mins ago" text from a given time.
 	public static function getHumanTimeSince($epoch) {
-        if (time() >= $epoch) {
+        if ( time() >= $epoch ) {
+            $epoch_since = time() - $epoch;
+		} else {
+			$epoch_since = $epoch - time();
+		}
 
-                $epoch_since = time() - $epoch;
-				//Debug::text(' Epoch Since: '. $epoch_since, __FILE__, __LINE__, __METHOD__,10);
-                switch (true) {
+		//Debug::text(' Epoch Since: '. $epoch_since, __FILE__, __LINE__, __METHOD__,10);
+		switch ( TRUE ) {
+			case ($epoch_since > 31536000):
+					//Years
+					$num = ( ( ( ( ($epoch_since / 60) / 60) / 24 ) / 30 )  / 12 );
+					$suffix = TTi18n::gettext('yr');
+					break;
+			//case ($epoch_since > 2592000):
+			case ($epoch_since > ((3600 * 24) * 60)):
+					//Months the above number should be 2 months, so we don't get 0 months showing up.
+					$num = ( ( ( ( ($epoch_since / 60) / 60) / 24 ) / 30 ) );
+					$suffix = TTi18n::gettext('mth');
+					break;
+			case ($epoch_since > 604800):
+					//Weeks
+					$num = ( ( ( ($epoch_since / 60) / 60) / 24 ) / 7 ) ;
+					$suffix = TTi18n::gettext('wk');
+					break;
+			case ($epoch_since > 86400):
+					//Days
+					$num = ( ( ($epoch_since / 60) / 60) / 24 );
+					$suffix = TTi18n::gettext('day');
+					break;
+			case ($epoch_since > 3600):
+					//Hours
+					$num = ( ($epoch_since / 60) / 60);
+					$suffix = TTi18n::gettext('hr');
 
-                        case ($epoch_since > 31536000):
-                                //Years
-                                $num = ( ( ( ( ($epoch_since / 60) / 60) / 24 ) / 30 )  / 12 );
-                                $suffix = TTi18n::gettext('yr');
-                                break;
-                        //case ($epoch_since > 2592000):
-                        case ($epoch_since > ((3600 * 24) * 60)):
-                                //Months the above number should be 2 months, so we don't get 0 months showing up.
-                                $num = ( ( ( ( ($epoch_since / 60) / 60) / 24 ) / 30 ) );
-                                $suffix = TTi18n::gettext('mth');
-                                break;
-                        case ($epoch_since > 604800):
-                                //Weeks
-                                $num = ( ( ( ($epoch_since / 60) / 60) / 24 ) / 7 ) ;
-                                $suffix = TTi18n::gettext('wk');
-                                break;
-                        case ($epoch_since > 86400):
-                                //Days
-                                $num = ( ( ($epoch_since / 60) / 60) / 24 );
-                                $suffix = TTi18n::gettext('day');
-                                break;
-                        case ($epoch_since > 3600):
-                                //Hours
-                                $num = ( ($epoch_since / 60) / 60);
-                                $suffix = TTi18n::gettext('hr');
+					break;
+			case ($epoch_since > 60):
+					//Mins
+					$num = ($epoch_since / 60);
+					$suffix = TTi18n::gettext('min');
+					break;
+			default:
+					//Secs
+					$num = $epoch_since;
+					$suffix = TTi18n::gettext('sec');
 
-                                break;
-                        case ($epoch_since > 60):
-                                //Mins
-                                $num = ($epoch_since / 60);
-                                $suffix = TTi18n::gettext('min');
-                                break;
-                        default:
-                                //Secs
-                                $num = $epoch_since;
-                                $suffix = TTi18n::gettext('sec');
+					break;
+		}
 
-                                break;
+		if ( $num > 1 ) {
+			$suffix .= TTi18n::gettext('s');
+		}
 
-                }
-
-				if ( $num > 1 ) {
-					$suffix .= TTi18n::gettext('s');
-				}
-
-				//Debug::text(' Num: '. $num .' Suffix: '. $suffix, __FILE__, __LINE__, __METHOD__,10);
-                return sprintf("%0.01f",$num)." ".$suffix;
-        } else {
-			Debug::text(' Returning False', __FILE__, __LINE__, __METHOD__,10);
-            return FALSE;
-        }
+		//Debug::text(' Num: '. $num .' Suffix: '. $suffix, __FILE__, __LINE__, __METHOD__,10);
+		return sprintf("%0.01f", $num)." ".$suffix;
 	}
 
 	//Runs strtotime over a string, but if it happens to be an epoch, strtotime
@@ -1709,6 +1835,516 @@ class TTDate {
 
 		return TRUE;
 	}
+
+	public static function getTimePeriodOptions( $include_pay_period = TRUE ) {
+		$retarr = array(
+						'-1000-custom_date' => TTi18n::gettext('Custom Dates'), // Select Start/End dates from calendar.
+						//'-1005-custom_time' => TTi18n::gettext('Custom Date/Time'), // Select Start/End dates & time from calendar.
+						//'-1008-custom_pay_period' => TTi18n::gettext('Custom Pay Periods'), //Select pay periods individually
+						'-1010-today' => TTi18n::gettext('Today'),
+						'-1020-yesterday' => TTi18n::gettext('Yesterday'),
+						'-1030-last_24_hours' => TTi18n::gettext('Last 24 Hours'),
+						'-1032-last_48_hours' => TTi18n::gettext('Last 48 Hours'),
+						'-1034-last_72_hours' => TTi18n::gettext('Last 72 Hours'),
+
+						'-1100-this_week' => TTi18n::gettext('This Week'),
+						'-1110-last_week' => TTi18n::gettext('Last Week'),
+						'-1112-last_2_weeks' => TTi18n::gettext('Last 2 Weeks'),
+						'-1120-last_7_days' => TTi18n::gettext('Last 7 Days'),
+						'-1122-last_14_days' => TTi18n::gettext('Last 14 Days'),
+
+						'-1200-this_pay_period' => TTi18n::gettext('This Pay Period'), //Select one or more pay period schedules
+						'-1210-last_pay_period' => TTi18n::gettext('Last Pay Period'), //Select one or more pay period schedules
+
+						'-1300-this_month' => TTi18n::gettext('This Month'),
+						'-1310-last_month' => TTi18n::gettext('Last Month'),
+						'-1312-last_2_months' => TTi18n::gettext('Last 2 Months'),
+						'-1320-last_30_days' => TTi18n::gettext('Last 30 Days'),
+						'-1320-last_60_days' => TTi18n::gettext('Last 60 Days'),
+
+						'-1400-this_quarter' => TTi18n::gettext('This Quarter'),
+						'-1410-last_quarter' => TTi18n::gettext('Last Quarter'),
+						'-1420-last_90_days' => TTi18n::gettext('Last 90 Days'),
+						'-1430-this_year_1st_quarter' => TTi18n::gettext('1st Quarter (This Year)'),
+						'-1440-this_year_2nd_quarter' => TTi18n::gettext('2nd Quarter (This Year)'),
+						'-1450-this_year_3rd_quarter' => TTi18n::gettext('3rd Quarter (This Year)'),
+						'-1460-this_year_4th_quarter' => TTi18n::gettext('4th Quarter (This Year)'),
+						'-1470-last_year_1st_quarter' => TTi18n::gettext('1st Quarter (Last Year)'),
+						'-1480-last_year_2nd_quarter' => TTi18n::gettext('2nd Quarter (Last Year)'),
+						'-1490-last_year_3rd_quarter' => TTi18n::gettext('3rd Quarter (Last Year)'),
+						'-1500-last_year_4th_quarter' => TTi18n::gettext('4th Quarter (Last Year)'),
+
+						'-1600-last_3_months' => TTi18n::gettext('Last 3 Months'),
+						'-1610-last_6_months' => TTi18n::gettext('Last 6 Months'),
+						'-1620-last_9_months' => TTi18n::gettext('Last 9 Months'),
+						'-1630-last_12_months' => TTi18n::gettext('Last 12 Months'),
+
+						'-1700-this_year' => TTi18n::gettext('This Year (Year-To-Date)'),
+						'-1710-last_year' => TTi18n::gettext('Last Year'),
+						'-1990-all_years' => TTi18n::gettext('All Years'),
+					   );
+		return $retarr;
+	}
+	public static function getTimePeriodDates( $time_period, $epoch = NULL, $user_obj = NULL, $params = NULL ) {
+		$time_period = Misc::trimSortPrefix( $time_period );
+
+		if ($epoch == NULL OR $epoch == '' OR !is_numeric($epoch) ) {
+			$epoch = self::getTime();
+		}
+
+		$start_week_day = 0;
+		if ( is_object( $user_obj ) ) {
+			$user_prefs = $user_obj->getUserPreferenceObject();
+			if ( is_object($user_prefs) ) {
+				$start_week_day = $user_prefs->getStartWeekDay();
+			}
+		}
+
+		switch( $time_period ) {
+			case 'custom_date':
+				//Params must pass start_date/end_date
+				if ( isset($params['start_date']) ) {
+					$start_date = TTDate::getBeginDayEpoch( $params['start_date'] );
+				}
+				if ( isset($params['end_date']) ) {
+					$end_date = TTDate::getEndDayEpoch( $params['end_date'] );
+				}
+				break;
+			case 'custom_time':
+				//Params must pass start_date/end_date
+				if ( isset($params['start_date']) ) {
+					$start_date = $params['start_date'];
+				}
+				if ( isset($params['end_date']) ) {
+					$end_date = $params['end_date'];
+				}
+				break;
+
+			case 'today':
+				$start_date = TTDate::getBeginDayEpoch( $epoch );
+				$end_date = TTDate::getEndDayEpoch( $epoch );
+				break;
+			case 'yesterday':
+				$start_date = TTDate::getBeginDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				break;
+			case 'last_24_hours':
+				$start_date = $epoch-86400;
+				$end_date = $epoch;
+				break;
+			case 'last_48_hours':
+				$start_date = $epoch-(86400*2);
+				$end_date = $epoch;
+				break;
+			case 'last_72_hours':
+				$start_date = $epoch-(86400*3);
+				$end_date = $epoch;
+				break;
+			case 'this_week':
+				$start_date = TTDate::getBeginWeekEpoch( $epoch, $start_week_day );
+				$end_date = TTDate::getEndWeekEpoch( $epoch, $start_week_day );
+				break;
+			case 'last_week':
+				$start_date = TTDate::getBeginWeekEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*7)), $start_week_day );
+				$end_date = TTDate::getEndWeekEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*7)), $start_week_day );
+				break;
+			case 'last_2_weeks':
+				$start_date = TTDate::getBeginWeekEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*14)), $start_week_day );
+				$end_date = TTDate::getEndWeekEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*7)), $start_week_day );
+				break;
+			case 'last_7_days':
+				$start_date = TTDate::getBeginDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*7) ) );
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				break;
+			case 'last_14_days':
+				$start_date = TTDate::getBeginDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*14) ) );
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				break;
+
+			//Params must be passed if more than one pay period schedule exists.
+			case 'this_pay_period':
+			case 'last_pay_period':
+				Debug::text('Time Period for Pay Period Schedule selected...', __FILE__, __LINE__, __METHOD__,10);
+				//Make sure user_obj is set.
+				if ( !is_object( $user_obj ) ) {
+					Debug::text('User Object was not passsed...', __FILE__, __LINE__, __METHOD__,10);
+					break;
+				}
+
+				if ( !isset($params['pay_period_schedule_id']) ) {
+					$params['pay_period_schedule_id'] = NULL;
+				}
+
+				$pay_period_ids = array();
+
+				//Since we allow multiple pay_period schedules to be selected, we have to return pay_period_ids, not start/end dates.
+				if ( $time_period == 'this_pay_period' ) {
+					Debug::text('this_pay_period', __FILE__, __LINE__, __METHOD__,10);
+					$pplf = new PayPeriodListFactory();
+					$pplf->getThisPayPeriodByCompanyIdAndPayPeriodScheduleIdAndDate( $user_obj->getCompany(), $params['pay_period_schedule_id'], time() );
+					if ( $pplf->getRecordCount() > 0 ) {
+						foreach( $pplf as $pp_obj ) {
+							$pay_period_ids[] = $pp_obj->getId();
+						}
+					}
+				} elseif ( $time_period == 'last_pay_period' ) {
+					Debug::text('last_pay_period', __FILE__, __LINE__, __METHOD__,10);
+					$pplf = new PayPeriodListFactory();
+					$pplf->getLastPayPeriodByCompanyIdAndPayPeriodScheduleIdAndDate( $user_obj->getCompany(), $params['pay_period_schedule_id'], time() );
+					if ( $pplf->getRecordCount() > 0 ) {
+						foreach( $pplf as $pp_obj ) {
+							$pay_period_ids[] = $pp_obj->getId();
+						}
+					}
+				}
+				Debug::Arr($pay_period_ids, 'aPay Period IDs: ('. (int)$pplf->getRecordCount().')', __FILE__, __LINE__, __METHOD__,10);
+				break;
+			case 'this_month':
+				$start_date = TTDate::getBeginMonthEpoch( $epoch );
+				$end_date = TTDate::getEndMonthEpoch( $epoch );
+				break;
+			case 'last_month':
+				$start_date = TTDate::getBeginMonthEpoch( (TTDate::getBeginMonthEpoch( $epoch )-86400) );
+				$end_date = TTDate::getEndMonthEpoch( (TTDate::getBeginMonthEpoch( $epoch )-86400) );
+				break;
+			case 'last_2_months':
+				$start_date = TTDate::getBeginMonthEpoch( (TTDate::getBeginMonthEpoch( $epoch )-(86400*32)) );
+				$end_date = TTDate::getEndMonthEpoch( (TTDate::getBeginMonthEpoch( $epoch )-86400) );
+				break;
+			case 'last_30_days':
+				$start_date = TTDate::getBeginDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*30) ) );
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				break;
+			case 'last_60_days':
+				$start_date = TTDate::getBeginDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*60) ) );
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				break;
+			case 'this_quarter':
+				$quarter = TTDate::getYearQuarter( $epoch );
+				$quarter_dates = TTDate::getYearQuarters( $epoch, $quarter );
+				Debug::Arr($quarter_dates, 'Quarter Dates: Quarter: '. $quarter, __FILE__, __LINE__, __METHOD__,10);
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'last_quarter':
+				$quarter = TTDate::getYearQuarter( $epoch )-1;
+				if ( $quarter == 0 ) {
+					$quarter = 4;
+				}
+				$quarter_dates = TTDate::getYearQuarters( $epoch, $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'last_90_days':
+				$start_date = TTDate::getBeginDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-(86400*90) ) );
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				break;
+			case 'this_year_1st_quarter':
+				$quarter = 1;
+				$quarter_dates = TTDate::getYearQuarters( $epoch, $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'this_year_2nd_quarter':
+				$quarter = 2;
+				$quarter_dates = TTDate::getYearQuarters( $epoch, $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'this_year_3rd_quarter':
+				$quarter = 3;
+				$quarter_dates = TTDate::getYearQuarters( $epoch, $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'this_year_4th_quarter':
+				$quarter = 4;
+				$quarter_dates = TTDate::getYearQuarters( $epoch, $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'last_year_1st_quarter':
+				$quarter = 1;
+				$quarter_dates = TTDate::getYearQuarters( (TTDate::getBeginYearEpoch( $epoch )-86400), $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'last_year_2nd_quarter':
+				$quarter = 2;
+				$quarter_dates = TTDate::getYearQuarters( (TTDate::getBeginYearEpoch( $epoch )-86400), $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'last_year_3rd_quarter':
+				$quarter = 3;
+				$quarter_dates = TTDate::getYearQuarters( (TTDate::getBeginYearEpoch( $epoch )-86400), $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+			case 'last_year_4th_quarter':
+				$quarter = 4;
+				$quarter_dates = TTDate::getYearQuarters( (TTDate::getBeginYearEpoch( $epoch )-86400), $quarter );
+
+				$start_date = $quarter_dates['start'];
+				$end_date = $quarter_dates['end'];
+				break;
+
+			case 'last_3_months':
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date )-3, TTDate::getDayOfMonth( $end_date ), TTDate::getYear( $end_date ) );
+				break;
+			case 'last_6_months':
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date )-6, TTDate::getDayOfMonth( $end_date ), TTDate::getYear( $end_date ) );
+				break;
+			case 'last_9_months':
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date )-9, TTDate::getDayOfMonth( $end_date ), TTDate::getYear( $end_date ) );
+				break;
+			case 'last_12_months':
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date), TTDate::getDayOfMonth( $end_date ), (TTDate::getYear( $end_date )-1) );
+				break;
+			case 'this_year':
+				$start_date = TTDate::getBeginYearEpoch( $epoch );
+				$end_date = TTDate::getEndYearEpoch( $epoch );
+				break;
+			case 'last_year':
+				$start_date = TTDate::getBeginYearEpoch( (TTDate::getBeginYearEpoch( $epoch )-86400) );
+				$end_date = TTDate::getEndYearEpoch( (TTDate::getBeginYearEpoch( $epoch )-86400) );
+				break;
+			case 'all_years':
+				$start_date = TTDate::getBeginYearEpoch( (TTDate::getBeginYearEpoch( 31564800 )-86400) );
+				$end_date = TTDate::getEndYearEpoch( time()+(86400*(365*2)) );
+				break;
+			default:
+				break;
+		}
+
+		if ( isset($start_date) AND isset($end_date) ) {
+			Debug::text('Period: '. $time_period .' Start: '. TTDate::getDate('DATE+TIME', $start_date ) .'('.$start_date.') End: '. TTDate::getDate('DATE+TIME', $end_date ) .'('.$end_date.')', __FILE__, __LINE__, __METHOD__,10);
+
+			return array('start_date' => $start_date, 'end_date' => $end_date );
+		} elseif ( isset($pay_period_ids) ) {
+			Debug::text('Period: '. $time_period .' returning just pay_period_ids...', __FILE__, __LINE__, __METHOD__,10);
+			return array('pay_period_id' => $pay_period_ids );
+		}
+
+		return FALSE;
+	}
+
+	public static function getReportDateOptions( $column_name_prefix = NULL, $column_name = NULL, $sort_prefix = NULL, $include_pay_period = TRUE ) {
+		if ( $sort_prefix == '' ) {
+			$sort_prefix = 19;
+		}
+
+		if ( $column_name == '' ) {
+			$column_name = TTi18n::gettext('Date');
+		}
+
+		if ( $column_name_prefix != '' ) {
+			$column_name_prefix .= '-';
+		}
+
+		$retarr = array(
+						'-'.$sort_prefix.'00-'. $column_name_prefix .'date_stamp' 				=> $column_name,
+						'-'.$sort_prefix.'01-'. $column_name_prefix .'time_stamp' 				=> $column_name.' - '. TTi18n::gettext('Time of Day'),
+						'-'.$sort_prefix.'01-'. $column_name_prefix .'date_time_stamp' 			=> $column_name.' - '. TTi18n::gettext('w/Time'),
+
+						'-'.$sort_prefix.'10-'. $column_name_prefix .'date_dow' 				=> $column_name.' - '. TTi18n::gettext('Day of Week'),
+						'-'.$sort_prefix.'12-'. $column_name_prefix .'date_dow_week' 			=> $column_name.' - '. TTi18n::gettext('Day of Week+Week'),
+						'-'.$sort_prefix.'14-'. $column_name_prefix .'date_dow_month' 			=> $column_name.' - '. TTi18n::gettext('Day of Week+Month'),
+						'-'.$sort_prefix.'16-'. $column_name_prefix .'date_dow_month_year'		=> $column_name.' - '. TTi18n::gettext('Day of Week+Month+Year'),
+
+						'-'.$sort_prefix.'20-'. $column_name_prefix .'date_week' 				=> $column_name.' - '. TTi18n::gettext('Week'),
+						'-'.$sort_prefix.'22-'. $column_name_prefix .'date_week_month' 			=> $column_name.' - '. TTi18n::gettext('Week+Month'),
+						'-'.$sort_prefix.'24-'. $column_name_prefix .'date_week_month_year'		=> $column_name.' - '. TTi18n::gettext('Week+Month+Year'),
+
+						'-'.$sort_prefix.'30-'. $column_name_prefix .'date_dom' 				=> $column_name.' - '. TTi18n::gettext('Day of Month'),
+						'-'.$sort_prefix.'32-'. $column_name_prefix .'date_dom_month' 			=> $column_name.' - '. TTi18n::gettext('Day of Month+Month'),
+						'-'.$sort_prefix.'34-'. $column_name_prefix .'date_dom_month_year' 		=> $column_name.' - '. TTi18n::gettext('Day of Month+Month+Year'),
+
+						'-'.$sort_prefix.'40-'. $column_name_prefix .'date_month' 				=> $column_name.' - '. TTi18n::gettext('Month'),
+						'-'.$sort_prefix.'42-'. $column_name_prefix .'date_month_year'		 	=> $column_name.' - '. TTi18n::gettext('Month+Year'),
+
+						'-'.$sort_prefix.'50-'. $column_name_prefix .'date_quarter' 			=> $column_name.' - '. TTi18n::gettext('Quarter'),
+						'-'.$sort_prefix.'52-'. $column_name_prefix .'date_quarter_year'	 	=> $column_name.' - '. TTi18n::gettext('Quarter+Year'),
+
+						'-'.$sort_prefix.'60-'. $column_name_prefix .'date_year' 				=> $column_name.' - '. TTi18n::gettext('Year'),
+					   );
+
+		if ( $include_pay_period == TRUE ) {
+			$pay_period_arr = array(
+						'-'.$sort_prefix.'70-'. $column_name_prefix .'pay_period' 				=> $column_name.' - '. TTi18n::gettext('Pay Period'),
+						'-'.$sort_prefix.'71-'. $column_name_prefix .'pay_period_start_date' 	=> $column_name.' - '. TTi18n::gettext('Pay Period - Start Date'),
+						'-'.$sort_prefix.'72-'. $column_name_prefix .'pay_period_end_date' 		=> $column_name.' - '. TTi18n::gettext('Pay Period - End Date'),
+						'-'.$sort_prefix.'73-'. $column_name_prefix .'pay_period_transaction_date' => $column_name.' - '. TTi18n::gettext('Pay Period - Transaction Date'),
+					);
+			$retarr = array_merge( $retarr, $pay_period_arr );
+		}
+
+		return $retarr;
+	}
+
+	public static function getReportDates( $column, $epoch = NULL, $post_processing = TRUE, $user_obj = NULL, $params = NULL ) {
+		$column = Misc::trimSortPrefix( $column );
+
+		//Trim off a column_name_prefix, or everything before the "-"
+		$tmp_column = explode( '-', $column );
+		if ( isset($tmp_column[1]) ) {
+			$column = $tmp_column[1];
+		}
+
+		if ($epoch == NULL OR $epoch == '' ) { //Epoch can be a string sometimes.
+			$epoch = self::getTime();
+		}
+
+		$start_week_day = 0;
+		if ( is_object( $user_obj ) ) {
+			$user_prefs = $user_obj->getUserPreferenceObject();
+			if ( is_object($user_prefs) ) {
+				$start_week_day = $user_prefs->getStartWeekDay();
+			}
+		}
+
+		if ( $post_processing == TRUE ) {
+			//Human friendly display, NOT for sorting.
+			switch( $column ) {
+				case 'pay_period_start_date':
+				case 'pay_period_end_date':
+				case 'pay_period_transaction_date':
+					if ( isset($params['include_pay_period_dates']) AND $params['include_pay_period_dates'] == FALSE ) {
+						$retval = NULL;
+					} else {
+						$retval = TTDate::getDate( 'DATE', $epoch );
+					}
+					break;
+				case 'date_stamp':
+					$retval = TTDate::getDate( 'DATE', strtotime($epoch) );
+					break;
+				case 'time_stamp':
+					$retval = TTDate::getDate( 'TIME', $epoch );
+					break;
+				case 'date_time_stamp':
+					$retval = TTDate::getDate( 'DATE+TIME', $epoch );
+					break;
+				case 'date_dow':
+					//$retval = date('D', $epoch);
+					$retval = TTDate::getDayOfWeekName( $epoch );
+					break;
+				case 'date_dow_week':
+					$split_epoch = explode('-', $epoch);
+					$retval = TTDate::getDayOfWeekName( $split_epoch[1] ).' '.$split_epoch[0];
+					break;
+				case 'date_dow_month':
+					$split_epoch = explode('-', $epoch);
+					$retval = TTDate::getDayOfWeekName( $split_epoch[1] ).'-'.TTDate::getMonthName( $split_epoch[0] );
+					break;
+				case 'date_dow_month_year':
+					$split_epoch = explode('-', $epoch);
+					$retval = TTDate::getDayOfWeekName( $split_epoch[2] ).'-'.TTDate::getMonthName( $split_epoch[1] ).'-'.$split_epoch[0];
+					break;
+				case 'date_week':
+					$retval = $epoch;
+					break;
+				case 'date_week_month':
+					$split_epoch = explode('-', $epoch);
+					$retval = $split_epoch[1].' '.TTDate::getMonthName( $split_epoch[0] );
+					break;
+				case 'date_week_month_year':
+					$split_epoch = explode('-', $epoch);
+					$retval = $split_epoch[2].' '.TTDate::getMonthName( $split_epoch[1] ).'-'.$split_epoch[0];
+					break;
+				case 'date_dom':
+					$retval = $epoch;
+					break;
+				case 'date_dom_month':
+					$split_epoch = explode('-', $epoch);
+					$retval = $split_epoch[1].'-'.TTDate::getMonthName( $split_epoch[0] );
+					break;
+				case 'date_dom_month_year':
+					$split_epoch = explode('-', $epoch);
+					$retval = $split_epoch[2].'-'.TTDate::getMonthName( $split_epoch[1], TRUE ).'-'.$split_epoch[0];
+					break;
+				case 'date_month':
+					$retval = TTDate::getMonthName( $epoch );
+					break;
+				case 'date_month_year':
+					$split_epoch = explode('-', $epoch);
+					$retval = TTDate::getMonthName( $split_epoch[1] ).'-'.$split_epoch[0];
+					break;
+				case 'date_quarter':
+					$retval = $epoch;
+					break;
+				case 'date_quarter_year':
+					$split_epoch = explode('-', $epoch);
+					$retval = $split_epoch[1].'-'.$split_epoch[0];
+					break;
+				case 'date_year':
+					$retval = $epoch;
+					break;
+				case 'pay_period':
+					$retval = $params;
+					break;
+				default:
+					Debug::text('Date Column does not match!: '. $column, __FILE__, __LINE__, __METHOD__,10);
+					break;
+			}
+			//Debug::text('Column: '. $column .' Input: '. $epoch .' Retval: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+		} else {
+			//Return data for *all* columns at once.
+			if ($epoch == NULL OR $epoch == '' OR !is_numeric($epoch) ) { //Epoch must be numeric
+				$epoch = self::getTime();
+			}
+
+			$column_prefix = NULL;
+			if ( $column != '' ) {
+				$column_prefix = $column.'-';
+			}
+			$retval = array(
+				$column_prefix.'date_stamp' => date('Y-m-d', $epoch ),
+				$column_prefix.'time_stamp' => $epoch,
+				$column_prefix.'date_time_stamp' => $epoch,
+				$column_prefix.'date_dow' => date('w', $epoch),
+				$column_prefix.'date_dow_week' => date('W-w', $epoch ),
+				$column_prefix.'date_dow_month' => date('m-w', $epoch ),
+				$column_prefix.'date_dow_month_year' => date('Y-m-w', $epoch ),
+				$column_prefix.'date_week' => date('W', $epoch ),
+				$column_prefix.'date_week_month' => date('m-W', $epoch ),
+				$column_prefix.'date_week_month_year' => date('Y-m-W', $epoch ),
+				$column_prefix.'date_dom' => date('d', $epoch ),
+				$column_prefix.'date_dom_month' => date('m-d', $epoch ),
+				$column_prefix.'date_dom_month_year' => date('Y-m-d', $epoch ),
+				$column_prefix.'date_month' => date('m', $epoch ),
+				$column_prefix.'date_month_year' => date('Y-m', $epoch ),
+				$column_prefix.'date_quarter' => TTDate::getYearQuarter( $epoch ),
+				$column_prefix.'date_quarter_year' => date('Y', $epoch).'-'.TTDate::getYearQuarter( $epoch ),
+				$column_prefix.'date_year' => TTDate::getYear( $epoch ),
+			);
+
+			if ( !isset($params['include_pay_period_dates']) OR $params['include_pay_period_dates'] == TRUE ) {
+				$retval[$column_prefix.'pay_period_start_date'] = $epoch;
+				$retval[$column_prefix.'pay_period_end_date'] = $epoch;
+				$retval[$column_prefix.'pay_period_transaction_date'] = $epoch;
+			}
+		}
+
+		if ( isset( $retval ) ) {
+			return $retval;
+		}
+
+		return FALSE;
+	}
+
 }
 
 ?>
