@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,21 +34,27 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: TTLog.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4000 $
+ * $Id: TTLog.class.php 4000 2010-11-30 17:13:27Z ipso $
+ * $Date: 2010-11-30 09:13:27 -0800 (Tue, 30 Nov 2010) $
  */
 
 /**
  * @package Core
  */
 class TTLog {
-	static function addEntry( $object_id, $action_id, $description, $user_id, $table ) {
+	static function addEntry( $object_id, $action_id, $description, $user_id, $table, $object = NULL ) {
+		global $config_vars;
+		
+		if ( isset($config_vars['other']['disable_audit_log']) AND $config_vars['other']['disable_audit_log'] == TRUE ) {
+			return TRUE;
+		}
+
 		if ( !is_numeric($object_id) ) {
 			return FALSE;
 		}
 
-		if ($action_id == '') {
+		if ( $action_id == '' ) {
 			return FALSE;
 		}
 
@@ -75,7 +81,17 @@ class TTLog {
 
 		//Debug::text('Object ID: '. $object_id .' Action ID: '. $action_id .' Table: '. $table .' Description: '. $description, __FILE__, __LINE__, __METHOD__, 10);
 		if ( $lf->isValid() === TRUE ) {
-			$lf->Save();
+			$insert_id = $lf->Save();
+
+			if ( 	(
+					!isset($config_vars['other']['disable_audit_log_detail'])
+						OR isset($config_vars['other']['disable_audit_log_detail']) AND $config_vars['other']['disable_audit_log_detail'] != TRUE
+					)
+					AND is_object($object) AND $object->getEnableSystemLogDetail() == TRUE ) {
+
+				$ldf = new LogDetailFactory();
+				$ldf->addLogDetail( $action_id, $insert_id, $object );
+			}
 
 			return TRUE;
 		}
