@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3349 $
- * $Id: TTi18n.class.php 3349 2010-02-10 17:38:41Z ipso $
- * $Date: 2010-02-10 09:38:41 -0800 (Wed, 10 Feb 2010) $
+ * $Revision: 3928 $
+ * $Id: TTi18n.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /*
@@ -685,7 +685,18 @@ class TTi18n {
 				$decimal_places = $max_decimals;
 			}
 
-			$custom_format = self::getLocaleHandler()->numberFormats[I18Nv2_NUMBER_FLOAT];
+			if ( isset(self::getLocaleHandler()->numberFormats[I18Nv2_NUMBER_FLOAT]) ) {
+				$custom_format = self::getLocaleHandler()->numberFormats[I18Nv2_NUMBER_FLOAT];
+			} else {
+				$custom_format = array(
+									   'float' => array(
+														0 => 2,
+														1 => '.',
+														2 => ',',
+											        )
+									   );
+			}
+
 			$custom_format[0] = $decimal_places;
 			self::getLocaleHandler()->numberFormats['long_float'] = $custom_format;
 
