@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2555 $
- * $Id: UserDateListFactory.class.php 2555 2009-05-21 00:11:04Z ipso $
- * $Date: 2009-05-20 17:11:04 -0700 (Wed, 20 May 2009) $
+ * $Revision: 3939 $
+ * $Id: UserDateListFactory.class.php 3939 2010-11-19 22:41:24Z ipso $
+ * $Date: 2010-11-19 14:41:24 -0800 (Fri, 19 Nov 2010) $
  */
 
 /**
@@ -420,17 +420,12 @@ class UserDateListFactory extends UserDateFactory implements IteratorAggregate {
 			$strict = TRUE;
 		}
 
-		$ph = array(
-					'user_id' => $user_id,
-					'pay_period_id' => $pay_period_id,
-					);
-
 		$query = '
 					select 	*
 					from	'. $this->getTable() .'
 					where
-						user_id = ?
-						AND pay_period_id = ?
+						user_id in ('. $this->getListSQL($user_id, $ph) .')
+						AND pay_period_id in ('. $this->getListSQL($pay_period_id, $ph) .')
 						AND deleted = 0
 					';
 
@@ -464,7 +459,7 @@ class UserDateListFactory extends UserDateFactory implements IteratorAggregate {
 
 		$ph = array(
 					'company_id' => $company_id,
-					'pay_period_id' => $pay_period_id,
+					//'pay_period_id' => $pay_period_id,
 					);
 
 		$query = '
@@ -474,7 +469,7 @@ class UserDateListFactory extends UserDateFactory implements IteratorAggregate {
 					where
 						a.user_id = b.id
 						AND b.company_id = ?
-						AND a.pay_period_id = ?
+						AND a.pay_period_id in ('. $this->getListSQL($pay_period_id, $ph) .')
 						AND ( a.deleted = 0 AND b.deleted = 0 )
 					';
 
