@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3298 $
- * $Id: Validator.class.php 3298 2010-01-20 18:52:46Z ipso $
- * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
+ * $Revision: 3951 $
+ * $Id: Validator.class.php 3951 2010-11-22 16:26:10Z ipso $
+ * $Date: 2010-11-22 08:26:10 -0800 (Mon, 22 Nov 2010) $
  */
 
 /**
@@ -370,7 +370,7 @@ class Validator {
 	function isIPAddress($label, $value, $msg = NULL) {
 		//Debug::text('Raw IP: '. $value, __FILE__, __LINE__, __METHOD__, $this->verbosity);
 
-		$ip = explode(".", $value);
+		$ip = explode('.', $value);
 
 		if( count($ip) == 4 ) {
 			$valid = TRUE;
@@ -393,7 +393,7 @@ class Validator {
 
 	function isDate($label, $value, $msg = NULL) {
 		if ( $value != '' AND is_numeric($value) ) {
-			$date = gmdate("U", $value);
+			$date = gmdate('U', $value);
 			//Debug::text('Raw Date: '. $value .' Converted Value: '. $date, __FILE__, __LINE__, __METHOD__, $this->verbosity);
 
 			if (  $date == $value ) {
@@ -508,11 +508,10 @@ class Validator {
 	}
 
 	final function isValid($label = NULL) {
-
 		if ($this->num_errors == 0) {
 			return TRUE;
 		} elseif ($label != NULL) {
-			Debug::text('Num Errors: '. $this->num_errors, __FILE__, __LINE__, __METHOD__, $this->verbosity);
+			//Debug::text('Num Errors: '. $this->num_errors, __FILE__, __LINE__, __METHOD__, $this->verbosity);
 
 			//Check to see if a single form variable is valid.
             if ( !isset($this->errors[$label]) ) {
