@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2710 $
- * $Id: CronJobFactory.class.php 2710 2009-08-07 22:46:58Z ipso $
- * $Date: 2009-08-07 15:46:58 -0700 (Fri, 07 Aug 2009) $
+ * $Revision: 3928 $
+ * $Id: CronJobFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -96,7 +96,7 @@ class CronJobFactory extends Factory {
 
 			$this->data['status_id'] = $status;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -120,7 +120,7 @@ class CronJobFactory extends Factory {
 
 			$this->data['name'] = $name;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -164,7 +164,7 @@ class CronJobFactory extends Factory {
 
 			$this->data['minute'] = $value;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -188,7 +188,7 @@ class CronJobFactory extends Factory {
 
 			$this->data['hour'] = $value;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -212,7 +212,7 @@ class CronJobFactory extends Factory {
 
 			$this->data['day_of_month'] = $value;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -236,7 +236,7 @@ class CronJobFactory extends Factory {
 
 			$this->data['month'] = $value;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -260,7 +260,7 @@ class CronJobFactory extends Factory {
 
 			$this->data['day_of_week'] = $value;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -284,7 +284,7 @@ class CronJobFactory extends Factory {
 
 			$this->data['command'] = $value;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -333,96 +333,10 @@ class CronJobFactory extends Factory {
 		return $this->execute_flag;
 	}
 
-	function getSystemLoad() {
-		if ( OPERATING_SYSTEM == 'LINUX' ) {
-			$loadavg_file = '/proc/loadavg';
-			if ( file_exists( $loadavg_file ) AND is_readable( $loadavg_file ) ) {
-				$buffer = '0 0 0';
-				$buffer = file_get_contents( $loadavg_file );
-				$load = explode(' ',$buffer);
-
-				$retval = max((float)$load[0], (float)$load[1], (float)$load[2]);
-				Debug::text(' Load Average: '. $retval , __FILE__, __LINE__, __METHOD__,10);
-
-				return $retval;
-			}
-		}
-
-		return 0;
-	}
-
 	function isSystemLoadValid() {
-		global $config_vars;
-
-		if ( !isset($config_vars['other']['max_cron_system_load']) ) {
-			$config_vars['other']['max_cron_system_load'] = 9999;
-		}
-
-		$system_load = $this->getSystemLoad();
-		if ( isset($config_vars['other']['max_cron_system_load']) AND $system_load <= $config_vars['other']['max_cron_system_load'] ) {
-			Debug::text(' Load average within valid limits: Current: '. $system_load .' Max: '. $config_vars['other']['max_cron_system_load'], __FILE__, __LINE__, __METHOD__,10);
-
-			return TRUE;
-		}
-
-		Debug::text(' Load average NOT within valid limits: Current: '. $system_load .' Max: '. $config_vars['other']['max_cron_system_load'], __FILE__, __LINE__, __METHOD__,10);
-
-		return FALSE;
+		return Misc::isSystemLoadValid();
 	}
-
-	//Parses any column into a complete list of entries.
-	//ie: converts: 	0-59 to an array of: 0,1,2,3,4,5,6,...
-	//					0-2,16,18 to array of 0,1,2,16,18
-	//					*/2 to array of 0,2,4,6,8,...
-	function parseScheduleString( $str, $type ) {
-		$split_str = explode(',', $str);
-
-		if ( count($split_str) == 0 ) {
-			//Debug::text('Schedule String DOES NOT have multiple commas: '. count($split_str), __FILE__, __LINE__, __METHOD__, 10);
-			$split_str = array($split_str);
-		} else {
-			//Debug::text('Schedule String has multiple commas: '. count($split_str), __FILE__, __LINE__, __METHOD__, 10);
-		}
-
-		$retarr = array();
-		$limit_options = $this->getOptions('limit');
-		foreach( $split_str as $str_atom ) {
-			if ( strpos($str_atom, '-') !== FALSE ) {
-				//Debug::text('Schedule atom has basic range: '. $str_atom, __FILE__, __LINE__, __METHOD__, 10);
-				//Found basic range
-				//get Min/Max of range
-				$str_atom_range = explode('-', $str_atom);
-
-				$retarr = array_merge( $retarr, range($str_atom_range[0], $str_atom_range[1]) );
-				unset($str_atom_range);
-			} elseif ( strpos($str_atom, '/') !== FALSE ) {
-				//Debug::text('Schedule atom has advanced range: '. $str_atom, __FILE__, __LINE__, __METHOD__, 10);
-				//Found basic range
-				//get Min/Max of range
-				$str_atom_range = explode('/', $str_atom);
-
-				$retarr = array_merge( $retarr, range($limit_options[$type]['min'],$limit_options[$type]['max'], $str_atom_range[1]) );
-				unset($str_atom_range);
-			} else {
-				//No Range found
-				//Debug::text('Schedule atom does not have range: '. $str_atom, __FILE__, __LINE__, __METHOD__, 10);
-
-				if ( trim($str_atom) == '*' ) {
-					//Debug::text('Found Full Range!: '. $str_atom, __FILE__, __LINE__, __METHOD__, 10);
-					$retarr = array_merge( $retarr, range($limit_options[$type]['min'],$limit_options[$type]['max']) );
-				} else {
-					//Debug::text('Singleton: '. $str_atom, __FILE__, __LINE__, __METHOD__, 10);
-					$retarr[] = (int)$str_atom;
-				}
-			}
-		}
-
-		rsort($retarr);
-
-		//Debug::Arr($retarr, 'Final Array: ', __FILE__, __LINE__, __METHOD__, 10);
-		return $retarr;
-	}
-
+	
 	//Check if job is scheduled to run right NOW.
 	//If the job has missed a run, it will run immediately.
 	function isScheduledToRun( $epoch = NULL, $last_run_date = NULL ) {
@@ -433,81 +347,11 @@ class CronJobFactory extends Factory {
 
 		//Debug::text('Checking if Cron Job is scheduled to run: '. $this->getName(), __FILE__, __LINE__, __METHOD__, 10);
 		if ( $last_run_date == '' ) {
-			$last_run_date = $this->getLastRunDate();
-		}
-		//Debug::text(' Name: '. $this->getName() .' Current Epoch: '. TTDate::getDate('DATE+TIME', $epoch) .' Last Run Date: '. TTDate::getDate('DATE+TIME', $last_run_date) , __FILE__, __LINE__, __METHOD__,10);
-
-		$current_date_arr = getdate( $epoch );
-		//Debug::Arr($current_date_arr, 'Current Date Arr: ', __FILE__, __LINE__, __METHOD__,10);
-
-		//
-		// In cases where cron has fallen behind, or wasn't being run for days on end,
-		// It will run old jobs only once the hour/minute has passed, so it could take up to one hour for all jobs to catch-up.
-		//
-		//Debug::text(' Checking if Job: '. $this->getName() .' Is Scheduled to Run...', __FILE__, __LINE__, __METHOD__,10);
-
-		$day_of_week_arr = $this->parseScheduleString( $this->getDayOfWeek(), 'day_of_week' );
-		//Debug::Arr($day_of_week_arr, 'Day Of Week Arr: ', __FILE__, __LINE__, __METHOD__,10);
-		foreach( $day_of_week_arr as $day_of_week ) {
-			if ( $day_of_week <= $current_date_arr['wday'] ) {
-				//Debug::text(' Day Of Week: '. $day_of_week, __FILE__, __LINE__, __METHOD__,10);
-
-				$month_arr = $this->parseScheduleString( $this->getMonth(), 'month' );
-				//Debug::Arr($month_arr, 'Month Arr: ', __FILE__, __LINE__, __METHOD__,10);
-				foreach( $month_arr as $month ) {
-					if ( $month <= $current_date_arr['mon'] ) {
-						//Debug::text(' Month: '. $month, __FILE__, __LINE__, __METHOD__,10);
-
-						$day_of_month_arr = $this->parseScheduleString( $this->getDayOfMonth(), 'day_of_month' );
-						//Debug::Arr($day_of_month_arr, 'Day Of Month Arr: ', __FILE__, __LINE__, __METHOD__,10);
-						foreach( $day_of_month_arr as $day_of_month ) {
-							if ( $day_of_month <= $current_date_arr['mday'] ) {
-								//Debug::text(' Day Of Month: '. $day_of_month, __FILE__, __LINE__, __METHOD__,10);
-
-								$hour_arr = $this->parseScheduleString( $this->getHour(), 'hour' );
-								//Debug::Arr($hour_arr, 'Hour Arr: ', __FILE__, __LINE__, __METHOD__,10);
-								foreach( $hour_arr as $hour ) {
-									if ( $hour <= $current_date_arr['hours'] ) {
-										//Debug::text(' Hour: '. $hour, __FILE__, __LINE__, __METHOD__,10);
-
-										$minute_arr = $this->parseScheduleString( $this->getMinute(), 'minute' );
-										//Debug::Arr($minute_arr, 'Minute Arr: ', __FILE__, __LINE__, __METHOD__,10);
-										foreach( $minute_arr as $minute ) {
-											if ( $minute <= $current_date_arr['minutes'] ) {
-												//Debug::text(' Minute: '. $minute, __FILE__, __LINE__, __METHOD__,10);
-
-												$prev_scheduled_time = mktime( $hour, $minute, 0, $month, $day_of_month, $current_date_arr['year'] );
-												Debug::text(' Name: '. $this->getName() .' Previous Scheduled Date: '. date('r', $prev_scheduled_time ) .'('.$prev_scheduled_time.') Last Run Time: '. date('r', $last_run_date ) .'('.$last_run_date.') Current Epoch: '. $epoch , __FILE__, __LINE__, __METHOD__,10);
-
-												if ( $last_run_date < $prev_scheduled_time ) {
-													Debug::text('  JOB is SCHEDULED TO RUN NOW!', __FILE__, __LINE__, __METHOD__,10);
-													return TRUE;
-												} else {
-													Debug::text('  JOB is NOT scheduled to run right now...' , __FILE__, __LINE__, __METHOD__,10);
-												}
-
-												break;
-											}
-										}
-
-										break;
-									}
-								}
-
-								break;
-							}
-						}
-
-						break;
-					}
-				}
-
-				break;
-			}
+			$last_run_date = (int)$this->getLastRunDate();
 		}
 
-		//Debug::text('  JOB is NOT SCHEDULED TO RUN YET!', __FILE__, __LINE__, __METHOD__,10);
-		return FALSE;
+		Debug::text(' Name: '. $this->getName() .' Current Epoch: '. TTDate::getDate('DATE+TIME', $epoch) .' Last Run Date: '. TTDate::getDate('DATE+TIME', $last_run_date) , __FILE__, __LINE__, __METHOD__,10);
+		return Cron::isScheduledToRun( $this->getMinute(), $this->getHour(), $this->getDayOfMonth(), $this->getMonth(), $this->getDayOfWeek(), $epoch, $last_run_date );
 	}
 
 	//Executes the CronJob
