@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: DepartmentListFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3764 $
+ * $Id: DepartmentListFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
+ * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
  */
 
 /**
@@ -89,6 +89,21 @@ class DepartmentListFactory extends DepartmentFactory implements IteratorAggrega
 		return $this;
 	}
 
+	static function getNameById( $id ) {
+		if ( $id == '') {
+			return FALSE;
+		}
+
+		$lf = new DepartmentListFactory();
+		$lf = $lf->getById( $id );
+		if ( $lf->getRecordCount() > 0 ) {
+			$obj = $lf->getCurrent();
+			return $obj->getName();
+		}
+
+		return FALSE;
+	}
+
 	function getByCompanyId($id, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
 		if ( $id == '' ) {
 			return FALSE;
