@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2637 $
- * $Id: HierarchyControlFactory.class.php 2637 2009-07-07 21:26:01Z ipso $
- * $Date: 2009-07-07 14:26:01 -0700 (Tue, 07 Jul 2009) $
+ * $Revision: 4073 $
+ * $Id: HierarchyControlFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -46,8 +46,60 @@ class HierarchyControlFactory extends Factory {
 	protected $table = 'hierarchy_control';
 	protected $pk_sequence_name = 'hierarchy_control_id_seq'; //PK Sequence name
 
-	//Temporaray holding array.
-	protected $object_type_ids = NULL;
+	function _getFactoryOptions( $name ) {
+
+		$retval = NULL;
+		switch( $name ) {
+			case 'object_type':
+				$hotlf = new HierarchyObjectTypeListFactory();
+				$retval = $hotlf->getOptions('object_type');
+				break;
+			case 'columns':
+				$retval = array(
+										'-1010-name' => TTi18n::gettext('Name'),
+										'-1020-description' => TTi18n::gettext('Description'),
+										'-1030-object_type_display' => TTi18n::gettext('Objects'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'name',
+								'description',
+								'object_type_display'
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
+		}
+
+		return $retval;
+	}
+
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'name' => 'Name',
+										'description' => 'Description',
+										'object_type' => 'ObjectType',
+										'object_type_display' => FALSE,
+										'user' => 'User',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
+
 	function getCompany() {
 		return $this->data['company_id'];
 	}
@@ -133,17 +185,18 @@ class HierarchyControlFactory extends Factory {
 		return FALSE;
 	}
 
-	//Return the temp IDs for validation.
-	function getTmpObjectType() {
-		if ( isset( $this->object_type_ids ) ) {
-			return 	$this->object_type_ids;
+	function getObjectTypeDisplay() {
+		$object_type_ids = $this->getObjectType();
+		$object_types = $this->getOptions('object_type');
+
+		foreach( $object_type_ids as $object_type_id ) {
+			$retval[] = Option::getByKey( $object_type_id, $object_types );
+
 		}
 
-		return FALSE;
+		return implode("\n", $retval );
 	}
 
-
-	//Return IDs from the database,
 	function getObjectType() {
 		$hotlf = new HierarchyObjectTypeListFactory();
 		$hotlf->getByHierarchyControlId( $this->getId() );
@@ -161,36 +214,27 @@ class HierarchyControlFactory extends Factory {
 
 	function setObjectType($ids) {
 		if ( is_array($ids) AND count($ids) > 0 ) {
-			$this->object_type_ids = $ids;
+			$tmp_ids = array();
+			Debug::Arr($ids, 'IDs: ', __FILE__, __LINE__, __METHOD__, 10);
 
-			return TRUE;
-		}
-
-		$this->Validator->isTrue(		'object_type',
-										FALSE,
-										TTi18n::gettext('At least one object type must be selected'));
-		return FALSE;
-	}
-
-	function setObjectTypeIds($ids) {
-		if ( is_array($ids) ) {
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$lf_a = new HierarchyObjectTypeListFactory();
 				$lf_a->getByHierarchyControlId( $this->getId() );
+				Debug::text('Existing Object Type Rows: '. $lf_a->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 
-				$tmp_ids = array();
 				foreach ($lf_a as $obj) {
-					$id = $obj->getId();
+					//$id = $obj->getId();
+					$id = $obj->getObjectType(); //Need to use object_types rather than row IDs.
 					Debug::text('Hierarchy Object Type ID: '. $obj->getId() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
 
 					//Delete users that are not selected.
 					if ( !in_array($id, $ids) ) {
-						Debug::text('Deleting: '. $id, __FILE__, __LINE__, __METHOD__, 10);
+						Debug::text('Deleting: Object Type: '. $id .' ID: '. $obj->getID(), __FILE__, __LINE__, __METHOD__, 10);
 						$obj->Delete();
 					} else {
 						//Save ID's that need to be updated.
-						Debug::text('NOT Deleting : '. $id, __FILE__, __LINE__, __METHOD__, 10);
+						Debug::text('NOT Deleting: Object Type: '. $id .' ID: '. $obj->getID(), __FILE__, __LINE__, __METHOD__, 10);
 						$tmp_ids[] = $id;
 					}
 				}
@@ -214,6 +258,10 @@ class HierarchyControlFactory extends Factory {
 			return TRUE;
 		}
 
+		$this->Validator->isTrue(		'object_type',
+										FALSE,
+										TTi18n::gettext('At least one object must be selected'));
+
 		return FALSE;
 	}
 
@@ -231,14 +279,19 @@ class HierarchyControlFactory extends Factory {
 		return FALSE;
 	}
 	function setUser($ids) {
+		if ( !is_array($ids) ) {
+			$ids = array($ids);
+		}
+
 		Debug::text('Setting User IDs : ', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($ids) ) {
+			$tmp_ids = array();
+
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$hulf = new HierarchyUserListFactory();
 				$hulf->getByHierarchyControlID( $this->getId() );
 
-				$tmp_ids = array();
 				foreach ($hulf as $obj) {
 					$id = $obj->getUser();
 					Debug::text('HierarchyControl ID: '. $obj->getHierarchyControl() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
@@ -278,7 +331,6 @@ class HierarchyControlFactory extends Factory {
 				}
 			}
 
-
 			return TRUE;
 		}
 
@@ -291,15 +343,62 @@ class HierarchyControlFactory extends Factory {
 	}
 
 	function postSave() {
-		//Save objectype IDs
-
-		$this->setObjectTypeIds( $this->getTmpObjectType() );
-
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'object_type_display':
+							$data[$variable] = $this->getObjectTypeDisplay();
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Hierarchy'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Hierarchy'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
