@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3415 $
- * $Id: HierarchyControlListFactory.class.php 3415 2010-03-12 22:31:26Z ipso $
- * $Date: 2010-03-12 14:31:26 -0800 (Fri, 12 Mar 2010) $
+ * $Revision: 3725 $
+ * $Id: HierarchyControlListFactory.class.php 3725 2010-07-28 21:16:05Z ipso $
+ * $Date: 2010-07-28 14:16:05 -0700 (Wed, 28 Jul 2010) $
  */
 
 /**
@@ -241,5 +241,91 @@ class HierarchyControlListFactory extends HierarchyControlFactory implements Ite
 		return $this;
 	}
 
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array();
+
+		$sort_column_aliases = array();
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'name' => 'asc', 'description' => 'asc');
+			$strict = FALSE;
+		} else {
+			//Always sort by last name,first name after other columns
+			if ( !isset($order['name']) ) {
+				$order['name'] = 'asc';
+			}
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$uf = new UserFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	a.*,
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name
+					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					where	a.company_id = ?
+					';
+
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['name']) AND trim($filter_data['name']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['name']));
+			$query  .=	' AND lower(a.name) LIKE ?';
+		}
+		if ( isset($filter_data['description']) AND trim($filter_data['description']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['description']));
+			$query  .=	' AND lower(a.description) LIKE ?';
+		}
+		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
+		}
+		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
+			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
+		}
+
+		$query .= 	'
+						AND a.deleted = 0
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
 }
 ?>
