@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -86,6 +86,38 @@ class HierarchyLevelListFactory extends HierarchyLevelFactory implements Iterato
 		return $this;
 	}
 
+	function getByIdAndCompanyId($id, $company_id, $where = NULL, $order = NULL) {
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		if ( $company_id == '' ) {
+			return FALSE;
+		}
+
+		$hcf = new HierarchyControlFactory();
+
+		$ph = array(
+					'id' => $id,
+					'company_id' => $company_id
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $hcf->getTable() .' as b ON a.hierarchy_control_id = b.id
+					where	a.id = ?
+						AND b.company_id = ?
+						AND a.deleted = 0
+				';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByHierarchyControlId($id, $where = NULL, $order = NULL) {
 		if ( $id == '' ) {
 			return FALSE;
@@ -146,6 +178,39 @@ class HierarchyLevelListFactory extends HierarchyLevelFactory implements Iterato
 		return $this;
 	}
 
+	function getByHierarchyControlIdAndUserIdAndExcludeID($id, $user_id, $exclude_id, $where = NULL, $order = NULL) {
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		$strict_order = TRUE;
+		if ( $order == NULL ) {
+			$order = array('level' => 'asc', 'user_id' => 'asc');
+			$strict_order = FALSE;
+		}
+
+		$ph = array(
+					'id' => (int)$id,
+					'user_id' => (int)$user_id,
+					'exclude_id' => (int)$exclude_id
+					);
+
+		$query = '
+					select 	*
+					from	'. $this->getTable() .'
+					where	hierarchy_control_id = ?
+						AND user_id = ?
+						AND id != ?
+						AND deleted = 0
+				';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getLevelsByHierarchyControlIdAndUserId( $id, $user_id ) {
 		if ( $id == '' ) {
 			return FALSE;
@@ -316,6 +381,87 @@ class HierarchyLevelListFactory extends HierarchyLevelFactory implements Iterato
 		return FALSE;
 	}
 
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array();
+
+		$sort_column_aliases = array();
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'level' => 'asc');
+			$strict = FALSE;
+		} else {
+			//Always sort by last name,first name after other columns
+			if ( !isset($order['level']) ) {
+				$order['level'] = 'asc';
+			}
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$uf = new UserFactory();
+		$hcf = new HierarchyControlFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	a.*,
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name
+					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $hcf->getTable() .' as b ON ( a.hierarchy_control_id = b.id AND b.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					where	b.company_id = ?
+					';
+
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['hierarchy_control_id']) AND isset($filter_data['hierarchy_control_id'][0]) AND !in_array(-1, (array)$filter_data['hierarchy_control_id']) ) {
+			$query  .=	' AND a.hierarchy_control_id in ('. $this->getListSQL($filter_data['hierarchy_control_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
+		}
+		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
+			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
+		}
+
+		$query .= 	'
+						AND a.deleted = 0
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 /*
 	function getByCompanyIdAndObjectTypeId($id, $object_type_id, $where = NULL, $order = NULL) {
 		if ( $id == '' ) {
