@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2637 $
- * $Id: HierarchyObjectTypeFactory.class.php 2637 2009-07-07 21:26:01Z ipso $
- * $Date: 2009-07-07 14:26:01 -0700 (Tue, 07 Jul 2009) $
+ * $Revision: 4073 $
+ * $Id: HierarchyObjectTypeFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -100,8 +100,9 @@ class HierarchyObjectTypeFactory extends Factory {
 		$id = trim($id);
 
 		$hclf = new HierarchyControlListFactory();
+		Debug::Text('Hierarchy Control ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 
-		if ( $id == 0
+		if ( $id != 0
 				OR $this->Validator->isResultSetWithRows(	'hierarchy_control_id',
 															$hclf->getByID($id),
 															TTi18n::gettext('Invalid Hierarchy Control')
@@ -218,5 +219,9 @@ class HierarchyObjectTypeFactory extends Factory {
 		return FALSE;
 	}
 
+	function addLog( $log_action ) {
+		$object_type = Option::getByKey($this->getObjectType(), Misc::TrimSortPrefix( $this->getOptions('object_type') ) );
+		return TTLog::addEntry( $this->getHierarchyControl(), $log_action, TTi18n::getText('Object').': '. $object_type, NULL, $this->getTable() );
+	}
 }
 ?>
