@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2555 $
- * $Id: HolidayFactory.class.php 2555 2009-05-21 00:11:04Z ipso $
- * $Date: 2009-05-20 17:11:04 -0700 (Wed, 20 May 2009) $
+ * $Revision: 3928 $
+ * $Id: HolidayFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -47,6 +47,52 @@ class HolidayFactory extends Factory {
 	protected $pk_sequence_name = 'holidays_id_seq'; //PK Sequence name
 
 	protected $holiday_policy_obj = NULL;
+
+	function _getFactoryOptions( $name ) {
+
+		$retval = NULL;
+		switch( $name ) {
+			case 'columns':
+				$retval = array(
+										'-1010-name' => TTi18n::gettext('Name'),
+										'-1020-date_stamp' => TTi18n::gettext('Date'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'name',
+								'date_stamp',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
+		}
+
+		return $retval;
+	}
+
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'holiday_policy_id' => 'HolidayPolicyID',
+										'date_stamp' => 'DateStamp',
+										'name' => 'Name',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
+
 	function getHolidayPolicyObject() {
 		if ( is_object($this->holiday_policy_obj) ) {
 			return $this->holiday_policy_obj;
@@ -147,14 +193,18 @@ class HolidayFactory extends Factory {
 												FALSE,
 												TTi18n::gettext('Incorrect date'));
 			}
-
-
 		}
 
 		return FALSE;
 	}
 
 	function isUniqueName($name) {
+		//BindDate() causes a deprecated error if date_stamp is not set, so just return TRUE so we can throw a invalid date error elsewhere instead.
+		//This also causes it so we can never have a invalid date and invalid name validation errors at the same time.
+		if ( $this->getDateStamp() == '' ) {
+			return TRUE;
+		}
+
 		$ph = array(
 					'policy_id' => $this->getHolidayPolicyID(),
 					'name' => $name,
@@ -203,6 +253,7 @@ class HolidayFactory extends Factory {
 	}
 	function setName($name) {
 		$name = trim($name);
+
 		if (	$this->Validator->isLength(	'name',
 											$name,
 											TTi18n::gettext('Name is invalid'),
@@ -314,7 +365,7 @@ class HolidayFactory extends Factory {
 			Debug::text('Employee has been employed long enough!', __FILE__, __LINE__, __METHOD__,10);
 
 			if ( $this->getHolidayPolicyObject()->getType() == 20 OR $this->getHolidayPolicyObject()->getType() == 30 ) {
-				if ( $this->getHolidayPolicyObject()->getWorkedScheduledDays() == TRUE
+				if ( $this->getHolidayPolicyObject()->getWorkedScheduledDays() == 1 //Scheduled Days
 						AND $this->getHolidayPolicyObject()->getMinimumWorkedDays() > 0 AND $this->getHolidayPolicyObject()->getMinimumWorkedPeriodDays() > 0 ) {
 					Debug::text('aUsing scheduled days!', __FILE__, __LINE__, __METHOD__,10);
 					$slf->getByUserIdAndTypeAndDirectionFromDate($user_obj->getId(), 10, 'before', $this->getDateStamp(), $this->getHolidayPolicyObject()->getMinimumWorkedPeriodDays() );
@@ -330,7 +381,7 @@ class HolidayFactory extends Factory {
 					Debug::text('aUsing calendar days, NOT scheduled days!', __FILE__, __LINE__, __METHOD__,10);
 				}
 
-				if ( $this->getHolidayPolicyObject()->getWorkedAfterScheduledDays() == TRUE
+				if ( $this->getHolidayPolicyObject()->getWorkedAfterScheduledDays() == 1 //Scheduled Days
 						AND $this->getHolidayPolicyObject()->getMinimumWorkedAfterDays() > 0 AND $this->getHolidayPolicyObject()->getMinimumWorkedAfterPeriodDays() > 0 ) {
 					$slf->getByUserIdAndTypeAndDirectionFromDate($user_obj->getId(), 10, 'after', $this->getDateStamp(), $this->getHolidayPolicyObject()->getMinimumWorkedAfterPeriodDays() );
 					Debug::text('bUsing scheduled days!', __FILE__, __LINE__, __METHOD__,10);
@@ -347,9 +398,12 @@ class HolidayFactory extends Factory {
 
 				$worked_before_days_count = 0;
 				if ( $this->getHolidayPolicyObject()->getMinimumWorkedDays() > 0 AND $this->getHolidayPolicyObject()->getMinimumWorkedPeriodDays() > 0 ) {
-					if ( isset($scheduled_user_date_ids_before) AND $this->getHolidayPolicyObject()->getWorkedScheduledDays() == TRUE ) {
+					if ( isset($scheduled_user_date_ids_before) AND $this->getHolidayPolicyObject()->getWorkedScheduledDays() == 1 ) { //Scheduled Days
 						$worked_before_days_count = $udtlf->getDaysWorkedByUserIDAndUserDateIDs($user_obj->getId(), $scheduled_user_date_ids_before );
-					} else {
+					} elseif ( $this->getHolidayPolicyObject()->getWorkedScheduledDays() == 2 ) {  //Holiday Week Days
+						//Start/End date should reflect weeks, no days here.
+						$worked_before_days_count = $udtlf->getDaysWorkedByUserIDAndStartDateAndEndDateAndDayOfWeek($user_obj->getId(), ( $this->getDateStamp() - ( ($this->getHolidayPolicyObject()->getMinimumWorkedPeriodDays()*7) * 86400 ) ), $this->getDateStamp()-86400, TTDate::getDayOfWeek( $this->getDateStamp() ) );
+					} else { //Calendar Days
 						$worked_before_days_count = $udtlf->getDaysWorkedByUserIDAndStartDateAndEndDate($user_obj->getId(), ( $this->getDateStamp() - ( $this->getHolidayPolicyObject()->getMinimumWorkedPeriodDays() * 86400) ), $this->getDateStamp()-86400  );
 					}
 				}
@@ -357,9 +411,9 @@ class HolidayFactory extends Factory {
 
 				$worked_after_days_count = 0;
 				if ( $this->getHolidayPolicyObject()->getMinimumWorkedAfterDays() > 0 AND $this->getHolidayPolicyObject()->getMinimumWorkedAfterPeriodDays() > 0 ) {
-					if ( isset($scheduled_user_date_ids_after) AND $this->getHolidayPolicyObject()->getWorkedAfterScheduledDays() == TRUE ) {
+					if ( isset($scheduled_user_date_ids_after) AND $this->getHolidayPolicyObject()->getWorkedAfterScheduledDays() == 1 ) { //Scheduled Days
 						$worked_after_days_count = $udtlf->getDaysWorkedByUserIDAndUserDateIDs($user_obj->getId(), $scheduled_user_date_ids_after );
-					} else {
+					} else { //Calendar Days
 						$worked_after_days_count = $udtlf->getDaysWorkedByUserIDAndStartDateAndEndDate($user_obj->getId(), $this->getDateStamp()+86400, ( $this->getDateStamp() + ( $this->getHolidayPolicyObject()->getMinimumWorkedAfterPeriodDays() * 86400) ) );
 					}
 				}
@@ -386,6 +440,12 @@ class HolidayFactory extends Factory {
 	}
 
 	function Validate() {
+		if ( $this->Validator->hasError('date_stamp') == FALSE AND $this->getDateStamp() == '' ) {
+			$this->Validator->isTrue(		'date_stamp',
+											FALSE,
+											TTi18n::gettext('Date is invalid'));
+		}
+
 		return TRUE;
 	}
 
@@ -397,8 +457,66 @@ class HolidayFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'date_stamp':
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'date_stamp':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = TTDate::getAPIDate( 'DATE', $this->$function() );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Holiday'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Holiday'), NULL, $this->getTable(), $this );
 	}
 
 }
