@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2876 $
- * $Id: HolidayListFactory.class.php 2876 2009-10-07 20:27:23Z ipso $
- * $Date: 2009-10-07 13:27:23 -0700 (Wed, 07 Oct 2009) $
+ * $Revision: 3764 $
+ * $Id: HolidayListFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
+ * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
  */
 
 /**
@@ -84,6 +84,41 @@ class HolidayListFactory extends HolidayFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByIDAndCompanyId($id, $company_id, $where = NULL, $order = NULL) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( $id == '') {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'date_stamp' => 'desc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$hpf = new HolidayPolicyFactory();
+
+		$ph = array( 	'company_id' => $company_id,
+						'id' => $id
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+						LEFT JOIN '. $hpf->getTable() .' as b ON a.holiday_policy_id = b.id
+					where	b.company_id = ?
+						AND a.id = ?
+						AND ( a.deleted = 0 AND b.deleted = 0 ) ';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict );
+
+		$this->rs = $this->db->Execute($query, $ph);
+	}
+
 	function getByIdAndHolidayPolicyID($id, $holiday_policy_id, $where = NULL, $order = NULL) {
 		if ( $id == '') {
 			return FALSE;
@@ -384,26 +419,93 @@ class HolidayListFactory extends HolidayFactory implements IteratorAggregate {
 		return FALSE;
 	}
 
-/*
-	function getByCompanyIdArray($company_id, $include_blank = TRUE) {
-
-		$aplf = new AbsencePolicyListFactory();
-		$aplf->getByCompanyId($company_id);
-
-		if ( $include_blank == TRUE ) {
-			$list[0] = '--';
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
 		}
 
-		foreach ($aplf as $ap_obj) {
-			$list[$ap_obj->getID()] = $ap_obj->getName();
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
 		}
 
-		if ( isset($list) ) {
-			return $list;
+		$additional_order_fields = array();
+
+		$sort_column_aliases = array();
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'date_stamp' => 'desc', 'name' => 'asc');
+			$strict = FALSE;
+		} else {
+			if ( !isset($order['date_stamp']) ) {
+				$order = Misc::prependArray( array('date_stamp' => 'desc'), $order );
+			}
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$uf = new UserFactory();
+		$hpf = new HolidayPolicyFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	a.*,
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name
+					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $hpf->getTable() .' as hpf ON ( a.holiday_policy_id = hpf.id AND hpf.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					where	hpf.company_id = ?
+					';
+
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['holiday_policy_id']) AND isset($filter_data['holiday_policy_id'][0]) AND !in_array(-1, (array)$filter_data['holiday_policy_id']) ) {
+			$query  .=	' AND a.holiday_policy_id in ('. $this->getListSQL($filter_data['holiday_policy_id'], $ph) .') ';
 		}
 
-		return FALSE;
+		if ( isset($filter_data['name']) AND trim($filter_data['name']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['name']));
+			$query  .=	' AND lower(a.name) LIKE ?';
+		}
+		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
+		}
+		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
+			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
+		}
+
+		$query .= 	'
+						AND a.deleted = 0
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
 	}
-*/
+
 }
 ?>
