@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3298 $
- * $Id: RecurringHolidayFactory.class.php 3298 2010-01-20 18:52:46Z ipso $
- * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
+ * $Revision: 4073 $
+ * $Id: RecurringHolidayFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -98,6 +98,7 @@ class RecurringHolidayFactory extends Factory {
 			case 'columns':
 				$retval = array(
 										'-1010-name' => TTi18n::gettext('Name'),
+										'-1010-type' => TTi18n::gettext('Type'),
 										'-1020-next_date' => TTi18n::gettext('Next Date'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
@@ -138,6 +139,7 @@ class RecurringHolidayFactory extends Factory {
 										'day_of_week' => 'DayOfWeek',
 										'day_of_month' => 'DayOfMonth',
 										'month_int' => 'Month',
+										'always_week_day_id' => 'AlwaysOnWeekDay',
 										'next_date' => 'NextDate',
 										'deleted' => 'Deleted',
 										);
@@ -662,7 +664,7 @@ class RecurringHolidayFactory extends Factory {
 				$rhf->setName( 'Victoria Day' );
 				$rhf->setType( 30 );
 				$rhf->setSpecialDay( 0 );
-				$rhf->setPivotDayDirection( 10 );
+				$rhf->setPivotDayDirection( 30 );
 				$rhf->setDayOfWeek( 1 );
 				$rhf->setDayOfMonth( 24 );
 				$rhf->setMonth( 5 );
@@ -1732,6 +1734,11 @@ class RecurringHolidayFactory extends Factory {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
 							}
 							break;
+						case 'next_date':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = TTDate::getAPIDate( 'DATE', $this->$function() );
+							}
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
@@ -1748,7 +1755,7 @@ class RecurringHolidayFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Holiday'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Holiday'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
\ No newline at end of file
