@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: InstallSchema_1014A.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3764 $
+ * $Id: InstallSchema_1014A.class.php 3764 2010-08-13 18:07:55Z ipso $
+ * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
  */
 
 /**
@@ -130,8 +130,8 @@ class InstallSchema_1014A extends InstallSchema_Base {
 						Debug::text('Company ID: '. $company_id .' Checking Permission Differences Between User ID: '. $user_id .' AND Group: '. $group_name , __FILE__, __LINE__, __METHOD__, 10);
 
 						//Need to diff the arrays both directions, because the diff function only checks in one direction on its own.
-						$forward_permission_diff_arr = Misc::array_diff_assoc_recursive($permission_user_data, $permission_group_data);
-						$reverse_permission_diff_arr = Misc::array_diff_assoc_recursive($permission_group_data, $permission_user_data );
+						$forward_permission_diff_arr = Misc::arrayDiffAssocRecursive($permission_user_data, $permission_group_data);
+						$reverse_permission_diff_arr = Misc::arrayDiffAssocRecursive($permission_group_data, $permission_user_data );
 						Debug::text('Permission User Data Count: '. count($permission_user_data, COUNT_RECURSIVE) .' Permission Group Data Count: '. count($permission_group_data, COUNT_RECURSIVE), __FILE__, __LINE__, __METHOD__, 10);
 						if ( $forward_permission_diff_arr == FALSE AND $reverse_permission_diff_arr == FALSE ) {
 							Debug::text('No Differences Found in Permissions! ', __FILE__, __LINE__, __METHOD__, 10);
@@ -155,7 +155,7 @@ class InstallSchema_1014A extends InstallSchema_Base {
 						$preset_arr = array(10,18,20,30,40);
 						foreach( $preset_arr as $preset ) {
 							$tmp_preset_permissions = $pf->getPresetPermissions( $preset, array() );
-							$preset_permission_diff_arr = Misc::array_diff_assoc_recursive($permission_user_data, $tmp_preset_permissions);
+							$preset_permission_diff_arr = Misc::arrayDiffAssocRecursive($permission_user_data, $tmp_preset_permissions);
 
 							$preset_permission_diff_count = count($preset_permission_diff_arr, COUNT_RECURSIVE);
 							Debug::text('Preset Permission Diff Count...: '. $preset_permission_diff_count .' Preset ID: '. $preset, __FILE__, __LINE__, __METHOD__, 10);
