@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -53,6 +53,12 @@ class MessageControlFactory extends Factory {
 
 		$retval = NULL;
 		switch( $name ) {
+			case 'status':
+				$retval = array(
+										10 => TTi18n::gettext('UNREAD'),
+										20 => TTi18n::gettext('READ')
+									);
+				break;
 			case 'type':
 				$retval = array(
 										5 => 'email',
@@ -68,6 +74,7 @@ class MessageControlFactory extends Factory {
 										100 => 'user' //For notes assigned to users?
 									);
 				break;
+			case 'object_type':
 			case 'object_name':
 				$retval = array(
 										5 => TTi18n::gettext('Email'), //Email from user to another
@@ -97,12 +104,75 @@ class MessageControlFactory extends Factory {
 										110 => TTi18n::gettext('URGENT')
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1010-from_first_name' => TTi18n::gettext('From: First Name'),
+										'-1020-from_middle_name' => TTi18n::gettext('From: Middle Name'),
+										'-1030-from_last_name' => TTi18n::gettext('From: Last Name'),
 
+										'-1110-to_first_name' => TTi18n::gettext('To: First Name'),
+										'-1120-to_middle_name' => TTi18n::gettext('To: Middle Name'),
+										'-1130-to_last_name' => TTi18n::gettext('To: Last Name'),
+
+										'-1200-subject' => TTi18n::gettext('Subject'),
+										'-1210-object_type' => TTi18n::gettext('Type'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										//'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										//'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'from_first_name',
+								'from_last_name',
+								'to_first_name',
+								'to_last_name',
+								'subject',
+								'object_type',
+								'created_date',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array();
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array();
+				break;
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+
+										'from_user_id' => 'FromUserID',
+										'from_first_name' => FALSE,
+										'from_middle_name' => FALSE,
+										'from_last_name' => FALSE,
+
+										'to_user_id' => 'ToUserID',
+										'to_first_name' => FALSE,
+										'to_middle_name' => FALSE,
+										'to_last_name' => FALSE,
+
+										'status_id' => FALSE,
+										'object_type_id' => 'ObjectType',
+										'object_type' => FALSE,
+										'object_id' => 'Object',
+										'parent_id' => 'Parent',
+										'priority_id' => 'Priority',
+										'subject' => 'Subject',
+										'body' => 'Body',
+										'require_ack' => 'RequireAck',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
+
 
 	function getFromUserId() {
 		if ( isset($this->tmp_data['from_user_id']) ) {
@@ -402,6 +472,14 @@ class MessageControlFactory extends Factory {
 			}
 		}
 
+		/* This causes issues with the HTML interface.
+		if ( $this->getObjectType() == '' ) {
+				$this->Validator->isTrue(	'object_type_id',
+											FALSE,
+											TTi18n::gettext('Object type is invalid') );
+		}
+		*/
+
 		//If deleted is TRUE, we need to make sure all sender/recipient records are also deleted.
 		return TRUE;
 	}
@@ -615,5 +693,68 @@ class MessageControlFactory extends Factory {
 
 		return TRUE;
 	}
+
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'to_user_id':
+						case 'to_first_name':
+						case 'to_middle_name':
+						case 'to_last_name':
+						case 'from_user_id':
+						case 'from_first_name':
+						case 'from_middle_name':
+						case 'from_last_name':
+						case 'status_id':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'object_type':
+							$data[$variable] = Option::getByKey( $this->getObjectType(), $this->getOptions( $variable ) );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 }
 ?>
