@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -557,5 +557,268 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 
 		return FALSE;
 	}
+
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array('status_id');
+
+		$sort_column_aliases = array(
+									 'status' => 'a.status_id',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'a.status_id' => '= 10 desc', 'a.created_date' => 'desc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		if ( !isset($filter_data['folder_id']) ) {
+			$filter_data['folder_id'] = 10; //Inbox.
+		}
+
+		$mrf = new MessageRecipientFactory();
+		$msf = new MessageSenderFactory();
+		$rf = new RequestFactory();
+		$uf = new UserFactory();
+		$udf = new UserDateFactory();
+		$pptsvf = new PayPeriodTimeSheetVerifyFactory();
+
+		$ph = array(
+					'user_id' => $filter_data['current_user_id'],
+					'company_id' => $company_id,
+					);
+
+		if ( $filter_data['folder_id'] == 10 ) { //Inbox
+			$additional_order_fields = array('from_last_name');
+
+			//Need to include all threads that user has posted to.
+			$query = '
+						SELECT
+								c.*,
+								a.*,
+								b.id as id,
+								a.user_id as to_user_id,
+								aa.first_name as to_first_name,
+								aa.middle_name as to_middle_name,
+								aa.last_name as to_last_name,
+								b.user_id as from_user_id,
+								bb.first_name as from_first_name,
+								bb.middle_name as from_middle_name,
+								bb.last_name as from_last_name
+						FROM '. $mrf->getTable() .' as a
+							LEFT JOIN '. $uf->getTable() .' 	as aa ON a.user_id = aa.id
+							LEFT JOIN '. $msf->getTable() .' 	as b ON a.message_sender_id = b.id
+							LEFT JOIN '. $uf->getTable() .' 	as bb ON b.user_id = bb.id
+							LEFT JOIN '. $this->getTable() .' 	as c ON b.message_control_id = c.id
+							LEFT JOIN '. $uf->getTable() .' 	as d ON c.object_type_id = 5 AND c.object_id = d.id
+							LEFT JOIN '. $rf->getTable() .' 	as f ON c.object_type_id = 50 AND c.object_id = f.id
+							LEFT JOIN '. $pptsvf->getTable() .' as h ON c.object_type_id = 90 AND c.object_id = h.id
+						WHERE
+								a.user_id = ?
+								AND bb.company_id = ?
+								AND c.object_type_id in (5,50,90)';
+
+			if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+				$query  .=	' AND b.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+			}
+			if ( isset($filter_data['object_type_id']) AND isset($filter_data['object_type_id'][0]) AND !in_array(-1, (array)$filter_data['object_type_id']) ) {
+				$query  .=	' AND c.object_type_id in ('. $this->getListSQL($filter_data['object_type_id'], $ph) .') ';
+			}
+			if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+				$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+			}
+			if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+				$query  .=	' AND b.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+			}
+			if ( isset($filter_data['subject']) AND trim($filter_data['subject']) != '' ) {
+				$ph[] = strtolower(trim($filter_data['subject']));
+				$query  .=	' AND lower(c.subject) LIKE ?';
+			}
+			if ( isset($filter_data['body']) AND trim($filter_data['body']) != '' ) {
+				$ph[] = strtolower(trim($filter_data['body']));
+				$query  .=	' AND lower(c.body) LIKE ?';
+			}
+
+			$query .= '			AND ( a.deleted = 0 AND c.deleted = 0
+										AND ( d.id IS NULL OR ( d.id IS NOT NULL AND d.deleted = 0 ) )
+										AND ( f.id IS NULL OR ( f.id IS NOT NULL AND f.deleted = 0 ) )
+										AND ( h.id IS NULL OR ( h.id IS NOT NULL AND h.deleted = 0 ) )
+									)
+						';
+		} else {  //Sent
+			//Need to include all threads that user has posted to.
+			$additional_order_fields = array('to_last_name');
+
+			$query = '
+						SELECT
+								c.*,
+								a.*,
+								b.id as id,
+								a.user_id as to_user_id,
+								aa.first_name as to_first_name,
+								aa.middle_name as to_middle_name,
+								aa.last_name as to_last_name,
+								b.user_id as from_user_id,
+								bb.first_name as from_first_name,
+								bb.middle_name as from_middle_name,
+								bb.last_name as from_last_name
+						FROM '. $mrf->getTable() .' as a
+							LEFT JOIN '. $uf->getTable() .' 	as aa ON a.user_id = aa.id
+							LEFT JOIN '. $msf->getTable() .' 	as b ON a.message_sender_id = b.id
+							LEFT JOIN '. $uf->getTable() .' 	as bb ON b.user_id = bb.id
+							LEFT JOIN '. $this->getTable() .' 	as c ON b.message_control_id = c.id
+							LEFT JOIN '. $uf->getTable() .' 	as d ON c.object_type_id = 5 AND c.object_id = d.id
+							LEFT JOIN '. $rf->getTable() .' 	as f ON c.object_type_id = 50 AND c.object_id = f.id
+							LEFT JOIN '. $pptsvf->getTable() .' as h ON c.object_type_id = 90 AND c.object_id = h.id
+						WHERE
+								b.user_id = ?
+								AND bb.company_id = ?
+								AND c.object_type_id in (5,50,90)';
+
+			if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+				$query  .=	' AND b.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+			}
+			if ( isset($filter_data['object_type_id']) AND isset($filter_data['object_type_id'][0]) AND !in_array(-1, (array)$filter_data['object_type_id']) ) {
+				$query  .=	' AND c.object_type_id in ('. $this->getListSQL($filter_data['object_type_id'], $ph) .') ';
+			}
+			if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+				$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+			}
+			if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+				$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+			}
+			if ( isset($filter_data['subject']) AND trim($filter_data['subject']) != '' ) {
+				$ph[] = strtolower(trim($filter_data['subject']));
+				$query  .=	' AND lower(c.subject) LIKE ?';
+			}
+			if ( isset($filter_data['body']) AND trim($filter_data['body']) != '' ) {
+				$ph[] = strtolower(trim($filter_data['body']));
+				$query  .=	' AND lower(c.body) LIKE ?';
+			}
+
+			$query .= '			AND ( b.deleted = 0 AND c.deleted = 0
+										AND ( d.id IS NULL OR ( d.id IS NOT NULL AND d.deleted = 0 ) )
+										AND ( f.id IS NULL OR ( f.id IS NOT NULL AND f.deleted = 0 ) )
+										AND ( h.id IS NULL OR ( h.id IS NOT NULL AND h.deleted = 0 ) )
+									)
+						';
+		}
+
+		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
+	function getAPIMessageByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array('from_last_name', 'to_last_name', 'subject', 'object_type_id');
+
+		$strict = TRUE;
+		if ( $order == NULL ) {
+			$strict = FALSE;
+			$order = array( 'a.created_date' => 'asc' );
+		}
+
+		$mrf = new MessageRecipientFactory();
+		$msf = new MessageSenderFactory();
+		$rf = new RequestFactory();
+		$uf = new UserFactory();
+		$udf = new UserDateFactory();
+		$pptsvf = new PayPeriodTimeSheetVerifyFactory();
+
+
+
+		$ph = array(
+					'company_id' => $company_id,
+
+					'id' => $filter_data['id'],
+					'id_b' => $filter_data['id'],
+					'id_c' => $filter_data['id'],
+					'id_d' => $filter_data['id'],
+
+					'user_id' => $filter_data['current_user_id'],
+					'user_id_b' => $filter_data['current_user_id'],
+					//'id_b' => $id,
+					//'parent_id' => $id,
+					);
+
+		//Need to include all threads that user has posted to.
+		$query = '
+					SELECT 	a.*,
+							b.id as id,
+							c.status_id as status_id,
+							b.user_id as from_user_id,
+							bb.first_name as from_first_name,
+							bb.middle_name as from_middle_name,
+							bb.last_name as from_last_name,
+							c.user_id as to_user_id,
+							cb.first_name as to_first_name,
+							cb.middle_name as to_middle_name,
+							cb.last_name as to_last_name
+					FROM '. $this->getTable() .' as a
+						LEFT JOIN '. $msf->getTable() .' 	as b ON a.id = b.message_control_id
+						LEFT JOIN '. $uf->getTable() .' 	as bb ON b.user_id = bb.id
+						LEFT JOIN '. $mrf->getTable() .' 	as c ON b.id = c.message_sender_id
+						LEFT JOIN '. $uf->getTable() .' 	as cb ON c.user_id = cb.id
+					WHERE
+							cb.company_id = ? AND cb.company_id = bb.company_id
+							AND ( b.id = ?
+									OR b.id = ( select parent_id from '. $msf->getTable() .' where id = ? AND parent_id != 0 )
+									OR b.parent_id = ( select parent_id from '. $msf->getTable() .' where id = ? AND parent_id != 0 )
+									OR ( b.parent_id = ? )
+								)
+							AND ( b.user_id = ? OR c.user_id = ? )
+							AND ( a.deleted = 0 AND c.deleted = 0 )
+					';
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, array('from_last_name', 'to_last_name') );
+
+		//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
+
+		if ($limit == NULL) {
+			//Run query without limit
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 }
 ?>
