@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2209 $
- * $Id: PayStubEntryListFactory.class.php 2209 2008-10-21 19:12:28Z ipso $
- * $Date: 2008-10-21 12:12:28 -0700 (Tue, 21 Oct 2008) $
+ * $Revision: 3928 $
+ * $Id: PayStubEntryListFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -127,6 +127,54 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 
 		return $this;
 	}
+
+	function getByPayStubIdAndYTDAdjustment($id, $ytd_adjustment, $where = NULL, $order = NULL) {
+		if ( $id == '') {
+			return FALSE;
+		}
+
+		$strict = TRUE;
+		if ( $order == NULL ) {
+			$strict = FALSE;
+
+			$order = array( 'b.ps_order' => 'asc', 'abs(a.ytd_amount)' => 'asc', 'a.id' => 'asc' );
+		}
+
+		//This is needed to ensure the proper order of entries for pay stubs
+		//VERY IMPORTANT!
+		//notice b."order" in the query.
+		//
+		// NOTICE: For accruals, if we order ytd_amount asc negative values come before
+		// 0.00 or postitive values. Keep this in mind when calculating overall YTD totals.
+		// abs(a.ytd_amount) is CRITICAL here, this keeps negative amounts after 0.00 values
+		// and keeps negative accrual amounts from being calculated incorrectly.
+
+		$psealf = new PayStubEntryAccountListFactory();
+		$psalf = new PayStubAmendmentListFactory();
+
+		$ph = array(
+					'id' => $id,
+					'ytd_adjustment' => $this->toBool( $ytd_adjustment ),
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $psealf->getTable() .' as b ON ( a.pay_stub_entry_name_id = b.id )
+					LEFT JOIN '. $psalf->getTable() .' as c ON ( a.pay_stub_amendment_id = c.id )
+					where	a.pay_stub_id = ?
+						AND ( c.ytd_adjustment is NULL OR c.ytd_adjustment = ? )
+						AND ( a.deleted = 0 AND b.deleted = 0 AND ( c.deleted is NULL OR c.deleted = 0 ) )
+					';
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 /*
 	function getByPayStubIdAndName($id, $name, $where = NULL, $order = NULL) {
 		if ( $id == '') {
@@ -1515,5 +1563,152 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		return $this;
 	}
 
+	function getAPIReportByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array(	'default_branch',
+											'default_department',
+											'group',
+											'title',
+											'currency',
+											);
+
+		if ( $order == NULL ) {
+			$order = array( 'b.user_id' => 'asc');
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
+		$psf = new PayStubFactory();
+		$uf = new UserFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	a.*,
+							b.user_id as user_id,
+							b.pay_period_id as pay_period_id,
+							b.start_date as pay_stub_start_date,
+							b.end_date as pay_stub_end_date,
+							b.transaction_date as pay_stub_transaction_date,
+							b.currency_id as currency_id,
+							b.currency_rate as currency_rate,
+							a.pay_stub_entry_name_id as pay_stub_entry_name_id,
+							a.amount as amount,
+							a.ytd_amount as ytd_amount
+					from 	(
+							select aa.pay_stub_id as pay_stub_id,
+								aa.pay_stub_entry_name_id as pay_stub_entry_name_id,
+								sum(aa.amount) as amount,
+								max(aa.ytd_amount) as ytd_amount
+							from '. $this->getTable() .' as aa
+							LEFT JOIN '. $psf->getTable() .' as bb ON aa.pay_stub_id = bb.id
+							LEFT JOIN '. $uf->getTable() .' as cc ON bb.user_id = cc.id
+							LEFT JOIN '. $bf->getTable() .' as dd ON cc.default_branch_id = dd.id
+							LEFT JOIN '. $df->getTable() .' as ee ON cc.default_department_id = ee.id
+							LEFT JOIN '. $ugf->getTable() .' as ff ON cc.group_id = ff.id
+							LEFT JOIN '. $utf->getTable() .' as gg ON cc.title_id = gg.id
+
+							where cc.company_id = ? ';
+							if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+								$query  .=	' AND cc.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+							}
+							if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+								$query  .=	' AND cc.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+							}
+							if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+								$query  .=	' AND cc.id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+								$query  .=	' AND cc.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+								$query  .=	' AND cc.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
+								if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+									$uglf = new UserGroupListFactory();
+									$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
+								}
+								$query  .=	' AND cc.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+								$query  .=	' AND cc.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+								$query  .=	' AND cc.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
+								$query  .=	' AND cc.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['sex_id']) AND isset($filter_data['sex_id'][0]) AND !in_array(-1, (array)$filter_data['sex_id']) ) {
+								$query  .=	' AND cc.sex_id in ('. $this->getListSQL($filter_data['sex_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['currency_id']) AND isset($filter_data['currency_id'][0]) AND !in_array(-1, (array)$filter_data['currency_id']) ) {
+								$query  .=	' AND bb.currency_id in ('. $this->getListSQL($filter_data['currency_id'], $ph) .') ';
+							}
+							if ( isset($filter_data['pay_period_id']) AND isset($filter_data['pay_period_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_id']) ) {
+								$query .= 	' AND bb.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_id'], $ph) .') ';
+							}
+
+							if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+								$ph[] = $this->db->BindTimeStamp( strtolower(trim($filter_data['start_date'])) );
+								$query  .=	' AND bb.transaction_date >= ?';
+							}
+							if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+								$ph[] = $this->db->BindTimeStamp( strtolower(trim($filter_data['end_date'])) );
+								$query  .=	' AND bb.transaction_date <= ?';
+							}
+							/*
+							if ( isset($filter_data['transaction_date']) AND trim($filter_data['transaction_date']) != '' ) {
+								$ph[] = $this->db->BindTimeStamp( strtolower(trim($filter_data['transaction_date'])) );
+								$query  .=	' AND bb.transaction_date = ?';
+							}
+							*/
+
+		$query .= '
+								AND (aa.deleted = 0 AND bb.deleted = 0 AND cc.deleted=0)
+							group by aa.pay_stub_id,aa.pay_stub_entry_name_id
+							) a
+						LEFT JOIN '. $psf->getTable() .' as b ON a.pay_stub_id = b.id
+						LEFT JOIN '. $uf->getTable() .' as c ON b.user_id = c.id
+					where	1=1
+					';
+
+		$query .= 	'
+						AND (c.deleted=0)
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		Debug::Text('Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 }
 ?>
