@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PayStubAmendmentFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: PayStubAmendmentFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -109,7 +109,7 @@ class PayStubAmendmentFactory extends Factory {
 										'-1160-rate' => TTi18n::gettext('Rate'),
 										'-1170-units' => TTi18n::gettext('Units'),
 										'-1180-description' => TTi18n::gettext('Description'),
-										//'-1190-ytd_adjustment' => TTi18n::gettext('YTD'),
+										'-1190-ytd_adjustment' => TTi18n::gettext('YTD Adjustment'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
@@ -244,7 +244,7 @@ class PayStubAmendmentFactory extends Factory {
 
 		$ulf = new UserListFactory();
 
-		if ( $this->Validator->isResultSetWithRows(	'user',
+		if ( $this->Validator->isResultSetWithRows(	'user_id',
 															$ulf->getByID($id),
 															TTi18n::gettext('Invalid Employee')
 															) ) {
@@ -269,7 +269,7 @@ class PayStubAmendmentFactory extends Factory {
 		//$psenlf = new PayStubEntryNameListFactory();
 		$psealf = new PayStubEntryAccountListFactory();
 		$result = $psealf->getById( $id );
-		Debug::Arr($result, 'Result: ID: '. $id .' Rows: '. $result->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($result, 'Result: ID: '. $id .' Rows: '. $result->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 
 		if (  $this->Validator->isResultSetWithRows(	'pay_stub_entry_name_id',
 														$result,
@@ -661,7 +661,7 @@ class PayStubAmendmentFactory extends Factory {
 
 			$this->data['percent_amount_entry_name_id'] = $id;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -849,6 +849,11 @@ class PayStubAmendmentFactory extends Factory {
 				if ( isset($data[$key]) ) {
 					$function = 'set'.$function;
 					switch( $key ) {
+						case 'effective_date':
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							}
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$this->$function( $data[$key] );
@@ -921,7 +926,7 @@ class PayStubAmendmentFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Pay Stub Amendment - Employee').': '. UserListFactory::getFullNameById( $this->getUser() ) .' '.  TTi18n::getText('Amount').': '. $this->getAmount(), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Pay Stub Amendment - Employee').': '. UserListFactory::getFullNameById( $this->getUser() ) .' '.  TTi18n::getText('Amount').': '. $this->getAmount(), NULL, $this->getTable(), $this );
 	}
 }
 ?>
