@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PayStubAmendmentListFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3928 $
+ * $Id: PayStubAmendmentListFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -438,6 +438,64 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		return FALSE;
 	}
 
+	function getByCompanyIdAndAuthorizedAndStartDateAndEndDate($company_id, $authorized, $start_date, $end_date, $where = NULL, $order = NULL) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( $authorized == '') {
+			return FALSE;
+		}
+
+		if ( $start_date == '') {
+			return FALSE;
+		}
+
+		if ( $end_date == '') {
+			return FALSE;
+		}
+
+		$uf = new UserFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'authorized' => $this->toBool($authorized) ,
+					'start_date' => $start_date,
+					'end_date' => $end_date,
+					);
+
+		//CalculatePayStub uses this to find PS amendments.
+		//Because of percent amounts, make sure we order by effective date FIRST,
+		//Then FIXED amounts, then percents.
+
+
+		//Pay period end dates never equal the start start date, so >= and <= are proper.
+
+		//06-Oct-06: Start including YTD_adjustment entries for the new pay stub calculation system.
+		//						AND ytd_adjustment = 0
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+							'. $uf->getTable() .' as uf
+					where
+						a.user_id = uf.id
+						AND uf.company_id = ?
+						AND a.authorized = ?
+						AND a.effective_date >= ?
+						AND a.effective_date <= ?
+						AND a.deleted = 0
+					ORDER BY a.effective_date asc, a.type_id asc
+				';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		//Debug::text(' Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByUserIdAndAuthorizedAndStartDateAndEndDate($user_id, $authorized, $start_date, $end_date, $where = NULL, $order = NULL) {
 		if ( $user_id == '') {
 			return FALSE;
@@ -812,12 +870,19 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
+		if ( strncmp($this->db->databaseType,'mysql',5) == 0 ) {
+			$to_timestamp_sql = 'from_unixtime(a.effective_date)';
+		} else {
+			$to_timestamp_sql = 'to_timestamp(a.effective_date)';
+		}
+
 		$uf = new UserFactory();
 		$bf = new BranchFactory();
 		$df = new DepartmentFactory();
 		$ugf = new UserGroupFactory();
 		$utf = new UserTitleFactory();
 		$pseaf = new PayStubEntryAccountFactory();
+		$ppf = new PayPeriodFactory();
 
 		$ph = array(
 					'company_id' => $company_id,
@@ -854,6 +919,7 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 						LEFT JOIN '. $utf->getTable() .' as utf ON ( b.title_id = utf.id AND utf.deleted = 0 )
 
 						LEFT JOIN '. $pseaf->getTable() .' as pseaf ON ( a.pay_stub_entry_name_id = pseaf.id AND pseaf.deleted = 0 )
+						LEFT JOIN '. $ppf->getTable() .' as ppf ON ( '. $to_timestamp_sql .' >= ppf.start_date AND '. $to_timestamp_sql .' <= ppf.end_date AND ppf.deleted = 0 )
 
 						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
 						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
@@ -877,6 +943,10 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
 		}
 
+		if ( isset($filter_data['pay_period_id']) AND isset($filter_data['pay_period_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_id']) ) {
+			$query  .=	' AND ppf.id in ('. $this->getListSQL($filter_data['pay_period_id'], $ph) .') ';
+		}
+
 		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
 			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
 				$uglf = new UserGroupListFactory();
