@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3298 $
- * $Id: RecurringPayStubAmendmentFactory.class.php 3298 2010-01-20 18:52:46Z ipso $
- * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
+ * $Revision: 4073 $
+ * $Id: RecurringPayStubAmendmentFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -53,6 +53,11 @@ class RecurringPayStubAmendmentFactory extends Factory {
 
 		$retval = NULL;
 		switch( $name ) {
+			case 'filtered_status':
+				//Select box options;
+				$status_options_filter = array(50, 60);
+				$retval = Option::getByArray( $status_options_filter, $this->getOptions('status') );
+				break;
 			case 'status':
 				$retval = array(
 										10 => TTi18n::gettext('INCOMPLETE'),
@@ -91,12 +96,87 @@ class RecurringPayStubAmendmentFactory extends Factory {
 											20 => TTi18n::gettext('Percent')
 										);
 				break;
+			case 'pay_stub_account_type':
+				$retval = array(10,20,30,50,60,65);
+				break;
+			case 'percent_pay_stub_account_type':
+				$retval = array(10,20,30,40,50,60,65);
+				break;
+			case 'columns':
+				$retval = array(
+										'-1000-name' => TTi18n::gettext('Name'),
+										'-1002-description' => TTi18n::gettext('Description'),
+
+										'-1110-status' => TTi18n::gettext('Status'),
+										'-1115-frequency' => TTi18n::gettext('Frequency'),
+										'-1120-type' => TTi18n::gettext('Type'),
+										'-1130-pay_stub_entry_name' => TTi18n::gettext('Account'),
+										'-1140-effective_date' => TTi18n::gettext('Effective Date'),
+										'-1150-amount' => TTi18n::gettext('Amount'),
+										'-1160-rate' => TTi18n::gettext('Rate'),
+										'-1170-units' => TTi18n::gettext('Units'),
+
+										'-1180-ps_amendment_description' => TTi18n::gettext('PS Amendment Description'),
+
+										'-1190-start_date' => TTi18n::gettext('Start Date'),
+										'-1190-end_date' => TTi18n::gettext('End Date'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'status',
+								'name',
+								'description',
+								'type',
+								'frequency',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
 
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'start_date' => 'StartDate',
+										'end_date' => 'EndDate',
+										'frequency_id' => 'Frequency',
+										'frequency' => FALSE,
+										'name' => 'Name',
+										'description' => 'Description',
+										'pay_stub_entry_name_id' => 'PayStubEntryNameId',
+										'pay_stub_entry_name' => FALSE,
+										'status_id' => 'Status',
+										'status' => FALSE,
+										'type_id' => 'Type',
+										'type' => FALSE,
+										'rate' => 'Rate',
+										'units' => 'Units',
+										'amount' => 'Amount',
+										'percent_amount' => 'PercentAmount',
+										'percent_amount_entry_name_id' => 'PercentAmountEntryNameId',
+										'ps_amendment_description' => 'PayStubAmendmentDescription',
+										'user' => 'User',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
 
 	function getCompany() {
 		if ( isset($this->data['company_id']) ) {
@@ -198,7 +278,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 
 			$this->data['frequency_id'] = $status;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -270,43 +350,71 @@ class RecurringPayStubAmendmentFactory extends Factory {
 		return FALSE;
 	}
 	function setUser($ids) {
-		if (is_array($ids) ) {
-			if ( in_array(0, $ids ) ) {
+		if ( !is_array($ids) ) {
+			$ids = array($ids);
+		}
+		Debug::Arr($ids, 'Selected IDs: ', __FILE__, __LINE__, __METHOD__, 10);
+
+		if ( is_array($ids) ) {
+			if ( in_array( -1, $ids ) ) {
 				Debug::text('All Users is selected: ', __FILE__, __LINE__, __METHOD__, 10);
-				$ids = array(0);
+				$ids = array(-1);
 			}
 
-			//If needed, delete mappings first.
-			$rpsaulf = new RecurringPayStubAmendmentUserListFactory();
-			$rpsaulf->getByRecurringPayStubAmendment( $this->getId() );
+			if ( !$this->isNew() ) {
+				//If needed, delete mappings first.
+				$rpsaulf = new RecurringPayStubAmendmentUserListFactory();
+				$rpsaulf->getByRecurringPayStubAmendment( $this->getId() );
 
-			$user_ids = array();
-			foreach ($rpsaulf as $ps_amendment_user) {
-				$user_id = $ps_amendment_user->getUser();
-				Debug::text('Recurring PS Amendment ID: '. $ps_amendment_user->getRecurringPayStubAmendment() .' User: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
+				$tmp_ids = array();
+				foreach ($rpsaulf as $obj) {
+					$id = $obj->getUser();
+					Debug::text('Recurring Schedule ID: '. $obj->getRecurringPayStubAmendment() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
 
-				//Delete users that are not selected.
-				if ( !in_array($user_id, $ids) ) {
-					Debug::text('Deleting PS Amendment User: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
-					$ps_amendment_user->Delete();
-				} else {
-					//Save branch ID's that need to be updated.
-					Debug::text('NOT Deleting PS Amendment User: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
-					$user_ids[] = $user_id;
+					//Delete users that are not selected.
+					if ( !in_array($id, $ids) ) {
+						Debug::text('Deleting: '. $id, __FILE__, __LINE__, __METHOD__, 10);
+						$obj->Delete();
+					} else {
+						//Save ID's that need to be updated.
+						Debug::text('NOT Deleting : '. $id, __FILE__, __LINE__, __METHOD__, 10);
+						$tmp_ids[] = $id;
+					}
 				}
+				unset($id, $obj);
 			}
 
 			//Insert new mappings.
-			$rpsauf = new RecurringPayStubAmendmentUserFactory();
+			$ulf = new UserListFactory();
 			foreach ($ids as $id) {
-				if ( !in_array($id, $user_ids) ) {
-					$rpsauf->setRecurringPayStubAmendment( $this->getId() );
-					$rpsauf->setUser( $id );
+				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
+					if ( $id == -1 ) {
+						Debug::text('--ALL-- Employees selected...', __FILE__, __LINE__, __METHOD__, 10);
+						$rpsauf = new RecurringPayStubAmendmentUserFactory();
+						$rpsauf->setRecurringPayStubAmendment( $this->getId() );
+						$rpsauf->setUser( $id );
 
-					if ($this->Validator->isTrue(		'user',
-														$rpsauf->Validator->isValid(),
-														TTi18n::gettext('Invalid User'))) {
-						$rpsauf->save();
+						if ($this->Validator->isTrue(		'user',
+															$rpsauf->Validator->isValid(),
+															TTi18n::gettext('Invalid Employee') ) ) {
+							$rpsauf->save();
+						}
+
+					} else {
+						$rpsauf = new RecurringPayStubAmendmentUserFactory();
+						$rpsauf->setRecurringPayStubAmendment( $this->getId() );
+						$rpsauf->setUser( $id );
+
+						$ulf->getById( $id );
+						if ( $ulf->getRecordCount() > 0 ) {
+							$obj = $ulf->getCurrent();
+
+							if ($this->Validator->isTrue(		'user',
+																$rpsauf->Validator->isValid(),
+																TTi18n::gettext('Selected Employee is invalid').' ('. $obj->getFullName() .')' )) {
+								$rpsauf->save();
+							}
+						}
 					}
 				}
 			}
@@ -314,6 +422,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 			return TRUE;
 		}
 
+		Debug::text('No User IDs to set.', __FILE__, __LINE__, __METHOD__, 10);
 		return FALSE;
 	}
 
@@ -326,20 +435,16 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	}
 	function setPayStubEntryNameId($id) {
 		$id = trim($id);
-/*
-		$psenlf = new PayStubEntryNameListFactory();
-		$result = $psenlf->getById( $id )->getCurrent();
-*/
-		$psealf = new PayStubEntryAccountListFactory();
-		$result = $psealf->getById( $id )->getCurrent();
 
+		$psealf = new PayStubEntryAccountListFactory();
+		$psealf->getById( $id );
 
 		if (  $this->Validator->isResultSetWithRows(	'pay_stub_entry_name_id',
-														$result,
-														TTi18n::gettext('Invalid Type')
+														$psealf,
+														TTi18n::gettext('Invalid Pay Stub Account')
 														) ) {
 
-			$this->data['pay_stub_entry_name_id'] = $result->getId();
+			$this->data['pay_stub_entry_name_id'] = $psealf->getCurrent()->getId();
 
 			return TRUE;
 		}
@@ -388,7 +493,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 
 			$this->data['status_id'] = $status;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -432,11 +537,9 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	function setRate($value) {
 		$value = trim($value);
 
-		/*
-		if ($value == NULL OR $value == '') {
-			return FALSE;
+		if ($value == 0 OR $value == '') {
+			$value = NULL;
 		}
-		*/
 
 		if (	empty($value) OR
 				$this->Validator->isFloat(				'rate',
@@ -444,6 +547,8 @@ class RecurringPayStubAmendmentFactory extends Factory {
 														TTi18n::gettext('Invalid Rate')
 														) ) {
 			Debug::text('Setting Rate to: '. $value, __FILE__, __LINE__, __METHOD__,10);
+			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
+			//$this->data['rate'] = Misc::MoneyFormat( $value, FALSE );
 			$this->data['rate'] = $value;
 
 			return TRUE;
@@ -462,16 +567,17 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	function setUnits($value) {
 		$value = trim($value);
 
-		/*
-		if ($value == NULL OR $value == '') {
-			return FALSE;
+		if ($value == 0 OR $value == '') {
+			$value = NULL;
 		}
-		*/
+
 		if (	empty($value) OR
 				$this->Validator->isFloat(				'units',
 														$value,
 														TTi18n::gettext('Invalid Units')
 														) ) {
+			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
+			//$this->data['units'] = Misc::MoneyFormat( $value, FALSE );
 			$this->data['units'] = $value;
 
 			return TRUE;
@@ -545,15 +651,16 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	}
 	function setPercentAmountEntryNameId($id) {
 		$id = trim($id);
-/*
-		$psenlf = new PayStubEntryNameListFactory();
-		$result = $psenlf->getById( $id )->getCurrent();
-*/
-		$psealf = new PayStubEntryAccountListFactory();
-		$result = $psealf->getById( $id )->getCurrent();
 
-		if (  $this->Validator->isResultSetWithRows(	'percent_amount_entry_name',
-														$result,
+		$psealf = new PayStubEntryAccountListFactory();
+		$psealf->getById( $id );
+		//Not sure why we tried to use $result here, as if the ID passed is NULL, it causes a fatal error.
+		//$result = $psealf->getById( $id )->getCurrent();
+
+		if (	( $id == NULL OR $id == 0 )
+				OR
+				$this->Validator->isResultSetWithRows(	'percent_amount_entry_name',
+														$psealf,
 														TTi18n::gettext('Invalid Percent Of')
 														) ) {
 
@@ -800,12 +907,15 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	}
 
 	function Validate() {
-		//If amount is set, make sure percent is cleared.
+
+		/*
+		//If amount is set, make sure percent is cleared. The type defines this, so its not really needed.
 		if ( $this->getAmount() != '' AND $this->getPercentAmount() != '' ) {
 			$this->Validator->isTrue(		'amount',
 											FALSE,
 											TTi18n::gettext('Fixed Amount and Percent cannot both be entered'));
 		}
+		*/
 
 		if ( $this->getType() == 10 ) {
 			//If rate and units are set, and not amount, calculate the amount for us.
@@ -880,8 +990,80 @@ class RecurringPayStubAmendmentFactory extends Factory {
 		}
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'start_date':
+						case 'end_date':
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$uf = new UserFactory();
+
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'pay_stub_entry_name':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'status':
+						case 'type':
+						case 'frequency':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'start_date':
+						case 'end_date':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = TTDate::getAPIDate( 'DATE', $this->$function() );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Pay Stub Amendment'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Pay Stub Amendment'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
