@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PayPeriodFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3928 $
+ * $Id: PayPeriodFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -56,7 +56,7 @@ class PayPeriodFactory extends Factory {
 				$retval = array(
 										10 => TTi18n::gettext('OPEN'),
 										12 => TTi18n::gettext('Locked - Pending Approval'), //Go to this state as soon as date2 is passed
-										15 => TTi18n::gettext('Locked - Pending Transaction'), //Go to this as soon as approved, or 48hrs before transaction date.
+										//15 => TTi18n::gettext('Locked - Pending Transaction'), //Go to this as soon as approved, or 48hrs before transaction date.
 										20 => TTi18n::gettext('CLOSED'), //Once paid
 										30 => TTi18n::gettext('Post Adjustment')
 									);
@@ -71,6 +71,16 @@ class PayPeriodFactory extends Factory {
 										'-1050-end_date' => TTi18n::gettext('End Date'),
 										'-1060-transaction_date' => TTi18n::gettext('Transaction Date'),
 
+										'-1500-pending_requests' => TTi18n::gettext('Pending Requests'),
+										'-1510-exceptions_high' => TTi18n::gettext('High'),
+										'-1512-exceptions_medium' => TTi18n::gettext('Medium'),
+										'-1514-exceptions_low' => TTi18n::gettext('Low'),
+										'-1520-verified_timesheets' => TTi18n::gettext('Verified'),
+										'-1522-pending_timesheets' => TTi18n::gettext('Pending'),
+										'-1524-total_timesheets' => TTi18n::gettext('Total'),
+										'-1530-ps_amendments' => TTi18n::gettext('PS Amendments'),
+										'-1540-pay_stubs' => TTi18n::gettext('Pay Stubs'),
+
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
 										'-2020-updated_by' => TTi18n::gettext('Updated By'),
@@ -120,6 +130,17 @@ class PayPeriodFactory extends Factory {
 											//'tainted' => 'Tainted',
 											//'tainted_date' => 'TaintedDate',
 											//'tainted_by' => 'TaintedBy',
+
+											'pending_requests' => 'PendingRequests',
+											'exceptions_high' => 'Exceptions',
+											'exceptions_medium' => 'Exceptions',
+											'exceptions_low' => 'Exceptions',
+											'verified_timesheets' => 'TimeSheets',
+											'pending_timesheets' => 'TimeSheets',
+											'total_timesheets' => 'TimeSheets',
+											'ps_amendments' => 'PayStubAmendments',
+											'pay_stubs' => 'PayStubs',
+
 											'deleted' => 'Deleted',
 											);
 			return $variable_function_map;
@@ -647,6 +668,99 @@ class PayPeriodFactory extends Factory {
 		return TRUE;
 	}
 
+	function getPendingRequests() {
+		if ( $this->getCompany() != '' AND $this->isNew() == FALSE ) {
+			//Get all pending requests
+			$rlf = new RequestListFactory();
+			$rlf->getSumByCompanyIDAndPayPeriodIdAndStatus( $this->getCompany(), $this->getID(), 30 );
+			if ( $rlf->getRecordCount() == 1 ) {
+				return $rlf->getCurrent()->getColumn('total');
+			}
+
+			return 0;
+		}
+
+		return FALSE;
+	}
+
+	function getExceptions() {
+		$retarr = array(
+						'exceptions_low' => 0,
+						'exceptions_medium' => 0,
+						'exceptions_high' => 0,
+						);
+
+		$elf = new ExceptionListFactory();
+		$elf->getSumExceptionsByPayPeriodIdAndBeforeDate( $this->getID(), $this->getEndDate() );
+		if ( $elf->getRecordCount() > 0 ) {
+			Debug::Text(' Found Exceptions: '. $elf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+			foreach($elf as $e_obj ) {
+				if ( $e_obj->getColumn('severity_id') == 10 ) {
+					$retarr['exceptions_low'] = $e_obj->getColumn('count');
+				}
+				if ( $e_obj->getColumn('severity_id') == 20 ) {
+					$retarr['exceptions_medium'] = $e_obj->getColumn('count');
+				}
+				if ( $e_obj->getColumn('severity_id') == 30 ) {
+					$retarr['exceptions_high']= $e_obj->getColumn('count');
+				}
+
+			}
+		} else {
+			Debug::Text(' No Exceptions!', __FILE__, __LINE__, __METHOD__,10);
+		}
+
+		return $retarr;
+	}
+
+	function getTimeSheets() {
+		$retarr = array(
+						'verified_timesheets' => 0,
+						'pending_timesheets' => 0,
+						'total_timesheets' => 0,
+						);
+
+		//Get verified timesheets
+		$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+		$pptsvlf->getByPayPeriodIdAndCompanyId( $this->getID(), $this->getCompany() );
+		if ( $pptsvlf->getRecordCount() > 0 ) {
+			foreach( $pptsvlf as $pptsv_obj ) {
+				if ( $pptsv_obj->getAuthorized() == TRUE ) {
+					$retarr['verified_timesheets']++;
+				} elseif (  $pptsv_obj->getStatus() == 30 OR $pptsv_obj->getStatus() == 45 ) {
+					$retarr['pending_timesheets']++;
+				}
+			}
+		}
+
+		//Get total employees with time for this pay period.
+		$udtlf = new UserDateTotalListFactory();
+		$retarr['total_timesheets'] = $udtlf->getWorkedUsersByPayPeriodId( $this->getID() );
+
+		return $retarr;
+	}
+
+	function getPayStubAmendments() {
+		//Get PS Amendments.
+		$psalf = new PayStubAmendmentListFactory();
+		$psalf->getByCompanyIdAndAuthorizedAndStartDateAndEndDate( $this->getCompany(), TRUE, $this->getStartDate(), $this->getEndDate() );
+		$total_ps_amendments = 0;
+		if ( is_object($psalf) ) {
+			$total_ps_amendments = $psalf->getRecordCount();
+		}
+
+		Debug::Text(' Total PS Amendments: '. $total_ps_amendments, __FILE__, __LINE__, __METHOD__,10);
+		return $total_ps_amendments;
+	}
+
+	function getPayStubs() {
+		//Count how many pay stubs for each pay period.
+		$pslf = new PayStubListFactory();
+		$total_pay_stubs = $pslf->getByPayPeriodId( $this->getId() )->getRecordCount();
+		Debug::Text(' Total Pay Stubs: '. $total_pay_stubs, __FILE__, __LINE__, __METHOD__,10);
+		return $total_pay_stubs;
+	}
+
 	function Validate() {
 		//Make sure there aren't conflicting pay periods.
 		//Start date checks that...
@@ -750,10 +864,10 @@ class PayPeriodFactory extends Factory {
 		} else {
 			if ( $this->getStatus() == 20 ) { //Closed
 				//Mark pay stubs as PAID once the pay period is closed?
-				TTLog::addEntry( $this->getId(), 'Edit',  TTi18n::getText('Setting Pay Period to Closed'), NULL, $this->getTable() );
+				TTLog::addEntry( $this->getId(), 20,  TTi18n::getText('Setting Pay Period to Closed'), NULL, $this->getTable() );
 				$this->setPayStubStatus(40);
 			} elseif ( $this->getStatus() == 30 ) {
-				TTLog::addEntry( $this->getId(), 'Edit',  TTi18n::getText('Setting Pay Period to Post-Adjustment'), NULL, $this->getTable() );
+				TTLog::addEntry( $this->getId(), 20,  TTi18n::getText('Setting Pay Period to Post-Adjustment'), NULL, $this->getTable() );
 			}
 
 			if ( $this->getEnableImportData() == TRUE ) {
@@ -833,6 +947,38 @@ class PayPeriodFactory extends Factory {
 								$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', $this->$function() );
 							}
 							break;
+						case 'pending_requests':
+						case 'ps_amendments':
+						case 'pay_stubs':
+							//These functions are slow to obtain, so make sure the column is requested explicitly before we include it.
+							if ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+						case 'exceptions_high':
+						case 'exceptions_medium':
+						case 'exceptions_low':
+							//These functions are slow to obtain, so make sure the column is requested explicitly before we include it.
+							if ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) {
+								if ( !isset($exceptions_arr) ) {
+									$exceptions_arr = $this->getExceptions();
+								}
+
+								$data[$variable] = $exceptions_arr[$variable];
+							}
+							break;
+						case 'verified_timesheets':
+						case 'pending_timesheets':
+						case 'total_timesheets':
+							//These functions are slow to obtain, so make sure the column is requested explicitly before we include it.
+							if ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) {
+								if ( !isset($timesheet_arr) ) {
+									$timesheet_arr = $this->getTimeSheets();
+								}
+
+								$data[$variable] = $timesheet_arr[$variable];
+							}
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
@@ -849,7 +995,7 @@ class PayPeriodFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Pay Period'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Pay Period') .' - '. TTi18n::getText('Start Date') .': '. TTDate::getDate('DATE+TIME', $this->getStartDate() ) .' '. TTi18n::getText('End Date') .': '. TTDate::getDate('DATE+TIME', $this->getEndDate() ) .' '. TTi18n::getText('Transaction Date') .': '. TTDate::getDate('DATE+TIME', $this->getTransactionDate() ), NULL, $this->getTable(), $this );
 	}
 }
 ?>
