@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3298 $
- * $Id: PayPeriodListFactory.class.php 3298 2010-01-20 18:52:46Z ipso $
- * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
+ * $Revision: 3939 $
+ * $Id: PayPeriodListFactory.class.php 3939 2010-11-19 22:41:24Z ipso $
+ * $Date: 2010-11-19 14:41:24 -0800 (Fri, 19 Nov 2010) $
  */
 
 /**
@@ -104,8 +104,7 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 							'. $ppsf->getTable() .' as b
 					where	a.pay_period_schedule_id = b.id
 						AND a.id in ( '. $this->getListSQL($ids, $ph) .' )
-						AND a.deleted=0
-						AND b.deleted=0';
+						AND ( a.deleted = 0 AND b.deleted = 0 )';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
@@ -154,21 +153,27 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 			return FALSE;
 		}
 
+		Debug::Text('Total Rows: '. $lf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+
 		if ( $include_blank == TRUE ) {
 			$list[0] = '--';
 		}
 
 		$use_names = FALSE;
 
-		//Get all pay period schedules.
+		//Get all pay period schedules, if more than one pay period schedule is in use, include PP schedule name.
+		$pay_period_schedule_id = array();
+		$i=0;
 		foreach ($lf as $obj) {
-			if ( is_object($obj->getPayPeriodScheduleObject()) ) {
-				$pay_period_schedule_id[$obj->getPayPeriodScheduleObject()->getId()] = $obj->getPayPeriodScheduleObject()->getName();
+			if ( !isset($pay_period_schedule_id[$obj->getPayPeriodSchedule()]) ) {
+				$pay_period_schedule_id[$obj->getPayPeriodSchedule()] = TRUE;
+				$i++;
+			}
+
+			if ( $i >= 2 ) {
+				$use_names = TRUE;
+				break;
 			}
-		}
-		$use_names = FALSE;
-		if ( isset($pay_period_schedule_id) AND count($pay_period_schedule_id) > 1 ) {
-			$use_names = TRUE;
 		}
 
 		$prefix = NULL;
@@ -635,6 +640,198 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 		return $this;
 	}
 
+	function getByCompanyIDAndPayPeriodScheduleIdAndStartTransactionDateAndEndTransactionDate($company_id, $id, $start_transaction_date, $end_transaction_date, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $company_id == '' ) {
+			return FALSE;
+		}
+
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		if ( $start_transaction_date == '' ) {
+			return FALSE;
+		}
+
+		if ( $end_transaction_date == '' ) {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'a.transaction_date' => 'desc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$ppsf = new PayPeriodScheduleFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'start_date' => $this->db->BindTimeStamp( $start_transaction_date ),
+					'end_date' => $this->db->BindTimeStamp( $end_transaction_date ),
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $ppsf->getTable() .' as ppsf ON ( a.pay_period_schedule_id = ppsf.id )
+					where 	ppsf.company_id = ?
+						AND a.transaction_date >= ?
+						AND a.transaction_date <= ?
+						AND a.pay_period_schedule_id in ( '. $this->getListSQL($id, $ph) .' )
+						AND a.deleted=0';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		//Debug::Text('Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
+	function getByCompanyIDAndPayPeriodScheduleIdAndAnyDate($company_id, $id, $date, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $company_id == '' ) {
+			return FALSE;
+		}
+
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'a.transaction_date' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$ppsf = new PayPeriodScheduleFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'start_date' => $this->db->BindTimeStamp( $date ),
+					'end_date' => $this->db->BindTimeStamp( $date ),
+					'transaction_date' => $this->db->BindTimeStamp( $date ),
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $ppsf->getTable() .' as ppsf ON ( a.pay_period_schedule_id = ppsf.id )
+					where 	ppsf.company_id = ?
+						AND ( a.start_date >= ? OR a.end_date >= ? OR a.transaction_date >= ? )
+						AND a.pay_period_schedule_id in ( '. $this->getListSQL($id, $ph) .' )
+						AND a.deleted=0';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		//Debug::Arr($ph, 'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
+	function getThisPayPeriodByCompanyIdAndPayPeriodScheduleIdAndDate($company_id, $id, $date, $where = NULL, $order = NULL) {
+		if ( $company_id == '' ) {
+			return FALSE;
+		}
+
+		//ID can be blank/NULL, which means we search all pay_period schedules.
+		if ( $date == '' ) {
+			return FALSE;
+		}
+
+		$ppsf = new PayPeriodScheduleFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'start_date' => $this->db->BindTimeStamp( $date ),
+					'end_date' => $this->db->BindTimeStamp( $date ),
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $ppsf->getTable() .' as ppsf ON ( a.pay_period_schedule_id = ppsf.id )
+					where ppsf.company_id = ?
+						AND a.start_date <= ?
+						AND a.end_date >= ? ';
+
+		if ( isset($id[0]) AND !in_array(-1, (array)$id) ) {
+			$query .= '
+							AND a.pay_period_schedule_id in ( '. $this->getListSQL($id, $ph) .' ) ';
+		}
+
+		$query .= '		AND ( a.deleted = 0 AND ppsf.deleted = 0)';
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
+	function getLastPayPeriodByCompanyIdAndPayPeriodScheduleIdAndDate($company_id, $id, $date, $where = NULL, $order = NULL) {
+		if ( $company_id == '' ) {
+			return FALSE;
+		}
+
+		//ID can be blank/NULL, which means we search all pay_period schedules.
+		if ( $date == '' ) {
+			return FALSE;
+		}
+
+		$ppsf = new PayPeriodScheduleFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'end_date' => $this->db->BindTimeStamp( $date ),
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+					( 	select
+							b.pay_period_schedule_id,
+							max(b.start_date) as start_date
+						FROM '. $this->getTable() .' as b
+						LEFT JOIN '. $ppsf->getTable() .' as ppsf ON ( b.pay_period_schedule_id = ppsf.id )
+						where ppsf.company_id = ?
+							AND b.end_date < ?
+							AND ( b.deleted = 0 AND ppsf.deleted = 0 )
+						GROUP BY b.pay_period_schedule_id
+					) as pp2
+
+					where a.pay_period_schedule_id = pp2.pay_period_schedule_id
+						AND a.start_date = pp2.start_date ';
+
+		if ( isset($id[0]) AND !in_array(-1, (array)$id) ) {
+			$query .= '
+							AND a.pay_period_schedule_id in ( '. $this->getListSQL($id, $ph) .' ) ';
+		}
+
+		$query .= '		AND ( a.deleted = 0 )';
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByPayPeriodScheduleIdAndTransactionDate($id, $transaction_date, $where = NULL, $order = NULL) {
 		if ( $id == '' ) {
 			return FALSE;
@@ -937,13 +1134,14 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 		$uf = new UserFactory();
 		$psf = new PayStubFactory();
 
+		//Make sure just one row per pay period is returned.
 		$query = '
 					select 	a.*
 					from	'. $this->getTable() .' as a
-					LEFT JOIN '. $psf->getTable() .' as b ON a.id = b.pay_period_id
 					where	a.company_id = ?
-						AND b.id IS NOT NULL
-						AND ( a.deleted = 0 AND b.deleted = 0 )';
+						AND ( a.deleted = 0 )
+						AND EXISTS ( select id from '. $psf->getTable() .' as b WHERE a.id = b.pay_period_id AND b.deleted = 0)';
+
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
