@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PayPeriodScheduleFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3883 $
+ * $Id: PayPeriodScheduleFactory.class.php 3883 2010-10-01 21:10:50Z ipso $
+ * $Date: 2010-10-01 14:10:50 -0700 (Fri, 01 Oct 2010) $
  */
 
 /**
@@ -60,14 +60,14 @@ class PayPeriodScheduleFactory extends Factory {
 				 */
 				$retval = array(
 											5 => TTi18n::gettext('Manual'),
-											10  => TTi18n::gettext('Weekly'),
-											20  => TTi18n::gettext('Bi-Weekly'),
-											30  => TTi18n::gettext('Semi-Monthly'),
+											10  => TTi18n::gettext('Weekly (52/year)'),
+											20  => TTi18n::gettext('Bi-Weekly (26/year)'),
+											30  => TTi18n::gettext('Semi-Monthly (24/year)'),
 											//40  => TTi18n::gettext('Monthly + Advance'), //Handled with monthly PP schedule and Tax / Deduction to automatically enter advance each month. Advances are paid manually.
-											50  => TTi18n::gettext('Monthly') //Must have this here, for ROEs
+											50  => TTi18n::gettext('Monthly (12/year)') //Must have this here, for ROEs
 										);
 				break;
-			case 'startweekday':
+			case 'start_week_day':
 				$retval = array(
 											0 => TTi18n::gettext('Sunday-Saturday'),
 											1 => TTi18n::gettext('Monday-Sunday'),
@@ -86,6 +86,11 @@ class PayPeriodScheduleFactory extends Factory {
 											40 => TTi18n::gettext('Each Day (Split at Midnight)'),
 										);
 				break;
+			case 'transaction_date':
+				for ($i=1; $i <= 31; $i++) {
+					$retval[$i] = $i;
+				}
+				break;
 			case 'transaction_date_business_day':
 				$retval = array(
 											//Adjust Transaction Date To:
@@ -105,10 +110,11 @@ class PayPeriodScheduleFactory extends Factory {
 				break;
 			case 'columns':
 				$retval = array(
-										'-1010-type_id' => TTi18n::gettext('Type'),
+										'-1010-type' => TTi18n::gettext('Type'),
 										'-1020-name' => TTi18n::gettext('Name'),
 										'-1030-description' => TTi18n::gettext('Description'),
-										'-1040-shift_assigned_day_id' => TTi18n::gettext('Assign Shifts To'),
+										'-1030-start_week_day' => TTi18n::gettext('Overtime Week'),
+										'-1040-shift_assigned_day' => TTi18n::gettext('Assign Shifts To'),
 										'-1050-time_zone' => TTi18n::gettext('TimeZone'),
 										'-1060-new_day_trigger_time' => TTi18n::gettext('Minimum Time Off Between Shifts'),
 										'-1070-maximum_shift_time' => TTi18n::gettext('Maximum Shift Time'),
@@ -137,16 +143,21 @@ class PayPeriodScheduleFactory extends Factory {
 										'id' => 'ID',
 										'company_id' => 'Company',
 										'type_id' => 'Type',
+										'type' => FALSE,
 										'start_week_day_id' => 'StartWeekDay',
+										'start_week_day' => FALSE,
 										'shift_assigned_day_id' => 'ShiftAssignedDay',
+										'shift_assigned_day' => FALSE,
 										'name' => 'Name',
 										'description' => 'Description',
 										'start_day_of_week' => 'StartDayOfWeek',
 										'transaction_date' => 'TransactionDate',
+
 										'primary_day_of_month' => 'PrimaryDayOfMonth',
 										'secondary_day_of_month' => 'SecondaryDayOfMonth',
 										'primary_transaction_day_of_month' => 'PrimaryTransactionDayOfMonth',
 										'secondary_transaction_day_of_month' => 'SecondaryTransactionDayOfMonth',
+
 										'transaction_date_bd' => 'TransactionDateBusinessDay',
 										'anchor_date' => 'AnchorDate',
 										'day_start_time' => 'DayStartTime',
@@ -154,6 +165,13 @@ class PayPeriodScheduleFactory extends Factory {
 										'day_continuous_time' => 'ContinuousTime',
 										'new_day_trigger_time' => 'NewDayTriggerTime',
 										'maximum_shift_time' => 'MaximumShiftTime',
+										'annual_pay_periods' => 'AnnualPayPeriods',
+										'timesheet_verify_type_id' => 'TimeSheetVerifyType',
+										'timesheet_verify_before_end_date' => 'TimeSheetVerifyBeforeEndDate',
+										'timesheet_verify_before_transaction_date' => 'TimeSheetVerifyBeforeTransactionDate',
+										//'timesheet_verify_notice_before_transaction_date' => 'TimeSheetVerifyNoticeBeforeTransactionDate',
+										//'timesheet_verify_notice_email' => 'TimeSheetVerifyNoticeEmail',
+										'user' => 'User',
 										'deleted' => 'Deleted',
 										);
 		return $variable_function_map;
@@ -216,7 +234,7 @@ class PayPeriodScheduleFactory extends Factory {
 	function setStartWeekDay($val) {
 		$val = trim($val);
 
-		$key = Option::getByValue($val, $this->getOptions('startweekday') );
+		$key = Option::getByValue($val, $this->getOptions('start_week_day') );
 		if ($key !== FALSE) {
 			$type = $key;
 		}
@@ -224,7 +242,7 @@ class PayPeriodScheduleFactory extends Factory {
 		if ( $this->Validator->inArrayKey(	'start_week_day',
 											$val,
 											TTi18n::gettext('Incorrect Start Week Day'),
-											$this->getOptions('startweekday')) ) {
+											$this->getOptions('start_week_day')) ) {
 
 			$this->data['start_week_day_id'] = $val;
 
@@ -402,10 +420,10 @@ class PayPeriodScheduleFactory extends Factory {
 			$val = $key;
 		}
 
-		if ( $val == -1
+		if ( 	( $val == -1 OR $val == '' OR $val == 0 )
 				OR $this->Validator->inArrayKey(	'primary_day_of_month',
 											$val,
-											TTi18n::gettext('Incorrect primary day of month'),
+											TTi18n::getText('Incorrect primary day of month'),
 											TTDate::getDayOfMonthArray() ) ) {
 
 			$this->data['primary_day_of_month'] = $val;
@@ -431,7 +449,7 @@ class PayPeriodScheduleFactory extends Factory {
 			$val = $key;
 		}
 
-		if ( $val == -1
+		if ( 	( $val == -1 OR $val == '' OR $val == 0 )
 				OR $this->Validator->inArrayKey(	'secondary_day_of_month',
 											$val,
 											TTi18n::gettext('Incorrect secondary day of month'),
@@ -460,7 +478,7 @@ class PayPeriodScheduleFactory extends Factory {
 			$val = $key;
 		}
 
-		if ( $val == -1
+		if ( 	( $val == -1 OR $val == '' OR $val == 0 )
 				OR $this->Validator->inArrayKey(	'primary_transaction_day_of_month',
 											$val,
 											TTi18n::gettext('Incorrect primary transaction day of month'),
@@ -489,7 +507,7 @@ class PayPeriodScheduleFactory extends Factory {
 			$val = $key;
 		}
 
-		if ( $val == -1
+		if ( 	( $val == -1 OR $val == '' OR $val == 0 )
 				OR $this->Validator->inArrayKey(	'secondary_transaction_day_of_month',
 											$val,
 											TTi18n::gettext('Incorrect secondary transaction day of month'),
@@ -597,17 +615,12 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 	function setTimeZone($time_zone) {
-		$time_zone = trim($time_zone);
-
-		$key = Option::getByValue($time_zone, $this->getTimeZoneOptions() );
-		if ($key !== FALSE) {
-			$time_zone = $key;
-		}
+		$time_zone = Misc::trimSortPrefix( trim($time_zone) );
 
 		if ( $this->Validator->inArrayKey(	'time_zone',
 											$time_zone,
 											TTi18n::gettext('Incorrect time zone'),
-											$this->getTimeZoneOptions() ) ) {
+											Misc::trimSortPrefix( $this->getTimeZoneOptions() ) ) ) {
 
 			$this->data['time_zone'] = $time_zone;
 
@@ -826,6 +839,10 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 	function setUser($ids) {
+		if ( !is_array($ids) ) {
+			$ids = array($ids);
+		}
+
 		if ( is_array($ids) ) {
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
@@ -1428,14 +1445,9 @@ class PayPeriodScheduleFactory extends Factory {
 				//When editing, simply pass the existing PunchControl object to this function so we can
 				//use it instead of the one in the database perhaps?
 				$total_time = $punch_control_obj->getTotalTime();
-/*
+
 				//We can't skip records with total_time == 0, because then when deleting one of the two
 				//punches in a pair, the remaining punch is ignored and causing punches to jump around between days in some cases.
-				if ( $total_time == 0 ) {
-					Debug::text('Total time is 0, skipping this punch control object...', __FILE__, __LINE__, __METHOD__, 10);
-					//continue;
-				}
-*/
 				if ( $i > 0 AND isset($shift_data[$shift]['last_out'])
 						AND ( $p_obj->getStatus() == 10 OR $p_obj->getStatus() == $prev_punch_arr['status_id'] )) {
 					//Debug::text('Checking for new shift...', __FILE__, __LINE__, __METHOD__, 10);
@@ -1558,6 +1570,13 @@ class PayPeriodScheduleFactory extends Factory {
 						$last_out = $shift_data['first_in']['time_stamp'];
 					}
 
+					//The check below must occur so if the user attempts to add an In punch that occurs AFTER the Out punch, this function
+					//still returns the shift data, so the validation checks can occur in PunchControl factory.
+					if ( $first_in > $last_out ) {
+						//It appears that the first in punch has occurred after the OUT punch, so swap first_in and last_out, so we don't return FALSE in this case.
+						list( $first_in, $last_out ) = array( $last_out, $first_in );
+					}
+
 					if ( TTDate::isTimeOverLap($epoch, $epoch, ($first_in-$new_shift_trigger_time), ($last_out+$new_shift_trigger_time) ) == FALSE ) {
 						Debug::Text('Nearest shift is outside the new shift trigger time... Epoch: '. $epoch .' First In: '. $first_in .' Last Out: '. $last_out .' New Shift Trigger: '. $new_shift_trigger_time, __FILE__, __LINE__, __METHOD__, 10);
 
@@ -1649,6 +1668,8 @@ class PayPeriodScheduleFactory extends Factory {
 	}
 
 	function postSave() {
+		$this->removeCache( $this->getId() );
+
 		if ( $this->getEnableInitialPayPeriods() == TRUE AND $this->getCreateInitialPayPeriods() == TRUE ) {
 			$ppslf = new PayPeriodScheduleListFactory();
 			$pay_period_schedule_obj = $ppslf->getById( $this->getId() )->getCurrent();
@@ -1680,6 +1701,21 @@ class PayPeriodScheduleFactory extends Factory {
 
 					$function = 'set'.$function;
 					switch( $key ) {
+						/*
+						case 'new_day_trigger_time':
+						case 'maximum_shift_time':
+							Debug::text('Raw Time Unit: '. $data[$key] .' Parsing To: '. TTDate::parseTimeUnit( $data[$key] ), __FILE__, __LINE__, __METHOD__, 10);
+
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseTimeUnit( $data[$key] ) );
+							}
+							break;
+						*/
+						case 'anchor_date':
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							}
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$this->$function( $data[$key] );
@@ -1707,13 +1743,17 @@ class PayPeriodScheduleFactory extends Factory {
 					$function = 'get'.$function_stub;
 					switch( $variable ) {
 						case 'type':
-						case 'startweekday':
-						case 'shift_assigned_day':
 							$function = 'get'.$variable;
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
 							}
 							break;
+						case 'start_week_day':
+							$data[$variable] = Option::getByKey( $this->getStartWeekDay(), $this->getOptions( $variable ) );
+							break;
+						case 'shift_assigned_day':
+							$data[$variable] = Option::getByKey( $this->getShiftAssignedDay(), $this->getOptions( $variable ) );
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
@@ -1730,7 +1770,7 @@ class PayPeriodScheduleFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Pay Period Schedule'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Pay Period Schedule'), NULL, $this->getTable(), $this );
 	}
 
 }
