@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2490 $
- * $Id: PayPeriodScheduleListFactory.class.php 2490 2009-04-24 22:13:40Z ipso $
- * $Date: 2009-04-24 15:13:40 -0700 (Fri, 24 Apr 2009) $
+ * $Revision: 3735 $
+ * $Id: PayPeriodScheduleListFactory.class.php 3735 2010-08-03 17:47:12Z ipso $
+ * $Date: 2010-08-03 10:47:12 -0700 (Tue, 03 Aug 2010) $
  */
 
 /**
@@ -67,19 +67,24 @@ class PayPeriodScheduleListFactory extends PayPeriodScheduleFactory implements I
 			return FALSE;
 		}
 
-		$ph = array(
-					'id' => $id,
-					);
+		$this->rs = $this->getCache($id);
+		if ( $this->rs === FALSE ) {
+			$ph = array(
+						'id' => $id,
+						);
 
-		$query = '
-					select 	*
-					from	'. $this->getTable() .'
-					where	id = ?
-						AND deleted=0';
-		$query .= $this->getWhereSQL( $where );
-		$query .= $this->getSortSQL( $order );
+			$query = '
+						select 	*
+						from	'. $this->getTable() .'
+						where	id = ?
+							AND deleted=0';
+			$query .= $this->getWhereSQL( $where );
+			$query .= $this->getSortSQL( $order );
 
-		$this->rs = $this->db->Execute($query, $ph);
+			$this->rs = $this->db->Execute($query, $ph);
+
+			$this->saveCache($this->rs,$id);
+		}
 
 		return $this;
 	}
@@ -321,10 +326,18 @@ class PayPeriodScheduleListFactory extends PayPeriodScheduleFactory implements I
 		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
 			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
 		}
+		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
+			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
+		}
 		if ( isset($filter_data['name']) AND trim($filter_data['name']) != '' ) {
 			$ph[] = strtolower(trim($filter_data['name']));
 			$query  .=	' AND lower(a.name) LIKE ?';
 		}
+		if ( isset($filter_data['description']) AND trim($filter_data['description']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['description']));
+			$query  .=	' AND lower(a.description) LIKE ?';
+		}
+
 		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
 		}
