@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PayPeriodTimeSheetVerifyFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3928 $
+ * $Id: PayPeriodTimeSheetVerifyFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -298,6 +298,25 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 		return $retval;
 	}
 
+	function getVerificationStatusShortDisplay( $status_id = NULL ) {
+		if ( $status_id == '' ) {
+			$status_id = $this->getStatus();
+		}
+
+		//If no verification object exists, we assume "No" for verification status.
+		if ( $status_id == 50 ) {
+			$retval = TTi18n::gettext('Yes');
+		} elseif ( $status_id == 30 OR $status_id == 45 ) {
+			$retval = TTi18n::gettext('Pending');
+		} elseif ( $status_id == 55 )  {
+			$retval = TTi18n::gettext('Declined');
+		} else {
+			$retval = TTi18n::gettext('No');
+		}
+
+		return $retval;
+	}
+
 	function getVerificationStatusDisplay() {
 		$retval = TTi18n::getText('Not Verified');
 		if ( $this->getUserVerifiedDate() == TRUE AND $this->getAuthorized() == TRUE ) {
