@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: AccrualPolicyFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 4073 $
+ * $Id: AccrualPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -63,7 +63,7 @@ class AccrualPolicyFactory extends Factory {
 			case 'apply_frequency':
 				$retval = array(
 										10 => TTi18n::gettext('each Pay Period'),
-										20 => TTi18n::gettext('Yearly'),
+										20 => TTi18n::gettext('Annually'),
 										30 => TTi18n::gettext('Monthly'),
 										40 => TTi18n::gettext('Weekly'),
 									);
@@ -109,11 +109,12 @@ class AccrualPolicyFactory extends Factory {
 											'enable_pay_stub_balance_display' => 'EnablePayStubBalanceDisplay',
 											'minimum_time' => 'MinimumTime',
 											'maximum_time' => 'MaximumTime',
-											'apply_frequency_id' => 'ApplyFrequency',
 											'apply_frequency' => 'ApplyFrequency',
+											'apply_frequency_id' => 'ApplyFrequency', //Must go after apply_frequency, so its set last.
 											'apply_frequency_month' => 'ApplyFrequencyMonth',
 											'apply_frequency_day_of_month' => 'ApplyFrequencyDayOfMonth',
 											'apply_frequency_day_of_week' => 'ApplyFrequencyDayOfWeek',
+											'apply_frequency_hire_date' => 'ApplyFrequencyHireDate',
 											'milestone_rollover_hire_date' => 'MilestoneRolloverHireDate',
 											'milestone_rollover_month' => 'MilestoneRolloverMonth',
 											'milestone_rollover_day_of_month' => 'MilestoneRolloverDayOfMonth',
@@ -373,6 +374,15 @@ class AccrualPolicyFactory extends Factory {
 		return FALSE;
 	}
 
+	function getApplyFrequencyHireDate() {
+		return $this->fromBool( $this->data['apply_frequency_hire_date'] );
+	}
+	function setApplyFrequencyHireDate($bool) {
+		$this->data['apply_frequency_hire_date'] = $this->toBool($bool);
+
+		return TRUE;
+	}
+
 	function getMilestoneRolloverHireDate() {
 		return $this->fromBool( $this->data['milestone_rollover_hire_date'] );
 	}
@@ -527,7 +537,7 @@ class AccrualPolicyFactory extends Factory {
 		return FALSE;
 	}
 
-	function inApplyFrequencyWindow( $current_epoch, $offset, $pay_period_end_date = NULL ) {
+	function inApplyFrequencyWindow( $current_epoch, $offset, $pay_period_end_date = NULL, $hire_date = NULL ) {
 		$retval = FALSE;
 		switch( $this->getApplyFrequency() ) {
 			case 10: //Pay Period
@@ -540,7 +550,13 @@ class AccrualPolicyFactory extends Factory {
 				}
 				break;
 			case 20: //Year
-				$year_epoch = mktime( 0,0,0, $this->getApplyFrequencyMonth(), $this->getApplyFrequencyDayOfMonth(), TTDate::getYear( $current_epoch ) );
+				if ( $this->getApplyFrequencyHireDate() == TRUE ) {
+					Debug::Text('Hire Date: '. TTDate::getDate('DATE', $hire_date), __FILE__, __LINE__, __METHOD__,10);
+					$year_epoch = mktime( 0,0,0, TTDate::getMonth( $hire_date ), TTDate::getDayOfMonth( $hire_date ), TTDate::getYear( $current_epoch ) );
+				} else {
+					Debug::Text('Static Date', __FILE__, __LINE__, __METHOD__,10);
+					$year_epoch = mktime( 0,0,0, $this->getApplyFrequencyMonth(), $this->getApplyFrequencyDayOfMonth(), TTDate::getYear( $current_epoch ) );
+				}
 				Debug::Text('Year EPOCH: '. TTDate::getDate('DATE+TIME', $year_epoch), __FILE__, __LINE__, __METHOD__,10);
 
 				if ( $year_epoch >= ($current_epoch-$offset)
@@ -723,9 +739,10 @@ class AccrualPolicyFactory extends Factory {
 						if ( $ulf->getRecordCount() == 1 ) {
 							$u_obj = $ulf->getCurrent();
 							Debug::Text('User: '. $u_obj->getFullName() .' Status: '. $u_obj->getStatus(), __FILE__, __LINE__, __METHOD__,10);
-							//Make sure only active employees accrue time. Will this negative affect
-							//Employees who may be on leave?
+							//Make sure only active employees accrue time *after* their hire date.
+							//Will this negative affect Employees who may be on leave?
 							if ( $u_obj->getStatus() == 10
+									AND $epoch >= $u_obj->getHireDate()
 									AND ( $this->getMinimumEmployedDays() == 0
 										OR TTDate::getDays( ($epoch-$u_obj->getHireDate()) ) >= $this->getMinimumEmployedDays() ) ) {
 								Debug::Text('&nbsp;&nbsp;User is active and has been employed long enough.', __FILE__, __LINE__, __METHOD__,10);
@@ -764,7 +781,7 @@ class AccrualPolicyFactory extends Factory {
 										} else {
 											Debug::Text('&nbsp;&nbsp; No Pay Period Found.', __FILE__, __LINE__, __METHOD__,10);
 										}
-									} elseif ( $this->inApplyFrequencyWindow( $epoch, $offset ) == TRUE ) {
+									} elseif ( $this->inApplyFrequencyWindow( $epoch, $offset, NULL, $u_obj->getHireDate() ) == TRUE ) {
 										Debug::Text('&nbsp;&nbsp;User IS in NON-PayPeriod Apply Frequency Window.', __FILE__, __LINE__, __METHOD__,10);
 										$in_apply_frequency_window = TRUE;
 									} else {
@@ -876,7 +893,7 @@ class AccrualPolicyFactory extends Factory {
 									unset($milestone_obj);
 								}
 							} else {
-								Debug::Text('&nbsp;&nbsp;User is not active (Status: '. $u_obj->getStatus() .') or has only been employed: '. TTDate::getDays( ($epoch-$u_obj->getHireDate()) ) .' Days, not enough.', __FILE__, __LINE__, __METHOD__,10);
+								Debug::Text('&nbsp;&nbsp;User is not active (Status: '. $u_obj->getStatus() .') or has only been employed: '. TTDate::getDays( ($epoch-$u_obj->getHireDate()) ) .' Days, not enough. Hire Date: '. TTDate::getDATE( 'DATE+TIME', $u_obj->getHireDate() ) , __FILE__, __LINE__, __METHOD__,10);
 							}
 						} else {
 							Debug::Text('No User Found. Company ID: '. $this->getCompany(), __FILE__, __LINE__, __METHOD__,10);
@@ -976,8 +993,7 @@ class AccrualPolicyFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Accrual Policy'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Accrual Policy'), NULL, $this->getTable(), $this );
 	}
-
 }
 ?>
