@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3628 $
- * $Id: ExceptionPolicyFactory.class.php 3628 2010-05-28 00:36:37Z ipso $
- * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
+ * $Revision: 4073 $
+ * $Id: ExceptionPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -122,6 +122,20 @@ class ExceptionPolicyFactory extends Factory {
 											100 => TTi18n::gettext('Both')
 								);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1010-active' => TTi18n::gettext('Active'),
+										'-1010-severity' => TTi18n::gettext('Severity'),
+										'-1010-grace' => TTi18n::gettext('Grace'),
+										'-1010-watch_window' => TTi18n::gettext('Watch Window'),
+										'-1010-email_notification' => TTi18n::gettext('Email Notification'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
 		}
 
 		return $retval;
@@ -1963,8 +1977,8 @@ class ExceptionPolicyFactory extends Factory {
 
 	//This function needs to determine which new exceptions to create, and which old exceptions are no longer valid and to delete.
 	function diffExistingAndCurrentExceptions( $existing_exceptions, $current_exceptions ) {
-		Debug::Arr($existing_exceptions, 'Existing Exceptions: ', __FILE__, __LINE__, __METHOD__,10);
-		Debug::Arr($current_exceptions, 'Current Exceptions: ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($existing_exceptions, 'Existing Exceptions: ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($current_exceptions, 'Current Exceptions: ', __FILE__, __LINE__, __METHOD__,10);
 
 		if ( is_array($existing_exceptions) AND count($existing_exceptions) == 0 ) {
 			//No existing exceptions, nothing to delete or compare, just create new exceptions.
@@ -2025,7 +2039,7 @@ class ExceptionPolicyFactory extends Factory {
 		}
 
 		$retarr = array( 'create_exceptions' => $new_exceptions, 'delete_exceptions' => $delete_exceptions );
-		Debug::Arr($retarr, 'RetArr Exceptions: ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($retarr, 'RetArr Exceptions: ', __FILE__, __LINE__, __METHOD__,10);
 		return $retarr;
 	}
 
@@ -2092,5 +2106,10 @@ class ExceptionPolicyFactory extends Factory {
 		return $data;
 	}
 
+	//This is called for every record everytime, and doesn't help much because of that.
+	//This has to be enabled to properly log modifications though.
+	function addLog( $log_action ) {
+		return TTLog::addEntry( $this->getExceptionPolicyControl(), $log_action, TTi18n::getText('Exception Policy') .' - '. TTi18n::getText('Type') .': '. Option::getByKey( $this->getType(), $this->getOptions('type') ), NULL, $this->getTable(), $this );
+	}
 }
 ?>
