@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2741 $
- * $Id: HolidayPolicyFactory.class.php 2741 2009-08-19 22:11:46Z ipso $
- * $Date: 2009-08-19 15:11:46 -0700 (Wed, 19 Aug 2009) $
+ * $Revision: 4073 $
+ * $Id: HolidayPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -67,8 +67,9 @@ class HolidayPolicyFactory extends Factory {
 				break;
 			case 'scheduled_day':
 				$retval = array(
-										0 => TTi18n::gettext('Calendar'),
-										1 => TTi18n::gettext('Scheduled'),
+										0 => TTi18n::gettext('Calendar Days'),
+										1 => TTi18n::gettext('Scheduled Days'),
+										2 => TTi18n::gettext('Holiday Week Days'),
 									);
 				break;
 			case 'columns':
@@ -76,6 +77,9 @@ class HolidayPolicyFactory extends Factory {
 										'-1020-name' => TTi18n::gettext('Name'),
 										'-1010-type' => TTi18n::gettext('Type'),
 
+										'-1010-default_schedule_status' => TTi18n::gettext('Default Schedule Status'),
+										'-1010-minimum_employed_days' => TTi18n::gettext('Minimum Employed Days'),
+
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
 										'-2020-updated_by' => TTi18n::gettext('Updated By'),
@@ -111,6 +115,7 @@ class HolidayPolicyFactory extends Factory {
 										'type' => FALSE,
 										'name' => 'Name',
 										'default_schedule_status_id' => 'DefaultScheduleStatus',
+										'default_schedule_status' => FALSE,
 										'minimum_employed_days' => 'MinimumEmployedDays',
 										'minimum_worked_period_days' => 'MinimumWorkedPeriodDays',
 										'minimum_worked_days' => 'MinimumWorkedDays',
@@ -357,12 +362,28 @@ class HolidayPolicyFactory extends Factory {
 	}
 
 	function getWorkedScheduledDays() {
-		return $this->fromBool( $this->data['worked_scheduled_days'] );
-	}
-	function setWorkedScheduledDays($bool) {
-		$this->data['worked_scheduled_days'] = $this->toBool($bool);
+		if ( isset($this->data['worked_scheduled_days']) ) {
+			return (int)$this->data['worked_scheduled_days'];
+		}
 
-		return true;
+		return TRUE;
+	}
+	function setWorkedScheduledDays($int) {
+		$int = trim($int);
+
+		if  ( empty($int) ){
+			$int = 0;
+		}
+
+		if 	(	$this->Validator->isNumeric(		'minimum_worked_period_days',
+													$int,
+													TTi18n::gettext('Incorrect Eligibility Type')) ) {
+			$this->data['worked_scheduled_days'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
 	}
 
 	function getMinimumWorkedAfterPeriodDays() {
@@ -416,12 +437,28 @@ class HolidayPolicyFactory extends Factory {
 	}
 
 	function getWorkedAfterScheduledDays() {
-		return $this->fromBool( $this->data['worked_after_scheduled_days'] );
-	}
-	function setWorkedAfterScheduledDays($bool) {
-		$this->data['worked_after_scheduled_days'] = $this->toBool($bool);
+		if ( isset($this->data['worked_after_scheduled_days']) ) {
+			return (int)$this->data['worked_after_scheduled_days'];
+		}
 
-		return true;
+		return TRUE;
+	}
+	function setWorkedAfterScheduledDays($int) {
+		$int = trim($int);
+
+		if  ( empty($int) ){
+			$int = 0;
+		}
+
+		if 	(	$this->Validator->isNumeric(		'minimum_worked_after_period_days',
+													$int,
+													TTi18n::gettext('Incorrect Eligibility Type')) ) {
+			$this->data['worked_after_scheduled_days'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
 	}
 
 	function getAverageTimeDays() {
@@ -757,6 +794,7 @@ class HolidayPolicyFactory extends Factory {
 					$function = 'get'.$function_stub;
 					switch( $variable ) {
 						case 'type':
+						case 'default_schedule_status':
 							$function = 'get'.str_replace('_','',$variable);
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
@@ -778,7 +816,7 @@ class HolidayPolicyFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Holiday Policy'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Holiday Policy'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
