@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2698 $
- * $Id: MealPolicyFactory.class.php 2698 2009-07-31 20:50:37Z ipso $
- * $Date: 2009-07-31 13:50:37 -0700 (Fri, 31 Jul 2009) $
+ * $Revision: 4073 $
+ * $Id: MealPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -71,6 +71,15 @@ class MealPolicyFactory extends Factory {
 										'-1010-type' => TTi18n::gettext('Type'),
 										'-1020-name' => TTi18n::gettext('Name'),
 										'-1030-amount' => TTi18n::gettext('Meal Time'),
+										'-1040-trigger_time' => TTi18n::gettext('Active After'),
+
+										'-1050-auto_detect_type' => TTi18n::gettext('Auto Detect Meals By'),
+										//'-1060-start_window' => TTi18n::gettext('Start Window'),
+										//'-1070-window_length' => TTi18n::gettext('Window Length'),
+										//'-1080-minimum_punch_time' => TTi18n::gettext('Minimum Punch Time'),
+										//'-1090-maximum_punch_time' => TTi18n::gettext('Maximum Punch Time'),
+
+										'-1100-include_lunch_punch_time' => TTi18n::gettext('Include Lunch Punch'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
@@ -492,7 +501,7 @@ class MealPolicyFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Meal Policy'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Meal Policy'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
