@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: OverTimePolicyFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 4073 $
+ * $Id: OverTimePolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -109,7 +109,9 @@ class OverTimePolicyFactory extends Factory {
 										'-1010-type' => TTi18n::gettext('Type'),
 										'-1020-name' => TTi18n::gettext('Name'),
 
-										'-1140-trigger_time' => TTi18n::gettext('Active After'),
+										'-1030-trigger_time' => TTi18n::gettext('Active After'),
+										'-1040-rate' => TTi18n::gettext('Rate'),
+										'-1050-accrual_rate' => TTi18n::gettext('Accrual Rate'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
@@ -269,6 +271,10 @@ class OverTimePolicyFactory extends Factory {
 		return FALSE;
 	}
 
+	function getHourlyRate( $hourly_rate ) {
+		return bcmul( $hourly_rate, $this->getRate() );
+	}
+
 	function getRate() {
 		if ( isset($this->data['rate']) ) {
 			return $this->data['rate'];
@@ -492,7 +498,7 @@ class OverTimePolicyFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('OverTime Policy'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('OverTime Policy'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
