@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: PolicyGroupFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 4073 $
+ * $Id: PolicyGroupFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -171,7 +171,10 @@ class PolicyGroupFactory extends Factory {
 		return FALSE;
 	}
 	function setUser($ids) {
-		Debug::text('Setting User IDs : ', __FILE__, __LINE__, __METHOD__, 10);
+		if ( !is_array($ids) ) {
+			$ids = array($ids);
+		}
+
 		if ( is_array($ids) ) {
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
@@ -198,7 +201,6 @@ class PolicyGroupFactory extends Factory {
 
 			//Insert new mappings.
 			$ulf = new UserListFactory();
-
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
 					$pguf = new PolicyGroupUserFactory();
@@ -211,7 +213,7 @@ class PolicyGroupFactory extends Factory {
 
 						if ($this->Validator->isTrue(		'user',
 															$pguf->Validator->isValid(),
-															TTi18n::gettext('Selected employee is invalid or already assigned to another policy group ').' ('. $obj->getFullName() .')' )) {
+															TTi18n::gettext('Selected employee is invalid or already assigned to another policy group').' ('. $obj->getFullName() .')' )) {
 							$pguf->save();
 						}
 					}
@@ -227,74 +229,10 @@ class PolicyGroupFactory extends Factory {
 
 	function getOverTimePolicy() {
 		return CompanyGenericMapListFactory::getArrayByCompanyIDAndObjectTypeIDAndObjectID( $this->getCompany(), 110, $this->getID() );
-/*
-		$pgotplf = new PolicyGroupOverTimePolicyListFactory();
-		$pgotplf->getByPolicyGroupId( $this->getId() );
-		foreach ($pgotplf as $obj) {
-			$list[] = $obj->getOverTimePolicy();
-		}
-
-		if ( isset($list) ) {
-			return $list;
-		}
-
-		return FALSE;
-*/
 	}
 	function setOverTimePolicy($ids) {
 		Debug::text('Setting OverTime Policy IDs : ', __FILE__, __LINE__, __METHOD__, 10);
 		return CompanyGenericMapFactory::setMapIDs( $this->getCompany(), 110, $this->getID(), $ids );
-/*
-		Debug::text('Setting OTP IDs : ', __FILE__, __LINE__, __METHOD__, 10);
-		if ( is_array($ids) ) {
-			if ( !$this->isNew() ) {
-				//If needed, delete mappings first.
-				$pgotplf = new PolicyGroupOverTimePolicyListFactory();
-				$pgotplf->getByPolicyGroupId( $this->getId() );
-
-				$tmp_ids = array();
-				foreach ($pgotplf as $obj) {
-					$id = $obj->getOverTimePolicy();
-					Debug::text('Policy ID: '. $obj->getPolicyGroup() .' ID: '. $id, __FILE__, __LINE__, __METHOD__, 10);
-
-					//Delete users that are not selected.
-					if ( !in_array($id, $ids) ) {
-						Debug::text('Deleting: '. $id, __FILE__, __LINE__, __METHOD__, 10);
-						$obj->Delete();
-					} else {
-						//Save ID's that need to be updated.
-						Debug::text('NOT Deleting : '. $id, __FILE__, __LINE__, __METHOD__, 10);
-						$tmp_ids[] = $id;
-					}
-				}
-				unset($id, $obj);
-			}
-
-			//Insert new mappings.
-			$otplf = new OverTimePolicyListFactory();
-
-			foreach ($ids as $id) {
-				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
-					$pgotpf = new PolicyGroupOverTimePolicyFactory();
-					$pgotpf->setPolicyGroup( $this->getId() );
-					$pgotpf->setOverTimePolicy( $id );
-
-					$obj = $otplf->getById( $id )->getCurrent();
-
-					if ($this->Validator->isTrue(		'over_time_policy',
-														$pgotpf->Validator->isValid(),
-														TTi18n::gettext('Selected Overtime Policy is invalid').' ('. $obj->getName() .')' )) {
-						$pgotpf->save();
-					}
-				}
-			}
-
-			return TRUE;
-		}
-
-		Debug::text('No OTP IDs to set.', __FILE__, __LINE__, __METHOD__, 10);
-		return FALSE;
-*/
 	}
 
 	function getPremiumPolicy() {
@@ -342,40 +280,9 @@ class PolicyGroupFactory extends Factory {
 	}
 	function setHolidayPolicy($ids) {
 		Debug::text('Setting Holiday Policy IDs : ', __FILE__, __LINE__, __METHOD__, 10);
-		return CompanyGenericMapFactory::setMapIDs( $this->getCompany(), 180, $this->getID(), $ids );
+		return CompanyGenericMapFactory::setMapIDs( $this->getCompany(), 180, $this->getID(), (array)$ids );
 	}
-/*
-	function getHolidayPolicyID() {
-		if ( isset($this->data['holiday_policy_id']) ) {
-			return $this->data['holiday_policy_id'];
-		}
 
-		return FALSE;
-	}
-	function setHolidayPolicyID($id) {
-		$id = trim($id);
-
-		if ( $id == '' OR empty($id) ) {
-			$id = NULL;
-		}
-
-		$hplf = new HolidayPolicyListFactory();
-
-		if ( $id == NULL
-				OR
-				$this->Validator->isResultSetWithRows(	'holiday_policy',
-														$hplf->getByID($id),
-														TTi18n::gettext('Holiday Policy is invalid')
-													) ) {
-
-			$this->data['holiday_policy_id'] = $id;
-
-			return TRUE;
-		}
-
-		return FALSE;
-	}
-*/
 	function getExceptionPolicyControlID() {
 		if ( isset($this->data['exception_policy_control_id']) ) {
 			return $this->data['exception_policy_control_id'];
@@ -479,7 +386,7 @@ class PolicyGroupFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Policy Group'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Policy Group'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
