@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: PolicyGroupUserFactory.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3764 $
+ * $Id: PolicyGroupUserFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
+ * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
  */
 
 /**
@@ -45,6 +45,9 @@
 class PolicyGroupUserFactory extends Factory {
 	protected $table = 'policy_group_user';
 	protected $pk_sequence_name = 'policy_group_user_id_seq'; //PK Sequence name
+
+	var $user_obj = NULL;
+
 	function getPolicyGroup() {
 		if ( isset($this->data['policy_group_id']) ) {
 			return $this->data['policy_group_id'];
@@ -57,7 +60,8 @@ class PolicyGroupUserFactory extends Factory {
 
 		$pglf = new PolicyGroupListFactory();
 
-		if ( $this->Validator->isResultSetWithRows(	'policy_group',
+		if ( $id != 0
+				OR $this->Validator->isResultSetWithRows(	'policy_group',
 															$pglf->getByID($id),
 															TTi18n::gettext('Policy Group is invalid')
 															) ) {
@@ -69,6 +73,20 @@ class PolicyGroupUserFactory extends Factory {
 		return FALSE;
 	}
 
+	function getUserObject() {
+		if ( is_object($this->user_obj) ) {
+			return $this->user_obj;
+		} else {
+			$ulf = new UserListFactory();
+			$ulf->getById( $this->getUser() );
+			if ( $ulf->getRecordCount() == 1 ) {
+				$this->user_obj = $ulf->getCurrent();
+				return $this->user_obj;
+			}
+
+			return FALSE;
+		}
+	}
 	function isUniqueUser($id) {
 		$pglf = new PolicyGroupListFactory();
 
@@ -78,7 +96,7 @@ class PolicyGroupUserFactory extends Factory {
 
 		$query = 'select a.id from '. $this->getTable() .' as a, '. $pglf->getTable() .' as b where a.policy_group_id = b.id AND a.user_id = ? AND b.deleted=0';
 		$user_id = $this->db->GetOne($query, $ph);
-		Debug::Arr($user_id,'Unique User ID: '. $user_id, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($user_id,'Unique User ID: '. $user_id, __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $user_id === FALSE ) {
 			return TRUE;
@@ -162,5 +180,14 @@ class PolicyGroupUserFactory extends Factory {
 	function setDeletedBy($id = NULL) {
 		return FALSE;
 	}
+
+	function addLog( $log_action ) {
+		$u_obj = $this->getUserObject();
+		if ( is_object($u_obj) ) {
+			return TTLog::addEntry( $this->getPolicyGroup(), $log_action, TTi18n::getText('Employee').': '. $u_obj->getFullName( FALSE, TRUE ) , NULL, $this->getTable() );
+		}
+
+		return FALSE;
+	}
 }
 ?>
