@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2740 $
- * $Id: PremiumPolicyDepartmentFactory.class.php 2740 2009-08-19 20:21:50Z ipso $
- * $Date: 2009-08-19 13:21:50 -0700 (Wed, 19 Aug 2009) $
+ * $Revision: 4073 $
+ * $Id: PremiumPolicyDepartmentFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -46,6 +46,23 @@ class PremiumPolicyDepartmentFactory extends Factory {
 	protected $table = 'premium_policy_department';
 	protected $pk_sequence_name = 'premium_policy_department_id_seq'; //PK Sequence name
 
+	protected $department_obj = NULL;
+
+	function getDepartmentObject() {
+		if ( is_object($this->department_obj) ) {
+			return $this->department_obj;
+		} else {
+			$lf = new DepartmentListFactory();
+			$lf->getById( $this->getDepartment() );
+			if ( $lf->getRecordCount() == 1 ) {
+				$this->department_obj = $lf->getCurrent();
+				return $this->department_obj;
+			}
+
+			return FALSE;
+		}
+	}
+
 	function getPremiumPolicy() {
 		if ( isset($this->data['premium_policy_id']) ) {
 			return $this->data['premium_policy_id'];
@@ -147,5 +164,12 @@ class PremiumPolicyDepartmentFactory extends Factory {
 	function setDeletedBy($id = NULL) {
 		return FALSE;
 	}
+
+	function addLog( $log_action ) {
+		$obj = $this->getDepartmentObject();
+		if ( is_object($obj) ) {
+			return TTLog::addEntry( $this->getPremiumPolicy(), $log_action,  TTi18n::getText('Department').': '. $obj->getName(), NULL, $this->getTable() );
+		}
+	}
 }
 ?>
