@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: PremiumPolicyFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 4073 $
+ * $Id: PremiumPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -117,6 +117,10 @@ class PremiumPolicyFactory extends Factory {
 										'-1010-type' => TTi18n::gettext('Type'),
 										'-1030-name' => TTi18n::gettext('Name'),
 
+										'-1040-pay_type' => TTi18n::gettext('Pay Type'),
+										'-1040-rate' => TTi18n::gettext('Rate'),
+										'-1050-accrual_rate' => TTi18n::gettext('Accrual Rate'),
+
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
 										'-2020-updated_by' => TTi18n::gettext('Updated By'),
@@ -875,6 +879,10 @@ class PremiumPolicyFactory extends Factory {
 			case 20: //Pay Plus Premium
 				$rate = $this->getRate();
 				break;
+			case 30: //Flat Hourly Rate
+				//Get the difference between the employees current wage and the premium wage.
+				$rate = $this->getRate() - $original_hourly_rate;
+				break;
 		}
 
 		return Misc::MoneyFormat($rate, FALSE);
@@ -1511,11 +1519,12 @@ class PremiumPolicyFactory extends Factory {
 	function isTimeRestricted() {
 		//If time restrictions account for over 23.5 hours, then we assume
 		//that this policy is not time restricted at all.
-		if ( $this->getEndTime() - $this->getStartTime() > (23.5*3600) ) {
-			return FALSE;
+		$time_diff = abs( $this->getEndTime() - $this->getStartTime() );
+		if ( $time_diff > 0 AND $time_diff < (23.5*3600) ) {
+			return TRUE;
 		}
 
-		return TRUE;
+		return FALSE;
 	}
 
 	function isHourRestricted() {
@@ -1567,8 +1576,8 @@ class PremiumPolicyFactory extends Factory {
 		Debug::text(' Checking for Active Time with: In: '. TTDate::getDate('DATE+TIME', $in_epoch) .' Out: '. TTDate::getDate('DATE+TIME', $out_epoch), __FILE__, __LINE__, __METHOD__, 10);
 
 		Debug::text(' Raw Start TimeStamp('.$this->getStartTime(TRUE).'): '. TTDate::getDate('DATE+TIME', $this->getStartTime() ) .' Raw End TimeStamp: '. TTDate::getDate('DATE+TIME', $this->getEndTime() )  , __FILE__, __LINE__, __METHOD__, 10);
-		$start_time_stamp = TTDate::getTimeLockedDate( $this->getStartTime(), $in_epoch);
-		$end_time_stamp = TTDate::getTimeLockedDate( $this->getEndTime(), $in_epoch);
+		$start_time_stamp = TTDate::getTimeLockedDate( $this->getStartTime(), $in_epoch); //Base the end time on day of the in_epoch.
+		$end_time_stamp = TTDate::getTimeLockedDate( $this->getEndTime(), $in_epoch); //Base the end time on day of the in_epoch.
 
 		//Check if end timestamp is before start, if it is, move end timestamp to next day.
 		if ( $end_time_stamp < $start_time_stamp ) {
@@ -1806,7 +1815,7 @@ class PremiumPolicyFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Premium Policy'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Premium Policy'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
