@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PunchControlFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3884 $
+ * $Id: PunchControlFactory.class.php 3884 2010-10-05 14:40:19Z ipso $
+ * $Date: 2010-10-05 07:40:19 -0700 (Tue, 05 Oct 2010) $
  */
 
 /**
@@ -1049,8 +1049,8 @@ class PunchControlFactory extends Factory {
 					}
 
 
-					Debug::text(' Current Punch Object: ID: '. $this->getPunchObject()->getId() .' TimeStamp: '. $this->getPunchObject()->getTimeStamp() .' Status: '. $this->getPunchObject()->getStatus(), __FILE__, __LINE__, __METHOD__,10);
-					Debug::text(' Looping Punch Object: ID: '. $punch_data['id'] .' TimeStamp: '. $punch_data['time_stamp'] .' Status: '.$punch_data['status_id'], __FILE__, __LINE__, __METHOD__,10);
+					//Debug::text(' Current Punch Object: ID: '. $this->getPunchObject()->getId() .' TimeStamp: '. $this->getPunchObject()->getTimeStamp() .' Status: '. $this->getPunchObject()->getStatus(), __FILE__, __LINE__, __METHOD__,10);
+					//Debug::text(' Looping Punch Object: ID: '. $punch_data['id'] .' TimeStamp: '. $punch_data['time_stamp'] .' Status: '.$punch_data['status_id'], __FILE__, __LINE__, __METHOD__,10);
 
 					//Check for another punch that matches the timestamp and status.
 					if ( $this->getPunchObject()->getID() != $punch_data['id'] ) {
@@ -1115,7 +1115,7 @@ class PunchControlFactory extends Factory {
 
 					//Check to make sure punches don't exceed maximum shift time.
 					$maximum_shift_time = $plf->getPayPeriodMaximumShiftTime( $this->getPunchObject()->getUser() );
-					Debug::text('aaaMaximum shift time: '. $maximum_shift_time, __FILE__, __LINE__, __METHOD__,10);
+					Debug::text('Maximum shift time: '. $maximum_shift_time, __FILE__, __LINE__, __METHOD__,10);
 					if ( $shift_data['total_time'] > $maximum_shift_time ) {
 						$this->Validator->isTRUE(	'time_stamp',
 													FALSE,
@@ -1234,7 +1234,7 @@ class PunchControlFactory extends Factory {
 							}
 						}
 					}
-					Debug::Arr($this->old_user_date_ids, 'aOld User Date IDs: ', __FILE__, __LINE__, __METHOD__,10);
+					//Debug::Arr($this->old_user_date_ids, 'aOld User Date IDs: ', __FILE__, __LINE__, __METHOD__,10);
 
 					return TRUE;
 				}
@@ -1629,5 +1629,8 @@ class PunchControlFactory extends Factory {
 		return $data;
 	}
 
+	function addLog( $log_action ) {
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Punch Control - Employee').': '. UserListFactory::getFullNameById( $this->getUser() ), NULL, $this->getTable(), $this );
+	}
 }
 ?>
