@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PunchFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: PunchFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -85,6 +85,9 @@ class PunchFactory extends Factory {
 										'-1160-branch' => TTi18n::gettext('Branch'),
 										'-1170-department' => TTi18n::gettext('Department'),
 
+										'-1180-job' => TTi18n::gettext('Job'),
+										'-1190-job_item' => TTi18n::gettext('Task'),
+
 										'-1200-type' => TTi18n::gettext('Type'),
 										'-1202-status' => TTi18n::gettext('Status'),
 										'-1210-date_stamp' => TTi18n::gettext('Date'),
@@ -130,7 +133,8 @@ class PunchFactory extends Factory {
 											'status_id' => 'Status',
 											'status' => FALSE,
 											'time_stamp' => 'TimeStamp',
-											'full_time_stamp' => FALSE,
+											'punch_date' => FALSE,
+											'punch_time' => FALSE,
 											'punch_control_id' => 'PunchControlID',
 											'actual_time_stamp' => 'ActualTimeStamp',
 											'original_time_stamp' => 'OriginalTimeStamp',
@@ -429,18 +433,13 @@ class PunchFactory extends Factory {
 		$original_epoch = $epoch;
 
 		Debug::text(' Rounding Timestamp: '. TTDate::getDate('DATE+TIME', $epoch ) .' Status ID: '. $this->getStatus() .' Type ID: '. $this->getType() , __FILE__, __LINE__, __METHOD__,10);
-/*
+		
 		//Punch control is no longer used for rounding.
-		if ( !is_object( $this->getPunchControlObject() ) ) {
-			return FALSE;
-		}
-*/
 		//Check for rounding policies.
 		$riplf = new RoundIntervalPolicyListFactory();
 		$type_id = $riplf->getPunchTypeFromPunchStatusAndType( $this->getStatus(), $this->getType() );
 
 		Debug::text(' Round Interval Punch Type: '. $type_id .' User: '. $this->getUser(), __FILE__, __LINE__, __METHOD__,10);
-		//$riplf->getByPolicyGroupUserIdAndTypeId( $this->getPunchControlObject()->getUserDateObject()->getUser(), $type_id );
 		$riplf->getByPolicyGroupUserIdAndTypeId( $this->getUser(), $type_id );
 		if ( $riplf->getRecordCount() == 1 ) {
 			$round_policy_obj = $riplf->getCurrent();
@@ -1236,6 +1235,15 @@ class PunchFactory extends Factory {
 										TTi18n::gettext('Invalid Punch Control ID'));
 		}
 
+		if ( is_object( $this->getPunchControlObject() )
+				AND is_object( $this->getPunchControlObject()->getUserDateObject() )
+				AND is_object( $this->getPunchControlObject()->getUserDateObject()->getPayPeriodObject() )
+				AND $this->getPunchControlObject()->getUserDateObject()->getPayPeriodObject()->getIsLocked() == TRUE ) {
+			$this->Validator->isTRUE(	'pay_period',
+										FALSE,
+										TTi18n::gettext('Pay Period is Currently Locked') );
+		}
+
 		return TRUE;
 	}
 
@@ -1467,13 +1475,13 @@ class PunchFactory extends Factory {
 			foreach ( $data as $key => $row ) {
 				if ( $row['type_id'] != 10 ) {
 					if ( $row['status_id'] == 20 ) {
-						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev'] = TTDate::strtotime($row['full_time_stamp']);
+						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev'] = TTDate::strtotime($row['time_stamp']);
 					} elseif ( isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev']) ) {
 						if ( !isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time']) ) {
 							$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] = 0;
 						}
 
-						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] = bcadd( $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'], bcsub( TTDate::strtotime($row['full_time_stamp']), $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev']) );
+						$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'] = bcadd( $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_time'], bcsub( TTDate::strtotime($row['time_stamp']), $tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['prev']) );
 
 						if ( !isset($tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_breaks']) ) {
 							$tmp_date_break_totals[$row['date_stamp']][$row['type_id']]['total_breaks'] = 0;
@@ -1565,14 +1573,14 @@ class PunchFactory extends Factory {
 									$enable_rounding = TRUE;
 								}
 
-								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data['time_stamp']) AND $data['time_stamp'] != '' ) {
-									$full_time_stamp = TTDate::parseDateTime( $data['date_stamp'].' '.$data['time_stamp'] );
+								if ( isset($data['punch_date']) AND $data['punch_date'] != '' AND isset($data['punch_time']) AND $data['punch_time'] != '' ) {
+									$full_time_stamp = TTDate::parseDateTime( $data['punch_date'].' '.$data['punch_time'] );
+									//Debug::text('Setting Punch Time/Date: Date Stamp: '. $data['punch_date'] .' Time Stamp: '. $data['punch_time'] .' Full Time Stamp: '. $data['full_time_stamp'] .' Parsed: '. TTDate::getDate('DATE+TIME', $full_time_stamp ), __FILE__, __LINE__, __METHOD__, 10);
 								} elseif ( isset($data['time_stamp']) AND $data['time_stamp'] != '' ) {
 									$full_time_stamp = TTDate::parseDateTime( $data['time_stamp'] );
 								}
 
 								$this->$function( $full_time_stamp, $enable_rounding ); //Assume time_stamp contains date as well.
-
 							}
 							break;
 						case 'actual_time_stamp': //Ignore actual/original timestamps.
@@ -1660,15 +1668,19 @@ class PunchFactory extends Factory {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
 							}
 							break;
-						case 'date_stamp':
+						case 'date_stamp': //Date the punch falls on for timesheet generation. The punch itself may have a different date.
 							$data[$variable] = TTDate::getAPIDate( 'DATE', TTDate::strtotime( $this->getColumn( 'date_stamp' ) ) );
 							break;
-						case 'time_stamp':
-							$data[$variable] = TTDate::getAPIDate( 'TIME', TTDate::strtotime( $this->getColumn( 'time_stamp' ) ) );
-							break;
-						case 'full_time_stamp':
+						case 'time_stamp': //Full date/time of the punch itself.
+							//$data[$variable] = TTDate::getAPIDate( 'TIME', TTDate::strtotime( $this->getColumn( 'time_stamp' ) ) );
 							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', TTDate::strtotime( $this->getColumn( 'time_stamp' ) ) );
 							break;
+						case 'punch_date': //Just date portion of the punch
+							$data[$variable] = TTDate::getAPIDate( 'DATE', TTDate::strtotime( $this->getColumn( 'time_stamp' ) ) );
+							break;
+						case 'punch_time': //Just the time portion of the punch
+							$data[$variable] = TTDate::getAPIDate( 'TIME', TTDate::strtotime( $this->getColumn( 'time_stamp' ) ) );
+							break;
 						case 'original_time_stamp':
 							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', TTDate::strtotime( $this->getColumn( 'original_time_stamp' ) ) );
 							break;
@@ -1691,7 +1703,7 @@ class PunchFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Punch - Employee').': '. UserListFactory::getFullNameById( $this->getUser() ) . TTi18n::getText(' Timestamp').': '. TTDate::getDate('DATE+TIME', $this->getTimeStamp() ) , NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Punch - Employee').': '. UserListFactory::getFullNameById( $this->getUser() ) . TTi18n::getText(' Timestamp').': '. TTDate::getDate('DATE+TIME', $this->getTimeStamp() ) , NULL, $this->getTable(), $this );
 	}
 }
 ?>
