@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: PunchListFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: PunchListFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -645,8 +645,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 					LIMIT 1
 					';
 		$query .= $this->getSortSQL( $order );
-		Debug::Text(' Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-		//echo "Get Previous Punch Query: ". $query ."<br>\n";
+		//Debug::Text(' Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 
 		$this->rs = $this->db->Execute($query, $ph);
 
@@ -1380,6 +1379,9 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		if ( isset($filter_data['include_user_ids']) ) {
 			$filter_data['id'] = $filter_data['include_user_ids'];
 		}
+		if ( isset($filter_data['include_user_id']) ) {
+			$filter_data['id'] = $filter_data['include_user_id'];
+		}
 		if ( isset($filter_data['user_status_ids']) ) {
 			$filter_data['status_id'] = $filter_data['user_status_ids'];
 		}
@@ -1578,6 +1580,9 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
+		//Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($ph,'PlaceHolders:', __FILE__, __LINE__, __METHOD__,10);
+
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -1834,8 +1839,8 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
 			$query  .=	' AND d.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
 		}
-		if ( isset($filter_data['branch_id']) AND isset($filter_data['punch_branch_id'][0]) AND !in_array(-1, (array)$filter_data['punch_branch_id']) ) {
-			$query  .=	' AND b.branch_id in ('. $this->getListSQL($filter_data['punch_branch_id'], $ph) .') ';
+		if ( isset($filter_data['branch_id']) AND isset($filter_data['branch_id'][0]) AND !in_array(-1, (array)$filter_data['branch_id']) ) {
+			$query  .=	' AND b.branch_id in ('. $this->getListSQL($filter_data['branch_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['department_id']) AND isset($filter_data['department_id'][0]) AND !in_array(-1, (array)$filter_data['department_id']) ) {
 			$query  .=	' AND b.department_id in ('. $this->getListSQL($filter_data['department_id'], $ph) .') ';
@@ -1886,6 +1891,9 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
+		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+		Debug::Arr($ph,'PlaceHolders:', __FILE__, __LINE__, __METHOD__,10);
+
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
