@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: RequestFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: RequestFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -73,12 +73,73 @@ class RequestFactory extends Factory {
 										60 => TTi18n::gettext('DISABLED')
 									);
 				break;
+			case 'columns':
+				$retval = array(
 
+										'-1010-first_name' => TTi18n::gettext('First Name'),
+										'-1020-last_name' => TTi18n::gettext('Last Name'),
+										'-1060-title' => TTi18n::gettext('Title'),
+										'-1070-group' => TTi18n::gettext('Group'),
+										'-1080-default_branch' => TTi18n::gettext('Branch'),
+										'-1090-default_department' => TTi18n::gettext('Department'),
+
+										'-1110-date_stamp' => TTi18n::gettext('Date'),
+										'-1120-status' => TTi18n::gettext('Status'),
+										'-1130-type' => TTi18n::gettext('Type'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'type',
+								'date_stamp',
+								'status'
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'user_date_id' => 'UserDateID',
+										'user_id' => FALSE,
+
+										'first_name' => FALSE,
+										'last_name' => FALSE,
+										'default_branch' => FALSE,
+										'default_department' => FALSE,
+										'group' => FALSE,
+										'title' => FALSE,
+
+										'date_stamp' => FALSE,
+										'type_id' => 'Type',
+										'type' => FALSE,
+										'status_id' => 'Status',
+										'status' => FALSE,
+										'authorized' => 'Authorized',
+										'authorization_level' => 'AuthorizationLevel',
+										'message' => 'Message',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
 
 	function getUserDateObject() {
 		if ( is_object($this->user_date_obj) ) {
@@ -175,11 +236,6 @@ class RequestFactory extends Factory {
 	function setStatus($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, $this->getOptions('status') );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
 		if ( $this->Validator->inArrayKey(	'status',
 											$value,
 											TTi18n::gettext('Incorrect Status'),
@@ -271,6 +327,17 @@ class RequestFactory extends Factory {
 											TTi18n::gettext('Date/Time is incorrect or pay period does not exist for this date. Please create a pay period schedule if you have not done so already') );
 		}
 
+		//Check to make sure this user has superiors to send a request too, otherwise we can't save the request.
+		$hlf = new HierarchyListFactory();
+		$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUser(), 50, TRUE, FALSE ); //Request - Immediate parents only.
+		Debug::Arr($request_parent_level_user_ids, 'Check for Superiors: ', __FILE__, __LINE__, __METHOD__,10);
+
+		if ( !is_array($request_parent_level_user_ids) OR count($request_parent_level_user_ids) == 0 ) {
+			$this->Validator->isTRUE(		'message',
+											FALSE,
+											TTi18n::gettext('No supervisors are assigned to you at this time, please try again later') );
+		}
+
 		return TRUE;
 	}
 
@@ -343,6 +410,92 @@ class RequestFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			if ( isset($data['user_id']) AND $data['user_id'] != ''
+					AND isset($data['date_stamp']) AND $data['date_stamp'] != '' ) {
+				Debug::text('Setting User Date ID based on User ID:'. $data['user_id'] .' Date Stamp: '. $data['date_stamp'] , __FILE__, __LINE__, __METHOD__, 10);
+				$this->setUserDate( $data['user_id'], TTDate::parseDateTime( $data['date_stamp'] ) );
+			} elseif ( isset( $data['user_date_id'] ) AND $data['user_date_id'] > 0 ) {
+				Debug::text(' Setting UserDateID: '. $data['user_date_id'], __FILE__, __LINE__, __METHOD__,10);
+				$this->setUserDateID( $data['user_date_id'] );
+			} else {
+				Debug::text(' NOT CALLING setUserDate or setUserDateID!', __FILE__, __LINE__, __METHOD__,10);
+			}
+
+			if ( isset($data['status_id']) AND $data['status_id'] == '' ) {
+				unset($data['status_id']);
+				$this->setStatus( 30 ); //Pending authorization
+			}
+			if ( isset($data['user_date_id']) AND $data['user_date_id'] == '' ) {
+				unset($data['user_date_id']);
+			}
+
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'first_name':
+						case 'last_name':
+						case 'title':
+						case 'group':
+						case 'default_branch':
+						case 'default_department':
+						case 'user_id':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'message': //Message is attached in the message factory, so we can't return it here.
+							break;
+						case 'status':
+						case 'type':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'date_stamp':
+							$data[$variable] = TTDate::getAPIDate( 'DATE', TTDate::parseDateTime( $this->getColumn( 'date_stamp' ) ) );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Request - Type').': '. $this->getType(), NULL, $this->getTable() );
 	}
