@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3415 $
- * $Id: RequestListFactory.class.php 3415 2010-03-12 22:31:26Z ipso $
- * $Date: 2010-03-12 14:31:26 -0800 (Fri, 12 Mar 2010) $
+ * $Revision: 3928 $
+ * $Id: RequestListFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -391,14 +391,22 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 
 		$additional_sort_fields = array( 'date_stamp', 'user_id' );
 
+		$sort_column_aliases = array(
+									 'date_stamp' => 'date_stamp',
+									 'user_id' => 'c.last_name',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
 		$strict_order = TRUE;
 		if ( $order == NULL ) {
-			$order = array('b.user_id' => 'asc', 'b.date_stamp' => 'asc');
+			$order = array('b.date_stamp' => 'desc', 'c.last_name' => 'asc' );
 			$strict_order = FALSE;
 		}
 
 		$af = new AuthorizationFactory();
 		$udf = new UserDateFactory();
+		$uf = new UserFactory();
 		$huf = new HierarchyUserFactory();
 
 		$ph = array(
@@ -409,13 +417,15 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 					select 	a.*
 					from	'. $this->getTable() .' as a,
 							'. $udf->getTable() .' as b,
+							'. $uf->getTable() .' as c,
 							'. $huf->getTable() .' as z
 					where	a.user_date_id = b.id
 						AND b.user_id = z.user_id
+						AND b.user_id = c.id
 						AND	a.status_id = ?
 						AND a.authorized = 0
 						AND ( '. HierarchyLevelFactory::convertHierarchyLevelMapToSQL( $hierarchy_level_map ) .' )
-						AND ( a.deleted = 0 AND b.deleted = 0 )
+						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 )
 				';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict_order, $additional_sort_fields );
@@ -518,18 +528,43 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 		$query .= $this->getSortSQL( $order );
 
 		$this->rs = $this->db->Execute($query, $ph);
-		/*
-		//$this->rs = $this->db->PageExecute($query, $limit, $page);
 
-		$total = $this->db->GetOne($query, $ph);
+		return $this;
+	}
 
-		if ($total === FALSE ) {
-			$total = 0;
+	function getSumByCompanyIDAndPayPeriodIdAndStatus($company_id, $pay_period_id, $status, $where = NULL, $order = NULL) {
+		$key = Option::getByValue($status, $this->getOptions('status') );
+		if ($key !== FALSE) {
+			$status = $key;
 		}
-		Debug::text('Total: '. $total, __FILE__, __LINE__, __METHOD__, 10);
 
-		return $total;
-		*/
+		$af = new AuthorizationFactory();
+
+		$udf = new UserDateFactory();
+		$uf = new UserFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'status_id' => $status,
+					);
+
+		$query = '
+					select 	b.pay_period_id as pay_period_id, count(*) as total
+					from	'. $this->getTable() .' as a,
+							'. $udf->getTable() .' as b,
+							'. $uf->getTable() .' as c
+					where	a.user_date_id = b.id
+						AND b.user_id = c.id
+						AND c.company_id = ?
+						AND	a.status_id = ?
+						AND b.pay_period_id in ('. $this->getListSQL($pay_period_id, $ph).')
+						AND ( a.deleted = 0 AND b.deleted = 0 )
+					GROUP By b.pay_period_id
+				';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
 	}
@@ -633,5 +668,140 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 
 		return $this;
 	}
+
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array();
+		if ( $order == NULL ) {
+			$order = array( 'status_id' => 'asc', 'type_id' => 'asc', 'date_stamp' => 'desc', );
+			$strict = FALSE;
+		} else {
+			//Always sort by last name,first name after other columns
+			/*
+			if ( !isset($order['effective_date']) ) {
+				$order['effective_date'] = 'desc';
+			}
+			*/
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$uf = new UserFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
+		$udf = new UserDateFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select 	a.*,
+							b.first_name as first_name,
+							b.last_name as last_name,
+							b.country as country,
+							b.province as province,
+
+							udf.date_stamp as date_stamp,
+							udf.user_id as user_id,
+
+							c.id as default_branch_id,
+							c.name as default_branch,
+							d.id as default_department_id,
+							d.name as default_department,
+							e.id as group_id,
+							e.name as group,
+							f.id as title_id,
+							f.name as title
+					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $udf->getTable() .' as udf ON ( a.user_date_id = udf.id AND udf.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as b ON ( udf.user_id = b.id AND b.deleted = 0 )
+
+						LEFT JOIN '. $bf->getTable() .' as c ON ( b.default_branch_id = c.id AND c.deleted = 0)
+						LEFT JOIN '. $df->getTable() .' as d ON ( b.default_department_id = d.id AND d.deleted = 0)
+						LEFT JOIN '. $ugf->getTable() .' as e ON ( b.group_id = e.id AND e.deleted = 0 )
+						LEFT JOIN '. $utf->getTable() .' as f ON ( b.title_id = f.id AND f.deleted = 0 )
+
+					where	b.company_id = ?
+					';
+
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND a.user_id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
+			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
+			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
+			}
+			$query  .=	' AND b.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+			$query  .=	' AND b.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+			$query  .=	' AND b.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
+			$query  .=	' AND b.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['country']) AND isset($filter_data['country'][0]) AND !in_array(-1, (array)$filter_data['country']) ) {
+			$query  .=	' AND b.country in ('. $this->getListSQL($filter_data['country'], $ph) .') ';
+		}
+		if ( isset($filter_data['province']) AND isset($filter_data['province'][0]) AND !in_array( -1, (array)$filter_data['province']) AND !in_array( '00', (array)$filter_data['province']) ) {
+			$query  .=	' AND b.province in ('. $this->getListSQL($filter_data['province'], $ph) .') ';
+		}
+
+
+		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
+		}
+		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
+			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
+		}
+
+		$query .= 	'
+						AND a.deleted = 0
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 }
 ?>
