@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: RecurringScheduleControlFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3928 $
+ * $Id: RecurringScheduleControlFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 
 /**
@@ -160,7 +160,7 @@ class RecurringScheduleControlFactory extends Factory {
 
 		if ( $this->Validator->isResultSetWithRows(	'recurring_schedule_template_control_id',
 													$rstclf->getByID($id),
-													TTi18n::gettext('Recurring Schedule Template Control is invalid')
+													TTi18n::gettext('Recurring Schedule Template is invalid')
 													) ) {
 
 			$this->data['recurring_schedule_template_control_id'] = $id;
@@ -281,8 +281,11 @@ class RecurringScheduleControlFactory extends Factory {
 		return FALSE;
 	}
 	function setUser($ids) {
-		Debug::text('Setting User IDs : ', __FILE__, __LINE__, __METHOD__, 10);
-		if ( is_array($ids) and count($ids) > 0 ) {
+		if ( !is_array($ids) ) {
+			$ids = array($ids);
+		}
+
+		if ( is_array($ids) ) {
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
 				$rsulf = new RecurringScheduleUserListFactory();
@@ -570,7 +573,7 @@ class RecurringScheduleControlFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Schedule'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Schedule'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
