@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: RecurringScheduleTemplateControlFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3764 $
+ * $Id: RecurringScheduleTemplateControlFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
+ * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
  */
 
 /**
@@ -217,7 +217,7 @@ class RecurringScheduleTemplateControlFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Schedule Template'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Schedule Template'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
