@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: RecurringScheduleTemplateFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: RecurringScheduleTemplateFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -803,5 +803,9 @@ class RecurringScheduleTemplateFactory extends Factory {
 			$this->setEndTime( $this->getEndTime() + 86400 ); //End time spans midnight, add 24hrs.
 		}
 	}
+
+	function addLog( $log_action ) {
+		return TTLog::addEntry( $this->getRecurringScheduleTemplateControl(), $log_action, TTi18n::getText('Recurring Schedule Week'), NULL, $this->getTable(), $this );
+	}
 }
 ?>
