@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: RecurringScheduleUserFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3764 $
+ * $Id: RecurringScheduleUserFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
+ * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
  */
 
 /**
@@ -45,6 +45,9 @@
 class RecurringScheduleUserFactory extends Factory {
 	protected $table = 'recurring_schedule_user';
 	protected $pk_sequence_name = 'recurring_schedule_user_id_seq'; //PK Sequence name
+
+	var $user_obj = NULL;
+
 	function getRecurringScheduleControl() {
 		if ( isset($this->data['recurring_schedule_control_id']) ) {
 			return $this->data['recurring_schedule_control_id'];
@@ -75,6 +78,20 @@ class RecurringScheduleUserFactory extends Factory {
 		return FALSE;
 	}
 
+	function getUserObject() {
+		if ( is_object($this->user_obj) ) {
+			return $this->user_obj;
+		} else {
+			$ulf = new UserListFactory();
+			$ulf->getById( $this->getUser() );
+			if ( $ulf->getRecordCount() == 1 ) {
+				$this->user_obj = $ulf->getCurrent();
+				return $this->user_obj;
+			}
+
+			return FALSE;
+		}
+	}
 	function getUser() {
 		if ( isset($this->data['user_id']) ) {
 			return $this->data['user_id'];
@@ -154,5 +171,14 @@ class RecurringScheduleUserFactory extends Factory {
 	function setDeletedBy($id = NULL) {
 		return FALSE;
 	}
+
+	function addLog( $log_action ) {
+		$u_obj = $this->getUserObject();
+		if ( is_object($u_obj) ) {
+			return TTLog::addEntry( $this->getRecurringScheduleControl(), $log_action, TTi18n::getText('Employee').': '. $u_obj->getFullName( FALSE, TRUE ) , NULL, $this->getTable() );
+		}
+
+		return FALSE;
+	}
 }
 ?>
