@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: ScheduleFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: ScheduleFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -338,13 +338,6 @@ class ScheduleFactory extends Factory {
 	function getStartTime( $raw = FALSE ) {
 		if ( isset($this->data['start_time']) ) {
 			return TTDate::strtotime( $this->data['start_time'] );
-			/*
-			if ( $raw === TRUE) {
-				return $this->data['start_time'];
-			} else {
-				return TTDate::strtotime( $this->data['start_time'] );
-			}
-			*/
 		}
 
 		return FALSE;
@@ -369,13 +362,6 @@ class ScheduleFactory extends Factory {
 	function getEndTime( $raw = FALSE ) {
 		if ( isset($this->data['end_time']) ) {
 			return TTDate::strtotime( $this->data['end_time'] );
-			/*
-			if ( $raw === TRUE) {
-				return $this->data['end_time'];
-			} else {
-				return TTDate::strtotime( $this->data['end_time'] );
-			}
-			*/
 		}
 
 		return FALSE;
@@ -810,7 +796,7 @@ class ScheduleFactory extends Factory {
 													'type_id' => 10, //Committed
 													'status_id' => (int)$s_obj->getStatus(),
 
-													'date_stamp' => TTDate::getAPIDate( 'DATE', TTDate::parseDateTime( $s_obj->getColumn('date_stamp') ) ),
+													'date_stamp' => TTDate::getAPIDate( 'DATE', strtotime( $s_obj->getColumn('date_stamp') ) ),
 													'start_date' => ( defined('TIMETREX_API') ) ? TTDate::getAPIDate('DATE+TIME', $s_obj->getStartTime() ) : $s_obj->getStartTime(),
 													'end_date' => ( defined('TIMETREX_API') ) ? TTDate::getAPIDate('DATE+TIME', $s_obj->getEndTime() ) : $s_obj->getEndTime(),
 													'start_time' => ( defined('TIMETREX_API') ) ? TTDate::getAPIDate('TIME', $s_obj->getStartTime() ) : $s_obj->getStartTime(),
@@ -1552,12 +1538,18 @@ class ScheduleFactory extends Factory {
 							break;
 						case 'start_time':
 							if ( method_exists( $this, $function ) ) {
+								Debug::text('..aaSetting start time from EPOCH: "'. $data[$key]  .'"', __FILE__, __LINE__, __METHOD__,10);
+
 								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data['start_date']) AND strlen($data['start_date']) > strlen($data[$key]) ) {
 									Debug::text(' aSetting start time... "'. $data['date_stamp'].' '.$data[$key] .'"', __FILE__, __LINE__, __METHOD__,10);
 									$this->$function( TTDate::parseDateTime( $data['date_stamp'].' '.$data[$key] ) ); //Prefix date_stamp onto start_time
-								} elseif ( is_object( $this->getUserDateObject() ) ) {
-									Debug::text(' bSetting start time...: '. $this->getUserDateObject()->getDateStamp(), __FILE__, __LINE__, __METHOD__,10);
-									$this->$function( TTDate::parseDateTime( TTDate::getDate('DATE', $this->getUserDateObject()->getDateStamp() ) .' '. $data[$key] ) );
+								} elseif ( isset($data[$key]) AND $data[$key] != '' ) {
+									//When start_time is provided as a full timestamp. Happens with audit log detail.
+									Debug::text(' aaSetting start time...: '. $data[$key], __FILE__, __LINE__, __METHOD__,10);
+									$this->$function( TTDate::parseDateTime( $data[$key] ) );
+								//} elseif ( is_object( $this->getUserDateObject() ) ) {
+								//	Debug::text(' aaaSetting start time...: '. $this->getUserDateObject()->getDateStamp(), __FILE__, __LINE__, __METHOD__,10);
+								//	$this->$function( TTDate::parseDateTime( TTDate::getDate('DATE', $this->getUserDateObject()->getDateStamp() ) .' '. $data[$key] ) );
 								} else {
 									Debug::text(' Not setting start time...', __FILE__, __LINE__, __METHOD__,10);
 								}
@@ -1566,11 +1558,17 @@ class ScheduleFactory extends Factory {
 						case 'end_time':
 							if ( method_exists( $this, $function ) ) {
 								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data['end_date']) AND strlen($data['end_date']) > strlen($data[$key]) ) {
-									Debug::text(' aaSetting start time... "'. $data['date_stamp'].' '.$data[$key] .'"', __FILE__, __LINE__, __METHOD__,10);
+									Debug::text(' aSetting end time... "'. $data['date_stamp'].' '.$data[$key] .'"', __FILE__, __LINE__, __METHOD__,10);
 									$this->$function( TTDate::parseDateTime( $data['date_stamp'].' '.$data[$key] ) ); //Prefix date_stamp onto end_time
-								} elseif ( is_object( $this->getUserDateObject() ) ) {
-									Debug::text(' bbSetting start time... "'. TTDate::getDate('DATE', $this->getUserDateObject()->getDateStamp() ) .' '. $data[$key]  .'"', __FILE__, __LINE__, __METHOD__,10);
-									$this->$function( TTDate::parseDateTime( TTDate::getDate('DATE', $this->getUserDateObject()->getDateStamp() ) .' '. $data[$key] ) );
+								} elseif ( isset($data[$key]) AND $data[$key] != '' ) {
+									Debug::text(' aaSetting end time...: '. $data[$key], __FILE__, __LINE__, __METHOD__,10);
+									//When end_time is provided as a full timestamp. Happens with audit log detail.
+									$this->$function( TTDate::parseDateTime( $data[$key] ) );
+								//} elseif ( is_object( $this->getUserDateObject() ) ) {
+								//	Debug::text(' bbbSetting end time... "'. TTDate::getDate('DATE', $this->getUserDateObject()->getDateStamp() ) .' '. $data[$key]  .'"', __FILE__, __LINE__, __METHOD__,10);
+								//	$this->$function( TTDate::parseDateTime( TTDate::getDate('DATE', $this->getUserDateObject()->getDateStamp() ) .' '. $data[$key] ) );
+								} else {
+									Debug::text(' Not setting end time...', __FILE__, __LINE__, __METHOD__,10);
 								}
 							}
 							break;
@@ -1583,6 +1581,8 @@ class ScheduleFactory extends Factory {
 				}
 			}
 
+			$this->setTotalTime( $this->calcTotalTime() ); //Calculate total time immediately after. This is required for proper audit logging too.
+
 			$this->setCreatedAndUpdatedColumns( $data );
 
 			return TRUE;
@@ -1660,7 +1660,7 @@ class ScheduleFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Schedule'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Schedule'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
\ No newline at end of file
