@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3628 $
- * $Id: ScheduleListFactory.class.php 3628 2010-05-28 00:36:37Z ipso $
- * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
+ * $Revision: 3786 $
+ * $Id: ScheduleListFactory.class.php 3786 2010-08-17 22:15:45Z ipso $
+ * $Date: 2010-08-17 15:15:45 -0700 (Tue, 17 Aug 2010) $
  */
 
 /**
@@ -722,12 +722,12 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 							LEFT JOIN '. $ugf->getTable() .' as ugf ON ( uf.group_id = ugf.id AND ugf.deleted = 0 )
 							LEFT JOIN '. $utf->getTable() .' as utf ON ( uf.title_id = utf.id AND utf.deleted = 0 )
 							LEFT JOIN '. $apf->getTable() .' as apf ON a.absence_policy_id = apf.id
-							LEFT JOIN '. $uwf->getTable() .' as uwf ON uwf.id = (select uwf.id
+							LEFT JOIN '. $uwf->getTable() .' as uwf ON uwf.id = (select z.id
 																		from '. $uwf->getTable() .' as z
-																		where uwf.user_id = udf.user_id
-																			and uwf.effective_date <= udf.date_stamp
-																			and uwf.deleted = 0
-																			order by uwf.effective_date desc limit 1)
+																		where z.user_id = udf.user_id
+																			and z.effective_date <= udf.date_stamp
+																			and z.deleted = 0
+																			order by z.effective_date desc limit 1)
 					';
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= '	LEFT JOIN '. $jf->getTable() .' as x ON a.job_id = x.id';
