@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2780 $
- * $Id: TimeTrexSoapClient.class.php 2780 2009-09-03 23:32:38Z ipso $
- * $Date: 2009-09-03 16:32:38 -0700 (Thu, 03 Sep 2009) $
+ * $Revision: 4073 $
+ * $Id: TimeTrexSoapClient.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -82,6 +82,10 @@ class TimeTrexSoapClient {
 	}
 
 	function isUpdateNotifyEnabled() {
+		if ( DEPLOYMENT_ON_DEMAND == TRUE ) {
+			return FALSE; //Disabled with On-Demand service.
+		}
+
 		if ( getTTProductEdition() == 10 ) {
 			$sslf = new SystemSettingListFactory();
 			$sslf->getByName('update_notify');
@@ -339,18 +343,15 @@ class TimeTrexSoapClient {
 		}
 
 		//Check for anonymous update notifications
+		$anonymous_update_notify = 0;
 		if ( $force == FALSE OR getTTProductEdition() == 10 ) {
 			$sslf = new SystemSettingListFactory();
 			$sslf->getByName('anonymous_update_notify');
 			if ( $sslf->getRecordCount() == 1 ) {
 				$anonymous_update_notify = $sslf->getCurrent()->getValue();
-			} else {
-				$anonymous_update_notify = 0;
 			}
-		} else {
-			$anonymous_update_notify = 0;
 		}
-
+		
 		$clf = new CompanyListFactory();
 		$clf->getById( $company_id );
 		if ( $clf->getRecordCount() > 0 ) {
@@ -371,6 +372,34 @@ class TimeTrexSoapClient {
 					$company_data['address2'] = $c_obj->getAddress2();
 					$company_data['work_phone'] = $c_obj->getWorkPhone();
 					$company_data['fax_phone'] = $c_obj->getFaxPhone();
+
+					$ulf = new UserListFactory();
+					if ( $c_obj->getBillingContact() != '' ) {
+						$ulf->getById( $c_obj->getBillingContact() );
+						if ( $ulf->getRecordCount() == 1 ) {
+							$u_obj = $ulf->getCurrent();
+							$company_data['billing_contact'] = '"'.$u_obj->getFullName().'" <'. $u_obj->getWorkEmail() .'>';
+						}
+					}
+					if ( $c_obj->getAdminContact() != '' ) {
+						$ulf->getById( $c_obj->getAdminContact() );
+						if ( $ulf->getRecordCount() == 1 ) {
+							$u_obj = $ulf->getCurrent();
+							$company_data['admin_contact'] = '"'.$u_obj->getFullName().'" <'. $u_obj->getWorkEmail() .'>';
+						}
+					}
+					if ( $c_obj->getSupportContact() != '' ) {
+						$ulf->getById( $c_obj->getSupportContact() );
+						if ( $ulf->getRecordCount() == 1 ) {
+							$u_obj = $ulf->getCurrent();
+							$company_data['support_contact'] = '"'.$u_obj->getFullName().'" <'. $u_obj->getWorkEmail() .'>';
+						}
+					}
+
+					$logo_file = $c_obj->getLogoFileName( $c_obj->getId(), FALSE ); //Ignore default logo
+					if ( $logo_file != '' AND file_exists( $logo_file ) ) {
+						$company_data['logo'] = array('file_name' => $logo_file, 'data' => base64_encode( file_get_contents($logo_file) ) );
+					}
 				}
 
 				$company_data['city'] = $c_obj->getCity();
