@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,16 +34,16 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: TimeTrexSoapServerUnAuthenticated.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: TimeTrexSoapServerUnAuthenticated.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
  * @package Module_SOAP
  */
 class TimeTrexSoapServerUnAuthenticated {
-
+	/*
 	function helloworld($text) {
 		return "Hello World: $text";
 	}
@@ -78,6 +78,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			return $retarr;
 		}
 	}
+	*/
 
 	function getClientVersion() {
 		if ( isset($_GET['v']) AND $_GET['v'] != '' ) {
@@ -146,6 +147,9 @@ class TimeTrexSoapServerUnAuthenticated {
 	}
 
 	function isLatestVersion($current_version) {
+		//Appears to be a bug in the client where if it downloads the file and the hashes don't match, it never overwrites the file again, and can't upgrade.
+		return TRUE;
+
 		if ( $current_version == '' ) {
 			return FALSE;
 		}
@@ -164,13 +168,16 @@ class TimeTrexSoapServerUnAuthenticated {
 	}
 
 	function getLatestVersionURL() {
-		if ( isset($_SERVER["HTTPS"]) ) {
+		$prefix = 'http';
+		/*
+		if ( isset($_SERVER['HTTPS']) ) {
 			$prefix = 'https';
 		} else {
 			$prefix = 'http';
 		}
+		*/
 
-		$retval = $prefix.'://'. $_SERVER["HTTP_HOST"].'/'.Environment::getBaseURL().'/help/Timetrex_Client.exe';
+		$retval = $prefix.'://'. $_SERVER['HTTP_HOST'].'/'.Environment::getBaseURL().'/help/Timetrex_Client.exe';
 
 		Debug::text('Client URL: '. $retval , __FILE__, __LINE__, __METHOD__, 10);
 
@@ -922,6 +929,12 @@ class TimeTrexSoapServerUnAuthenticated {
 			return FALSE;
 		}
 
+		//With an intermittent internet connection, the TimeTrex Client can sometimes send offline punches too soon
+		//Which causes online punches and offline punches to reach the server within the same second.
+		//Delay offline punches slightly to try and avoid this.
+		Debug::Text('Sleeping for 3 seconds attempting to avoid duplicate punches.', __FILE__, __LINE__, __METHOD__,10);
+		sleep(3);
+
 		ksort($data);
 
 		//Debug::Arr($data, 'offlinePunchDataArr', __FILE__, __LINE__, __METHOD__,10);
