@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3143 $
- * $Id: UserDeductionFactory.class.php 3143 2009-12-02 17:21:41Z ipso $
- * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
+ * $Revision: 4073 $
+ * $Id: UserDeductionFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -49,6 +49,65 @@ class UserDeductionFactory extends Factory {
 	var $user_obj = NULL;
 	var $company_deduction_obj = NULL;
 	var $pay_stub_entry_account_link_obj = NULL;
+
+	function _getFactoryOptions( $name ) {
+
+		$retval = NULL;
+		switch( $name ) {
+			case 'columns':
+				$retval = array(
+										'-1010-first_name' => TTi18n::gettext('First Name'),
+										'-1020-last_name' => TTi18n::gettext('Last Name'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'manual_id',
+								'name',
+								'city',
+								'province',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
+		}
+
+		return $retval;
+	}
+
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'user_id' => 'User',
+										'company_deduction_id' => 'CompanyDeduction',
+										'first_name' => FALSE,
+										'last_name' => FALSE,
+										'user_value1' => 'UserValue1',
+										'user_value2' => 'UserValue2',
+										'user_value3' => 'UserValue3',
+										'user_value4' => 'UserValue4',
+										'user_value5' => 'UserValue5',
+										'user_value6' => 'UserValue6',
+										'user_value7' => 'UserValue7',
+										'user_value8' => 'UserValue8',
+										'user_value9' => 'UserValue9',
+										'user_value10' => 'UserValue10',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
+
 	function getUserObject() {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
@@ -143,16 +202,19 @@ class UserDeductionFactory extends Factory {
 		Debug::Text('ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$cdlf = new CompanyDeductionListFactory();
 
-		if (
-				$this->Validator->isResultSetWithRows(	'company_deduction',
-														$cdlf->getByID($id),
-														TTi18n::gettext('Deduction is invalid')
-													)
-				AND
-				$this->Validator->isTrue(				'company_deduction',
-														$this->isUniqueCompanyDeduction($id),
-														TTi18n::gettext('Deduction is already assigned to employee')
+		if (	(
+					$id != 0
+					OR
+					$this->Validator->isResultSetWithRows(	'company_deduction',
+															$cdlf->getByID($id),
+															TTi18n::gettext('Deduction is invalid')
 														)
+				)
+					AND
+					$this->Validator->isTrue(				'company_deduction',
+															$this->isUniqueCompanyDeduction($id),
+															TTi18n::gettext('Deduction is already assigned to employee')
+															)
 
 
 													) {
@@ -833,7 +895,7 @@ class UserDeductionFactory extends Factory {
 				unset($fixed_amount, $tmp_amount, $amount, $min_limit, $max_limit);
 
 				break;
-			case 80: //US Earning Income Credit (EIC)
+			case 80: //US Earning Income Credit (EIC). Repealed as of 31-Dec-2010.
 				if ( $this->getUserValue1() == '' ) {
 					$user_value1 = $cd_obj->getUserValue1();
 				} else {
@@ -1199,10 +1261,66 @@ class UserDeductionFactory extends Factory {
 
 	function postSave() {
 		$this->removeCache( $this->getId() );
+
+		return TRUE;
+	}
+
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'first_name':
+						case 'last_name':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Deduction'), NULL, $this->getTable() );
+		$obj = $this->getUserObject();
+		if ( is_object($obj) ) {
+			return TTLog::addEntry( $this->getCompanyDeduction(), $log_action, TTi18n::getText('Employee Deduction') .': '. $obj->getFullName(), NULL, $this->getTable(), $this );
+		}
 	}
 }
 ?>
