@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2089 $
- * $Id: UserDefaultFactory.class.php 2089 2008-08-28 17:04:23Z ipso $
- * $Date: 2008-08-28 10:04:23 -0700 (Thu, 28 Aug 2008) $
+ * $Revision: 4073 $
+ * $Id: UserDefaultFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -51,6 +51,41 @@ class UserDefaultFactory extends Factory {
 
 	protected $city_validator_regex = '/^[a-zA-Z0-9-\.\ |\x7F-\xFF|\x{4E00}-\x{9FFF}]{1,250}$/iu';
 
+	function _getVariableToFunctionMap() {
+			$variable_function_map = array(
+											'id' => 'ID',
+											'company_id' => 'Company',
+											'permission_control_id' => 'PermissionControl',
+											'pay_period_schedule_id' => 'PayPeriodSchedule',
+											'policy_group_id' => 'PolicyGroup',
+											'employee_number' => 'EmployeeNumber',
+											'title_id' => 'Title',
+											'default_branch_id' => 'DefaultBranch',
+											'default_department_id' => 'DefaultDepartment',
+											'currency_id' => 'Currency',
+											'city' => 'City',
+											'country' => 'Country',
+											'province' => 'Province',
+											'work_phone' => 'WorkPhone',
+											'work_phone_ext' => 'WorkPhoneExt',
+											'work_email' => 'WorkEmail',
+											'hire_date' => 'HireDate',
+											'language' => 'Language',
+											'date_format' => 'DateFormat',
+											'time_format' => 'TimeFormat',
+											'time_zone' => 'TimeZone',
+											'time_unit_format' => 'TimeUnitFormat',
+											'items_per_page' => 'ItemsPerPage',
+											'start_week_day' => 'StartWeekDay',
+											'enable_email_notification_exception' => 'EnableEmailNotificationException',
+											'enable_email_notification_message' => 'EnableEmailNotificationMessage',
+											'enable_email_notification_home' => 'EnableEmailNotificationHome',
+											'company_deduction' => 'CompanyDeduction',
+											'deleted' => 'Deleted',
+											);
+			return $variable_function_map;
+	}
+
 	function getCompanyObject() {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
@@ -559,22 +594,16 @@ class UserDefaultFactory extends Factory {
 	}
 	function setDateFormat($date_format) {
 		$date_format = trim($date_format);
-
 		$upf = new UserPreferenceFactory();
 
-		$key = Option::getByValue($date_format, $upf->getOptions('date_format') );
-		if ($key !== FALSE) {
-			$date_format = $key;
-		}
-
 		if ( $this->Validator->inArrayKey(	'date_format',
 											$date_format,
 											TTi18n::gettext('Incorrect date format'),
-											$upf->getOptions('date_format')) ) {
+											Misc::trimSortPrefix( $upf->getOptions('date_format') )) ) {
 
 			$this->data['date_format'] = $date_format;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -604,7 +633,7 @@ class UserDefaultFactory extends Factory {
 
 			$this->data['time_format'] = $time_format;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -634,7 +663,7 @@ class UserDefaultFactory extends Factory {
 
 			$this->data['time_zone'] = $time_zone;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -665,7 +694,7 @@ class UserDefaultFactory extends Factory {
 
 			$this->data['time_unit_format'] = $time_unit_format;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -720,7 +749,7 @@ class UserDefaultFactory extends Factory {
 
 			$this->data['start_week_day'] = $value;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -838,8 +867,60 @@ class UserDefaultFactory extends Factory {
 		return TRUE;
 	}
 
+	//Support setting created_by,updated_by especially for importing data.
+	//Make sure data is set based on the getVariableToFunctionMap order.
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$uf = new UserFactory();
+
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Default Information'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Default Information'), NULL, $this->getTable(), $this );
 	}
 
 }
