@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: UserFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: UserFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -77,8 +77,9 @@ class UserFactory extends Factory {
 				break;
 			case 'sex':
 				$retval = array(
-										10 => TTi18n::gettext('MALE'),
-										20 => TTi18n::gettext('FEMALE'),
+										5 => TTi18n::gettext('Unspecified'),
+										10 => TTi18n::gettext('Male'),
+										20 => TTi18n::gettext('Female'),
 									);
 				break;
 			case 'columns':
@@ -96,6 +97,7 @@ class UserFactory extends Factory {
 										'-1099-group' => TTi18n::gettext('Group'),
 										'-1100-default_branch' => TTi18n::gettext('Branch'),
 										'-1110-default_department' => TTi18n::gettext('Department'),
+										'-1110-currency' => TTi18n::gettext('Currency'),
 
 										'-1112-permission_control' => TTi18n::gettext('Permission Group'),
 										'-1112-pay_period_schedule' => TTi18n::gettext('Pay Period Schedule'),
@@ -111,6 +113,7 @@ class UserFactory extends Factory {
 										'-1170-country' => TTi18n::gettext('Country'),
 										'-1180-postal_code' => TTi18n::gettext('Postal Code'),
 										'-1190-work_phone' => TTi18n::gettext('Work Phone'),
+										'-1191-work_phone_ext' => TTi18n::gettext('Work Phone Ext'),
 										'-1200-home_phone' => TTi18n::gettext('Home Phone'),
 										'-1210-mobile_phone' => TTi18n::gettext('Mobile Phone'),
 										'-1220-fax_phone' => TTi18n::gettext('Fax Phone'),
@@ -185,6 +188,7 @@ class UserFactory extends Factory {
 										'first_name' => 'FirstName',
 										'middle_name' => 'MiddleName',
 										'last_name' => 'LastName',
+										'full_name' => 'FullName',
 										'second_last_name' => 'SecondLastName',
 										'sex_id' => 'Sex',
 										'sex' => FALSE,
@@ -324,7 +328,7 @@ class UserFactory extends Factory {
 
 			$this->data['status_id'] = $status;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -358,6 +362,11 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 
+	function getPermissionLevel() {
+		$permission = new Permission();
+		return $permission->getLevel( $this->getID(), $this->getCompany() );
+	}
+
 	function getPermissionControl() {
 		if ( isset($this->tmp_data['permission_control_id']) ) {
 			return $this->tmp_data['permission_control_id'];
@@ -370,12 +379,38 @@ class UserFactory extends Factory {
 
 		$pclf = new PermissionControlListFactory();
 
+		//Get currently logged in users permission level, so we can ensure they don't assign another user to a higher level.
+		global $current_user;
+		if ( isset($current_user) AND is_object($current_user) ) {
+			$permission = new Permission();
+			$current_user_permission_level = $permission->getLevel( $current_user->getId(), $current_user->getCompany() );
+
+		} else {
+			//If we can't find the current_user object, we need to allow any permission group to be assigned, in case
+			//its being modified from raw factory calls.
+			$current_user_permission_level = 100;
+		}
+
+		$modify_permissions = FALSE;
+		if ( $current_user_permission_level >= $this->getPermissionLevel() ) {
+			$modify_permissions = TRUE;
+		}
+		Debug::Text('Current User Permission Level: '. $current_user_permission_level, __FILE__, __LINE__, __METHOD__,10);
+
+		//Don't allow permissions to be modified if the currently logged in user has a lower permission level.
+		//As such if someone with a lower level is able to edit the user of higher level, they must not call this function at all, or use a blank value.
 		if (	$id != ''
 				AND
 				$this->Validator->isResultSetWithRows(		'permission_control_id',
-															$pclf->getByID($id),
+															$pclf->getByIDAndLevel($id, $current_user_permission_level),
 															TTi18n::gettext('Permission Group is invalid')
-															) ) {
+															)
+				AND
+				$this->Validator->isTrue(		'permission_control_id',
+												$modify_permissions,
+												TTi18n::gettext('Insufficient access to modify permissions for this employee')
+												)
+				) {
 			$this->tmp_data['permission_control_id'] = $id;
 
 			return TRUE;
@@ -547,6 +582,8 @@ class UserFactory extends Factory {
 	function checkPassword($password) {
 		global $config_vars;
 
+		$password = html_entity_decode( $password );
+
 		//Check if LDAP is enabled
 		$ldap_authentication_type_id = 0;
 		if ( DEMO_MODE != TRUE AND function_exists('ldap_connect') AND !isset($config_vars['other']['enable_ldap']) OR ( isset($config_vars['other']['enable_ldap']) AND $config_vars['other']['enable_ldap'] == TRUE ) ) {
@@ -571,18 +608,23 @@ class UserFactory extends Factory {
 						TTLog::addEntry( $this->getId(), 510, TTi18n::getText('LDAP Authentication failed, falling back to local password for username').': '. $this->getUserName() . TTi18n::getText('IP Address') .': '.$_SERVER['REMOTE_ADDR'], $this->getId(), $this->getTable() );
 					}
 					unset($ldap);
+				} else {
+					Debug::Text('LDAP authentication is not enabled...', __FILE__, __LINE__, __METHOD__,10);
 				}
 			}
+		} else {
+			Debug::Text('LDAP authentication disabled due to config or extension missing...', __FILE__, __LINE__, __METHOD__,10);
 		}
 
 		$password = $this->encryptPassword( trim(strtolower($password)) );
+
 		//Don't check local TT passwords if LDAP Only authentication is enabled. Still accept override passwords though.
 		if ( $ldap_authentication_type_id != 2 AND $password == $this->getPassword() ) {
 			return TRUE;
 		} elseif ( isset($config_vars['other']['override_password_prefix'])
 						AND $config_vars['other']['override_password_prefix'] != '' ) {
 			//Check override password
-			if ( $password == $this->encryptPassword( trim( trim($config_vars['other']['override_password_prefix']).substr($this->getUserName(),0,2) ) ) ) {
+			if ( $password == $this->encryptPassword( trim( trim( strtolower($config_vars['other']['override_password_prefix']) ).substr($this->getUserName(),0,2) ) ) ) {
 				TTLog::addEntry( $this->getId(), 510, TTi18n::getText('Override Password successful from IP Address').': '. $_SERVER['REMOTE_ADDR'], NULL, $this->getTable() );
 				return TRUE;
 			}
@@ -693,18 +735,19 @@ class UserFactory extends Factory {
 	function setPhonePassword($phone_password) {
 		$phone_password = trim($phone_password);
 
+		//Limit phone password to max of 9 digits so we don't overflow an integer on the timeclocks. (10 digits, but maxes out at 2billion)
 		if 	(	$phone_password == ''
 				OR (
 				$this->Validator->isRegEx(		'phone_password',
 												$phone_password,
-												TTi18n::gettext('Phone password must be digits only.'),
+												TTi18n::gettext('PIN/Phone password must be digits only'),
 												$this->phonepassword_validator_regex)
 				AND
 					$this->Validator->isLength(		'phone_password',
 													$phone_password,
-													TTi18n::gettext('Incorrect phone password length'),
+													TTi18n::gettext('PIN/Phone password must be between 4 and 9 digits'),
 													4,
-													12) ) ) {
+													9) ) ) {
 
 			$this->data['phone_password'] = $phone_password;
 
@@ -1253,22 +1296,6 @@ class UserFactory extends Factory {
 
 	function getFullName($reverse = FALSE, $include_middle = TRUE ) {
 		return Misc::getFullName($this->getFirstName(), $this->getMiddleInitial(), $this->getLastName(), $reverse, $include_middle);
-		/*
-		if ( $this->getFirstName() != '' AND $this->getLastName() != '' ) {
-			if ( $reverse === TRUE ) {
-				$retval = $this->getLastName() .', '. $this->getFirstName();
-				if ( $include_middle == TRUE AND $this->getMiddleInitial() != '' ) {
-					$retval .= ' '.$this->getMiddleInitial().'.';
-				}
-			} else {
-				$retval = $this->getFirstName() .' '. $this->getLastName();
-			}
-
-			return $retval;
-		}
-
-		return FALSE;
-		*/
 	}
 
 	function getFirstName() {
@@ -1424,8 +1451,7 @@ class UserFactory extends Factory {
 											TTi18n::gettext('Invalid gender type'),
 											$this->getOptions('sex') ) ) {
 
-			//$this->data['sex_id'] = Option::getByValue($sex, $this->sex_options);
-			$this->data['sex_id']= $sex;
+			$this->data['sex_id'] = $sex;
 
 			return TRUE;
 		}
@@ -1844,7 +1870,8 @@ class UserFactory extends Factory {
 												$epoch,
 												TTi18n::gettext('Hire date is invalid')) ) {
 
-			$this->data['hire_date'] = TTDate::getMiddleDayEpoch( $epoch );
+			//Use the beginning of the day epoch, so accrual policies that apply on the hired date still work.
+			$this->data['hire_date'] = TTDate::getBeginDayEpoch( $epoch );
 
 			return TRUE;
 		}
@@ -1905,13 +1932,16 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 
-	function getSecureSIN() {
-		if ( $this->getSIN() != '' ) {
+	function getSecureSIN( $sin = NULL ) {
+		if ( $sin == '' ) {
+			$sin = $this->getSIN();
+		}
+		if ( $sin != '' ) {
 			//Grab the first 1, and last 3 digits.
-			$first_four = substr( $this->getSIN(), 0, 1 );
-			$last_four = substr( $this->getSIN(), -3 );
+			$first_four = substr( $sin, 0, 1 );
+			$last_four = substr( $sin, -3 );
 
-			$total = strlen($this->getSIN())-4;
+			$total = strlen($sin)-4;
 
 			$retval = $first_four.str_repeat('X', $total).$last_four;
 
@@ -2408,7 +2438,7 @@ class UserFactory extends Factory {
 					Debug::text('Record Count: '. $pgulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 					if ( $pgulf->getRecordCount() > 0 ) {
 						foreach( $pgulf as $pgu_obj ) {
-							Debug::text('Deleteing from Policy Group: '. $pgu_obj->getPolicyGroup(), __FILE__, __LINE__, __METHOD__, 10);
+							Debug::text('Deleting from Policy Group: '. $pgu_obj->getPolicyGroup(), __FILE__, __LINE__, __METHOD__, 10);
 							$pgu_obj->Delete();
 						}
 					}
@@ -2527,7 +2557,7 @@ class UserFactory extends Factory {
 		}
 
 		if ( $this->getDeleted() == TRUE ) {
-			//Remove them from the authorization hierarchy, policy group, and pay period schedule.
+			//Remove them from the authorization hierarchy, policy group, pay period schedule, stations, jobs, etc...
 			//Delete any accruals for them as well.
 
 			//Pay Period Schedule
@@ -2542,7 +2572,7 @@ class UserFactory extends Factory {
 				Debug::text('Record Count: '. $ppsulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 				if ( $ppsulf->getRecordCount() > 0 ) {
 					foreach( $ppsulf as $ppsu_obj ) {
-						Debug::text('Deleteing from Pay Period Schedule: '. $ppsu_obj->getPayPeriodSchedule(), __FILE__, __LINE__, __METHOD__, 10);
+						Debug::text('Deleting from Pay Period Schedule: '. $ppsu_obj->getPayPeriodSchedule(), __FILE__, __LINE__, __METHOD__, 10);
 						$ppsu_obj->Delete();
 					}
 				}
@@ -2590,6 +2620,26 @@ class UserFactory extends Factory {
 					}
 				}
 			}
+
+			//Station employee critiera
+			$siuf = new StationIncludeUserFactory();
+			$seuf = new StationExcludeUserFactory();
+
+			$query = 'delete from '. $siuf->getTable() .' where user_id = '. $this->getId();
+			$this->db->Execute($query);
+
+			$query = 'delete from '. $seuf->getTable() .' where user_id = '. $this->getId();
+			$this->db->Execute($query);
+
+			//Job employee criteria
+			$cgmlf = new CompanyGenericMapListFactory();
+			$cgmlf->getByCompanyIDAndObjectTypeAndMapID( $this->getCompany(), array(1040,1050), $this->getID() );
+			if ( $cgmlf->getRecordCount() > 0 ) {
+				foreach( $cgmlf as $cgm_obj ) {
+					Debug::text('Deleteing from Company Generic Map: '. $cgm_obj->getID(), __FILE__, __LINE__, __METHOD__, 10);
+					$cgm_obj->Delete();
+				}
+			}
 		}
 
 		return TRUE;
@@ -2647,6 +2697,8 @@ class UserFactory extends Factory {
 
 					$function = 'get'.$function_stub;
 					switch( $variable ) {
+						case 'full_name':
+							$data[$variable] = $this->getFullName(TRUE);
 						case 'status':
 						case 'sex':
 							$function = 'get'.$variable;
@@ -2666,6 +2718,7 @@ class UserFactory extends Factory {
 						case 'policy_group_id':
 						case 'policy_group':
 							$data[$variable] = $this->getColumn( $variable );
+							break;
 						case 'password': //Don't return password
 							break;
 						case 'sin':
@@ -2686,8 +2739,9 @@ class UserFactory extends Factory {
 					}
 
 				}
+				unset($function);
 			}
-			$this->getPermissionColumns( &$data, $this->getID(), $this->getCreatedBy(), $permission_children_ids );
+			$this->getPermissionColumns( &$data, $this->getID(), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
@@ -2695,7 +2749,7 @@ class UserFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee').': '. $this->getFullName( FALSE, TRUE ) , NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee').': '. $this->getFullName( FALSE, TRUE ) , NULL, $this->getTable(), $this );
 	}
 }
 ?>
