@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3298 $
- * $Id: UserListFactory.class.php 3298 2010-01-20 18:52:46Z ipso $
- * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
+ * $Revision: 4073 $
+ * $Id: UserListFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -552,7 +552,7 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		}
 
 		if ( $order == NULL ) {
-			$order = array( 'a.last_name' => 'asc' );
+			$order = array( 'a.id' => 'asc' );
 			$strict = FALSE;
 		} else {
 			$strict = TRUE;
@@ -569,8 +569,8 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 					'company_id' => $company_id,
 					'station_id' => $station_id,
 					'status_id' => $status_id,
-					'date' => $date,
-					'date2' => $date,
+					//'date' => $date,
+					//'date2' => $date,
 					);
 
 		$query = '
@@ -603,9 +603,124 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 									AND a.id not in ( select f.user_id from '. $seuf->getTable() .' as f WHERE z.id = f.station_id )
 								)
 								OR a.id in ( select e.user_id from '. $siuf->getTable() .' as e WHERE z.id = e.station_id )
-							)
-						AND	( a.created_date >= ? OR a.updated_date >= ? )
+							)';
+
+		if ( isset($date) AND $date > 0 ) {
+			//Append the same date twice for created and updated.
+			$ph[] = $date;
+			$ph[] = $date;
+			$query  .=	' AND ( a.created_date >= ? OR a.updated_date >= ? )';
+			unset($date_filter);
+		}
+
+		$query .= ' AND ( a.deleted = 0 AND z.deleted = 0 )';
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict );
+
+		//Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
+
+	function getByCompanyIDAndStationIDAndStatusAndDateAndValidUserIDs($company_id, $station_id, $status_id, $date = NULL, $valid_user_ids = array(), $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( $station_id == '') {
+			return FALSE;
+		}
+
+		if ( $status_id == '') {
+			return FALSE;
+		}
+
+		if ( $date == '') {
+			$date = 0;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'a.id' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$sf = new StationFactory();
+		$sugf = new StationUserGroupFactory();
+		$sbf = new StationBranchFactory();
+		$sdf = new StationDepartmentFactory();
+		$siuf = new StationIncludeUserFactory();
+		$seuf = new StationExcludeUserFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'station_id' => $station_id,
+					'status_id' => $status_id,
+					//'date' => $date,
+					//'date2' => $date,
+					);
+
+		$query = '
+					select 	a.*
+					from 	'. $this->getTable() .' as a,
+							'. $sf->getTable() .' as z
+					where	a.company_id = ?
+						AND z.id = ?
+						AND a.status_id = ?
+						AND
+							(
+								(
+									(
+										(
+											(
+												z.user_group_selection_type_id = 10
+													OR ( z.user_group_selection_type_id = 20 AND a.group_id in ( select b.group_id from '. $sugf->getTable() .' as b WHERE z.id = b.station_id ) )
+													OR ( z.user_group_selection_type_id = 30 AND a.group_id not in ( select b.group_id from '. $sugf->getTable() .' as b WHERE z.id = b.station_id ) )
+											)
+											AND
+											(
+												z.branch_selection_type_id = 10
+													OR ( z.branch_selection_type_id = 20 AND a.default_branch_id in ( select c.branch_id from '. $sbf->getTable() .' as c WHERE z.id = c.station_id ) )
+													OR ( z.branch_selection_type_id = 30 AND a.default_branch_id not in ( select c.branch_id from '. $sbf->getTable() .' as c WHERE z.id = c.station_id ) )
+											)
+											AND
+											(
+												z.department_selection_type_id = 10
+													OR ( z.department_selection_type_id = 20 AND a.default_department_id in ( select d.department_id from '. $sdf->getTable() .' as d WHERE z.id = d.station_id ) )
+													OR ( z.department_selection_type_id = 30 AND a.default_department_id not in ( select d.department_id from '. $sdf->getTable() .' as d WHERE z.id = d.station_id ) )
+											)
+											AND a.id not in ( select f.user_id from '. $seuf->getTable() .' as f WHERE z.id = f.station_id )
+										)
+										OR a.id in ( select e.user_id from '. $siuf->getTable() .' as e WHERE z.id = e.station_id )
+									)
+
+							';
+
+		if ( isset($date) AND $date > 0 ) {
+			//Append the same date twice for created and updated.
+			$ph[] = (int)$date;
+			$ph[] = (int)$date;
+			$query  .=	' 		AND ( a.created_date >= ? OR a.updated_date >= ? )
+								)';
+		} else {
+				$query  .=	'   )';
+		}
+
+		if ( isset($valid_user_ids) AND is_array($valid_user_ids) AND count($valid_user_ids) > 0 ) {
+			$query  .=	' OR a.id in ('. $this->getListSQL($valid_user_ids, $ph) .') ';
+		}
+
+		$query .= '			)
 						AND ( a.deleted = 0 AND z.deleted = 0 )';
+
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict );
 
@@ -690,8 +805,12 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		}
 
 		foreach ($lf as $obj) {
+			if ( !isset($status_options) ) {
+				$status_options = $obj->getOptions('status');
+			}
+
 			if ( $obj->getStatus() > 10 ) { //INACTIVE
-				$status = '('.Option::getByKey( $obj->getStatus(), $obj->getOptions('status') ).') ';
+				$status = '('.Option::getByKey( $obj->getStatus(), $status_options ).') ';
 				//$status = '(INACTIVE) ';
 			} else {
 				$status = NULL;
@@ -709,6 +828,45 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		return FALSE;
 	}
 
+	function getDeletedByCompanyIdAndDate($company_id, $date, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( $date == '') {
+			return FALSE;
+		}
+
+		$ph = array(
+					'company_id' => $company_id,
+					'created_date' => $date,
+					'updated_date' => $date,
+					'deleted_date' => $date,
+					);
+
+		//INCLUDE Deleted rows in this query.
+		$query = '
+					select 	*
+					from	'. $this->getTable() .'
+					where
+							company_id = ?
+						AND
+							( created_date >= ? OR updated_date >= ? OR deleted_date >= ? )
+						AND deleted = 1
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+
+		}
+
+		return $this;
+	}
+
 	function getIsModifiedByCompanyIdAndDate($company_id, $date, $where = NULL, $order = NULL) {
 		if ( $company_id == '') {
 			return FALSE;
@@ -1423,6 +1581,13 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 			}
 		}
 
+		if ( isset($filter_data['include_user_id']) ) {
+			$filter_data['id'] = $filter_data['include_user_id'];
+		}
+		if ( isset($filter_data['exclude_user_id']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_user_id'];
+		}
+
 		//$additional_order_fields = array('b.name', 'c.name', 'd.name', 'e.name');
 		$additional_order_fields = array(	'default_branch',
 											'default_department',
@@ -1440,7 +1605,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 									 );
 
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
-
 		if ( $order == NULL ) {
 			$order = array( 'status_id' => 'asc', 'last_name' => 'asc', 'first_name' => 'asc', 'middle_name' => 'asc');
 			$strict = FALSE;
@@ -1635,6 +1799,7 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 			$ph[] = strtolower(trim($filter_data['last_name']));
 			$query  .=	' AND lower(a.last_name) LIKE ?';
 		}
+
 		if ( isset($filter_data['home_phone']) AND trim($filter_data['home_phone']) != '' ) {
 			$ph[] = trim($filter_data['home_phone']);
 			$query  .=	' AND a.home_phone LIKE ?';
