@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: UserPreferenceFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: UserPreferenceFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -48,7 +48,7 @@ class UserPreferenceFactory extends Factory {
 
 	var $user_obj = NULL;
 
-	function _getFactoryOptions( $name ) {
+	function _getFactoryOptions( $name, $include_sort_prefix = FALSE ) {
 
 		$retval = NULL;
 		switch( $name ) {
@@ -56,12 +56,12 @@ class UserPreferenceFactory extends Factory {
 			// I18n: No need to use gettext because these options only appear for english.
 			case 'date_format':
 				$retval = array(
-											'd-M-y'		=> '25-Feb-01 (dd-mmm-yy)',
-											'd-M-Y'		=> '25-Feb-2001 (dd-mmm-yyyy)',
+											'd-M-y'		=> TTi18n::gettext('25-Feb-01 (dd-mmm-yy)'),
+											'd-M-Y'		=> TTi18n::gettext('25-Feb-2001 (dd-mmm-yyyy)'),
 //PHP 5.1.2 fails to parse these with strtotime it looks like
 //											'd/M/y' 	=> '25/Feb/01 (dd/mmm/yy)',
 //											'd/M/Y' 	=> '25/Feb/2001 (dd/mmm/yyyy)',
-											'dMY' 		=> '25Feb2001 (ddmmmyyyy)',
+											'dMY' 		=> TTi18n::gettext('25Feb2001 (ddmmmyyyy)'),
 											'd/m/Y' 	=> '25/02/2001 (dd/mm/yyyy)',
 											'd/m/y' 	=> '25/02/01 (dd/mm/yy)',
 											'd-m-y' 	=> '25-02-01 (dd-mm-yy)',
@@ -71,16 +71,19 @@ class UserPreferenceFactory extends Factory {
 											'm-d-y'		=> '02-25-01 (mm-dd-yy)',
 											'm-d-Y'		=> '02-25-2001 (mm-dd-yyyy)',
 											'Y-m-d' 	=> '2001-02-25 (yyyy-mm-dd)',
-											'M-d-y' 	=> 'Feb-25-01 (mmm-dd-yy)',
-											'M-d-Y' 	=> 'Feb-25-2001 (mmm-dd-yyyy)',
-											'l, F d Y'	=> 'Sunday, February 25 2001',
-											'D, F d Y'	=> 'Sun, February 25 2001',
-											'D, M d Y'	=> 'Sun, Feb 25 2001',
-											'D, d-M-Y'	=> 'Sun, 25-Feb-2001',
-											'D, dMY'	=> 'Sun, 25Feb2001'
+											'M-d-y' 	=> TTi18n::gettext('Feb-25-01 (mmm-dd-yy)'),
+											'M-d-Y' 	=> TTi18n::gettext('Feb-25-2001 (mmm-dd-yyyy)'),
+											'l, F d Y' 	=> TTi18n::gettext('Sunday, February 25 2001'),
+											'D, F d Y' 	=> TTi18n::gettext('Sun, February 25 2001'),
+											'D, M d Y' 	=> TTi18n::gettext('Sun, Feb 25 2001'),
+											'D, d-M-Y' 	=> TTi18n::gettext('Sun, 25-Feb-2001'),
+											'D, dMY' 	=> TTi18n::gettext('Sun, 25Feb2001')
 									);
-				break;
 
+				if ( defined('TIMETREX_API') == TRUE AND TIMETREX_API == TRUE ) {
+					$retval = Misc::addSortPrefix( $retval );
+				}
+				break;
 			// I18n: We use fewer calendar options for non-en langs, as otherwise strtotime chokes.
 			case 'other_date_format':
 				$retval = array(
@@ -94,6 +97,10 @@ class UserPreferenceFactory extends Factory {
 											'm-d-Y'		=> '02-25-2001 (mm-dd-yyyy)',
 											'Y-m-d' 	=> '2001-02-25 (yyyy-mm-dd)',
 									);
+
+				if ( defined('TIMETREX_API') == TRUE AND TIMETREX_API == TRUE ) {
+					$retval = Misc::addSortPrefix( $retval );
+				}
 				break;
 			case 'js_date_format':
 				$retval = array(
@@ -150,8 +157,8 @@ class UserPreferenceFactory extends Factory {
 											'g:i a' 	=> TTi18n::gettext('8:09 pm'),
 											//'G:i:s' 	=> TTi18n::gettext('20:09:11'),
 											'G:i' 		=> TTi18n::gettext('20:09'),
-											'g:i A T' => TTi18n::gettext('8:09 PM GMT'),
-											'G:i T' => TTi18n::gettext('20:09 GMT')
+											'g:i A T' 	=> TTi18n::gettext('8:09 PM GMT'),
+											'G:i T' 	=> TTi18n::gettext('20:09 GMT')
 									);
 				break;
 			case 'js_time_format':
@@ -159,8 +166,8 @@ class UserPreferenceFactory extends Factory {
 											'g:i A' 	=> '%l:%M %p', //  8:09 PM
 											'g:i a' 	=> '%l:%M %P', //8:09 pm
 											'G:i' 		=> '%k:%M', //20:09
-											'g:i A T' => '%l:%M %p', //8:09 PM GMT
-											'G:i T' => '%k:%M' //20:09 PM GMT
+											'g:i A T' 	=> '%l:%M %p', //8:09 PM GMT
+											'G:i T' 	=> '%k:%M' //20:09 PM GMT
 									);
 				break;
 			case 'flex_time_format':
@@ -168,8 +175,8 @@ class UserPreferenceFactory extends Factory {
 											'g:i A' 	=> 'L:NN A', //  8:09 PM
 											'g:i a' 	=> 'L:NN a', //8:09 pm
 											'G:i' 		=> 'JJ:NN', //20:09
-											'g:i A T' => 'L:NN A T', //8:09 PM GMT
-											'G:i T' => 'JJ:NN T' //20:09 PM GMT
+											'g:i A T' 	=> 'L:NN A T', //8:09 PM GMT
+											'G:i T' 	=> 'JJ:NN T' //20:09 PM GMT
 									);
 				break;
 			case 'time_unit_format':
@@ -750,35 +757,84 @@ class UserPreferenceFactory extends Factory {
 											'Etc/GMT+13' => 'GMT-13',
 											'Etc/GMT+14' => 'GMT-14',
 									);
-				break;
 
-			case 'date_format':
+				if ( defined('TIMETREX_API') == TRUE AND TIMETREX_API == TRUE ) {
+					$retval = Misc::addSortPrefix( $retval );
+				}
+				break;
+			case 'location_timezone':
+				//Country/Province to TimeZone map.
 				$retval = array(
-											'd-M-y'		=> TTi18n::gettext('25-Feb-01 (dd-mmm-yy)'),
-											'd-M-Y'		=> TTi18n::gettext('25-Feb-2001 (dd-mmm-yyyy)'),
-//PHP 5.1.2 fails to parse these with strtotime it looks like
-//											'd/M/y' 	=> '25/Feb/01 (dd/mmm/yy)',
-//											'd/M/Y' 	=> '25/Feb/2001 (dd/mmm/yyyy)',
-											'dMY' 		=> TTi18n::gettext('25Feb2001 (ddmmmyyyy)'),
-											'd/m/Y' 	=> '25/02/2001 (dd/mm/yyyy)',
-											'd/m/y' 	=> '25/02/01 (dd/mm/yy)',
-											'd-m-y' 	=> '25-02-01 (dd-mm-yy)',
-											'd-m-Y'		=> '25-02-2001 (dd-mm-yyyy)',
-											'm/d/y' 	=> '02/25/01 (mm/dd/yy)',
-											'm/d/Y' 	=> '02/25/2001 (mm/dd/yyyy)',
-											'm-d-y'		=> '02-25-01 (mm-dd-yy)',
-											'm-d-Y'		=> '02-25-2001 (mm-dd-yyyy)',
-											'Y-m-d' 	=> '2001-02-25 (yyyy-mm-dd)',
-											'M-d-y' 	=> TTi18n::gettext('Feb-25-01 (mmm-dd-yy)'),
-											'M-d-Y' 	=> TTi18n::gettext('Feb-25-2001 (mmm-dd-yyyy)'),
-											'l, F d Y' 	=> TTi18n::gettext('Sunday, February 25 2001'),
-											'D, F d Y' 	=> TTi18n::gettext('Sun, February 25 2001'),
-											'D, M d Y' 	=> TTi18n::gettext('Sun, Feb 25 2001'),
-											'D, d-M-Y' 	=> TTi18n::gettext('Sun, 25-Feb-2001'),
-											'D, dMY' 	=> TTi18n::gettext('Sun, 25Feb2001')
-									);
+										'CA' => array(
+														'AB' => 'MST7MDT',
+														'BC' => 'PST8PDT',
+														'SK' => 'CST6CDT',
+														'MB' => 'CST6CDT',
+														'QC' => 'EST5EDT',
+														'ON' => 'EST5EDT',
+														'NL' => 'Canada/Newfoundland',
+														'NB' => 'EST5EDT',
+														'NS' => 'AST4ADT',
+														'PE' => 'AST4ADT',
+														'NT' => 'MST7MDT',
+														'YT' => 'PST8PDT',
+														'NU' => 'EST5EDT',
+														),
+										'US' => array(
+														'AL' => 'CST6CDT',
+														'AK' => 'US/Alaska',
+														'AZ' => 'MST7MDT',
+														'AR' => 'CST6CDT',
+														'CA' => 'PST8PDT',
+														'CO' => 'MST7MDT',
+														'CT' => 'EST5EDT',
+														'DE' => 'EST5EDT',
+														'DC' => 'EST5EDT',
+														'FL' => 'EST5EDT',
+														'GA' => 'EST5EDT',
+														'HI' => 'HST',
+														'ID' => 'MST7MDT',
+														'IL' => 'CST6CDT',
+														'IN' => 'EST5EDT',
+														'IA' => 'CST6CDT',
+														'KS' => 'CST6CDT',
+														'KY' => 'EST5EDT',
+														'LA' => 'CST6CDT',
+														'ME' => 'EST5EDT',
+														'MD' => 'CST6CDT',
+														'MA' => 'EST5EDT',
+														'MI' => 'EST5EDT',
+														'MN' => 'CST6CDT',
+														'MS' => 'CST6CDT',
+														'MO' => 'CST6CDT',
+														'MT' => 'MST7MDT',
+														'NE' => 'CST6CDT',
+														'NV' => 'PST8PDT',
+														'NH' => 'EST5EDT',
+														'NM' => 'MST7MDT',
+														'NJ' => 'EST5EDT',
+														'NY' => 'EST5EDT',
+														'NC' => 'EST5EDT',
+														'ND' => 'EST5EDT',
+														'OH' => 'EST5EDT',
+														'OK' => 'CST6CDT',
+														'OR' => 'PST8PDT',
+														'PA' => 'EST5EDT',
+														'RI' => 'EST5EDT',
+														'SC' => 'EST5EDT',
+														'SD' => 'EST5EDT',
+														'TN' => 'CST6CDT',
+														'TX' => 'CST6CDT',
+														'UT' => 'MST7MDT',
+														'VT' => 'EST5EDT',
+														'VA' => 'EST5EDT',
+														'WA' => 'PST8PDT',
+														'WV' => 'EST5EDT',
+														'WI' => 'CST6CDT',
+														'WY' => 'MST7MDT',
+													),
+								);
 				break;
-
 			case 'timesheet_view':
 				$retval = array(
 											10 	=> TTi18n::gettext('Calendar'),
@@ -797,6 +853,14 @@ class UserPreferenceFactory extends Factory {
 											6 	=> TTi18n::gettext('Saturday'),
 									);
 				break;
+			case 'language':
+				$retval = TTi18n::getLanguageArray();
+
+				//Because the array keys are strings, flex needs a sort prefix to maintain the order.
+				if ( defined('TIMETREX_API') == TRUE AND TIMETREX_API == TRUE ) {
+					$retval = Misc::addSortPrefix( $retval );
+				}
+				break;
 			case 'columns':
 				$retval = array(
 										'-1000-first_name' => TTi18n::gettext('First Name'),
@@ -810,13 +874,13 @@ class UserPreferenceFactory extends Factory {
 										'-1060-department' => TTi18n::gettext('Department'),
 
 										'-1120-language_display' => TTi18n::gettext('Language'),
-										'-1130-date_format' => TTi18n::gettext('Date Format'),
-										'-1140-time_format' => TTi18n::gettext('Time Format'),
-										'-1150-time_zone' => TTi18n::gettext('TimeZone'),
-										'-1160-time_unit_format' => TTi18n::gettext('Time Unit Format'),
+										'-1130-date_format_display' => TTi18n::gettext('Date Format'),
+										'-1140-time_format_display' => TTi18n::gettext('Time Format'),
+										'-1150-time_zone_display' => TTi18n::gettext('TimeZone'),
+										'-1160-time_unit_format_display' => TTi18n::gettext('Time Unit Format'),
 										'-1170-items_per_page' => TTi18n::gettext('Items Per Page'),
-										'-1180-timesheet_view' => TTi18n::gettext('TimeSheet View'),
-										'-1190-start_week_day' => TTi18n::gettext('Start Weekday'),
+										//'-1180-timesheet_view_display' => TTi18n::gettext('TimeSheet View'),
+										'-1190-start_week_day_display' => TTi18n::gettext('Start Weekday'),
 										//'-1100-enable_email_notification_exception' => TTi18n::gettext('Email Notification Exception'),
 										//'-1110-enable_email_notification_message' => TTi18n::gettext('Email Notification Message'),
 										//'-1120-enable_email_notification_home' => TTi18n::gettext('Email Notification Home'),
@@ -831,10 +895,10 @@ class UserPreferenceFactory extends Factory {
 				$retval = array(
 								'first_name',
 								'last_name',
-								'date_format',
-								'time_format',
-								'time_unit_format',
-								'time_zone',
+								'date_format_display',
+								'time_format_display',
+								'time_unit_format_display',
+								'time_zone_display',
 								);
 				break;
 		}
@@ -865,6 +929,14 @@ class UserPreferenceFactory extends Factory {
 										'time_format' => 'TimeFormat',
 										'time_zone' => 'TimeZone',
 										'time_unit_format' => 'TimeUnitFormat',
+
+										//Ignore when setting.
+										'language_display' => FALSE,
+										'date_format_display' => FALSE,
+										'time_format_display' => FALSE,
+										'time_zone_display' => FALSE,
+										'time_unit_format_display' => FALSE,
+
 										'items_per_page' => 'ItemsPerPage',
 										//'timesheet_view' => 'TimeSheetView',
 										'start_week_day' => 'StartWeekDay',
@@ -984,11 +1056,14 @@ class UserPreferenceFactory extends Factory {
 		if ($key !== FALSE) {
 			$date_format = $key;
 		}
+		Debug::text('Date Format: '. $date_format .' Type: '. gettype($date_format), __FILE__, __LINE__, __METHOD__, 10);
 
-		if ( $this->Validator->inArrayKey(	'date_format',
-											$date_format,
-											TTi18n::gettext('Incorrect date format'),
-											$this->getOptions('date_format')) ) {
+		if ( 	$date_format == ''
+				OR
+				$this->Validator->inArrayKey(	'date_format',
+												$date_format,
+												TTi18n::gettext('Incorrect date format'),
+												Misc::trimSortPrefix( $this->getOptions('date_format') ) ) ) {
 
 			$this->data['date_format'] = $date_format;
 
@@ -1052,17 +1127,12 @@ class UserPreferenceFactory extends Factory {
 		return FALSE;
 	}
 	function setTimeZone($time_zone) {
-		$time_zone = trim($time_zone);
-
-		$key = Option::getByValue($time_zone, $this->getOptions('time_zone') );
-		if ($key !== FALSE) {
-			$time_zone = $key;
-		}
+		$time_zone = Misc::trimSortPrefix( trim($time_zone) );
 
 		if ( $this->Validator->inArrayKey(	'time_zone',
 											$time_zone,
 											TTi18n::gettext('Incorrect time zone'),
-											$this->getOptions('time_zone')) ) {
+											Misc::trimSortPrefix( $this->getOptions('time_zone') ) ) ) {
 
 			$this->data['time_zone'] = Misc::trimSortPrefix( $time_zone );
 
@@ -1335,16 +1405,44 @@ class UserPreferenceFactory extends Factory {
 						case 'user_status':
 							$data[$variable] = Option::getByKey( (int)$this->getColumn( 'user_status_id' ), $uf->getOptions( 'status' ) );
 							break;
-						case 'language':
-						case 'date_format':
-						case 'time_format':
-						case 'time_zone':
-						case 'time_unit_format':
-						case 'timesheet_view':
-						case 'start_week_day':
-							if ( method_exists( $this, $function ) ) {
-								$data[$variable.'_display'] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+
+						//Add the *_display element for each of the below fields.
+						case 'language_display':
+						case 'date_format_display':
+						case 'time_format_display':
+						case 'time_zone_display':
+						case 'time_unit_format_display':
+						case 'timesheet_view_display':
+						case 'start_week_day_display':
+							switch ( $variable ) {
+								case 'language_display':
+									$function = 'getLanguage';
+									break;
+								case 'date_format_display':
+									$function = 'getDateFormat';
+									break;
+								case 'time_format_display':
+									$function = 'getTimeFormat';
+									break;
+								case 'time_zone_display':
+									$function = 'getTimeZone';
+									break;
+								case 'time_unit_format_display':
+									$function = 'getTimeUnitFormat';
+									break;
+								case 'timesheet_view_display':
+									$function = 'getTimeSheetView';
+									break;
+								case 'start_week_day_display':
+									$function = 'getStartWeekDay';
+									break;
 							}
+
+							$variable = str_replace('_display', '', $variable );
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable.'_display'] = Option::getByKey( $this->$function(), Misc::trimSortPrefix( $this->getOptions( $variable ) ) );
+							}
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
@@ -1360,7 +1458,7 @@ class UserPreferenceFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Preferences') , NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Preferences') , NULL, $this->getTable(), $this );
 	}
 }
 ?>
\ No newline at end of file
