@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2858 $
- * $Id: UserTitleFactory.class.php 2858 2009-09-29 18:12:05Z ipso $
- * $Date: 2009-09-29 11:12:05 -0700 (Tue, 29 Sep 2009) $
+ * $Revision: 3764 $
+ * $Id: UserTitleFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
+ * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
  */
 
 /**
@@ -227,7 +227,7 @@ class UserTitleFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Title'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Title'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
