@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: UserWageFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: UserWageFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -77,6 +77,10 @@ class UserWageFactory extends Factory {
 										'-1050-wage' => TTi18n::gettext('Wage'),
 										'-1060-effective_date' => TTi18n::gettext('Effective Date'),
 
+										'-1070-hourly_rate' => TTi18n::gettext('Hourly Rate'),
+										'-1070-labor_burden_percent' => TTi18n::gettext('Labor Burden Percent'),
+										'-1080-weekly_time' => TTi18n::gettext('Average Time/Week'),
+
 										'-1090-title' => TTi18n::gettext('Title'),
 										'-1099-group' => TTi18n::gettext('Group'),
 										'-1100-default_branch' => TTi18n::gettext('Branch'),
@@ -101,13 +105,8 @@ class UserWageFactory extends Factory {
 								);
 				break;
 			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
-/*
 				$retval = array(
-								'type_id',
-								'weekly_time',
-								'hourly_rate'
 								);
-*/
 				break;
 
 		}
@@ -148,9 +147,13 @@ class UserWageFactory extends Factory {
 			return $this->user_obj;
 		} else {
 			$ulf = new UserListFactory();
-			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
+			$ulf->getById( $this->getUser() );
+			if ( $ulf->getRecordCount() == 1 ) {
+				$this->user_obj = $ulf->getCurrent();
+				return $this->user_obj;
+			}
 
-			return $this->user_obj;
+			return FALSE;
 		}
 	}
 
@@ -739,7 +742,6 @@ class UserWageFactory extends Factory {
 							}
 							break;
 					}
-
 				}
 			}
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
@@ -749,7 +751,7 @@ class UserWageFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Wage'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee Wage'), NULL, $this->getTable(), $this );
 	}
 }
 ?>
