@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: UserWageListFactory.class.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: UserWageListFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -225,7 +225,7 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 						AND deleted = 0';
 		$query .= $this->getSortSQL( $order );
 
-		Debug::text(' Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
+		//Debug::text(' Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
 
 		$this->rs = $this->db->Execute($query, $ph);
 
@@ -490,39 +490,6 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 		$ph['company_id2'] = $company_id;
 		$ph['start_date2'] = $this->db->BindTimeStamp( $start_date );
 
-		//This query is broken, as the after the UNION it has LIMIT 1, which only shows wages for the first employee, not the last wage for EACH employee.
-/*
-		$query = '
-					(
-					select b.*
-					from	'. $uf->getTable() .' as a,
-							'. $this->getTable() .' as b
-					where	a.id = b.user_id
-						AND a.company_id = ?
-						AND b.effective_date >= ?
-						AND b.effective_date <= ?
-						AND	b.user_id in ('. $b_user_id_sql .')
-						AND b.wage_group_id = 0
-						AND (a.deleted = 0 AND b.deleted=0)
-
-					)
-					UNION
-					(
-						select d.*
-						from 	'. $uf->getTable() .' as c,
-								'. $this->getTable() .' as d
-						where c.id = d.user_id
-							AND c.company_id = ?
-							AND d.effective_date <= ?
-							AND	d.user_id in ('. $this->getListSQL($user_id, $ph) .')
-							AND (c.deleted = 0 AND d.deleted=0)
-						order by d.effective_date desc
-						LIMIT 1
-					)
-					ORDER BY effective_date desc
-					';
-*/
-
 		$query = '
 					(
 					select b.*
@@ -749,6 +716,194 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 			$query  .=	' AND b.province in ('. $this->getListSQL($filter_data['province'], $ph) .') ';
 		}
 
+		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
+		}
+		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
+			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
+		}
+
+		$query .= 	'
+						AND a.deleted = 0
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
+	function getAPILastWageSearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		if ( !isset($filter_data['effective_date']) ) {
+			$filter_data['effective_date'] = TTDate::getTime();
+		}
+
+		if ( isset($filter_data['include_user_id']) ) {
+			$filter_data['user_id'] = $filter_data['include_user_id'];
+		}
+		if ( isset($filter_data['exclude_user_id']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_user_id'];
+		}
+
+		$additional_order_fields = array( 'wage_group' );
+		if ( $order == NULL ) {
+			$order = array( 'effective_date' => 'desc', 'wage_group_id' => 'asc', 'type_id' => 'asc', );
+			$strict = FALSE;
+		} else {
+			//Always sort by last name,first name after other columns
+			if ( !isset($order['effective_date']) ) {
+				$order['effective_date'] = 'desc';
+			}
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		$uf = new UserFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
+		$cf = new CurrencyFactory();
+		$wgf = new WageGroupFactory();
+
+		$ph = array(
+					'effective_date' => $this->db->BindTimeStamp($filter_data['effective_date']),
+					'company_id' => $company_id,
+					);
+
+/*
+		$query = '
+					select a.*
+					from '. $this->getTable() .' as a,
+						(
+						select 	z.user_id, max(effective_date) as effective_date
+						from	'. $this->getTable() .' as z
+						where
+							z.effective_date <= ?
+							AND z.wage_group_id = 0
+							AND z.user_id in ('. $this->getListSQL( $user_id, $ph ) .')
+							AND ( z.deleted = 0 )
+						GROUP BY z.user_id
+						) as b,
+						'. $uf->getTable() .' as c
+					WHERE a.user_id = b.user_id
+						AND a.effective_date = b.effective_date
+						AND a.user_id = c.id
+						AND ( c.deleted = 0	AND a.deleted = 0)
+				';
+
+*/
+		$query = '
+					select 	a.*,
+							CASE WHEN a.wage_group_id = 0 THEN \''. TTi18n::getText('-Default-') .'\' ELSE ab.name END as wage_group,
+							b.first_name as first_name,
+							b.last_name as last_name,
+							b.country as country,
+							b.province as province,
+
+							c.id as default_branch_id,
+							c.name as default_branch,
+							d.id as default_department_id,
+							d.name as default_department,
+							e.id as group_id,
+							e.name as group,
+							f.id as title_id,
+							f.name as title,
+							g.id as currency_id,
+							g.iso_code as iso_code,
+
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name
+					from 	(
+								select 	uwf.user_id as user_id, uwf.wage_group_id as wage_group_id, max(effective_date) as effective_date
+								from	'. $this->getTable() .' as uwf
+								where uwf.effective_date <= ? AND uwf.deleted = 0
+								GROUP BY uwf.wage_group_id, uwf.user_id
+							) as uwf_b
+
+						LEFT JOIN '. $this->getTable() .' as a ON ( a.user_id = uwf_b.user_id AND a.wage_group_id = uwf_b.wage_group_id AND a.effective_date = uwf_b.effective_date )
+
+						LEFT JOIN '. $wgf->getTable() .' as ab ON ( a.wage_group_id = ab.id AND ab.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as b ON ( a.user_id = b.id AND b.deleted = 0 )
+
+						LEFT JOIN '. $bf->getTable() .' as c ON ( b.default_branch_id = c.id AND c.deleted = 0)
+						LEFT JOIN '. $df->getTable() .' as d ON ( b.default_department_id = d.id AND d.deleted = 0)
+						LEFT JOIN '. $ugf->getTable() .' as e ON ( b.group_id = e.id AND e.deleted = 0 )
+						LEFT JOIN '. $utf->getTable() .' as f ON ( b.title_id = f.id AND f.deleted = 0 )
+						LEFT JOIN '. $cf->getTable() .' as g ON ( b.currency_id = g.id AND g.deleted = 0 )
+
+
+						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					where	b.company_id = ?
+					';
+
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND a.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
+			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['wage_group_id']) AND isset($filter_data['wage_group_id'][0]) AND !in_array(-1, (array)$filter_data['wage_group_id']) ) {
+			$query  .=	' AND a.wage_group_id in ('. $this->getListSQL($filter_data['wage_group_id'], $ph) .') ';
+		}
+
+
+		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+			$query  .=	' AND b.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
+			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
+			}
+			$query  .=	' AND b.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+			$query  .=	' AND b.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+			$query  .=	' AND b.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
+			$query  .=	' AND b.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['country']) AND isset($filter_data['country'][0]) AND !in_array(-1, (array)$filter_data['country']) ) {
+			$query  .=	' AND b.country in ('. $this->getListSQL($filter_data['country'], $ph) .') ';
+		}
+		if ( isset($filter_data['province']) AND isset($filter_data['province'][0]) AND !in_array( -1, (array)$filter_data['province']) AND !in_array( '00', (array)$filter_data['province']) ) {
+			$query  .=	' AND b.province in ('. $this->getListSQL($filter_data['province'], $ph) .') ';
+		}
 
 		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
