@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: CA.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 4073 $
+ * $Id: CA.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -127,11 +127,6 @@ class PayrollDeduction_CA extends PayrollDeduction_CA_Data {
 	}
 
 	function setYearToDateCPPContribution($value) {
-		/*
-		if ($value > $this->cpp_employee_maximum_contribution) {
-			$value = $this->cpp_employee_maximum_contribution;
-		}
-		*/
 		if ( $value > 0 ) {
 			$this->data['cpp_year_to_date_contribution'] = $value;
 
@@ -163,11 +158,6 @@ class PayrollDeduction_CA extends PayrollDeduction_CA_Data {
 	}
 
 	function setYearToDateEIContribution($value) {
-		/*
-		if ($value > $this->ei_employee_maximum_contribution) {
-			$value = $this->ei_employee_maximum_contribution;
-		}
-		*/
 		if ( $value > 0 ) {
 			$this->data['ei_year_to_date_contribution'] = $value;
 
@@ -511,7 +501,6 @@ class PayrollDeduction_CA extends PayrollDeduction_CA_Data {
 		Debug::text('S: '. $S, __FILE__, __LINE__, __METHOD__,10);
 
 		return $T2;
-
 	}
 
 	function getProvincialBasicTax() {
