@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: BC.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 4073 $
+ * $Id: BC.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -52,7 +52,29 @@ class PayrollDeduction_CA_BC extends PayrollDeduction_CA {
 		$S = 0;
 
 		Debug::text('BC Specific - Province: '. $this->getProvince(), __FILE__, __LINE__, __METHOD__,10);
-		if ( $this->getDate() >= strtotime('01-Jan-2010') ) {
+		if ( $this->getDate() >= strtotime('01-Jan-2011') ) {
+			//Calculate S after Jan 1st 2009.
+			if ( $A <= 17493 ) {
+				Debug::text('S: Annual Income less than 17493', __FILE__, __LINE__, __METHOD__,10);
+				if ( $T4 > 394 ) {
+					$S = 394;
+				} else {
+					$S = $T4;
+				}
+			} elseif ( $A > 17493 AND $A <= 29805.50) {
+				Debug::text('S: Annual Income less than 29541.50', __FILE__, __LINE__, __METHOD__,10);
+
+				$tmp_S = bcsub( 394, bcmul( bcsub( $A, 17493 ), 0.032 ) );
+				Debug::text('Tmp_S: '. $tmp_S, __FILE__, __LINE__, __METHOD__,10);
+
+				if ( $T4 > $tmp_S ) {
+					$S = $tmp_S;
+				} else {
+					$S = $T4;
+				}
+				unset($tmp_S);
+			}
+		} elseif ( $this->getDate() >= strtotime('01-Jan-2010') ) {
 			//Calculate S after Jan 1st 2009.
 			if ( $A <= 17354 ) {
 				Debug::text('S: Annual Income less than 17354', __FILE__, __LINE__, __METHOD__,10);
