@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,13 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: Data.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
- */
-
-/**
- * @package PayrollDeduction
+ * $Revision: 4073 $
+ * $Id: Data.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -55,8 +51,23 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 	/*
 		Claim Code Basic Amounts
 	*/
-
 	var $basic_claim_code_options = array(
+							1293868800 => array( //01-Jan-2011
+										'CA' => 10527, //Federal
+										'BC' => 11088,
+										'AB' => 16977,
+										'SK' => 13535,
+										'MB' => 8134,
+										'QC' => 0,
+										'ON' => 9104,
+										'NL' => 7989,
+										'NB' => 8953,
+										'NS' => 8231,
+										'PE' => 7708,
+										'NT' => 12919,
+										'YT' => 10527,
+										'NU' => 11878,
+										),
 							1262332800 => array( //01-Jan-2010
 										'CA' => 10382, //Federal
 										'BC' => 11000,
@@ -191,6 +202,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		CPP settings
 	*/
 	var $cpp_options = array(
+							1293868800 => array( //2011
+										'maximum_pensionable_earnings' => 48300,
+										'basic_exemption' => 3500,
+										'employee_rate' => 0.0495,
+										'employee_maximum_contribution' => 2163.15
+										),
 							1262332800 => array( //2010
 										'maximum_pensionable_earnings' => 47200,
 										'basic_exemption' => 3500,
@@ -239,6 +256,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		EI settings
 	*/
 	var $ei_options = array(
+							1293868800 => array( //2011
+										'maximum_insurable_earnings' => 44200,
+										'employee_rate' => 0.0178,
+										'employee_maximum_contribution' => 786.76,
+										'employer_rate' => 1.4
+										),
 							1262332800 => array( //2010
 										'maximum_insurable_earnings' => 43200,
 										'employee_rate' => 0.0173,
