@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: US.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4073 $
+ * $Id: US.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -47,6 +47,10 @@ class PayrollDeduction_US extends PayrollDeduction_US_Data {
 	// Federal
 	//
 	function setFederalFilingStatus($value) {
+		//Check for invalid value, default to single if found.
+		if ( $value > 20 ) {
+			$value = 10; //Single
+		}
 		$this->data['federal_filing_status'] = $value;
 
 		return TRUE;
@@ -412,6 +416,33 @@ class PayrollDeduction_US extends PayrollDeduction_US_Data {
 	//
 	// Social Security
 	//
+	function getAnnualEmployeeSocialSecurity() {
+		if ( $this->getSocialSecurityExempt() == TRUE ) {
+			return 0;
+		}
+
+		$annual_income = $this->getAnnualTaxableIncome();
+		$rate = bcdiv( $this->getSocialSecurityRate(), 100 );
+		$maximum_contribution = $this->getSocialSecurityMaximumContribution();
+
+		Debug::text('Rate: '. $rate .' YTD Contribution: '. $ytd_contribution, __FILE__, __LINE__, __METHOD__,10);
+
+		$amount = bcmul( $annual_income, $rate );
+		$max_amount = $maximum_contribution;
+
+		if ( $amount > $max_amount ) {
+			$retval = $max_amount;
+		} else {
+			$retval = $amount;
+		}
+
+		if ( $retval < 0 ) {
+			$retval = 0;
+		}
+
+		return $retval;
+	}
+
 	function getEmployeeSocialSecurity() {
 		if ( $this->getSocialSecurityExempt() == TRUE ) {
 			return 0;
@@ -433,16 +464,24 @@ class PayrollDeduction_US extends PayrollDeduction_US_Data {
 			$retval = $amount;
 		}
 
+		if ( $retval < 0 ) {
+			$retval = 0;
+		}
+
 		return $retval;
 	}
 
-	function getEmployerSocialSecurity() {
-		return $this->getEmployeeSocialSecurity();
-	}
+	//Rates differ in 2011.
+	//function getEmployerSocialSecurity() {
+	//	return $this->getEmployeeSocialSecurity();
+	//}
 
 	//
 	// Medicare
 	//
+	function getAnnualEmployeeMedicare() {
+		return bcmul( $this->getEmployeeMedicare(), $this->getAnnualPayPeriods() );
+	}
 	function getEmployeeMedicare() {
 		if ( $this->getMedicareExempt() == TRUE ) {
 			return 0;
@@ -507,41 +546,45 @@ class PayrollDeduction_US extends PayrollDeduction_US_Data {
 	}
 
 	//
-	// Earning Income Tax Credit (EIC, EITC)
+	// Earning Income Tax Credit (EIC, EITC). - Repealed as of 31-Dec-2010.
 	//
 	function getEIC() {
-		$eic_options = $this->getEICRateArray( $this->getAnnualTaxableIncome(), $this->getEICFilingStatus() );
-		//Debug::Arr($eic_options, ' EIC Options: ', __FILE__, __LINE__, __METHOD__,10);
+		if ( $this->getDate() <= strtotime('31-Dec-2010') ) { //Repealed as of 31-Dec-2010.
+			$eic_options = $this->getEICRateArray( $this->getAnnualTaxableIncome(), $this->getEICFilingStatus() );
+			//Debug::Arr($eic_options, ' EIC Options: ', __FILE__, __LINE__, __METHOD__,10);
 
-		if ( is_array($eic_options) AND isset($eic_options['calculation_type']) ) {
-			$retval = 0;
-			switch	($eic_options['calculation_type']) {
-				case 10: //Percent
-					if ( isset($eic_options['percent']) ) {
-						$retval = bcmul( bcdiv($eic_options['percent'],100), $this->getAnnualTaxableIncome() );
-					}
-					break;
-				case 20: //Amount
-					if ( isset($eic_options['amount']) ) {
-						$retval = $eic_options['amount'];
-					}
-					break;
-				case 30: //Amount less percent
-					if ( isset($eic_options['percent']) AND isset($eic_options['amount']) AND isset($eic_options['income']) ) {
-						$retval = bcsub( $eic_options['amount'], bcmul( bcdiv($eic_options['percent'],100), bcsub( $this->getAnnualTaxableIncome(), $eic_options['income'] ) ) );
-					}
-					break;
-			}
-			Debug::Text(' Type: '. $eic_options['calculation_type'].' Annual Amount: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+			if ( is_array($eic_options) AND isset($eic_options['calculation_type']) ) {
+				$retval = 0;
+				switch	($eic_options['calculation_type']) {
+					case 10: //Percent
+						if ( isset($eic_options['percent']) ) {
+							$retval = bcmul( bcdiv($eic_options['percent'],100), $this->getAnnualTaxableIncome() );
+						}
+						break;
+					case 20: //Amount
+						if ( isset($eic_options['amount']) ) {
+							$retval = $eic_options['amount'];
+						}
+						break;
+					case 30: //Amount less percent
+						if ( isset($eic_options['percent']) AND isset($eic_options['amount']) AND isset($eic_options['income']) ) {
+							$retval = bcsub( $eic_options['amount'], bcmul( bcdiv($eic_options['percent'],100), bcsub( $this->getAnnualTaxableIncome(), $eic_options['income'] ) ) );
+						}
+						break;
+				}
+				Debug::Text(' Type: '. $eic_options['calculation_type'].' Annual Amount: '. $retval, __FILE__, __LINE__, __METHOD__,10);
 
-			if ( isset($retval) AND $retval > 0 ) {
-				$retval = bcdiv($retval, $this->getAnnualPayPeriods() );
+				if ( isset($retval) AND $retval > 0 ) {
+					$retval = bcdiv($retval, $this->getAnnualPayPeriods() );
 
-				Debug::Text('EIC Amount: '. $retval, __FILE__, __LINE__, __METHOD__,10);
-				return $retval*-1;
-			} else {
-				Debug::Text('Calculation didnt return valid amount...', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text('EIC Amount: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+					return $retval*-1;
+				} else {
+					Debug::Text('Calculation didnt return valid amount...', __FILE__, __LINE__, __METHOD__,10);
+				}
 			}
+		} else {
+			Debug::Text('EIC has been repealed for dates after 31-Dec-2010: '. $this->getDate() , __FILE__, __LINE__, __METHOD__,10);
 		}
 
 		return 0;
