@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: CA.class.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 4073 $
+ * $Id: CA.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -51,6 +51,21 @@ class PayrollDeduction_US_CA extends PayrollDeduction_US {
 */
 
 	var $state_options = array(
+								1293868800 => array( //01-Jan-11
+													'standard_deduction' => array(
+																				//First entry is 0,1 allowance, second is for 2 or more.
+																				'10' => array(3670.00, 3670.00),
+																				'20' => array(3670.00, 3670.00),
+																				'30' => array(3670.00, 7340.00),
+																				'40' => array(7340.00, 7340.00),
+																				),
+													'allowance' => array(
+																				'10' => 108.90,
+																				'20' => 108.90,
+																				'30' => 108.90,
+																				'40' => 108.90,
+																				),
+													),
 								1262332800 => array( //01-Jan-10
 													'standard_deduction' => array(
 																				//First entry is 0,1 allowance, second is for 2 or more.
