@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2568 $
- * $Id: CO.class.php 2568 2009-05-28 21:25:16Z ipso $
- * $Date: 2009-05-28 14:25:16 -0700 (Thu, 28 May 2009) $
+ * $Revision: 4073 $
+ * $Id: CO.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -45,6 +45,9 @@
 class PayrollDeduction_US_CO extends PayrollDeduction_US {
 
 	var $state_options = array(
+								1293868800 => array( //2011
+													'allowance' => 3700,
+													),
 								1230796800 => array( //2009
 													'allowance' => 3650,
 													),
