@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,57 +34,58 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3665 $
- * $Id: Data.class.php 3665 2010-06-18 18:01:03Z ipso $
- * $Date: 2010-06-18 11:01:03 -0700 (Fri, 18 Jun 2010) $
+ * $Revision: 4073 $
+ * $Id: Data.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /*
-Site with good Tax news on updates: http://www.sageabra.com/hr-news/
- - http://www.sageabra.com/hr-news/payroll_news.aspx?item={fe86cf98-8789-3d13-aabc-0dff4bf8cc13}
+* Other tax calculators:
+	http://www.yourmoneypage.com/withhold/fedwh1.php
 
-C:11-Jun-10-NOCHANGE-	Federal          		- Google: Notice 1036 http://www.irs.gov/pub/irs-pdf/n1036.pdf
-C:11-Jun-10-NOCHANGE-	'AL' => 'Alabama' 		- http://www.ador.state.al.us/Withholding/index.html *Withholding Tax Tables and Instructions
-C:11-Jun-10				'AZ' => 'Arizona',		- http://www.azdor.gov/Forms/Withholding.aspx *Employer chooses percent of federal tax.
-C:11-Jun-10-NOCHANGE-	'AR' => 'Arkansas'		- http://www.dfa.arkansas.gov/offices/incomeTax/withholding/Pages/withholdingForms.aspx *Witholding Tax Formula
-C:11-Jun-10-NOCHANGE-	'CA' => 'California' 	- http://www.edd.ca.gov/Payroll_Taxes/Rates_and_Withholding.htm *PIT Withholding schedules
-C:11-Jun-10-NOCHANGE-	'CO' => 'Colorado',		- http://www.colorado.gov/cs/Satellite?c=Page&cid=1214992372268&pagename=Revenue%2FREVXLayout *Form: DR 1098
-C:11-Jun-10-NOCHANGE-	'CT' => 'Connecticut'	- http://www.ct.gov/drs/cwp/view.asp?a=1509&q=306182&drsPNavCtr=|42845|#42889  *Withholding Forms and Withholding Tables
-C:11-Jun-10-NOCHANGE-	'DE' => 'Delaware',		- http://revenue.delaware.gov/services/WITBk.shtml *http://revenue.delaware.gov/services/wit_folder/section17.shtml
-C:11-Jun-10-NOCHANGE-	'DC' => 'D.C.', 		- http://otr.cfo.dc.gov/otr/cwp/view.asp?a=1330&Q=593946
-C:11-Jun-10-NOCHANGE-	'GA' => 'Georgia',		- https://etax.dor.ga.gov/inctax/withholding/whgeninfo.aspx *Employers Tax Guide
-C:11-Jun-10-NOCHANGE-	'HI' => 'Hawaii',		- http://www.state.hi.us/tax/a1_b1_5whhold.htm * Employers Tax Guide (Booklet A)
-C:11-Jun-10-NOCHANGE-	'ID' => 'Idaho',		- http://tax.idaho.gov/s-results-pub.cfm?doc=EPB00006&pkey=bus
-C:11-Jun-10-NOCHANGE-	'IL' => 'Illinois',		- http://www.revenue.state.il.us/Businesses/TaxInformation/Payroll/index.htm *Booklet IL-700-T
-C:11-Jun-10-NOCHANGE-	'IN' => 'Indiana',		- http://www.in.gov/dor/4006.htm#withholding *Departmental Notice #1 DN01
-C:11-Jun-10-NOCHANGE-	'IA' => 'Iowa',			- http://www.state.ia.us/tax/forms/withhold.html
-C:11-Jun-10-NOCHANGE-	'KS' => 'Kansas',		- http://www.ksrevenue.org/forms-btwh.htm
-C:11-Jun-10-NOCHANGE-	'KY' => 'Kentucky', 	- http://revenue.ky.gov/business/whtax.htm
-C:11-Jun-10-NOCHANGE-	'LA' => 'Louisiana',	- http://www.revenue.louisiana.gov/sections/publications/tm.asp
-C:11-Jun-10-NOCHANGE-	'ME' => 'Maine',		- http://www.state.me.us/revenue/forms/with/2010.htm -- Check each year on the right of the page.
-C:11-Jun-10-NOCHANGE-	'MD' => 'Maryland',		- http://business.marylandtaxes.com/taxinfo/withholding/default.asp - Use non-residents tables, minus 1.25%, manually calculate each bracket. FIX county taxes...
-C:11-Jun-10-NOCHANGE-	'MA' => 'Massachusetts' - http://www.mass.gov/?pageID=dorterminal&L=3&L0=Home&L1=Businesses&L2=Current+Tax+Year+Information&sid=Ador&b=terminalcontent&f=dor_business_buspubs&csid=Ador
-C:11-Jun-10-NOCHANGE-	'MI' => 'Michigan',		- http://www.michigan.gov/documents/treasury/446_2007_176836_7.pdf *Michigan Income Tax Withholding Guide
-C:11-Jun-10-NOCHANGE-	'MN' => 'Minnesota',	- http://www.taxes.state.mn.us/taxes/withholding/index.shtml *2010 Computer Formula
-C:11-Jun-10-NOCHANGE-	'MS' => 'Mississippi',	- http://www.mstc.state.ms.us/taxareas/withhold/main.html *Pub 89-350
-C:11-Jun-10-NOCHANGE-	'MO' => 'Missouri',		- http://www.dor.mo.gov/tax/business/withhold/ *Employers Tax Guide
-C:11-Jun-10-NOCHANGE-	'MT' => 'Montana',		- http://mt.gov/revenue/formsandresources/forms.asp *Montana Witholding Tax Guide
-C:11-Jun-10-NOCHANGE-	'NE' => 'Nebraska',		- http://www.revenue.state.ne.us/tax/current/current.htm#inc *Withholding Forms
-C:11-Jun-10-NOCHANGE-	'NM' => 'New Mexico', 	- http://www.tax.state.nm.us/pubs/withholding_taxrates.htm *FYI-104
-C:11-Jun-10-NOCHANGE-	'NJ' => 'New Jersey',	- http://www.state.nj.us/treasury/taxation/freqqite.shtml *Withholding Rate Tables
-C:11-Jun-10-NOCHANGE-	'NY' => 'New York',		- http://www.tax.state.ny.us/forms/withholding_cur_forms.htm *NYS-50-T.1
-C:11-Jun-10-NOCHANGE-	'NC' => 'North Carolina'- http://www.dornc.com/taxes/wh_tax/index.html *Income Tax Withholding Tables & Instructions for Employers, NC30
-C:11-Jun-10-NOCHANGE-	'ND' => 'North Dakota', - http://www.nd.gov/tax/indwithhold/pubs/guide/index.html *Withholding Rates and Instructions for Wages Paid in 2010
-C:11-Jun-10-NOCHANGE-	'OH' => 'Ohio',			- http://tax.ohio.gov/divisions/employer_withholding/index.stm *Income Tax Withholding Instructions
-C:11-Jun-10-NOCHANGE-	'OK' => 'Oklahoma',		- http://www.tax.ok.gov/btforms.html *OW-2, Oklahoma Income Tax Withholding Tables
-C:11-Jun-10-			'OR' => 'Oregon',		- http://www.oregon.gov/DOR/BUS/withholding.shtml
-C:11-Jun-10-NOCHANGE-	'PA' => 'Pennsylvania', - http://www.revenue.state.pa.us/portal/server.pt/community/employer_withholding/14495 *Rev 415 - Employer Withholding Information
-C:11-Jun-10-NOCHANGE-	'RI' => 'Rhode Island', - http://www.tax.state.ri.us/misc/software_developers.php *Withholding Tables
-C:11-Jun-10-NOCHANGE-	'SC' => 'South Carolina'- http://www.sctax.org/Publications/default.htm *Withholding, 09Withholding.pdf
-C:11-Jun-10-NOCHANGE-	'UT' => 'Utah',			- http://www.tax.utah.gov/forms/ *PUB 14
-C:11-Jun-10-NOCHANGE-	'VT' => 'Vermont',		- http://www.state.vt.us/tax/businesswithholding.shtml *Vermont Percentage Method Withholding Tables
-C:11-Jun-10-NOCHANGE- 	'VA' => 'Virginia',		- http://www.tax.virginia.gov/site.cfm?alias=WithholdingTax, http://www.tax.virginia.gov/site.cfm?alias=busforms&selOtherForm=10&CFID=6568377&CFTOKEN=b5c365f14d473a0e-A35BD51E-0E04-BFC5-09FA7EDF84E52AA5#displayedAfterSubmit *Employer Withholding Instructions
-C:11-Jun-10-NOCHANGE-	'WI' => 'Wisconsin',	- http://www.revenue.wi.gov/forms/with/index.html *Pub W-166, Method "B" calculation
+C:21-Dec-10-			Federal          		- Google: Notice 1036 http://www.irs.gov/pub/irs-pdf/n1036.pdf
+C:21-Dec-10-NOCHANGE-	'AL' => 'Alabama' 		- http://www.ador.state.al.us/Withholding/index.html *Withholding Tax Tables and Instructions
+C:21-Dec-10				'AZ' => 'Arizona',		- http://www.azdor.gov/Forms/Withholding.aspx *Form A4: Employees choose a straight percent to pick.
+C:21-Dec-10-NOCHANGE-	'AR' => 'Arkansas'		- http://www.dfa.arkansas.gov/offices/incomeTax/withholding/Pages/withholdingForms.aspx *Witholding Tax Formula
+C:21-Dec-10				'CA' => 'California' 	- http://www.edd.ca.gov/Payroll_Taxes/Rates_and_Withholding.htm *PIT Withholding schedules
+C:21-Dec-10				'CO' => 'Colorado',		- http://www.colorado.gov/cs/Satellite?c=Page&cid=1214992372268&pagename=Revenue%2FREVXLayout *Form: DR 1098
+C:21-Dec-10-NOCHANGE-	'CT' => 'Connecticut'	- http://www.ct.gov/drs/cwp/view.asp?a=1509&q=306182&drsPNavCtr=|42845|#42889  *Withholding Forms and Withholding Tables
+C:21-Dec-10-NOCHANGE-	'DE' => 'Delaware',		- http://revenue.delaware.gov/services/WITBk.shtml *http://revenue.delaware.gov/services/wit_folder/section17.shtml
+C:21-Dec-10				'DC' => 'D.C.', 		- http://otr.cfo.dc.gov/otr/cwp/view.asp?a=1330&Q=593946 *Form: FR-230
+C:21-Dec-10-NOCHANGE-	'GA' => 'Georgia',		- https://etax.dor.ga.gov/inctax/withholding/whgeninfo.aspx *Employers Tax Guide
+C:21-Dec-10-			'HI' => 'Hawaii',		- http://www.state.hi.us/tax/a1_b1_5whhold.htm *Employers Tax Guide (Booklet A)
+C:21-Dec-10-NOCHANGE-	'ID' => 'Idaho',		- http://tax.idaho.gov/s-results-pub.cfm?doc=EPB00006&pkey=bus
+C:21-Dec-10-NOCHANGE-	'IL' => 'Illinois',		- http://www.revenue.state.il.us/Businesses/TaxInformation/Payroll/index.htm *Booklet IL-700-T
+C:21-Dec-10-NOCHANGE-	'IN' => 'Indiana',		- http://www.in.gov/dor/4006.htm#withholding *Departmental Notice #1 DN01
+C:21-Dec-10-NOCHANGE-	'IA' => 'Iowa',			- http://www.state.ia.us/tax/forms/withhold.html
+C:21-Dec-10-NOCHANGE-	'KS' => 'Kansas',		- http://www.ksrevenue.org/forms-btwh.htm *Form: KW-100
+C:21-Dec-10-NOCHANGE-	'KY' => 'Kentucky', 	- http://revenue.ky.gov/business/whtax.htm
+C:21-Dec-10-NOCHANGE-	'LA' => 'Louisiana',	- http://www.revenue.louisiana.gov/sections/publications/tm.asp
+C:21-Dec-10				'ME' => 'Maine',		- http://www.state.me.us/revenue/forms/with/2010.htm -- Check each year on the right of the page.
+C:21-Dec-10-NOCHANGE-	'MD' => 'Maryland',		- http://business.marylandtaxes.com/taxinfo/withholding/default.asp - Use non-residents tables, minus 1.25%, manually calculate each bracket. FIX county taxes...
+C:21-Dec-10-NOCHANGE-	'MA' => 'Massachusetts' - http://www.mass.gov/?pageID=dorterminal&L=3&L0=Home&L1=Businesses&L2=Current+Tax+Year+Information&sid=Ador&b=terminalcontent&f=dor_business_buspubs&csid=Ador
+C:21-Dec-10-NOCHANGE-	'MI' => 'Michigan',		- http://www.michigan.gov/documents/treasury/446_2007_176836_7.pdf *Michigan Income Tax Withholding Guide
+C:21-Dec-10				'MN' => 'Minnesota',	- http://taxes.state.mn.us/withholding/pages/index.aspx *2011 Computer Formula
+C:21-Dec-10-NOCHANGE-	'MS' => 'Mississippi',	- http://www.dor.ms.gov/taxareas/withhold/main.html *Pub 89-700
+C:21-Dec-10-NOCHANGE-	'MO' => 'Missouri',		- http://www.dor.mo.gov/tax/business/withhold/ *Employers Tax Guide
+C:21-Dec-10-NOCHANGE-	'MT' => 'Montana',		- http://revenue.mt.gov/forbusinesses/Wage_Withholding_Tax/default.mcpx *Montana Witholding Tax Guide
+C:21-Dec-10				'NE' => 'Nebraska',		- http://www.revenue.ne.gov/tax/current/ind_inc_tax.html *2010 Nebraska Tax Rate Schedule
+C:22-Dec-10-NOCHANGE-	'NM' => 'New Mexico', 	- http://www.tax.newmexico.gov/Businesses/Wage-Withholding-Tax/Pages/Home.aspx *FYI-104
+C:22-Dec-10-NOCHANGE-	'NJ' => 'New Jersey',	- http://www.state.nj.us/treasury/taxation/freqqite.shtml *Withholding Rate Tables
+C:22-Dec-10				'NY' => 'New York',		- http://www.tax.state.ny.us/forms/withholding_cur_forms.htm *WATCH NYS=New York State, NYC=New York City. NYS-50-T.1 or .2
+C:22-Dec-10-NOCHANGE-	'NC' => 'North Carolina'- http://www.dornc.com/taxes/wh_tax/index.html *Income Tax Withholding Tables & Instructions for Employers, NC30
+C:22-Dec-10				'ND' => 'North Dakota', - http://www.nd.gov/tax/indwithhold/pubs/guide/index.html *Withholding Rates and Instructions for Wages Paid in 2010
+C:22-Dec-10-NOCHANGE-	'OH' => 'Ohio',			- http://tax.ohio.gov/divisions/employer_withholding/index.stm *Withholding Tables/Income Tax Withholding Instructions
+C:22-Dec-10				'OK' => 'Oklahoma',		- http://www.tax.ok.gov/btforms.html *OW-2, Oklahoma Income Tax Withholding Tables
+C:22-Dec-10-NOCHANGE-	'OR' => 'Oregon',		- http://www.oregon.gov/DOR/BUS/withholding.shtml
+C:22-Dec-10-NOCHANGE-	'PA' => 'Pennsylvania', - http://www.revenue.state.pa.us/portal/server.pt/community/employer_withholding/14495 *Rev 415 - Employer Withholding Information
+C:22-Dec-10				'RI' => 'Rhode Island', - http://www.tax.state.ri.us/misc/software_developers.php *Percentage Method Withholding Tables
+C:22-Dec-10-NOCHANGE-	'SC' => 'South Carolina'- http://www.sctax.org/Publications/default.htm *Withholding, 09Withholding.pdf
+C:22-Dec-10				'UT' => 'Utah',			- http://www.tax.utah.gov/forms/ *PUB 14
+C:22-Dec-10-NOCHANGE-	'VT' => 'Vermont',		- http://www.state.vt.us/tax/businesswithholding.shtml *Vermont Percentage Method Withholding Tables
+C:22-Dec-10-NOCHANGE- 	'VA' => 'Virginia',		- http://www.tax.virginia.gov/site.cfm?alias=WithholdingTax, http://www.tax.virginia.gov/site.cfm?alias=busforms&selOtherForm=10&CFID=6568377&CFTOKEN=b5c365f14d473a0e-A35BD51E-0E04-BFC5-09FA7EDF84E52AA5#displayedAfterSubmit *Employer Withholding Instructions
+C:22-Dec-10-NOCHANGE-	'WI' => 'Wisconsin',	- http://www.revenue.wi.gov/forms/with/index.html *Pub W-166, Method "B" calculation
+C:22-Dec-10-NOCHANGE-	'WV' => 'West Virginia',- http://www.wva.state.wv.us/wvtax/withholdingTaxForms.aspx *Pub W-166, Method "B" calculation
 
 	'AK' => 'Alaska',		- NO STATE TAXES
 	'FL' => 'Florida',		- NO STATE TAXES
@@ -94,7 +95,6 @@ C:11-Jun-10-NOCHANGE-	'WI' => 'Wisconsin',	- http://www.revenue.wi.gov/forms/wit
 	'TN' => 'Tennessee',	- NO STATE TAXES
 	'TX' => 'Texas',		- NO STATE TAXES
 	'WA' => 'Washington',	- NO STATE TAXES
-	'WV' => 'West Virginia'	- NO STATE TAXES
 	'WY' => 'Wyoming'		- NO STATE TAXES
 
 */
@@ -109,6 +109,7 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 	var $country_primary_currency = 'USD';
 
 	var $federal_allowance = array(
+									1293868800 => 3700.00, //01-Jan-11
 									//01-Jan-10 - No Change
 									1230796800 => 3650.00, //01-Jan-09
 									1199174400 => 3500.00, //01-Jan-08
@@ -117,7 +118,12 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 								);
 
 	//http://www.ssa.gov/pressoffice/factsheets/colafacts2007.htm
-	var $social_security_options = array(
+	var $social_security_options = array( 	//Employee Social Security only.
+									1293868800 => array( //2011 - Employer is still 6.2%
+														'maximum_earnings' => 106800,
+														'rate' => 4.2,
+														'maximum_contribution' => 4485.60
+													),
 									//2010a - No Change.
 									1230796800 => array( //2009a
 														'maximum_earnings' => 106800,
@@ -360,7 +366,7 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 				$prev_constant = $arr['constant'];
 			}
 
-			if ( isset($this->income_tax_rates) ) {
+			if ( isset($this->income_tax_rates) AND is_array($this->income_tax_rates) ) {
 				foreach( $this->income_tax_rates as $type => $brackets ) {
 					$i=0;
 					$total_brackets = count($brackets)-1;
