@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2299 $
- * $Id: HI.class.php 2299 2008-12-21 21:26:53Z ipso $
- * $Date: 2008-12-21 13:26:53 -0800 (Sun, 21 Dec 2008) $
+ * $Revision: 4073 $
+ * $Id: HI.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -45,6 +45,9 @@
 class PayrollDeduction_US_HI extends PayrollDeduction_US {
 
 	var $state_options = array(
+								1293868800 => array( //01-Jan-2011
+													'allowance' => 1144
+													),
 								1136102400 => array(
 													'allowance' => 1040
 													)
