@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2299 $
- * $Id: NE.class.php 2299 2008-12-21 21:26:53Z ipso $
- * $Date: 2008-12-21 13:26:53 -0800 (Sun, 21 Dec 2008) $
+ * $Revision: 4073 $
+ * $Id: NE.class.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 
 /**
@@ -45,14 +45,17 @@
 class PayrollDeduction_US_NE extends PayrollDeduction_US {
 
 	var $state_options = array(
-								1199174400 => array(
-													'allowance' => 1700
+								1262332800 => array( //01-Jan-2010: Formula changed.
+													'allowance' => 118
 													),
-								1167638400 => array(
-													'allowance' => 1530
+								1199174400 => array( //01-Jan-2008
+													'allowance' => 113
 													),
-								1136102400 => array(
-													'allowance' => 1490
+								1167638400 => array( //01-Jan-2007
+													'allowance' => 111
+													),
+								1136102400 => array( //01-Jan-2006
+													'allowance' => 103
 													)
 								);
 
@@ -62,9 +65,10 @@ class PayrollDeduction_US_NE extends PayrollDeduction_US {
 
 	function getStateAnnualTaxableIncome() {
 		$annual_income = $this->getAnnualTaxableIncome();
-		$state_allowance = $this->getStateAllowanceAmount();
+		//$state_allowance = $this->getStateAllowanceAmount();
 
-		$income = bcsub( $annual_income, $state_allowance );
+		//$income = bcsub( $annual_income, $state_allowance );
+		$income = $annual_income;
 
 		Debug::text('State Annual Taxable Income: '. $income, __FILE__, __LINE__, __METHOD__,10);
 
@@ -75,7 +79,6 @@ class PayrollDeduction_US_NE extends PayrollDeduction_US {
 		$retarr = $this->getDataFromRateArray($this->getDate(), $this->state_options);
 		if ( $retarr == FALSE ) {
 			return FALSE;
-
 		}
 
 		$allowance_arr = $retarr['allowance'];
@@ -98,7 +101,9 @@ class PayrollDeduction_US_NE extends PayrollDeduction_US {
 			$state_rate_income = $this->getData()->getStateRatePreviousIncome($annual_income);
 
 			$retval = bcadd( bcmul( bcsub( $annual_income, $state_rate_income ), $rate ), $state_constant );
-			//$retval = bcadd( bcmul( $annual_income, $rate ), $state_constant );
+			Debug::text('aState Annual Tax Payable: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+
+			$retval = bcsub( $retval, $this->getStateAllowanceAmount() );
 		}
 
 		if ( $retval < 0 ) {
