@@ -7,9 +7,14 @@ $global_class_map = array(
 	'AccrualListFactory' => 'accrual/AccrualListFactory.class.php',
 	'DiscoveryService' => 'api/amfphp/DiscoveryService.class.php',
 	'TimeTrexClientAPI' => 'api/client/TimeTrexClientAPI.class.php',
+    'APIEnvironment' => 'api/core/APIEnvironment.class.php',
+    'APILog' => 'api/core/APILog.class.php',
+    'APILogDetail' => 'api/core/APILogDetail.class.php',
 	'APIBranch' => 'api/company/APIBranch.class.php',
 	'APICompany' => 'api/company/APICompany.class.php',
 	'APIWageGroup' => 'api/company/APIWageGroup.class.php',
+    'APICompanyDeduction' => 'api/company/APICompanyDeduction.class.php',
+    'APIUserDeduction' => 'api/users/APIUserDeduction.class.php',
 	'APICurrency' => 'api/core/APICurrency.class.php',
 	'APIFactory' => 'api/core/APIFactory.class.php',
 	'APIPermission' => 'api/core/APIPermission.class.php',
@@ -34,6 +39,7 @@ $global_class_map = array(
 	'APIExceptionPolicy' => 'api/policy/APIExceptionPolicy.class.php',
 	'APIExceptionPolicyControl' => 'api/policy/APIExceptionPolicyControl.class.php',
 	'APIHolidayPolicy' => 'api/policy/APIHolidayPolicy.class.php',
+    'APIHoliday' => 'api/holiday/APIHoliday.class.php',
 	'APIMealPolicy' => 'api/policy/APIMealPolicy.class.php',
 	'APIOverTimePolicy' => 'api/policy/APIOverTimePolicy.class.php',
 	'APIPolicyGroup' => 'api/policy/APIPolicyGroup.class.php',
@@ -42,15 +48,18 @@ $global_class_map = array(
 	'APISchedulePolicy' => 'api/policy/APISchedulePolicy.class.php',
 	'APIPunch' => 'api/punch/APIPunch.class.php',
     'APIPunchControl' => 'api/punch/APIPunchControl.class.php',
+    'APITimeSheet' => 'api/core/APITimeSheet.class.php',
 	'APISchedule' => 'api/schedule/APISchedule.class.php',
     'APIRecurringScheduleTemplateControl' => 'api/schedule/APIRecurringScheduleTemplateControl.class.php',
     'APIRecurringScheduleTemplate' => 'api/schedule/APIRecurringScheduleTemplate.class.php',
     'APIRecurringScheduleControl' => 'api/schedule/APIRecurringScheduleControl.class.php',
 	'APIAuthentication' => 'api/unauthenticated/APIAuthentication.class.php',
 	'APIUser' => 'api/users/APIUser.class.php',
+	'APIUserReportData' => 'api/users/APIUserReportData.class.php',
 	'APIUserGenericData' => 'api/users/APIUserGenericData.class.php',
 	'APIUserGroup' => 'api/users/APIUserGroup.class.php',
 	'APIUserPreference' => 'api/users/APIUserPreference.class.php',
+    'APIUserDefault' => 'api/users/APIUserDefault.class.php',
 	'APIUserTitle' => 'api/users/APIUserTitle.class.php',
 	'APIUserWage' => 'api/users/APIUserWage.class.php',
     'APIJob' => 'api/job/APIJob.class.php',
@@ -64,10 +73,31 @@ $global_class_map = array(
     'APIPayStub' => 'api/pay_stub/APIPayStub.class.php',
     'APIMessageControl' => 'api/message/APIMessageControl.class.php',
     'APIClientGroup' => 'api/client/APIClientGroup.class.php',
+    'APIProductGroup' => 'api/product/APIProductGroup.class.php',
     'APIDocumentGroup' => 'api/document/APIDocumentGroup.class.php',
     'APIClient' => 'api/client/APIClient.class.php',
+    'APIClientContact' => 'api/client/APIClientContact.class.php',
+    'APIClientPayment' => 'api/client/APIClientPayment.class.php',
+    'APIRequest' => 'api/request/APIRequest.class.php',
+    'APIDocument' => 'api/document/APIDocument.class.php',
+    'APIDocumentRevision' => 'api/document/APIDocumentRevision.class.php',
+    'APIDocumentAttachment' => 'api/document/APIDocumentAttachment.class.php',
+    'APIReport' => 'api/report/APIReport.class.php',
+    'APIReportSchedule' => 'api/report/APIReportSchedule.class.php',
+    'APIUserSummaryReport' => 'api/report/APIUserSummaryReport.class.php',
+    'APITimesheetSummaryReport' => 'api/report/APITimesheetSummaryReport.class.php',
+    'APITimesheetDetailReport' => 'api/report/APITimesheetDetailReport.class.php',
+    'APIInvoiceTransactionSummaryReport' => 'api/report/APIInvoiceTransactionSummaryReport.class.php',
+    'APIForm941Report' => 'api/report/APIForm941Report.class.php',
     'APITimeClockUnAuthenticated' => 'api/time_clock/APITimeClockUnAuthenticated.class.php',
     'APITimeClockUnAuthenticated_TTA8' => 'api/time_clock/APITimeClockUnAuthenticated_TTA8.class.php',
+    'APITimeClockUnAuthenticated_TTUS100' => 'api/time_clock/APITimeClockUnAuthenticated_TTUS100.class.php',
+    'APIInvoiceDistrict' => 'api/invoice/APIInvoiceDistrict.class.php',
+    'APIAreaPolicy' => 'api/invoice_policy/APIAreaPolicy.class.php',
+    'APITaxPolicy' => 'api/invoice_policy/APITaxPolicy.class.php',
+    'APIShippingPolicy' => 'api/invoice_policy/APIShippingPolicy.class.php',
+    'APIProduct' => 'api/product/APIProduct.class.php',
+    'APIProductPrice' => 'api/product/APIProductPrice.class.php',
 	'ClientAuthentication' => 'client/ClientAuthentication.class.php',
 	'ClientBalanceFactory' => 'client/ClientBalanceFactory.class.php',
 	'ClientBalanceListFactory' => 'client/ClientBalanceListFactory.class.php',
@@ -116,6 +146,8 @@ $global_class_map = array(
 	'LockFile' => 'core/LockFile.class.php',
 	'LogFactory' => 'core/LogFactory.class.php',
 	'LogListFactory' => 'core/LogListFactory.class.php',
+    'LogDetailFactory' => 'core/LogDetailFactory.class.php',
+    'LogDetailListFactory' => 'core/LogDetailListFactory.class.php',
 	'LogRotate' => 'core/LogRotate.class.php',
 	'Misc' => 'core/Misc.class.php',
 	'Option' => 'core/Option.class.php',
@@ -136,6 +168,16 @@ $global_class_map = array(
 	'Serializer' => 'core/Serializer.class.php',
 	'SharedMemory' => 'core/SharedMemory.class.php',
 	'Sort' => 'core/Sort.class.php',
+    'Group' => 'core/Group.class.php',
+    'Report' => 'report/Report.class.php',
+    'ReportChart' => 'report/ReportChart.class.php',
+    'ReportScheduleFactory' => 'report/ReportScheduleFactory.class.php',
+    'ReportScheduleListFactory' => 'report/ReportScheduleListFactory.class.php',
+    'UserSummaryReport' => 'report/UserSummaryReport.class.php',
+    'TimesheetSummaryReport' => 'report/TimesheetSummaryReport.class.php',
+    'TimesheetDetailReport' => 'report/TimesheetDetailReport.class.php',
+    'InvoiceTransactionSummaryReport' => 'report/InvoiceTransactionSummaryReport.class.php',
+    'Form941Report' => 'report/Form941Report.class.php',
 	'StationBranchFactory' => 'core/StationBranchFactory.class.php',
 	'StationBranchListFactory' => 'core/StationBranchListFactory.class.php',
 	'StationDepartmentFactory' => 'core/StationDepartmentFactory.class.php',
@@ -168,6 +210,7 @@ $global_class_map = array(
 	'UserDateTotalListFactory' => 'core/UserDateTotalListFactory.class.php',
 	'Validator' => 'core/Validator.class.php',
 	'Wage' => 'core/Wage.class.php',
+    'Cron' => 'cron/Cron.class.php',
 	'CronJobFactory' => 'cron/CronJobFactory.class.php',
 	'CronJobListFactory' => 'cron/CronJobListFactory.class.php',
 	'DepartmentBranchFactory' => 'department/DepartmentBranchFactory.class.php',
@@ -208,68 +251,6 @@ $global_class_map = array(
 	'RecurringHolidayListFactory' => 'holiday/RecurringHolidayListFactory.class.php',
 	'Install' => 'install/Install.class.php',
 	'InstallSchema' => 'install/InstallSchema.class.php',
-	'InstallSchema_1000A' => 'install/InstallSchema_1000A.class.php',
-	'InstallSchema_1000B' => 'install/InstallSchema_1000B.class.php',
-	'InstallSchema_1000T' => 'install/InstallSchema_1000T.class.php',
-	'InstallSchema_1001A' => 'install/InstallSchema_1001A.class.php',
-	'InstallSchema_1001B' => 'install/InstallSchema_1001B.class.php',
-	'InstallSchema_1001T' => 'install/InstallSchema_1001T.class.php',
-	'InstallSchema_1002A' => 'install/InstallSchema_1002A.class.php',
-	'InstallSchema_1002B' => 'install/InstallSchema_1002B.class.php',
-	'InstallSchema_1002T' => 'install/InstallSchema_1002T.class.php',
-	'InstallSchema_1003A' => 'install/InstallSchema_1003A.class.php',
-	'InstallSchema_1003T' => 'install/InstallSchema_1003T.class.php',
-	'InstallSchema_1004A' => 'install/InstallSchema_1004A.class.php',
-	'InstallSchema_1004T' => 'install/InstallSchema_1004T.class.php',
-	'InstallSchema_1005A' => 'install/InstallSchema_1005A.class.php',
-	'InstallSchema_1005T' => 'install/InstallSchema_1005T.class.php',
-	'InstallSchema_1006A' => 'install/InstallSchema_1006A.class.php',
-	'InstallSchema_1006T' => 'install/InstallSchema_1006T.class.php',
-	'InstallSchema_1007A' => 'install/InstallSchema_1007A.class.php',
-	'InstallSchema_1007T' => 'install/InstallSchema_1007T.class.php',
-	'InstallSchema_1008A' => 'install/InstallSchema_1008A.class.php',
-	'InstallSchema_1008T' => 'install/InstallSchema_1008T.class.php',
-	'InstallSchema_1009A' => 'install/InstallSchema_1009A.class.php',
-	'InstallSchema_1009T' => 'install/InstallSchema_1009T.class.php',
-	'InstallSchema_1010A' => 'install/InstallSchema_1010A.class.php',
-	'InstallSchema_1010T' => 'install/InstallSchema_1010T.class.php',
-	'InstallSchema_1011A' => 'install/InstallSchema_1011A.class.php',
-	'InstallSchema_1011B' => 'install/InstallSchema_1011B.class.php',
-	'InstallSchema_1011T' => 'install/InstallSchema_1011T.class.php',
-	'InstallSchema_1012A' => 'install/InstallSchema_1012A.class.php',
-	'InstallSchema_1012T' => 'install/InstallSchema_1012T.class.php',
-	'InstallSchema_1013A' => 'install/InstallSchema_1013A.class.php',
-	'InstallSchema_1013B' => 'install/InstallSchema_1013B.class.php',
-	'InstallSchema_1013T' => 'install/InstallSchema_1013T.class.php',
-	'InstallSchema_1014A' => 'install/InstallSchema_1014A.class.php',
-	'InstallSchema_1014B' => 'install/InstallSchema_1014B.class.php',
-	'InstallSchema_1014T' => 'install/InstallSchema_1014T.class.php',
-	'InstallSchema_1015A' => 'install/InstallSchema_1015A.class.php',
-	'InstallSchema_1015B' => 'install/InstallSchema_1015B.class.php',
-	'InstallSchema_1015T' => 'install/InstallSchema_1015T.class.php',
-	'InstallSchema_1016A' => 'install/InstallSchema_1016A.class.php',
-	'InstallSchema_1016B' => 'install/InstallSchema_1016B.class.php',
-	'InstallSchema_1017A' => 'install/InstallSchema_1017A.class.php',
-	'InstallSchema_1018A' => 'install/InstallSchema_1018A.class.php',
-	'InstallSchema_1019A' => 'install/InstallSchema_1019A.class.php',
-	'InstallSchema_1020A' => 'install/InstallSchema_1020A.class.php',
-	'InstallSchema_1021A' => 'install/InstallSchema_1021A.class.php',
-	'InstallSchema_1022A' => 'install/InstallSchema_1022A.class.php',
-	'InstallSchema_1023A' => 'install/InstallSchema_1023A.class.php',
-	'InstallSchema_1023B' => 'install/InstallSchema_1023B.class.php',
-	'InstallSchema_1024A' => 'install/InstallSchema_1024A.class.php',
-	'InstallSchema_1025A' => 'install/InstallSchema_1025A.class.php',
-	'InstallSchema_1026A' => 'install/InstallSchema_1026A.class.php',
-	'InstallSchema_1027A' => 'install/InstallSchema_1027A.class.php',
-	'InstallSchema_1028A' => 'install/InstallSchema_1028A.class.php',
-	'InstallSchema_1029A' => 'install/InstallSchema_1029A.class.php',
-	'InstallSchema_1030A' => 'install/InstallSchema_1030A.class.php',
-	'InstallSchema_1031A' => 'install/InstallSchema_1031A.class.php',
-	'InstallSchema_1031B' => 'install/InstallSchema_1031B.class.php',
-	'InstallSchema_1032A' => 'install/InstallSchema_1032A.class.php',
-	'InstallSchema_1033A' => 'install/InstallSchema_1033A.class.php',
-	'InstallSchema_1034A' => 'install/InstallSchema_1034A.class.php',
-	'InstallSchema_1035A' => 'install/InstallSchema_1035A.class.php',
 	'InstallSchema_Base' => 'install/InstallSchema_Base.class.php',
 	'InvoiceConfigFactory' => 'invoice/InvoiceConfigFactory.class.php',
 	'InvoiceConfigListFactory' => 'invoice/InvoiceConfigListFactory.class.php',
@@ -449,6 +430,8 @@ $global_class_map = array(
 	'UserGenericDataListFactory' => 'users/UserGenericDataListFactory.class.php',
 	'UserGenericStatusFactory' => 'users/UserGenericStatusFactory.class.php',
 	'UserGenericStatusListFactory' => 'users/UserGenericStatusListFactory.class.php',
+	'UserReportDataFactory' => 'users/UserReportDataFactory.class.php',
+	'UserReportDataListFactory' => 'users/UserReportDataListFactory.class.php',
 	'UserGroupFactory' => 'users/UserGroupFactory.class.php',
 	'UserGroupListFactory' => 'users/UserGroupListFactory.class.php',
 	'UserIdentificationFactory' => 'users/UserIdentificationFactory.class.php',
