@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditUserAccrual.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 3815 $
+ * $Id: EditUserAccrual.php 3815 2010-08-26 20:18:01Z ipso $
+ * $Date: 2010-08-26 13:18:01 -0700 (Thu, 26 Aug 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -137,7 +137,7 @@ switch ($action) {
 		$user_options = $ulf->getByCompanyIDArray( $current_company->getId(), TRUE );
 
 		//Select box options;
-		$data['type_options'] = $af->getOptions('type');
+		$data['type_options'] = $af->getOptions('user_type');
 		$data['user_options'] = $user_options;
 		$data['accrual_policy_options'] = $accrual_options;
 
