@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: ViewUserAccrualList.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 3821 $
+ * $Id: ViewUserAccrualList.php 3821 2010-08-26 20:29:43Z ipso $
+ * $Date: 2010-08-26 13:29:43 -0700 (Thu, 26 Aug 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -93,7 +93,8 @@ switch ($action) {
 		Redirect::Page( URLBuilder::getURL( NULL, 'EditUserAccrual.php') );
 
 		break;
-	case 'delete' OR 'undelete':
+	case 'delete':
+	case 'undelete':
 		if ( strtolower($action) == 'delete' ) {
 			$delete = TRUE;
 		} else {
@@ -107,6 +108,7 @@ switch ($action) {
 
 			$alf->getById( $id );
 			foreach ($alf as $a_obj) {
+				//Allow user to delete AccrualPolicy entries, but not Banked/Used entries.
 				if ( $a_obj->getUserDateTotalID() == FALSE ) {
 					$a_obj->setEnableCalcBalance(FALSE);
 					$a_obj->setDeleted($delete);
@@ -131,8 +133,6 @@ switch ($action) {
 
 		$pager = new Pager($alf);
 
-		$type_options = $alf->getOptions('type');
-
 		foreach ($alf as $a_obj) {
 
 			$date_stamp = $a_obj->getColumn('date_stamp');
@@ -144,11 +144,12 @@ switch ($action) {
 								'user_id' => $a_obj->getUser(),
 								'accrual_policy_id' => $a_obj->getAccrualPolicyId(),
 								'type_id' => $a_obj->getType(),
-								'type' => $type_options[$a_obj->getType()],
+								'type' => Option::getByKey( $a_obj->getType(), $a_obj->getOptions('type') ),
 								'user_date_total_id' => $a_obj->getUserDateTotalId(),
 								'user_date_total_date_stamp' => $date_stamp,
 								'time_stamp' => $a_obj->getTimeStamp(),
 								'amount' => $a_obj->getAmount(),
+								'system_type' => $a_obj->isSystemType(),
 								'deleted' => $a_obj->getDeleted()
 							);
 
