@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1282 $
- * $Id: User.php 1282 2007-10-03 21:26:10Z ipso $
- * $Date: 2007-10-03 14:26:10 -0700 (Wed, 03 Oct 2007) $
+ * $Revision: 4073 $
+ * $Id: User.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 require_once('../../includes/global.inc.php');
 
@@ -107,6 +107,20 @@ switch ($action) {
 		if ( $uf->isValid() ) {
 			$user_id = $uf->Save();
 
+			//Assign this user as admin/support/billing contact for now.
+			$clf = new CompanyListFactory();
+			$clf->getById( $user_data['company_id'] );
+			if ( $clf->getRecordCount() == 1 ) {
+				$c_obj = $clf->getCurrent();
+				$c_obj->setAdminContact( $user_id );
+				$c_obj->setBillingContact( $user_id );
+				$c_obj->setSupportContact( $user_id );
+				if ( $c_obj->isValid() ) {
+					$c_obj->Save();
+				}
+				unset($c_obj, $clf);
+			}
+
 			$uf->CommitTransaction();
 
 			if ( $external_installer == 1 ) {
