@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3021 $
- * $Id: PayStubList.php 3021 2009-11-11 23:33:03Z ipso $
- * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 3934 $
+ * $Id: PayStubList.php 3934 2010-11-17 23:29:44Z ipso $
+ * $Date: 2010-11-17 15:29:44 -0800 (Wed, 17 Nov 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -157,7 +157,21 @@ switch ($action) {
 					if ( stristr( $export_type, 'cheque') ) {
 						Misc::FileDownloadHeader('checks_'. str_replace(array('/',',',' '), '_', TTDate::getDate('DATE', time() ) ) .'.pdf', 'application/pdf', strlen($output));
 					} else {
-						Misc::FileDownloadHeader('eft_'. str_replace(array('/',',',' '), '_', TTDate::getDate('DATE', time() ) ) .'.txt', 'application/text', strlen($output));
+						//Include file creation number in the exported file name, so the user knows what it is without opening the file,
+						//and can generate multiple files if they need to match a specific number.
+						$ugdlf = new UserGenericDataListFactory();
+						$ugdlf->getByCompanyIdAndScriptAndDefault( $current_company->getId(), 'PayStubFactory', TRUE );
+						if ( $ugdlf->getRecordCount() > 0 ) {
+							$ugd_obj = $ugdlf->getCurrent();
+							$setup_data = $ugd_obj->getData();
+						}
+
+						if ( isset($setup_data) ) {
+							$file_creation_number = $setup_data['file_creation_number']++;
+						} else {
+							$file_creation_number = 0;
+						}
+						Misc::FileDownloadHeader('eft_'. $file_creation_number .'_'. str_replace(array('/',',',' '), '_', TTDate::getDate('DATE', time() ) ) .'.txt', 'application/text', strlen($output));
 					}
 					echo $output;
 					//Debug::Display();
@@ -416,7 +430,7 @@ switch ($action) {
 			unset($end_date);
 			unset($transaction_date);
 		}
-		
+
 		$export_type_options = $pslf->getOptions('export_type');
 
 		$all_array_option = array('-1' => TTi18n::gettext('-- Any --'));
@@ -447,6 +461,7 @@ switch ($action) {
 		unset($column_key);
 
 
+
 		$smarty->assign_by_ref('pay_stubs', $pay_stubs);
 		$smarty->assign_by_ref('export_type_options', $export_type_options );
 		$smarty->assign_by_ref('filter_data', $filter_data);
