@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: EditPermissionControl.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 3928 $
+ * $Id: EditPermissionControl.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -81,6 +81,7 @@ switch ($action) {
 
 		$pcf->setName($data['name']);
 		$pcf->setDescription($data['description']);
+		$pcf->setLevel($data['level']);
 
 		//Check to make sure the currently logged in user is NEVER in the unassigned
 		//user list. This prevents an administrator from accidently un-assigning themselves
@@ -175,6 +176,7 @@ switch ($action) {
 									'id' => $pc_obj->getId(),
 									'name' => $pc_obj->getName(),
 									'description' => $pc_obj->getDescription(),
+									'level' => $pc_obj->getLevel(),
 									'user_ids' => $pc_obj->getUser(),
 									'created_date' => $pc_obj->getCreatedDate(),
 									'created_by' => $pc_obj->getCreatedBy(),
@@ -255,6 +257,9 @@ switch ($action) {
 		//var_dump($permission_data);
 		$preset_options = Misc::prependArray( array( -1 => TTi18n::gettext('--')), $pf->getOptions('preset') );
 
+
+		$data['level_options'] = $pcf->getOptions('level');
+
 		$data['user_options'] = UserListFactory::getByCompanyIdArray( $current_company->getId(), FALSE, TRUE);
 
 		if ( isset($data['user_ids']) AND is_array($data['user_ids']) ) {
