@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: EditAccrualPolicy.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3685 $
+ * $Id: EditAccrualPolicy.php 3685 2010-07-01 21:10:29Z ipso $
+ * $Date: 2010-07-01 14:10:29 -0700 (Thu, 01 Jul 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -143,6 +143,7 @@ switch ($action) {
 		$apf->setApplyFrequencyMonth( $data['apply_frequency_month'] );
 		$apf->setApplyFrequencyDayOfMonth( $data['apply_frequency_day_of_month'] );
 		$apf->setApplyFrequencyDayOfWeek( $data['apply_frequency_day_of_week'] );
+		$apf->setApplyFrequencyHireDate( $data['apply_frequency_hire_date'] );
 
 		if ( isset($data['milestone_rollover_hire_date']) ) {
 			$apf->setMilestoneRolloverHireDate( TRUE );
@@ -252,6 +253,7 @@ switch ($action) {
 										'apply_frequency_month' => $ap_obj->getApplyFrequencyMonth(),
 										'apply_frequency_day_of_month' => $ap_obj->getApplyFrequencyDayOfMonth(),
 										'apply_frequency_day_of_week' => $ap_obj->getApplyFrequencyDayOfWeek(),
+										'apply_frequency_hire_date' => $ap_obj->getApplyFrequencyHireDate(),
 										'milestone_rollover_hire_date' => $ap_obj->getMilestoneRolloverHireDate(),
 										'milestone_rollover_month' => $ap_obj->getMilestoneRolloverMonth(),
 										'milestone_rollover_day_of_month' => $ap_obj->getMilestoneRolloverDayOfMonth(),
@@ -304,6 +306,7 @@ switch ($action) {
 						'minimum_employed_days' => 0,
 						'recalculate_start_date' => TTDate::getBeginMonthEpoch( time() ),
 						'recalculate_end_date' => TTDate::getEndMonthEpoch( time() ),
+						'apply_frequency_hire_date' => TRUE,
 						'milestone_rows' => array( -1 => array(
 													'id' => -1,
 													'length_of_service' => 0,
