@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3199 $
- * $Id: ProgressBar.php 3199 2009-12-20 23:37:45Z ipso $
- * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
+ * $Revision: 3872 $
+ * $Id: ProgressBar.php 3872 2010-09-20 17:18:20Z ipso $
+ * $Date: 2010-09-20 10:18:20 -0700 (Mon, 20 Sep 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -700,8 +700,8 @@ switch ($action) {
 		//Debug::setVerbosity(11);
 		if ( isset($data['accrual_policy_id']) AND isset( $data['start_date'] ) AND isset( $data['end_date'] ) ) {
 			if ( $data['start_date'] <= $data['end_date']) {
-				$start_date = TTDate::getBeginDayEpoch( $data['start_date'] );
-				$end_date = TTDate::getBeginDayEpoch( $data['end_date'] );
+				$start_date = TTDate::getMiddleDayEpoch( $data['start_date'] );
+				$end_date = TTDate::getMiddleDayEpoch( $data['end_date'] );
 				$total_days = TTDate::getDays( ($end_date-$start_date) );
 				$offset = (86400/2);
 
@@ -726,7 +726,8 @@ switch ($action) {
 						TTLog::addEntry( $current_user->getId(), 500, 'Recalculate Accrual Policy: '. $ap_obj->getName() .' Start Date: '. TTDate::getDate('TIME', $data['start_date']) .' End Date: '. TTDate::getDate('TIME', $data['end_date']) .' Total Days: '. round( $total_days ), $current_user->getId(), $ap_obj->getTable() );
 
 						$x=0;
-						for( $i=$start_date; $i < $end_date; $i+=(86400+3601) ) {
+						for( $i=$start_date; $i < $end_date; $i+=(86400) ) {
+							//$i = TTDate::getBeginDayEpoch( $i ); //This causes infinite loops during DST transitions.
 							Debug::Text('Recalculating Accruals for Date: '. TTDate::getDate('DATE+TIME', TTDate::getBeginDayEpoch( $i ) ), __FILE__, __LINE__, __METHOD__,10);
 							$ap_obj->addAccrualPolicyTime( TTDate::getBeginDayEpoch( $i ), $offset );
 
