@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2882 $
- * $Id: Form1099Misc.php 2882 2009-10-07 23:10:54Z ipso $
- * $Date: 2009-10-07 16:10:54 -0700 (Wed, 07 Oct 2009) $
+ * $Revision: 3807 $
+ * $Id: Form1099Misc.php 3807 2010-08-24 23:14:34Z ipso $
+ * $Date: 2010-08-24 16:14:34 -0700 (Tue, 24 Aug 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -74,9 +74,9 @@ if ( $pseallf->getRecordCount() > 0 ) {
 }
 
 $column_ps_entry_name_map = array(
-								'4' => @$setup_data['4_psea_ids'],
-								'6' => @$setup_data['6_psea_ids'],
-								'7' => @$setup_data['7_psea_ids'],
+								'4' => @array( $setup_data['4_psea_ids'], $setup_data['4_exclude_psea_ids'] ),
+								'6' => @array( $setup_data['6_psea_ids'], $setup_data['6_exclude_psea_ids'] ),
+								'7' => @array( $setup_data['7_psea_ids'], $setup_data['7_exclude_psea_ids'] ),
 								);
 
 if ( isset($filter_data['transaction_start_date']) ) {
@@ -252,9 +252,9 @@ switch ($action) {
 							}
 						}
 
-						$lines_arr['4'] = Misc::sumMultipleColumns( $raw_row, $column_ps_entry_name_map['4']);
-						$lines_arr['6'] = Misc::sumMultipleColumns( $raw_row, $column_ps_entry_name_map['6']);
-						$lines_arr['7'] = Misc::sumMultipleColumns( $raw_row, $column_ps_entry_name_map['7']);
+						$lines_arr['4'] = Misc::calculateMultipleColumns( $raw_row, $column_ps_entry_name_map['4'][0], $column_ps_entry_name_map['4'][1] );
+						$lines_arr['6'] = Misc::calculateMultipleColumns( $raw_row, $column_ps_entry_name_map['6'][0], $column_ps_entry_name_map['6'][1] );
+						$lines_arr['7'] = Misc::calculateMultipleColumns( $raw_row, $column_ps_entry_name_map['7'][0], $column_ps_entry_name_map['7'][1] );
 						//print_r($lines_arr);
 
 						$pdf->setMargins(0,0,0,0);
@@ -503,11 +503,9 @@ switch ($action) {
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
-		//Deduction PSEA accounts
+		//PSEA accounts
 		$psealf = new PayStubEntryAccountListFactory();
-		$filter_data['deduction_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(20,30), TRUE );
-		$filter_data['earning_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,40), TRUE );
-		$filter_data['income_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,30,40), TRUE );
+		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40), TRUE );
 
 		//Get a unique list of states each employee belongs to
 		$ulf = new UserListFactory();
