@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3298 $
- * $Id: Form940.php 3298 2010-01-20 18:52:46Z ipso $
- * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
+ * $Revision: 3807 $
+ * $Id: Form940.php 3807 2010-08-24 23:14:34Z ipso $
+ * $Date: 2010-08-24 16:14:34 -0700 (Tue, 24 Aug 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -73,8 +73,8 @@ if ( $pseallf->getRecordCount() > 0 ) {
 }
 
 $column_ps_entry_name_map = array(
-								'p2_3' => @$setup_data['total_payment_psea_ids'],
-								'p2_4' => @$setup_data['exempt_payment_psea_ids'],
+								'p2_3' => @array( $setup_data['total_payment_psea_ids'], $setup_data['exclude_total_payment_psea_ids'] ),
+								'p2_4' => @array( $setup_data['exempt_payment_psea_ids'], $setup_data['exclude_exempt_payment_psea_ids'] ),
 								);
 
 $pplf = new PayPeriodListFactory();
@@ -209,15 +209,15 @@ switch ($action) {
 								}
 							}
 
-							$lines_arr[$quarter_id]['p2_3'] = Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['p2_3']);
-							$lines_arr[$quarter_id]['p2_4'] = Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['p2_4']);
+							$lines_arr[$quarter_id]['p2_3'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['p2_3'][0], $column_ps_entry_name_map['p2_3'][1] );
+							$lines_arr[$quarter_id]['p2_4'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['p2_4'][0], $column_ps_entry_name_map['p2_4'][1] );
 							$lines_arr[$quarter_id]['p2_5'] = 0;
 
 							//Get over cutoff amounts for each user.
 							$i=0;
 							foreach( $user_quarter_ps_entries[$quarter_id] as $user_id => $user_quarter_ps_entry_arr ) {
-								$user_quarter_lines_arr[$user_id]['p2_3'] = Misc::sumMultipleColumns( $user_quarter_ps_entry_arr, $column_ps_entry_name_map['p2_3']);
-								$user_quarter_lines_arr[$user_id]['p2_4'] = Misc::sumMultipleColumns( $user_quarter_ps_entry_arr, $column_ps_entry_name_map['p2_4']);
+								$user_quarter_lines_arr[$user_id]['p2_3'] = Misc::calculateMultipleColumns( $user_quarter_ps_entry_arr, $column_ps_entry_name_map['p2_3'][0], $column_ps_entry_name_map['p2_3'][1] );
+								$user_quarter_lines_arr[$user_id]['p2_4'] = Misc::calculateMultipleColumns( $user_quarter_ps_entry_arr, $column_ps_entry_name_map['p2_4'][0], $column_ps_entry_name_map['p2_4'][1] );
 								$tmp_quarter_user_payment = ($user_quarter_lines_arr[$user_id]['p2_3'] - $user_quarter_lines_arr[$user_id]['p2_4']);
 
 								if ( !isset($user_total_lines_arr[$user_id]['p2_3']) ) {
@@ -376,6 +376,7 @@ switch ($action) {
 					Misc::FileDownloadHeader('f940.pdf', 'application/pdf', strlen($output));
 					echo $output;
 				}
+				Debug::writeToLog();
 				exit;
 			}
 		}
@@ -468,11 +469,9 @@ switch ($action) {
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
-		//Deduction PSEA accounts
+		//PSEA accounts
 		$psealf = new PayStubEntryAccountListFactory();
-		$filter_data['deduction_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(20,30,40), TRUE );
-		$filter_data['earning_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,40), TRUE );
-		$filter_data['income_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,30,40), TRUE );
+		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40), TRUE );
 
 		$filter_data['return_type_options'] = array(
 											0 => TTi18n::getText('--'),
