@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2873 $
- * $Id: Form941.php 2873 2009-10-06 23:37:32Z ipso $
- * $Date: 2009-10-06 16:37:32 -0700 (Tue, 06 Oct 2009) $
+ * $Revision: 3928 $
+ * $Id: Form941.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -73,13 +73,13 @@ if ( $pseallf->getRecordCount() > 0 ) {
 }
 
 $column_ps_entry_name_map = array(
-								'2' => @$setup_data['2_psea_ids'], //Gross Pay
-								'3' => @$setup_data['3_psea_ids'],
-								'5a' => @$setup_data['5a_psea_ids'],
-								'5b' => @$setup_data['5b_psea_ids'],
-								'5c' => @$setup_data['5c_psea_ids'],
-								'7b' => @$setup_data['7b_psea_ids'],
-								'9' => @$setup_data['9_psea_ids'],
+								'2' 	=> @array( $setup_data['2_psea_ids'], $setup_data['2_exclude_psea_ids'] ),
+								'3' 	=> @array( $setup_data['3_psea_ids'], $setup_data['3_exclude_psea_ids'] ),
+								'5a' 	=> @array( $setup_data['5a_psea_ids'], $setup_data['5a_exclude_psea_ids'] ),
+								'5b' 	=> @array( $setup_data['5b_psea_ids'], $setup_data['5b_exclude_psea_ids'] ),
+								'5c' 	=> @array( $setup_data['5c_psea_ids'], $setup_data['5c_exclude_psea_ids'] ),
+								'7b'	=> @array( $setup_data['7b_psea_ids'], $setup_data['7b_exclude_psea_ids'] ),
+								'9' 	=> @array( $setup_data['9_psea_ids'], $setup_data['9_exclude_psea_ids'] ),
 								);
 
 $pplf = new PayPeriodListFactory();
@@ -232,24 +232,24 @@ switch ($action) {
 							}
 
 							if ( isset($ps_entries) ) {
-								$pp_lines_arr[$month_id][$pay_period_id]['2'] = Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['2']);
-								$pp_lines_arr[$month_id][$pay_period_id]['3'] = Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['3']);
+								$pp_lines_arr[$month_id][$pay_period_id]['2'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['2'][0], $column_ps_entry_name_map['2'][1] );
+								$pp_lines_arr[$month_id][$pay_period_id]['3'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['3'][0], $column_ps_entry_name_map['3'][1] );
 
-								$pp_lines_arr[$month_id][$pay_period_id]['5a'] = Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['5a']);
+								$pp_lines_arr[$month_id][$pay_period_id]['5a'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['5a'][0], $column_ps_entry_name_map['5a'][1] );
 								$pp_lines_arr[$month_id][$pay_period_id]['5a2'] = bcmul( $pp_lines_arr[$month_id][$pay_period_id]['5a'], $f941->social_security_rate );
-								$pp_lines_arr[$month_id][$pay_period_id]['5b'] = Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['5b']);
+								$pp_lines_arr[$month_id][$pay_period_id]['5b'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['5b'][0], $column_ps_entry_name_map['5b'][1] );
 								$pp_lines_arr[$month_id][$pay_period_id]['5b2'] = bcmul( $pp_lines_arr[$month_id][$pay_period_id]['5b'], $f941->social_security_rate );
-								$pp_lines_arr[$month_id][$pay_period_id]['5c'] = Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['5c']);
+								$pp_lines_arr[$month_id][$pay_period_id]['5c'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['5c'][0], $column_ps_entry_name_map['5c'][1] );
 								$pp_lines_arr[$month_id][$pay_period_id]['5c2'] = bcmul( $pp_lines_arr[$month_id][$pay_period_id]['5c'], $f941->medicare_rate );
 								$pp_lines_arr[$month_id][$pay_period_id]['5d'] =  bcadd( bcadd( $pp_lines_arr[$month_id][$pay_period_id]['5a2'], $pp_lines_arr[$month_id][$pay_period_id]['5b2']), $pp_lines_arr[$month_id][$pay_period_id]['5c2']);
 								$pp_lines_arr[$month_id][$pay_period_id]['6'] = bcadd( $pp_lines_arr[$month_id][$pay_period_id]['3'], $pp_lines_arr[$month_id][$pay_period_id]['5d']);
 
 								$pp_lines_arr[$month_id][$pay_period_id]['7a'] = bcsub( Misc::MoneyFormat($pp_lines_arr[$month_id][$pay_period_id]['5d'], FALSE) , bcadd( bcadd($pp_lines_arr[$month_id][$pay_period_id]['5a2'], $pp_lines_arr[$month_id][$pay_period_id]['5b2']), $pp_lines_arr[$month_id][$pay_period_id]['5c2'] ) );
-								$pp_lines_arr[$month_id][$pay_period_id]['7b'] = Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['7b']);
+								$pp_lines_arr[$month_id][$pay_period_id]['7b'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['7b'][0], $column_ps_entry_name_map['7b'][1] );
 
 								$pp_lines_arr[$month_id][$pay_period_id]['7d'] = bcadd($pp_lines_arr[$month_id][$pay_period_id]['7a'], $pp_lines_arr[$month_id][$pay_period_id]['7b']);
 								$pp_lines_arr[$month_id][$pay_period_id]['8'] = bcadd( $pp_lines_arr[$month_id][$pay_period_id]['6'], $pp_lines_arr[$month_id][$pay_period_id]['7d']);
-								$pp_lines_arr[$month_id][$pay_period_id]['9'] = abs(Misc::sumMultipleColumns( $ps_entries, $column_ps_entry_name_map['9']) );
+								$pp_lines_arr[$month_id][$pay_period_id]['9'] = abs(Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['9'][0], $column_ps_entry_name_map['9'][1] ) );
 								$pp_lines_arr[$month_id][$pay_period_id]['10'] = bcsub( $pp_lines_arr[$month_id][$pay_period_id]['8'], $pp_lines_arr[$month_id][$pay_period_id]['9']);
 							}
 							unset($ps_entries);
@@ -291,7 +291,7 @@ switch ($action) {
 					$f941->l1 = $total_users;
 					$f941->l2 = $lines_arr['total']['2'];
 					$f941->l3 = $lines_arr['total']['3'];
-					$f941->l5 = 9999.99;
+					//$f941->l5 = 9999.99;
 
 					$f941->l5a = $lines_arr['total']['5a'];
 					$f941->l5b = $lines_arr['total']['5b'];
@@ -369,6 +369,7 @@ switch ($action) {
 					Misc::FileDownloadHeader('f941.pdf', 'application/pdf', strlen($output));
 					echo $output;
 				}
+				Debug::writeToLog();
 				exit;
 			}
 		}
@@ -462,11 +463,9 @@ switch ($action) {
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
-		//Deduction PSEA accounts
+		//PSEA accounts
 		$psealf = new PayStubEntryAccountListFactory();
-		$filter_data['deduction_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(20,30), TRUE );
-		$filter_data['earning_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,40), TRUE );
-		$filter_data['income_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,30,40), TRUE );
+		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40), TRUE );
 
 		//Get employee list
 		//$filter_data['user_options'] = UserListFactory::getByCompanyIdArray( $current_company->getId(), FALSE );
