@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3474 $
- * $Id: FormW2.php 3474 2010-03-31 21:07:06Z ipso $
- * $Date: 2010-03-31 14:07:06 -0700 (Wed, 31 Mar 2010) $
+ * $Revision: 4073 $
+ * $Id: FormW2.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -109,24 +109,24 @@ if ( $pseallf->getRecordCount() > 0 ) {
 $columns = Misc::prependArray( $static_columns, $non_static_columns);
 
 $column_ps_entry_name_map = array(
-								'wage' => @$setup_data['1_psea_ids'],
-								'federal_tax' => @$setup_data['2_psea_ids'],
-								'ss_wage' => @$setup_data['3_psea_ids'],
-								'ss_tax' => @$setup_data['4_psea_ids'],
-								'medicare_wage' => @$setup_data['5_psea_ids'],
-								'medicare_tax' => @$setup_data['6_psea_ids'],
-								'ss_tips' => @$setup_data['7_psea_ids'],
-								'allocated_tips' => @$setup_data['8_psea_ids'],
-								'advance_eic' => @$setup_data['9_psea_ids'],
-								'dependent_care_benefit' => @$setup_data['10_psea_ids'],
-								'nonqualified_plan' => @$setup_data['11_psea_ids'],
-								'box_12a' => @$setup_data['12a_psea_ids'],
-								'box_12b' => @$setup_data['12b_psea_ids'],
-								'box_12c' => @$setup_data['12c_psea_ids'],
-								'box_12d' => @$setup_data['12d_psea_ids'],
-								'box_14a' => @$setup_data['14a_psea_ids'],
-								'box_14b' => @$setup_data['14b_psea_ids'],
-								'box_14c' => @$setup_data['14c_psea_ids'],
+								'wage' 					=> @array( $setup_data['1_psea_ids'], $setup_data['1_exclude_psea_ids'] ),
+								'federal_tax' 			=> @array( $setup_data['2_psea_ids'], $setup_data['2_exclude_psea_ids'] ),
+								'ss_wage' 				=> @array( $setup_data['3_psea_ids'], $setup_data['3_exclude_psea_ids'] ),
+								'ss_tax' 				=> @array( $setup_data['4_psea_ids'], $setup_data['4_exclude_psea_ids'] ),
+								'medicare_wage' 		=> @array( $setup_data['5_psea_ids'], $setup_data['5_exclude_psea_ids'] ),
+								'medicare_tax' 			=> @array( $setup_data['6_psea_ids'], $setup_data['6_exclude_psea_ids'] ),
+								'ss_tips' 				=> @array( $setup_data['7_psea_ids'], $setup_data['7_exclude_psea_ids'] ),
+								'allocated_tips'		=> @array( $setup_data['8_psea_ids'], $setup_data['8_exclude_psea_ids'] ),
+								'advance_eic'			=> @array( $setup_data['9_psea_ids'], $setup_data['9_exclude_psea_ids'] ),
+								'dependent_care_benefit'=> @array( $setup_data['10_psea_ids'], $setup_data['10_exclude_psea_ids'] ),
+								'nonqualified_plan' 	=> @array( $setup_data['11_psea_ids'], $setup_data['11_exclude_psea_ids'] ),
+								'box_12a' 				=> @array( $setup_data['12a_psea_ids'], $setup_data['12a_exclude_psea_ids'] ),
+								'box_12b' 				=> @array( $setup_data['12b_psea_ids'], $setup_data['12b_exclude_psea_ids'] ),
+								'box_12c' 				=> @array( $setup_data['12c_psea_ids'], $setup_data['12c_exclude_psea_ids'] ),
+								'box_12d' 				=> @array( $setup_data['12d_psea_ids'], $setup_data['12d_exclude_psea_ids'] ),
+								'box_14a' 				=> @array( $setup_data['14a_psea_ids'], $setup_data['14a_exclude_psea_ids'] ),
+								'box_14b' 				=> @array( $setup_data['14b_psea_ids'], $setup_data['14b_exclude_psea_ids'] ),
+								'box_14c' 				=> @array( $setup_data['14c_psea_ids'], $setup_data['14c_exclude_psea_ids'] ),
 								);
 
 $pplf = new PayPeriodListFactory();
@@ -247,7 +247,8 @@ switch ($action) {
 						$tmp_rows[$x]['ssn'] = $user_obj->getSIN();
 
 						foreach($column_ps_entry_name_map as $column_key => $ps_entry_map) {
-							$tmp_rows[$x][$column_key] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], $ps_entry_map), FALSE );
+							//$tmp_rows[$x][$column_key] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], $ps_entry_map), FALSE );
+							$tmp_rows[$x][$column_key] = Misc::MoneyFormat( Misc::calculateMultipleColumns( $raw_rows[$user_id], $ps_entry_map[0], $ps_entry_map[1] ), FALSE );
 						}
 
 						//Handle state/district data here
@@ -257,6 +258,7 @@ switch ($action) {
 						if ( isset($tax_deductions) ) {
 							foreach( $tax_deductions as $tax_deduction_arr ) {
 								if ( isset($tax_deduction_arr['user_ids']) AND is_array($tax_deduction_arr['user_ids']) AND in_array( $user_id, $tax_deduction_arr['user_ids'] ) ) {
+									//Debug::Arr($tax_deduction_arr, 'Tax / Deduction Data: ', __FILE__, __LINE__, __METHOD__,10);
 									Debug::Text('Found User ID: '. $user_id .' in Tax Deduction ID: '. $tax_deduction_arr['id'] .' Pay Stub Entry Account ID: '. $tax_deduction_arr['pay_stub_entry_account_id'], __FILE__, __LINE__, __METHOD__,10);
 
 									if ( $tax_deduction_arr['province'] != '' AND $tax_deduction_arr['district'] == '' ) {
@@ -782,6 +784,7 @@ switch ($action) {
 					Misc::FileDownloadHeader('w2.pdf', 'application/pdf', strlen($output));
 					echo $output;
 				}
+				Debug::writeToLog();
 				exit;
 			}
 		}
@@ -905,11 +908,9 @@ switch ($action) {
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
-		//Deduction PSEA accounts
+		//PSEA accounts
 		$psealf = new PayStubEntryAccountListFactory();
-		$filter_data['deduction_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(20,30,40), TRUE );
-		$filter_data['earning_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,40), TRUE );
-		$filter_data['income_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,30,40), TRUE );
+		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40), TRUE );
 
 		//Get column list
 		$filter_data['src_column_options'] = Misc::arrayDiffByKey( (array)$filter_data['column_ids'], $columns );
