@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3349 $
- * $Id: GeneralLedgerSummary.php 3349 2010-02-10 17:38:41Z ipso $
- * $Date: 2010-02-10 09:38:41 -0800 (Wed, 10 Feb 2010) $
+ * $Revision: 3891 $
+ * $Id: GeneralLedgerSummary.php 3891 2010-10-12 22:23:20Z ipso $
+ * $Date: 2010-10-12 15:23:20 -0700 (Tue, 12 Oct 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -227,8 +227,9 @@ switch ($action) {
 
 						//Get all PS Entries for this pay stub.
 						$pself = new PayStubEntryListFactory();
-						$pself->getByPayStubId( $ps_obj->getId() );
-						if ($pself->getRecordCount() > 0 ) {
+						//$pself->getByPayStubId( $ps_obj->getId() );
+						$pself->getByPayStubIdAndYTDAdjustment( $ps_obj->getId(), FALSE ); //Skip any YTD adjustments, as they aren't needed in the GL
+						if ( $pself->getRecordCount() > 0 ) {
 							Debug::Text('Found Pay Stub Entries for PS ID:'. $ps_obj->getId() , __FILE__, __LINE__, __METHOD__,10);
 							foreach ($pself as $pse_obj) {
 								Debug::Text('Pay Stub Entry ID:'. $pse_obj->getId() .' PSE Account ID: '. $pse_obj->getPayStubEntryNameId() .' Currency Rate: '. $ps_obj->getCurrencyRate() .' Amount: '. $pse_obj->getAmount(), __FILE__, __LINE__, __METHOD__,10);
@@ -305,10 +306,6 @@ switch ($action) {
 
 								$grouped_je_records['total'] = $total_je_records;
 
-								//var_dump($total_je_records);
-								//var_dump($grouped_je_records);
-
-								//var_dump($grouped_je_records);
 								foreach($grouped_je_records as $je_record) {
 									$tmp_arr = array(
 														'user_id' => $user_obj->getId(),
@@ -420,7 +417,6 @@ switch ($action) {
 
 						if ( $action == 'export' ) {
 							$gle = new GeneralLedgerExport();
-							//$gle->setFileFormat('CSV');
 							$gle->setFileFormat( $filter_data['export_type'] );
 						}
 
@@ -481,7 +477,6 @@ switch ($action) {
 						$file_name = 'general_ledger_'. str_replace( array('/',',',' '), '_', TTDate::getDate('DATE', time() ) ) .'.csv';
 					}
 
-					//Misc::FileDownloadHeader('general_ledger.csv', 'application/csv', strlen($data) );
 					Misc::FileDownloadHeader($file_name, 'application/text', strlen($data));
 					echo $data;
 				} else {
