@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -493,7 +493,7 @@ switch ($action) {
 						unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
 
 						break;
-					case 'millenium': //Millenium export format.
+					case 'millenium': //Millenium export format. Also used by Qqest.
 						$data = NULL;
 
 						ksort($setup_data['millenium']['columns']);
