@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: UserInformation.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 4073 $
+ * $Id: UserInformation.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -131,12 +131,12 @@ $columns = array(						'-1010-employee_number' => TTi18n::gettext('Employee #'),
 										'-1330-wage' => TTi18n::gettext('Wage'),
 										'-1340-effective_date' => TTi18n::gettext('Wage Effective Date'),
 
-										'-1500-language' => 'Language',
-										'-1510-date_format' => 'Date Format',
-										'-1520-time_format' => 'Time Format',
-										'-1530-time_unit' => 'Time Units',
-										'-1540-time_zone' => 'Time Zone',
-										'-1550-items_per_page' => 'Rows Per page',
+										'-1500-language' => TTi18n::gettext('Language'),
+										'-1510-date_format' => TTi18n::gettext('Date Format'),
+										'-1520-time_format' => TTi18n::gettext('Time Format'),
+										'-1530-time_unit' => TTi18n::gettext('Time Units'),
+										'-1540-time_zone' => TTi18n::gettext('Time Zone'),
+										'-1550-items_per_page' => TTi18n::gettext('Rows Per page'),
 										);
 
 //Get custom user fields
