@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2490 $
- * $Id: WagesPayableSummary.php 2490 2009-04-24 22:13:40Z ipso $
- * $Date: 2009-04-24 15:13:40 -0700 (Fri, 24 Apr 2009) $
+ * $Revision: 3937 $
+ * $Id: WagesPayableSummary.php 3937 2010-11-19 19:54:51Z ipso $
+ * $Date: 2010-11-19 11:54:51 -0800 (Fri, 19 Nov 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -49,7 +49,7 @@ if ( !$permission->Check('report','enabled')
 $smarty->assign('title', TTi18n::gettext($title = 'Wages Payable Report')); // See index.php
 
 //User Wage cache array.
-function getUserWageObject( $user_wage_id ) {
+function getUserWageObject( $user_wage_id, $user_id ) {
 	global $user_wage_obj;
 
 	if ( isset($user_wage_obj[$user_wage_id])
@@ -59,7 +59,7 @@ function getUserWageObject( $user_wage_id ) {
 		$uwlf = new UserWageListFactory();
 
 		//This handles future wage changes properly.
-		$uwlf->getByID( $user_wage_id );
+		$uwlf->getByIDAndUserId( $user_wage_id, $user_id );
 		if ( $uwlf->getRecordCount() > 0 ) {
 			$user_wage_obj[$user_wage_id] = $uwlf->getCurrent();
 
@@ -212,21 +212,34 @@ $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids',
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
-if ( $permission->Check('pay_stub','view') == FALSE ) {
+$wage_permission_children_ids = array();
+if ( $permission->Check('punch','view') == FALSE ) {
 	$hlf = new HierarchyListFactory();
-	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
+	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
-	if ( $permission->Check('pay_stub','view_child') == FALSE ) {
+	if ( $permission->Check('punch','view_child') == FALSE ) {
 		$permission_children_ids = array();
 	}
-	if ( $permission->Check('pay_stub','view_own') ) {
+	if ( $permission->Check('punch','view_own') ) {
 		$permission_children_ids[] = $current_user->getId();
 	}
 
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
+//Get Wage Permission Hierarchy Children first, as this can be used for viewing, or editing.
+if ( $permission->Check('wage','view') == FALSE ) {
+	if ( $permission->Check('wage','view_child') == FALSE ) {
+		$wage_permission_children_ids = array();
+	}
+	if ( $permission->Check('wage','view_own') ) {
+		$wage_permission_children_ids[] = $current_user->getId();
+	}
+
+	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
+}
+
 $ugdlf = new UserGenericDataListFactory();
 $ugdf = new UserGenericDataFactory();
 
@@ -380,13 +393,14 @@ switch ($action) {
 										$user_wage_id = $data_y['user_wage_id'];
 
 										$hourly_rate = 0;
-
-										$uw_obj = getUserWageObject($user_wage_id);
-										if ( is_object($uw_obj) ) {
-											if ( $currency_convert_to_base == TRUE ) {
-												$hourly_rate = $uw_obj->getBaseCurrencyHourlyRate( $uw_obj->getHourlyRate() );
-											} else {
-												$hourly_rate = $uw_obj->getHourlyRate();
+										if ( $permission->Check('wage','view') == TRUE OR in_array( $user_id, $wage_filter_data['permission_children_ids']) == TRUE ) {
+											$uw_obj = getUserWageObject( $user_wage_id, $user_id );
+											if ( is_object($uw_obj) ) {
+												if ( $currency_convert_to_base == TRUE ) {
+													$hourly_rate = $uw_obj->getBaseCurrencyHourlyRate( $uw_obj->getHourlyRate() );
+												} else {
+													$hourly_rate = $uw_obj->getHourlyRate();
+												}
 											}
 										}
 										$tmp_rows[$x]['hourly_rate'] = Misc::MoneyFormat( $hourly_rate, FALSE );
