@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditRecurringSchedule.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 3928 $
+ * $Id: EditRecurringSchedule.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -77,14 +77,14 @@ if ( $permission->Check('recurring_schedule','view') == FALSE ) {
 	$hlf = new HierarchyListFactory();
 	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
-	
+
 	if ( $permission->Check('recurring_schedule','view_child') == FALSE ) {
 		$permission_children_ids = array();
 	}
 	if ( $permission->Check('recurring_schedule','view_own') ) {
 		$permission_children_ids[] = $current_user->getId();
 	}
-	
+
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
@@ -96,33 +96,59 @@ switch ($action) {
 	case 'submit':
 		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);
 
-		$rscf->setId( $data['id'] );
-		$rscf->setCompany( $current_company->getId() );
-		$rscf->setRecurringScheduleTemplateControl( $data['template_id'] );
-		$rscf->setStartWeek( $data['start_week'] );
-		$rscf->setStartDate( $data['start_date'] );
-		$rscf->setEndDate( $data['end_date'] );
-		if ( isset($data['auto_fill']) ) {
-			$rscf->setAutoFill( TRUE );
+		$rscf->StartTransaction();
+
+		$fail_transaction = FALSE;
+		if ( is_array($data['template_id']) ) {
+			foreach( $data['template_id'] as $template_id ) {
+				$rscf->setId( $data['id'] );
+				$rscf->setCompany( $current_company->getId() );
+				$rscf->setRecurringScheduleTemplateControl( $template_id );
+				$rscf->setStartWeek( $data['start_week'] );
+				$rscf->setStartDate( $data['start_date'] );
+				$rscf->setEndDate( $data['end_date'] );
+				if ( isset($data['auto_fill']) ) {
+					$rscf->setAutoFill( TRUE );
+				} else {
+					$rscf->setAutoFill( FALSE );
+				}
+
+				if ( $rscf->isValid() ) {
+					if ( $rscf->Save(FALSE) === FALSE ) {
+						$fail_transaction = TRUE;
+						break;
+					}
+
+					if ( isset($data['user_ids']) ) {
+						$rscf->setUser( $data['user_ids'] );
+					}
+
+					if ( $rscf->isValid() ) {
+						if ( $rscf->Save() === FALSE ) {
+							$fail_transaction = TRUE;
+							break;
+						}
+					} else {
+						$fail_transaction = TRUE;
+						break;
+					}
+				} else {
+					$fail_transaction = TRUE;
+					break;
+				}
+			}
+		}
+
+		if ( $fail_transaction == FALSE ) {
+			//$rscf->FailTransaction();
+			$rscf->CommitTransaction();
+
+			Redirect::Page( URLBuilder::getURL( NULL, 'RecurringScheduleControlList.php') );
+			break;
 		} else {
-			$rscf->setAutoFill( FALSE );
+			$rscf->FailTransaction();
 		}
 
-		if ( $rscf->isValid() ) {
-			$rscf->Save(FALSE);
-
-			if ( isset($data['user_ids']) ) {
-				$rscf->setUser( $data['user_ids'] );
-			}
-
-			if ( $rscf->isValid() ) {
-				$rscf->Save();
-
-				Redirect::Page( URLBuilder::getURL( NULL, 'RecurringScheduleControlList.php') );
-
-				break;
-			}
-		}
 	default:
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
