@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3562 $
- * $Id: ViewUserTimeSheet.php 3562 2010-05-07 00:03:34Z ipso $
- * $Date: 2010-05-06 17:03:34 -0700 (Thu, 06 May 2010) $
+ * $Revision: 3928 $
+ * $Id: ViewUserTimeSheet.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -49,7 +49,7 @@ if ( !$permission->Check('punch','enabled')
 }
 
 function TimeSheetFormatArrayByDate($input_arr, $type_arr, $calendar_array, $name_key, $id_key = NULL ) {
-	Debug::text('Group Array While Loop: ', __FILE__, __LINE__, __METHOD__,10);
+	//Debug::text('Group Array While Loop: ', __FILE__, __LINE__, __METHOD__,10);
 	//Debug::Arr($input_arr, 'Input Array: ', __FILE__, __LINE__, __METHOD__,10);
 	//Debug::Arr($type_arr, 'Type Array: ', __FILE__, __LINE__, __METHOD__,10);
 	$x=0;
@@ -63,7 +63,7 @@ function TimeSheetFormatArrayByDate($input_arr, $type_arr, $calendar_array, $nam
 		}
 
 		//Debug::text('===========================================================', __FILE__, __LINE__, __METHOD__,10);
-		Debug::text('While Loop: '. $x .' Max No Punch Count: '. $max_no_punch_count .' Type ID: '. $type_id .' ... ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::text('While Loop: '. $x .' Max No Punch Count: '. $max_no_punch_count .' Type ID: '. $type_id .' ... ', __FILE__, __LINE__, __METHOD__,10);
 
 		$no_punch_count=0;
 
@@ -94,9 +94,9 @@ function TimeSheetFormatArrayByDate($input_arr, $type_arr, $calendar_array, $nam
 			$total_rows[$x]['data'][$cal_arr['epoch']] = $total_arr;
 		}
 
-		Debug::text('No Punch Count: '. $no_punch_count .' Max: '. $max_no_punch_count, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::text('No Punch Count: '. $no_punch_count .' Max: '. $max_no_punch_count, __FILE__, __LINE__, __METHOD__,10);
 		if ( $x == 100 OR $no_punch_count == $max_no_punch_count ) {
-			Debug::text('Stopping Loop at: '. $x, __FILE__, __LINE__, __METHOD__,10);
+			//Debug::text('Stopping Loop at: '. $x, __FILE__, __LINE__, __METHOD__,10);
 			//Clear last row, as its blank;
 			array_pop($total_rows);
 
@@ -632,21 +632,21 @@ switch ($action) {
 				}
 			}
 
-			Debug::text('No Punch Count: '. $no_punch_count .' Max: '. $max_no_punch_count, __FILE__, __LINE__, __METHOD__,10);
+			//Debug::text('No Punch Count: '. $no_punch_count .' Max: '. $max_no_punch_count, __FILE__, __LINE__, __METHOD__,10);
 			//Only pop off the last row if the rows aren't in pairs. Because if there is only ONE in punch at the first day of the week
 			//and no other punches, the Out row doesn't show otherwise.
 			if ( $x == 100 OR $no_punch_count >= $max_no_punch_count ) {
-				Debug::text('Stopping Loop at: '. $x, __FILE__, __LINE__, __METHOD__,10);
+				//Debug::text('Stopping Loop at: '. $x, __FILE__, __LINE__, __METHOD__,10);
 
 				//Made this >= 2 so it doesn't show 3 rows if the first day of the week only has the IN punch.
 				//It was > 2.
 				if ( $x >= 2 ) {
 					if ( $x % 2 == 0) {
 						//Clear last 1 rows, as its blank;
-						Debug::text('Popping Off Last Row: '. $x, __FILE__, __LINE__, __METHOD__,10);
+						//Debug::text('Popping Off Last Row: '. $x, __FILE__, __LINE__, __METHOD__,10);
 						array_pop($rows);
 					} else {
-						Debug::text('Popping Off Last TWO Row: '. $x, __FILE__, __LINE__, __METHOD__,10);
+						//Debug::text('Popping Off Last TWO Row: '. $x, __FILE__, __LINE__, __METHOD__,10);
 						array_pop($rows);
 						array_pop($rows);
 					}
