@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2684 $
- * $Id: EditUser.php 2684 2009-07-24 22:47:23Z ipso $
- * $Date: 2009-07-24 15:47:23 -0700 (Fri, 24 Jul 2009) $
+ * $Revision: 3928 $
+ * $Id: EditUser.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -177,28 +177,8 @@ switch ($action) {
 		}
 
 		if ( DEMO_MODE == FALSE OR $uf->isNew() == TRUE ) {
-			if ( !empty($user_data['id']) ) {
-				if ( !empty($user_data['password']) OR !empty($user_data['password2']) ) {
-					if ( $user_data['password'] == $user_data['password2'] ) {
-						$uf->setPassword($user_data['password']);
-					} else {
-						$uf->Validator->isTrue(	'password',
-												FALSE,
-												TTi18n::gettext('Passwords don\'t match') );
-					}
-				}
-
-				if ( !empty($user_data['phone_password']) OR !empty($user_data['phone_password2']) ) {
-					if ( $user_data['phone_password'] == $user_data['phone_password2'] ) {
-						$uf->setPhonePassword($user_data['phone_password']);
-					} else {
-						$uf->Validator->isTrue( 'phone_password',
-												FALSE,
-												TTi18n::gettext('Passwords don\'t match') );
-					}
-				}
-			} else {
-				if ( !empty($user_data['password']) AND $user_data['password'] == $user_data['password2'] ) {
+			if ( !empty($user_data['password']) OR !empty($user_data['password2']) ) {
+				if ( $user_data['password'] == $user_data['password2'] ) {
 					$uf->setPassword($user_data['password']);
 				} else {
 					$uf->Validator->isTrue(	'password',
@@ -206,6 +186,16 @@ switch ($action) {
 											TTi18n::gettext('Passwords don\'t match') );
 				}
 			}
+
+			if ( !empty($user_data['phone_password']) OR !empty($user_data['phone_password2']) ) {
+				if ( $user_data['phone_password'] == $user_data['phone_password2'] ) {
+					$uf->setPhonePassword($user_data['phone_password']);
+				} else {
+					$uf->Validator->isTrue( 'phone_password',
+											FALSE,
+											TTi18n::gettext('Passwords don\'t match') );
+				}
+			}
 		}
 
 		if ( $user_data['id'] != $current_user->getID()
@@ -322,7 +312,10 @@ switch ($action) {
 			$uf->setBirthDate( TTDate::getTimeStampFromSmarty('birth_', $user_data) );
 		}
 
-		if ( DEMO_MODE == FALSE AND isset($user_data['permission_control_id']) AND ( $permission->Check('permission','edit') OR $permission->Check('permission','edit_own') OR $permission->Check('user','edit_permission_group') ) ) {
+		if ( DEMO_MODE == FALSE
+			AND isset($user_data['permission_control_id'])
+			AND $uf->getPermissionLevel() <= $permission->getLevel()
+			AND ( $permission->Check('permission','edit') OR $permission->Check('permission','edit_own') OR $permission->Check('user','edit_permission_group') ) ) {
 			$uf->setPermissionControl( $user_data['permission_control_id'] );
 		} elseif ( isset($udf_obj) AND is_object($udf_obj) AND $uf->isNew() == TRUE ) {
 			$uf->setPermissionControl( $udf_obj->getPermissionControl() );
@@ -489,6 +482,7 @@ switch ($action) {
 										'default_department_id' => $user->getDefaultDepartment(),
 										'group_id' => $user->getGroup(),
                                         'currency_id' => $user->getCurrency(),
+										'permission_level' => $user->getPermissionLevel(),
 										'is_owner' => $is_owner,
 										'is_child' => $is_child,
 										'created_date' => $user->getCreatedDate(),
@@ -675,7 +669,7 @@ switch ($action) {
 
 		//Get Permission Groups
 		$pclf = new PermissionControlListFactory();
-		$pclf->getByCompanyId( $company_id );
+		$pclf->getByCompanyIdAndLevel( $company_id, $permission->getLevel() );
 		$user_data['permission_control_options'] = $pclf->getArrayByListFactory( $pclf, FALSE );
 
 		//Get pay period schedules
@@ -717,6 +711,9 @@ switch ($action) {
 		$smarty->assign_by_ref('saved_search_id', $saved_search_id);
 		$smarty->assign_by_ref('incomplete', $incomplete);
 		$smarty->assign_by_ref('data_saved', $data_saved);
+
+		Debug::Text('Current User Permission Level: '. $permission->getLevel() .' Level for user we are currently editing: '. $permission->getLevel( $uf->getID(), $uf->getCompany() ) .' User ID: '. $uf->getID(), __FILE__, __LINE__, __METHOD__,10);
+
 		break;
 }
 
