@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1806 $
- * $Id: cron.php 1806 2008-04-08 17:19:17Z ipso $
- * $Date: 2008-04-08 10:19:17 -0700 (Tue, 08 Apr 2008) $
+ * $Revision: 3928 $
+ * $Id: cron.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 /*
  * Cron replica
@@ -68,7 +68,7 @@ foreach( $job_arr as $job_id => $job_name ) {
 		}
 	}
 }
-echo "NOTE: Jobs are scheduled to run at specific times, therefore only some jobs are executed each time this file is run.\n";
+echo "NOTE: Jobs are scheduled to run at specific times each day, therefore it is normal for only some jobs to be executed each time this file is run.\n";
 echo "Jobs Executed: $executed_jobs of $total_jobs\n";
 Debug::text('CRON: Jobs Executed: '. $executed_jobs .' of '. $total_jobs, __FILE__, __LINE__, __METHOD__, 0);
 
