@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2534 $
- * $Id: import_users.php 2534 2009-05-13 00:02:20Z ipso $
- * $Date: 2009-05-12 17:02:20 -0700 (Tue, 12 May 2009) $
+ * $Revision: 4073 $
+ * $Id: import_users.php 4073 2010-12-27 23:35:24Z ipso $
+ * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
  */
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'global.inc.php');
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'CLI.inc.php');
@@ -58,7 +58,6 @@ require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR
 //
 function parse_status_id( $input, $default_value = NULL, $parse_hint = NULL ) {
 
-
 	if ( strtolower( $input ) == 'a'
 			OR strtolower( $input ) == 'active' ) {
 		$retval = 10;
@@ -89,7 +88,7 @@ function parse_title_id( $input, $default_value = NULL, $parse_hint = NULL ) {
 }
 
 function parse_default_branch_id( $input, $default_value = NULL, $parse_hint = NULL ) {
-	global $branch_options, $fuzzy_match;
+	global $branch_options, $branch_manual_id_options, $fuzzy_match;
 
 	if ( !is_numeric( $input ) ) {
 		if ( $fuzzy_match == TRUE ) {
@@ -99,13 +98,17 @@ function parse_default_branch_id( $input, $default_value = NULL, $parse_hint = N
 		} else {
 			return array_search( $input, $branch_options );
 		}
+	} elseif ( strtolower($parse_hint) == 'manual_id' ) {
+		//Find branch based on manual_id/code.
+		$retval = Misc::findClosestMatch( $input, $branch_manual_id_options, 90 );
+		return $retval;
 	}
 
 	return $input;
 }
 
 function parse_default_department_id( $input, $default_value = NULL, $parse_hint = NULL ) {
-	global $department_options, $fuzzy_match;
+	global $department_options, $department_manual_id_options, $fuzzy_match;
 
 	if ( !is_numeric( $input ) ) {
 		if ( $fuzzy_match == TRUE ) {
@@ -115,6 +118,10 @@ function parse_default_department_id( $input, $default_value = NULL, $parse_hint
 		} else {
 			return array_search( $input, $department_options );
 		}
+	} elseif ( strtolower($parse_hint) == 'manual_id' ) {
+		//Find department based on manual_id/code.
+		$retval = Misc::findClosestMatch( $input, $department_manual_id_options, 90 );
+		return $retval;
 	}
 
 	return $input;
@@ -185,6 +192,23 @@ function parse_sex( $input, $default_value = NULL, $parse_hint = NULL ) {
 	return $retval;
 }
 
+function parse_phone_id( $input, $default_value = NULL, $parse_hint = NULL ) {
+	if ( strlen( $input ) < 4 ) {
+		$retval = str_pad( $input, 4, 0, STR_PAD_LEFT );
+	} else {
+		$retval = $input;
+	}
+	return $retval;
+}
+function parse_phone_password( $input, $default_value = NULL, $parse_hint = NULL ) {
+	if ( strlen( $input ) < 4 ) {
+		$retval = str_pad( $input, 4, 0, STR_PAD_LEFT );
+	} else {
+		$retval = $input;
+	}
+	return $retval;
+}
+
 function parse_birth_date( $input, $default_value = NULL, $parse_hint = NULL ) {
 	if ( isset($parse_hint) AND $parse_hint != '' ) {
 		TTDate::setDateFormat( $parse_hint );
@@ -544,16 +568,30 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 			echo "  Importing User: $i. ". str_pad( Misc::importCallInputParseFunction( 'first_name', $mapped_row['first_name'], $filtered_import_map['first_name']['default_value'], $filtered_import_map['first_name']['parse_hint'] ) ." ". Misc::importCallInputParseFunction( 'last_name', $mapped_row['last_name'], $filtered_import_map['last_name']['default_value'], $filtered_import_map['last_name']['parse_hint'] ) , 30, '.', STR_PAD_RIGHT)."... ";
 			if ( isset($mapped_row['company_id']) AND $mapped_row['company_id'] != '' ) {
 				//Get all branches
+				$branch_options = $branch_manual_id_options = array();
 				$blf = new BranchListFactory();
 				$blf->getByCompanyId( $mapped_row['company_id'] );
-				$branch_options = (array)$blf->getArrayByListFactory( $blf, FALSE, TRUE );
-				unset($blf);
+				if ( $blf->getRecordCount() > 0 ) {
+					foreach( $blf as $b_obj ) {
+						$branch_options[$b_obj->getId()] = $b_obj->getName();
+						$branch_manual_id_options[$b_obj->getId()] = $b_obj->getManualId();
+					}
+				}
+				//$branch_options = (array)$blf->getArrayByListFactory( $blf, FALSE, TRUE );
+				unset($blf, $b_obj);
 
 				//Get departments
+				$department_options = $department_manual_id_options = array();
 				$dlf = new DepartmentListFactory();
 				$dlf->getByCompanyId( $mapped_row['company_id'] );
-				$department_options = (array)$dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
-				unset($dlf);
+				if ( $dlf->getRecordCount() > 0 ) {
+					foreach( $dlf as $d_obj ) {
+						$department_options[$d_obj->getId()] = $d_obj->getName();
+						$department_manual_id_options[$d_obj->getId()] = $d_obj->getManualId();
+					}
+				}
+				//$department_options = (array)$dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
+				unset($dlf, $d_obj);
 
 				//Get groups
 				$uglf = new UserGroupListFactory();
@@ -619,22 +657,26 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 			}
 
 			if ( isset($mapped_row['default_branch_id']) AND $mapped_row['default_branch_id'] != '' ) {
-				if ( $create_branch === TRUE AND !is_numeric($mapped_row['default_branch_id']) ) {
+				if ( $create_branch === TRUE ) {
 					//Check to see if branch exists or not.
-					//if ( array_search( $mapped_row['default_branch_id'], $branch_options ) === FALSE ) {
-					if ( parse_default_branch_id( $mapped_row['default_branch_id'] ) === FALSE ) {
+					if ( array_search( parse_default_branch_id( $mapped_row['default_branch_id'] ), $branch_options ) === FALSE ) {
 						//Create branch
 						$bf = new BranchFactory();
 						$bf->setCompany( $mapped_row['company_id'] );
 						$bf->setStatus( 10 );
-						$next_available_manual_id = BranchListFactory::getNextAvailableManualId( $mapped_row['company_id'] );
-						$bf->setManualId( $next_available_manual_id );
 						$bf->setName( $mapped_row['default_branch_id'] );
+						if ( strtolower($filtered_import_map['default_branch_id']['parse_hint']) == 'manual_id' ) {
+							$bf->setManualId( $mapped_row['default_branch_id'] );
+						} else {
+							$next_available_manual_id = BranchListFactory::getNextAvailableManualId( $mapped_row['company_id'] );
+							$bf->setManualId( $next_available_manual_id );
+						}
 						$bf->setCity( 'NA' );
 						if ( $bf->isValid() ) {
 							echo "[CB: ". $mapped_row['default_branch_id'] ."]";
-							$new_branch_id = $bf->Save();
-							$branch_options[$new_branch_id] = $mapped_row['default_branch_id'];
+							$new_branch_id = $bf->Save(FALSE);
+							$branch_options[$new_branch_id] = $bf->getName();
+							$branch_manual_id_options[$new_branch_id] = $bf->getManualId();
 						}
 						unset($bf, $new_branch_id, $next_available_manual_id );
 					}
@@ -644,20 +686,25 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 			}
 
 			if ( isset($mapped_row['default_department_id']) AND $mapped_row['default_department_id'] != '' ) {
-				if ( $create_department === TRUE AND !is_numeric($mapped_row['default_department_id']) ) {
+				if ( $create_department === TRUE ) {
 					//Check to see if department exists or not.
-					if ( array_search( $mapped_row['default_department_id'], $department_options ) === FALSE ) {
+					if ( array_search( parse_default_department_id( $mapped_row['default_department_id'] ), $department_options ) === FALSE ) {
 						//Create department
 						$df = new DepartmentFactory();
 						$df->setCompany( $mapped_row['company_id'] );
 						$df->setStatus( 10 );
 						$df->setName( $mapped_row['default_department_id'] );
-						$next_available_manual_id = DepartmentListFactory::getNextAvailableManualId( $mapped_row['company_id'] );
-						$df->setManualId( $next_available_manual_id );
+						if ( strtolower($filtered_import_map['default_department_id']['parse_hint']) == 'manual_id' ) {
+							$df->setManualId( $mapped_row['default_department_id'] );
+						} else {
+							$next_available_manual_id = DepartmentListFactory::getNextAvailableManualId( $mapped_row['company_id'] );
+							$df->setManualId( $next_available_manual_id );
+						}
 						if ( $df->isValid() ) {
 							echo "[CD: ". $mapped_row['default_department_id'] ."]";
-							$new_department_id = $df->Save();
-							$department_options[$new_department_id] = $mapped_row['default_department_id'];
+							$new_department_id = $df->Save(FALSE);
+							$department_options[$new_department_id] = $df->getName();
+							$department_manual_id_options[$new_department_id] = $df->getManualId();
 						}
 						unset($df, $new_department_id, $next_available_manual_id);
 					}
@@ -713,6 +760,13 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 				$uf->setPassword( uniqid() );
 			}
 
+			if ( isset($mapped_row['phone_id']) AND $mapped_row['phone_id'] != '' ) {
+				$uf->setPhoneID( Misc::importCallInputParseFunction( 'phone_id', $mapped_row['phone_id'], $filtered_import_map['phone_id']['default_value'], $filtered_import_map['phone_id']['parse_hint'] ) );
+			}
+			if ( isset($mapped_row['phone_password']) AND $mapped_row['phone_password'] != '' ) {
+				$uf->setPhonePassword( Misc::importCallInputParseFunction( 'phone_password', $mapped_row['phone_password'], $filtered_import_map['phone_password']['default_value'], $filtered_import_map['phone_password']['parse_hint'] ) );
+			}
+
 			if ( isset($mapped_row['first_name']) AND $mapped_row['first_name'] != '' ) {
 				$uf->setFirstName( Misc::importCallInputParseFunction( 'first_name', $mapped_row['first_name'], $filtered_import_map['first_name']['default_value'], $filtered_import_map['first_name']['parse_hint'] ) );
 			}
@@ -726,7 +780,7 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 			if ( isset($mapped_row['sex']) AND $mapped_row['sex'] != '' ) {
 				$uf->setSex( Misc::importCallInputParseFunction( 'sex', $mapped_row['sex'], $filtered_import_map['sex']['default_value'], $filtered_import_map['sex']['parse_hint'] ) );
 			} else {
-				$uf->setSex(10);
+				$uf->setSex(5); //UnSpecified.
 			}
 
 			if ( isset($mapped_row['address1']) AND $mapped_row['address1'] != '' ) {
@@ -980,7 +1034,6 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 								$commit_trans = FALSE;
 								$e++;
 
-
 								$errors = $udf->Validator->getErrorsArray();
 								if ( is_array($errors) ) {
 									foreach( $errors as $error_arr ) {
